import 'researchEdition.m.dart';
import 'liveConsultation.m.dart';

import 'package:fis_jsonrpc/utils.dart';

class AIDiagnosisRect {
	int right;
	int bottom;
	int left;
	int top;
	int width;
	int height;

	AIDiagnosisRect({
		this.right = 0,
		this.bottom = 0,
		this.left = 0,
		this.top = 0,
		this.width = 0,
		this.height = 0,
	});

	factory AIDiagnosisRect.fromJson(Map<String, dynamic> map) {
		return AIDiagnosisRect( 
			right: map['Right'],
			bottom: map['Bottom'],
			left: map['Left'],
			top: map['Top'],
			width: map['Width'],
			height: map['Height'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		map['Right'] = right;
		map['Bottom'] = bottom;
		map['Left'] = left;
		map['Top'] = top;
		map['Width'] = width;
		map['Height'] = height;
		return map;
	}
}

class AIDiagnosisPoint2D {
	int x;
	int y;

	AIDiagnosisPoint2D({
		this.x = 0,
		this.y = 0,
	});

	factory AIDiagnosisPoint2D.fromJson(Map<String, dynamic> map) {
		return AIDiagnosisPoint2D( 
			x: map['X'],
			y: map['Y'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		map['X'] = x;
		map['Y'] = y;
		return map;
	}
}

enum DiagnosisDescriptionEnum {
	Shape,
	Orientation,
	EchoPattern,
	LesionBoundary,
	Margin,
	Calcification,
	LesionSize,
	ThyroidEchoPattern,
	ThyroidShape,
	ThyroidMargin,
	ThyroidEchogenicFoci,
	LiverShape,
	LiverBoundary,
	LiverEchoTexture,
	QlaqueEchoPattern,
	QlaqueLocation,
	CarotidRateOfStenosis,
	CarotidInnerDiameter,
	CarotidIntimaMediaThickness,
}

class AIDiagnosisDescription {
	DiagnosisDescriptionEnum type;
	String? value;

	AIDiagnosisDescription({
		this.type = DiagnosisDescriptionEnum.Shape,
		this.value,
	});

	factory AIDiagnosisDescription.fromJson(Map<String, dynamic> map) {
		return AIDiagnosisDescription( 
			type: DiagnosisDescriptionEnum.values.firstWhere((e) => e.index == map['Type']),
			value: map['Value'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		map['Type'] = type.index;
		if (value != null)
			map['Value'] = value;
		return map;
	}
}

class AIDetectedObject {
	int label;
	double confidence;
	AIDiagnosisRect? boundingBox;
	List<AIDiagnosisPoint2D>? contours;
	List<AIDiagnosisDescription>? descriptions;

	AIDetectedObject({
		this.label = 0,
		this.confidence = 0,
		this.boundingBox,
		this.contours,
		this.descriptions,
	});

	factory AIDetectedObject.fromJson(Map<String, dynamic> map) {
		return AIDetectedObject( 
			label: map['Label'],
			confidence: double.parse(map['Confidence'].toString()),
			boundingBox: map['BoundingBox'] != null ? AIDiagnosisRect.fromJson(map['BoundingBox']) : null,
			contours: map['Contours'] != null ? (map['Contours'] as List).map((e)=>AIDiagnosisPoint2D.fromJson(e as Map<String,dynamic>)).toList() : null,
			descriptions: map['Descriptions'] != null ? (map['Descriptions'] as List).map((e)=>AIDiagnosisDescription.fromJson(e as Map<String,dynamic>)).toList() : null,
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		map['Label'] = label;
		map['Confidence'] = confidence;
		if (boundingBox != null)
			map['BoundingBox'] = boundingBox;
		if (contours != null)
			map['Contours'] = contours;
		if (descriptions != null)
			map['Descriptions'] = descriptions;
		return map;
	}
}

class AIDiagnosisResultPerOrgan {
	DiagnosisOrganEnum organ;
	AIDiagnosisRect? organBoundBox;
	List<AIDiagnosisPoint2D>? organContours;
	List<AIDiagnosisDescription>? organDescriptions;
	List<AIDetectedObject>? detectedObjects;

	AIDiagnosisResultPerOrgan({
		this.organ = DiagnosisOrganEnum.Null,
		this.organBoundBox,
		this.organContours,
		this.organDescriptions,
		this.detectedObjects,
	});

	factory AIDiagnosisResultPerOrgan.fromJson(Map<String, dynamic> map) {
		return AIDiagnosisResultPerOrgan( 
			organ: DiagnosisOrganEnum.values.firstWhere((e) => e.index == map['Organ']),
			organBoundBox: map['OrganBoundBox'] != null ? AIDiagnosisRect.fromJson(map['OrganBoundBox']) : null,
			organContours: map['OrganContours'] != null ? (map['OrganContours'] as List).map((e)=>AIDiagnosisPoint2D.fromJson(e as Map<String,dynamic>)).toList() : null,
			organDescriptions: map['OrganDescriptions'] != null ? (map['OrganDescriptions'] as List).map((e)=>AIDiagnosisDescription.fromJson(e as Map<String,dynamic>)).toList() : null,
			detectedObjects: map['DetectedObjects'] != null ? (map['DetectedObjects'] as List).map((e)=>AIDetectedObject.fromJson(e as Map<String,dynamic>)).toList() : null,
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		map['Organ'] = organ.index;
		if (organBoundBox != null)
			map['OrganBoundBox'] = organBoundBox;
		if (organContours != null)
			map['OrganContours'] = organContours;
		if (organDescriptions != null)
			map['OrganDescriptions'] = organDescriptions;
		if (detectedObjects != null)
			map['DetectedObjects'] = detectedObjects;
		return map;
	}
}

class AIDiagnosisPerImageDTO {
	int index;
	double priorityScore;
	List<AIDiagnosisResultPerOrgan>? diagResultsForEachOrgan;

	AIDiagnosisPerImageDTO({
		this.index = 0,
		this.priorityScore = 0,
		this.diagResultsForEachOrgan,
	});

	factory AIDiagnosisPerImageDTO.fromJson(Map<String, dynamic> map) {
		return AIDiagnosisPerImageDTO( 
			index: map['Index'],
			priorityScore: double.parse(map['PriorityScore'].toString()),
			diagResultsForEachOrgan: map['DiagResultsForEachOrgan'] != null ? (map['DiagResultsForEachOrgan'] as List).map((e)=>AIDiagnosisResultPerOrgan.fromJson(e as Map<String,dynamic>)).toList() : null,
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		map['Index'] = index;
		map['PriorityScore'] = priorityScore;
		if (diagResultsForEachOrgan != null)
			map['DiagResultsForEachOrgan'] = diagResultsForEachOrgan;
		return map;
	}
}

class DiagnosisImageResult {
	DiagnosisConclusionEnum diagnosisConclusion;
	List<AIDiagnosisPerImageDTO>? diagnosisResult;
	List<DiagnosisOrganEnum>? diagnosisOrgans;
	CarotidResultDTO? carotidResult;

	DiagnosisImageResult({
		this.diagnosisConclusion = DiagnosisConclusionEnum.NotRequired,
		this.diagnosisResult,
		this.diagnosisOrgans,
		this.carotidResult,
	});

	factory DiagnosisImageResult.fromJson(Map<String, dynamic> map) {
		return DiagnosisImageResult( 
			diagnosisConclusion: DiagnosisConclusionEnum.values.firstWhere((e) => e.index == map['DiagnosisConclusion']),
			diagnosisResult: map['DiagnosisResult'] != null ? (map['DiagnosisResult'] as List).map((e)=>AIDiagnosisPerImageDTO.fromJson(e as Map<String,dynamic>)).toList() : null,
			diagnosisOrgans: map['DiagnosisOrgans'] != null ? (map['DiagnosisOrgans'] as List).map((e)=>DiagnosisOrganEnum.values.firstWhere((i) => i.index == e)).toList() : null,
			carotidResult: map['CarotidResult'] != null ? CarotidResultDTO.fromJson(map['CarotidResult']) : null,
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		map['DiagnosisConclusion'] = diagnosisConclusion.index;
		if (diagnosisResult != null)
			map['DiagnosisResult'] = diagnosisResult;
		if (diagnosisOrgans != null) {
			List<int> diagnosisOrgansList = [];
			diagnosisOrgans!.forEach((e) => diagnosisOrgansList.add(e.index));
			map['DiagnosisOrgans'] = diagnosisOrgansList;
		}
		if (carotidResult != null)
			map['CarotidResult'] = carotidResult;
		return map;
	}
}

class DiagnosisImageRequest extends TokenRequest{
	String? fileToken;
	String? diskPath;
	String? relationCode;

	DiagnosisImageRequest({
		this.fileToken,
		this.diskPath,
		this.relationCode,
		String? token,
	}) : super(
			token: token,
		);

	factory DiagnosisImageRequest.fromJson(Map<String, dynamic> map) {
		return DiagnosisImageRequest( 
			fileToken: map['FileToken'],
			diskPath: map['DiskPath'],
			relationCode: map['RelationCode'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (fileToken != null)
			map['FileToken'] = fileToken;
		if (diskPath != null)
			map['DiskPath'] = diskPath;
		if (relationCode != null)
			map['RelationCode'] = relationCode;
		return map;
	}
}

class GetDiagnosisImageResultByAIResultRequest {
	String? fileUrl;
	String? relationCode;
	DateTime? createTime;
	DateTime? updateTime;
	String? aiResult;

	GetDiagnosisImageResultByAIResultRequest({
		this.fileUrl,
		this.relationCode,
		this.createTime,
		this.updateTime,
		this.aiResult,
	});

	factory GetDiagnosisImageResultByAIResultRequest.fromJson(Map<String, dynamic> map) {
		return GetDiagnosisImageResultByAIResultRequest( 
			fileUrl: map['FileUrl'],
			relationCode: map['RelationCode'],
			createTime: map['CreateTime'] != null ? DateTime.parse(map['CreateTime']) : null,
			updateTime: map['UpdateTime'] != null ? DateTime.parse(map['UpdateTime']) : null,
			aiResult: map['AiResult'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		if (fileUrl != null)
			map['FileUrl'] = fileUrl;
		if (relationCode != null)
			map['RelationCode'] = relationCode;
		if (createTime != null)
			map['CreateTime'] = JsonRpcUtils.dateFormat(createTime!);
		if (updateTime != null)
			map['UpdateTime'] = JsonRpcUtils.dateFormat(updateTime!);
		if (aiResult != null)
			map['AiResult'] = aiResult;
		return map;
	}
}

class GetCarotidResultRequest {
	String? remedicalCode;
	String? surfaceToken;
	String? mdlToken;
	CarotidScanTypeEnum carotidScanType;
	CarotidScanDirectionEnum carotidScanDirection;
	List<MeasureImageFileDTO>? measureImageFiles;
	String? measureResult;

	GetCarotidResultRequest({
		this.remedicalCode,
		this.surfaceToken,
		this.mdlToken,
		this.carotidScanType = CarotidScanTypeEnum.CarotidLeft,
		this.carotidScanDirection = CarotidScanDirectionEnum.TopToBottom,
		this.measureImageFiles,
		this.measureResult,
	});

	factory GetCarotidResultRequest.fromJson(Map<String, dynamic> map) {
		return GetCarotidResultRequest( 
			remedicalCode: map['RemedicalCode'],
			surfaceToken: map['SurfaceToken'],
			mdlToken: map['MdlToken'],
			carotidScanType: CarotidScanTypeEnum.values.firstWhere((e) => e.index == map['CarotidScanType']),
			carotidScanDirection: CarotidScanDirectionEnum.values.firstWhere((e) => e.index == map['CarotidScanDirection']),
			measureImageFiles: map['MeasureImageFiles'] != null ? (map['MeasureImageFiles'] as List).map((e)=>MeasureImageFileDTO.fromJson(e as Map<String,dynamic>)).toList() : null,
			measureResult: map['MeasureResult'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		if (remedicalCode != null)
			map['RemedicalCode'] = remedicalCode;
		if (surfaceToken != null)
			map['SurfaceToken'] = surfaceToken;
		if (mdlToken != null)
			map['MdlToken'] = mdlToken;
		map['CarotidScanType'] = carotidScanType.index;
		map['CarotidScanDirection'] = carotidScanDirection.index;
		if (measureImageFiles != null)
			map['MeasureImageFiles'] = measureImageFiles;
		if (measureResult != null)
			map['MeasureResult'] = measureResult;
		return map;
	}
}

class CreateCarotidSurfaceImagesResult {
	List<String>? surfaceImages;

	CreateCarotidSurfaceImagesResult({
		this.surfaceImages,
	});

	factory CreateCarotidSurfaceImagesResult.fromJson(Map<String, dynamic> map) {
		return CreateCarotidSurfaceImagesResult( 
			surfaceImages: map['SurfaceImages']?.cast<String>().toList(),
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		if (surfaceImages != null)
			map['SurfaceImages'] = surfaceImages;
		return map;
	}
}

class CreateCarotidSurfaceImagesRequest {
	String? surfaceFileUrl;

	CreateCarotidSurfaceImagesRequest({
		this.surfaceFileUrl,
	});

	factory CreateCarotidSurfaceImagesRequest.fromJson(Map<String, dynamic> map) {
		return CreateCarotidSurfaceImagesRequest( 
			surfaceFileUrl: map['SurfaceFileUrl'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		if (surfaceFileUrl != null)
			map['SurfaceFileUrl'] = surfaceFileUrl;
		return map;
	}
}

class DiagnosisPerImageDTO extends AIDiagnosisPerImageDTO{
	String? remedicalCode;
	RemedicalFileDataTypeEnum dataType;
	double pixel;
	String? remedicalFileToken;
	String? aIFileToken;
	String? aIPreviewFileToken;
	String? perImageJson;
	DiagnosisConclusionEnum diagnosisConclusion;
	List<DiagnosisOrganEnum>? diagnosisOrgans;

	DiagnosisPerImageDTO({
		this.remedicalCode,
		this.dataType = RemedicalFileDataTypeEnum.VinnoVidSingle,
		this.pixel = 0,
		this.remedicalFileToken,
		this.aIFileToken,
		this.aIPreviewFileToken,
		this.perImageJson,
		this.diagnosisConclusion = DiagnosisConclusionEnum.NotRequired,
		this.diagnosisOrgans,
		int index = 0,
		double priorityScore = 0,
		List<AIDiagnosisResultPerOrgan>? diagResultsForEachOrgan,
	}) : super(
			index: index,
			priorityScore: priorityScore,
			diagResultsForEachOrgan: diagResultsForEachOrgan,
		);

	factory DiagnosisPerImageDTO.fromJson(Map<String, dynamic> map) {
		return DiagnosisPerImageDTO( 
			remedicalCode: map['RemedicalCode'],
			dataType: RemedicalFileDataTypeEnum.values.firstWhere((e) => e.index == map['DataType']),
			pixel: double.parse(map['Pixel'].toString()),
			remedicalFileToken: map['RemedicalFileToken'],
			aIFileToken: map['AIFileToken'],
			aIPreviewFileToken: map['AIPreviewFileToken'],
			perImageJson: map['PerImageJson'],
			diagnosisConclusion: DiagnosisConclusionEnum.values.firstWhere((e) => e.index == map['DiagnosisConclusion']),
			diagnosisOrgans: map['DiagnosisOrgans'] != null ? (map['DiagnosisOrgans'] as List).map((e)=>DiagnosisOrganEnum.values.firstWhere((i) => i.index == e)).toList() : null,
			index: map['Index'],
			priorityScore: double.parse(map['PriorityScore'].toString()),
			diagResultsForEachOrgan: map['DiagResultsForEachOrgan'] != null ? (map['DiagResultsForEachOrgan'] as List).map((e)=>AIDiagnosisResultPerOrgan.fromJson(e as Map<String,dynamic>)).toList() : null,
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (remedicalCode != null)
			map['RemedicalCode'] = remedicalCode;
		map['DataType'] = dataType.index;
		map['Pixel'] = pixel;
		if (remedicalFileToken != null)
			map['RemedicalFileToken'] = remedicalFileToken;
		if (aIFileToken != null)
			map['AIFileToken'] = aIFileToken;
		if (aIPreviewFileToken != null)
			map['AIPreviewFileToken'] = aIPreviewFileToken;
		if (perImageJson != null)
			map['PerImageJson'] = perImageJson;
		map['DiagnosisConclusion'] = diagnosisConclusion.index;
		if (diagnosisOrgans != null) {
			List<int> diagnosisOrgansList = [];
			diagnosisOrgans!.forEach((e) => diagnosisOrgansList.add(e.index));
			map['DiagnosisOrgans'] = diagnosisOrgansList;
		}
		return map;
	}
}

class DiagnosisRemicalDTO {
	String? remedicalCode;
	RemedicalFileDataTypeEnum dataType;
	String? fileToken;
	List<AIDiagnosisPerImageDTO>? diagnosisResult;
	CarotidResultDTO? carotidResult;

	DiagnosisRemicalDTO({
		this.remedicalCode,
		this.dataType = RemedicalFileDataTypeEnum.VinnoVidSingle,
		this.fileToken,
		this.diagnosisResult,
		this.carotidResult,
	});

	factory DiagnosisRemicalDTO.fromJson(Map<String, dynamic> map) {
		return DiagnosisRemicalDTO( 
			remedicalCode: map['RemedicalCode'],
			dataType: RemedicalFileDataTypeEnum.values.firstWhere((e) => e.index == map['DataType']),
			fileToken: map['FileToken'],
			diagnosisResult: map['DiagnosisResult'] != null ? (map['DiagnosisResult'] as List).map((e)=>AIDiagnosisPerImageDTO.fromJson(e as Map<String,dynamic>)).toList() : null,
			carotidResult: map['CarotidResult'] != null ? CarotidResultDTO.fromJson(map['CarotidResult']) : null,
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		if (remedicalCode != null)
			map['RemedicalCode'] = remedicalCode;
		map['DataType'] = dataType.index;
		if (fileToken != null)
			map['FileToken'] = fileToken;
		if (diagnosisResult != null)
			map['DiagnosisResult'] = diagnosisResult;
		if (carotidResult != null)
			map['CarotidResult'] = carotidResult;
		return map;
	}
}

class DiagnosisReportResult {
	DiagnosisConclusionEnum diagnosisConclusion;
	List<DiagnosisPerImageDTO>? diagnosisResult;
	List<DiagnosisRemicalDTO>? carotidResult;
	List<DataItemDTO>? carotidItems;

	DiagnosisReportResult({
		this.diagnosisConclusion = DiagnosisConclusionEnum.NotRequired,
		this.diagnosisResult,
		this.carotidResult,
		this.carotidItems,
	});

	factory DiagnosisReportResult.fromJson(Map<String, dynamic> map) {
		return DiagnosisReportResult( 
			diagnosisConclusion: DiagnosisConclusionEnum.values.firstWhere((e) => e.index == map['DiagnosisConclusion']),
			diagnosisResult: map['DiagnosisResult'] != null ? (map['DiagnosisResult'] as List).map((e)=>DiagnosisPerImageDTO.fromJson(e as Map<String,dynamic>)).toList() : null,
			carotidResult: map['CarotidResult'] != null ? (map['CarotidResult'] as List).map((e)=>DiagnosisRemicalDTO.fromJson(e as Map<String,dynamic>)).toList() : null,
			carotidItems: map['CarotidItems'] != null ? (map['CarotidItems'] as List).map((e)=>DataItemDTO.fromJson(e as Map<String,dynamic>)).toList() : null,
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		map['DiagnosisConclusion'] = diagnosisConclusion.index;
		if (diagnosisResult != null)
			map['DiagnosisResult'] = diagnosisResult;
		if (carotidResult != null)
			map['CarotidResult'] = carotidResult;
		if (carotidItems != null)
			map['CarotidItems'] = carotidItems;
		return map;
	}
}

class DiagnosisReportRequest extends TokenRequest{
	DiagnosisOrganEnum organ;
	List<DiagnosisRemicalDTO>? remedicalList;

	DiagnosisReportRequest({
		this.organ = DiagnosisOrganEnum.Null,
		this.remedicalList,
		String? token,
	}) : super(
			token: token,
		);

	factory DiagnosisReportRequest.fromJson(Map<String, dynamic> map) {
		return DiagnosisReportRequest( 
			organ: DiagnosisOrganEnum.values.firstWhere((e) => e.index == map['Organ']),
			remedicalList: map['RemedicalList'] != null ? (map['RemedicalList'] as List).map((e)=>DiagnosisRemicalDTO.fromJson(e as Map<String,dynamic>)).toList() : null,
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		map['Organ'] = organ.index;
		if (remedicalList != null)
			map['RemedicalList'] = remedicalList;
		return map;
	}
}

class GetDiagnosisConclusionResult {
	DiagnosisConclusionEnum diagnosisConclusion;
	List<DiagnosisOrganEnum>? diagnosisOrgans;

	GetDiagnosisConclusionResult({
		this.diagnosisConclusion = DiagnosisConclusionEnum.NotRequired,
		this.diagnosisOrgans,
	});

	factory GetDiagnosisConclusionResult.fromJson(Map<String, dynamic> map) {
		return GetDiagnosisConclusionResult( 
			diagnosisConclusion: DiagnosisConclusionEnum.values.firstWhere((e) => e.index == map['DiagnosisConclusion']),
			diagnosisOrgans: map['DiagnosisOrgans'] != null ? (map['DiagnosisOrgans'] as List).map((e)=>DiagnosisOrganEnum.values.firstWhere((i) => i.index == e)).toList() : null,
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		map['DiagnosisConclusion'] = diagnosisConclusion.index;
		if (diagnosisOrgans != null) {
			List<int> diagnosisOrgansList = [];
			diagnosisOrgans!.forEach((e) => diagnosisOrgansList.add(e.index));
			map['DiagnosisOrgans'] = diagnosisOrgansList;
		}
		return map;
	}
}

class GetDiagnosisConclusionRequest extends TokenRequest{
	String? perImageJson;

	GetDiagnosisConclusionRequest({
		this.perImageJson,
		String? token,
	}) : super(
			token: token,
		);

	factory GetDiagnosisConclusionRequest.fromJson(Map<String, dynamic> map) {
		return GetDiagnosisConclusionRequest( 
			perImageJson: map['PerImageJson'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (perImageJson != null)
			map['PerImageJson'] = perImageJson;
		return map;
	}
}

class EnumFieldDTO {
	int id;
	String? value;

	EnumFieldDTO({
		this.id = 0,
		this.value,
	});

	factory EnumFieldDTO.fromJson(Map<String, dynamic> map) {
		return EnumFieldDTO( 
			id: map['Id'],
			value: map['Value'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		map['Id'] = id;
		if (value != null)
			map['Value'] = value;
		return map;
	}
}

class EnumItemDTO {
	String? code;
	List<EnumFieldDTO>? children;

	EnumItemDTO({
		this.code,
		this.children,
	});

	factory EnumItemDTO.fromJson(Map<String, dynamic> map) {
		return EnumItemDTO( 
			code: map['Code'],
			children: map['Children'] != null ? (map['Children'] as List).map((e)=>EnumFieldDTO.fromJson(e as Map<String,dynamic>)).toList() : null,
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		if (code != null)
			map['Code'] = code;
		if (children != null)
			map['Children'] = children;
		return map;
	}
}

class GetDiagnosisEnumItemsResult {
	List<EnumItemDTO>? source;

	GetDiagnosisEnumItemsResult({
		this.source,
	});

	factory GetDiagnosisEnumItemsResult.fromJson(Map<String, dynamic> map) {
		return GetDiagnosisEnumItemsResult( 
			source: map['Source'] != null ? (map['Source'] as List).map((e)=>EnumItemDTO.fromJson(e as Map<String,dynamic>)).toList() : null,
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		if (source != null)
			map['Source'] = source;
		return map;
	}
}

class GetDiagnosisEnumItemsRequest extends TokenRequest{

	GetDiagnosisEnumItemsRequest({
		String? token,
	}) : super(
			token: token,
		);

	factory GetDiagnosisEnumItemsRequest.fromJson(Map<String, dynamic> map) {
		return GetDiagnosisEnumItemsRequest( 
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		return map;
	}
}

enum DiagnosisKeyPointType {
	Null,
	OtherKeyPoints,
	HorizontalPointLeft,
	HorizontalPointRight,
	VerticalPointUp,
	VerticalPointDown,
}

class DiagnosisKeyPointDTO {
	DiagnosisKeyPointType type;
	AIDiagnosisPoint2D? point;
	int indexInContour;

	DiagnosisKeyPointDTO({
		this.type = DiagnosisKeyPointType.Null,
		this.point,
		this.indexInContour = 0,
	});

	factory DiagnosisKeyPointDTO.fromJson(Map<String, dynamic> map) {
		return DiagnosisKeyPointDTO( 
			type: DiagnosisKeyPointType.values.firstWhere((e) => e.index == map['Type']),
			point: map['Point'] != null ? AIDiagnosisPoint2D.fromJson(map['Point']) : null,
			indexInContour: map['IndexInContour'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		map['Type'] = type.index;
		if (point != null)
			map['Point'] = point;
		map['IndexInContour'] = indexInContour;
		return map;
	}
}

class AIDiagnosisLesionSize {
	AIDiagnosisPoint2D? horizontalPoint1;
	AIDiagnosisPoint2D? horizontalPoint2;
	AIDiagnosisPoint2D? verticalPoint1;
	AIDiagnosisPoint2D? verticalPoint2;
	int horizontalLengthInPixel;
	int verticalLengthInPixel;

	AIDiagnosisLesionSize({
		this.horizontalPoint1,
		this.horizontalPoint2,
		this.verticalPoint1,
		this.verticalPoint2,
		this.horizontalLengthInPixel = 0,
		this.verticalLengthInPixel = 0,
	});

	factory AIDiagnosisLesionSize.fromJson(Map<String, dynamic> map) {
		return AIDiagnosisLesionSize( 
			horizontalPoint1: map['HorizontalPoint1'] != null ? AIDiagnosisPoint2D.fromJson(map['HorizontalPoint1']) : null,
			horizontalPoint2: map['HorizontalPoint2'] != null ? AIDiagnosisPoint2D.fromJson(map['HorizontalPoint2']) : null,
			verticalPoint1: map['VerticalPoint1'] != null ? AIDiagnosisPoint2D.fromJson(map['VerticalPoint1']) : null,
			verticalPoint2: map['VerticalPoint2'] != null ? AIDiagnosisPoint2D.fromJson(map['VerticalPoint2']) : null,
			horizontalLengthInPixel: map['HorizontalLengthInPixel'],
			verticalLengthInPixel: map['VerticalLengthInPixel'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		if (horizontalPoint1 != null)
			map['HorizontalPoint1'] = horizontalPoint1;
		if (horizontalPoint2 != null)
			map['HorizontalPoint2'] = horizontalPoint2;
		if (verticalPoint1 != null)
			map['VerticalPoint1'] = verticalPoint1;
		if (verticalPoint2 != null)
			map['VerticalPoint2'] = verticalPoint2;
		map['HorizontalLengthInPixel'] = horizontalLengthInPixel;
		map['VerticalLengthInPixel'] = verticalLengthInPixel;
		return map;
	}
}

class GetKeyPointsOfContourRequest extends TokenRequest{
	List<AIDiagnosisPoint2D>? contours;
	AIDiagnosisLesionSize? lesionSize;

	GetKeyPointsOfContourRequest({
		this.contours,
		this.lesionSize,
		String? token,
	}) : super(
			token: token,
		);

	factory GetKeyPointsOfContourRequest.fromJson(Map<String, dynamic> map) {
		return GetKeyPointsOfContourRequest( 
			contours: map['Contours'] != null ? (map['Contours'] as List).map((e)=>AIDiagnosisPoint2D.fromJson(e as Map<String,dynamic>)).toList() : null,
			lesionSize: map['LesionSize'] != null ? AIDiagnosisLesionSize.fromJson(map['LesionSize']) : null,
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (contours != null)
			map['Contours'] = contours;
		if (lesionSize != null)
			map['LesionSize'] = lesionSize;
		return map;
	}
}

class AffectedKeyPointsByDragActionRequest extends TokenRequest{
	List<DiagnosisKeyPointDTO>? keyPoints;
	AIDiagnosisPoint2D? mousePoint;

	AffectedKeyPointsByDragActionRequest({
		this.keyPoints,
		this.mousePoint,
		String? token,
	}) : super(
			token: token,
		);

	factory AffectedKeyPointsByDragActionRequest.fromJson(Map<String, dynamic> map) {
		return AffectedKeyPointsByDragActionRequest( 
			keyPoints: map['KeyPoints'] != null ? (map['KeyPoints'] as List).map((e)=>DiagnosisKeyPointDTO.fromJson(e as Map<String,dynamic>)).toList() : null,
			mousePoint: map['MousePoint'] != null ? AIDiagnosisPoint2D.fromJson(map['MousePoint']) : null,
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (keyPoints != null)
			map['KeyPoints'] = keyPoints;
		if (mousePoint != null)
			map['MousePoint'] = mousePoint;
		return map;
	}
}

class ContourAndKeyPointsAfterDragResult {
	List<AIDiagnosisPoint2D>? dstContours;
	List<DiagnosisKeyPointDTO>? dstKeyPoints;
	List<int>? affectedKeyPointIndexes;

	ContourAndKeyPointsAfterDragResult({
		this.dstContours,
		this.dstKeyPoints,
		this.affectedKeyPointIndexes,
	});

	factory ContourAndKeyPointsAfterDragResult.fromJson(Map<String, dynamic> map) {
		return ContourAndKeyPointsAfterDragResult( 
			dstContours: map['DstContours'] != null ? (map['DstContours'] as List).map((e)=>AIDiagnosisPoint2D.fromJson(e as Map<String,dynamic>)).toList() : null,
			dstKeyPoints: map['DstKeyPoints'] != null ? (map['DstKeyPoints'] as List).map((e)=>DiagnosisKeyPointDTO.fromJson(e as Map<String,dynamic>)).toList() : null,
			affectedKeyPointIndexes: map['AffectedKeyPointIndexes']?.cast<int>().toList(),
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		if (dstContours != null)
			map['DstContours'] = dstContours;
		if (dstKeyPoints != null)
			map['DstKeyPoints'] = dstKeyPoints;
		if (affectedKeyPointIndexes != null)
			map['AffectedKeyPointIndexes'] = affectedKeyPointIndexes;
		return map;
	}
}

class ContourAndKeyPointsAfterDragRequest extends TokenRequest{
	List<AIDiagnosisPoint2D>? contours;
	List<DiagnosisKeyPointDTO>? keyPoints;
	AIDiagnosisPoint2D? startPoint;
	AIDiagnosisPoint2D? endPoint;

	ContourAndKeyPointsAfterDragRequest({
		this.contours,
		this.keyPoints,
		this.startPoint,
		this.endPoint,
		String? token,
	}) : super(
			token: token,
		);

	factory ContourAndKeyPointsAfterDragRequest.fromJson(Map<String, dynamic> map) {
		return ContourAndKeyPointsAfterDragRequest( 
			contours: map['Contours'] != null ? (map['Contours'] as List).map((e)=>AIDiagnosisPoint2D.fromJson(e as Map<String,dynamic>)).toList() : null,
			keyPoints: map['KeyPoints'] != null ? (map['KeyPoints'] as List).map((e)=>DiagnosisKeyPointDTO.fromJson(e as Map<String,dynamic>)).toList() : null,
			startPoint: map['StartPoint'] != null ? AIDiagnosisPoint2D.fromJson(map['StartPoint']) : null,
			endPoint: map['EndPoint'] != null ? AIDiagnosisPoint2D.fromJson(map['EndPoint']) : null,
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (contours != null)
			map['Contours'] = contours;
		if (keyPoints != null)
			map['KeyPoints'] = keyPoints;
		if (startPoint != null)
			map['StartPoint'] = startPoint;
		if (endPoint != null)
			map['EndPoint'] = endPoint;
		return map;
	}
}

class MinimumDistanceToContourPointsResult {
	double distanceCaught;
	int closestPointIndex;

	MinimumDistanceToContourPointsResult({
		this.distanceCaught = 0,
		this.closestPointIndex = 0,
	});

	factory MinimumDistanceToContourPointsResult.fromJson(Map<String, dynamic> map) {
		return MinimumDistanceToContourPointsResult( 
			distanceCaught: double.parse(map['DistanceCaught'].toString()),
			closestPointIndex: map['ClosestPointIndex'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		map['DistanceCaught'] = distanceCaught;
		map['ClosestPointIndex'] = closestPointIndex;
		return map;
	}
}

class MinimumDistanceToContourPointsRequest extends TokenRequest{
	List<AIDiagnosisPoint2D>? contourPoints;
	AIDiagnosisPoint2D? mousePoint;

	MinimumDistanceToContourPointsRequest({
		this.contourPoints,
		this.mousePoint,
		String? token,
	}) : super(
			token: token,
		);

	factory MinimumDistanceToContourPointsRequest.fromJson(Map<String, dynamic> map) {
		return MinimumDistanceToContourPointsRequest( 
			contourPoints: map['ContourPoints'] != null ? (map['ContourPoints'] as List).map((e)=>AIDiagnosisPoint2D.fromJson(e as Map<String,dynamic>)).toList() : null,
			mousePoint: map['MousePoint'] != null ? AIDiagnosisPoint2D.fromJson(map['MousePoint']) : null,
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (contourPoints != null)
			map['ContourPoints'] = contourPoints;
		if (mousePoint != null)
			map['MousePoint'] = mousePoint;
		return map;
	}
}

class ContourMergeResult {
	List<AIDiagnosisPoint2D>? dstContours;
	AIDiagnosisLesionSize? dstLesionSize;

	ContourMergeResult({
		this.dstContours,
		this.dstLesionSize,
	});

	factory ContourMergeResult.fromJson(Map<String, dynamic> map) {
		return ContourMergeResult( 
			dstContours: map['DstContours'] != null ? (map['DstContours'] as List).map((e)=>AIDiagnosisPoint2D.fromJson(e as Map<String,dynamic>)).toList() : null,
			dstLesionSize: map['DstLesionSize'] != null ? AIDiagnosisLesionSize.fromJson(map['DstLesionSize']) : null,
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		if (dstContours != null)
			map['DstContours'] = dstContours;
		if (dstLesionSize != null)
			map['DstLesionSize'] = dstLesionSize;
		return map;
	}
}

class ContourMergeRequest extends TokenRequest{
	List<AIDiagnosisPoint2D>? contourPoints;
	AIDiagnosisLesionSize? lesionSize;
	List<AIDiagnosisPoint2D>? drawingNewContourPoints;

	ContourMergeRequest({
		this.contourPoints,
		this.lesionSize,
		this.drawingNewContourPoints,
		String? token,
	}) : super(
			token: token,
		);

	factory ContourMergeRequest.fromJson(Map<String, dynamic> map) {
		return ContourMergeRequest( 
			contourPoints: map['ContourPoints'] != null ? (map['ContourPoints'] as List).map((e)=>AIDiagnosisPoint2D.fromJson(e as Map<String,dynamic>)).toList() : null,
			lesionSize: map['LesionSize'] != null ? AIDiagnosisLesionSize.fromJson(map['LesionSize']) : null,
			drawingNewContourPoints: map['DrawingNewContourPoints'] != null ? (map['DrawingNewContourPoints'] as List).map((e)=>AIDiagnosisPoint2D.fromJson(e as Map<String,dynamic>)).toList() : null,
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (contourPoints != null)
			map['ContourPoints'] = contourPoints;
		if (lesionSize != null)
			map['LesionSize'] = lesionSize;
		if (drawingNewContourPoints != null)
			map['DrawingNewContourPoints'] = drawingNewContourPoints;
		return map;
	}
}

class URMAnalysisResult {
	bool isSuccess;
	List<ImgItem>? uRMAnalysisDetails;
	String? urmPosition;

	URMAnalysisResult({
		this.isSuccess = false,
		this.uRMAnalysisDetails,
		this.urmPosition,
	});

	factory URMAnalysisResult.fromJson(Map<String, dynamic> map) {
		return URMAnalysisResult( 
			isSuccess: map['IsSuccess'],
			uRMAnalysisDetails: map['URMAnalysisDetails'] != null ? (map['URMAnalysisDetails'] as List).map((e)=>ImgItem.fromJson(e as Map<String,dynamic>)).toList() : null,
			urmPosition: map['UrmPosition'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		map['IsSuccess'] = isSuccess;
		if (uRMAnalysisDetails != null)
			map['URMAnalysisDetails'] = uRMAnalysisDetails;
		if (urmPosition != null)
			map['UrmPosition'] = urmPosition;
		return map;
	}
}

class URMAnalysisRequest extends TokenRequest{
	double x;
	double y;
	double width;
	double height;
	String? remedicalCode;

	URMAnalysisRequest({
		this.x = 0,
		this.y = 0,
		this.width = 0,
		this.height = 0,
		this.remedicalCode,
		String? token,
	}) : super(
			token: token,
		);

	factory URMAnalysisRequest.fromJson(Map<String, dynamic> map) {
		return URMAnalysisRequest( 
			x: double.parse(map['X'].toString()),
			y: double.parse(map['Y'].toString()),
			width: double.parse(map['Width'].toString()),
			height: double.parse(map['Height'].toString()),
			remedicalCode: map['RemedicalCode'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		map['X'] = x;
		map['Y'] = y;
		map['Width'] = width;
		map['Height'] = height;
		if (remedicalCode != null)
			map['RemedicalCode'] = remedicalCode;
		return map;
	}
}

class URMAnalysisV2Result {
	bool isSuccess;
	List<ImgItem>? uRMAnalysisDetails;
	String? urmPosition;
	int uRMSrcWidth;
	int uRMSrcHeight;
	double uRMRes;
	double uRMScaleOfPixel_x;
	double uRMScaleOfPixel_y;
	String? converImageUrl;

	URMAnalysisV2Result({
		this.isSuccess = false,
		this.uRMAnalysisDetails,
		this.urmPosition,
		this.uRMSrcWidth = 0,
		this.uRMSrcHeight = 0,
		this.uRMRes = 0,
		this.uRMScaleOfPixel_x = 0,
		this.uRMScaleOfPixel_y = 0,
		this.converImageUrl,
	});

	factory URMAnalysisV2Result.fromJson(Map<String, dynamic> map) {
		return URMAnalysisV2Result( 
			isSuccess: map['IsSuccess'],
			uRMAnalysisDetails: map['URMAnalysisDetails'] != null ? (map['URMAnalysisDetails'] as List).map((e)=>ImgItem.fromJson(e as Map<String,dynamic>)).toList() : null,
			urmPosition: map['UrmPosition'],
			uRMSrcWidth: map['URMSrcWidth'],
			uRMSrcHeight: map['URMSrcHeight'],
			uRMRes: double.parse(map['URMRes'].toString()),
			uRMScaleOfPixel_x: double.parse(map['URMScaleOfPixel_x'].toString()),
			uRMScaleOfPixel_y: double.parse(map['URMScaleOfPixel_y'].toString()),
			converImageUrl: map['ConverImageUrl'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		map['IsSuccess'] = isSuccess;
		if (uRMAnalysisDetails != null)
			map['URMAnalysisDetails'] = uRMAnalysisDetails;
		if (urmPosition != null)
			map['UrmPosition'] = urmPosition;
		map['URMSrcWidth'] = uRMSrcWidth;
		map['URMSrcHeight'] = uRMSrcHeight;
		map['URMRes'] = uRMRes;
		map['URMScaleOfPixel_x'] = uRMScaleOfPixel_x;
		map['URMScaleOfPixel_y'] = uRMScaleOfPixel_y;
		if (converImageUrl != null)
			map['ConverImageUrl'] = converImageUrl;
		return map;
	}
}

class URMAnalysisV2Request extends TokenRequest{
	String? notifyUserCode;
	double x;
	double y;
	double width;
	double height;
	int? customizedStartFrame;
	int? customizedEndFrame;
	String? remedicalCode;
	double roiXPercent;
	double roiYPercent;
	double roiWPercent;
	double roiHPercent;

	URMAnalysisV2Request({
		this.notifyUserCode,
		this.x = 0,
		this.y = 0,
		this.width = 0,
		this.height = 0,
		this.customizedStartFrame,
		this.customizedEndFrame,
		this.remedicalCode,
		this.roiXPercent = 0,
		this.roiYPercent = 0,
		this.roiWPercent = 0,
		this.roiHPercent = 0,
		String? token,
	}) : super(
			token: token,
		);

	factory URMAnalysisV2Request.fromJson(Map<String, dynamic> map) {
		return URMAnalysisV2Request( 
			notifyUserCode: map['NotifyUserCode'],
			x: double.parse(map['X'].toString()),
			y: double.parse(map['Y'].toString()),
			width: double.parse(map['Width'].toString()),
			height: double.parse(map['Height'].toString()),
			customizedStartFrame: map['CustomizedStartFrame'],
			customizedEndFrame: map['CustomizedEndFrame'],
			remedicalCode: map['RemedicalCode'],
			roiXPercent: double.parse(map['RoiXPercent'].toString()),
			roiYPercent: double.parse(map['RoiYPercent'].toString()),
			roiWPercent: double.parse(map['RoiWPercent'].toString()),
			roiHPercent: double.parse(map['RoiHPercent'].toString()),
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (notifyUserCode != null)
			map['NotifyUserCode'] = notifyUserCode;
		map['X'] = x;
		map['Y'] = y;
		map['Width'] = width;
		map['Height'] = height;
		if (customizedStartFrame != null)
			map['CustomizedStartFrame'] = customizedStartFrame;
		if (customizedEndFrame != null)
			map['CustomizedEndFrame'] = customizedEndFrame;
		if (remedicalCode != null)
			map['RemedicalCode'] = remedicalCode;
		map['RoiXPercent'] = roiXPercent;
		map['RoiYPercent'] = roiYPercent;
		map['RoiWPercent'] = roiWPercent;
		map['RoiHPercent'] = roiHPercent;
		return map;
	}
}

class URMProcessResult {
	String? base64String;
	double urmMinVal;
	double urmMaxVal;

	URMProcessResult({
		this.base64String,
		this.urmMinVal = 0,
		this.urmMaxVal = 0,
	});

	factory URMProcessResult.fromJson(Map<String, dynamic> map) {
		return URMProcessResult( 
			base64String: map['Base64String'],
			urmMinVal: double.parse(map['UrmMinVal'].toString()),
			urmMaxVal: double.parse(map['UrmMaxVal'].toString()),
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		if (base64String != null)
			map['Base64String'] = base64String;
		map['UrmMinVal'] = urmMinVal;
		map['UrmMaxVal'] = urmMaxVal;
		return map;
	}
}

class URMColorbarResult {
	String? colorbarBase64;
	String? logoBase64;

	URMColorbarResult({
		this.colorbarBase64,
		this.logoBase64,
	});

	factory URMColorbarResult.fromJson(Map<String, dynamic> map) {
		return URMColorbarResult( 
			colorbarBase64: map['ColorbarBase64'],
			logoBase64: map['LogoBase64'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		if (colorbarBase64 != null)
			map['ColorbarBase64'] = colorbarBase64;
		if (logoBase64 != null)
			map['LogoBase64'] = logoBase64;
		return map;
	}
}

class URMColorbarRequest extends URMProcessRequest{
	int processType;

	URMColorbarRequest({
		this.processType = 0,
		String? token,
		String? remedicalCode,
		List<UrmPoint>? urmTraceDPoints,
		String? urmImageType,
		int urmBlend = 0,
		double downsampleIndex = 0,
		double intPowerDen = 0,
		double intPowerDir = 0,
		double sigmaGauss = 0,
		double vessScale = 0,
		double velMaxScaler = 0,
		double velMinScaler = 0,
		double iterations = 0,
		int imgProcessVer = 0,
		bool zoomOn = false,
		double zoomRoix = 0,
		double zoomRoiy = 0,
		double zoomRoiwidth = 0,
		double zoomRoiheight = 0,
		int roix = 0,
		int roiy = 0,
		int roiwidth = 0,
		int roiheight = 0,
		bool leftRight = false,
		bool upDown = false,
		int screenWidth = 0,
		int screenHeight = 0,
	}) : super(
			token: token,
			remedicalCode: remedicalCode,
			urmTraceDPoints: urmTraceDPoints,
			urmImageType: urmImageType,
			urmBlend: urmBlend,
			downsampleIndex: downsampleIndex,
			intPowerDen: intPowerDen,
			intPowerDir: intPowerDir,
			sigmaGauss: sigmaGauss,
			vessScale: vessScale,
			velMaxScaler: velMaxScaler,
			velMinScaler: velMinScaler,
			iterations: iterations,
			imgProcessVer: imgProcessVer,
			zoomOn: zoomOn,
			zoomRoix: zoomRoix,
			zoomRoiy: zoomRoiy,
			zoomRoiwidth: zoomRoiwidth,
			zoomRoiheight: zoomRoiheight,
			roix: roix,
			roiy: roiy,
			roiwidth: roiwidth,
			roiheight: roiheight,
			leftRight: leftRight,
			upDown: upDown,
			screenWidth: screenWidth,
			screenHeight: screenHeight,
		);

	factory URMColorbarRequest.fromJson(Map<String, dynamic> map) {
		final urmTraceDPointsData = map['UrmTraceDPoints'];
		return URMColorbarRequest( 
			processType: map['ProcessType'],
			token: map['Token'],
			remedicalCode: map['RemedicalCode'],
			urmTraceDPoints: urmTraceDPointsData != null ? (urmTraceDPointsData as List).map((e) => UrmPoint.fromJson(e)).toList(): null,
			urmImageType: map['UrmImageType'],
			urmBlend: map['UrmBlend'],
			downsampleIndex: double.parse(map['DownsampleIndex'].toString()),
			intPowerDen: double.parse(map['IntPowerDen'].toString()),
			intPowerDir: double.parse(map['IntPowerDir'].toString()),
			sigmaGauss: double.parse(map['SigmaGauss'].toString()),
			vessScale: double.parse(map['VessScale'].toString()),
			velMaxScaler: double.parse(map['VelMaxScaler'].toString()),
			velMinScaler: double.parse(map['VelMinScaler'].toString()),
			iterations: double.parse(map['Iterations'].toString()),
			imgProcessVer: map['ImgProcessVer'],
			zoomOn: map['ZoomOn'],
			zoomRoix: double.parse(map['ZoomRoix'].toString()),
			zoomRoiy: double.parse(map['ZoomRoiy'].toString()),
			zoomRoiwidth: double.parse(map['ZoomRoiwidth'].toString()),
			zoomRoiheight: double.parse(map['ZoomRoiheight'].toString()),
			roix: map['Roix'],
			roiy: map['Roiy'],
			roiwidth: map['Roiwidth'],
			roiheight: map['Roiheight'],
			leftRight: map['LeftRight'],
			upDown: map['UpDown'],
			screenWidth: map['ScreenWidth'],
			screenHeight: map['ScreenHeight'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		map['ProcessType'] = processType;
		return map;
	}
}

class URMVideoProcessResult {
	String? base64String;
	double urmMinVal;
	double urmMaxVal;

	URMVideoProcessResult({
		this.base64String,
		this.urmMinVal = 0,
		this.urmMaxVal = 0,
	});

	factory URMVideoProcessResult.fromJson(Map<String, dynamic> map) {
		return URMVideoProcessResult( 
			base64String: map['Base64String'],
			urmMinVal: double.parse(map['UrmMinVal'].toString()),
			urmMaxVal: double.parse(map['UrmMaxVal'].toString()),
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		if (base64String != null)
			map['Base64String'] = base64String;
		map['UrmMinVal'] = urmMinVal;
		map['UrmMaxVal'] = urmMaxVal;
		return map;
	}
}

enum URMMeasureType {
	URMCurvature,
	URMDen,
	URMFracetalDim,
	URMLocationVel,
	URMVel,
	URMDenMeasure,
	URMVelMeasure,
	URMVesselMeasure,
	URMPerfusion,
	URMHist,
	URMTraceCurvature,
	URMDenVelMeasure,
}

enum URMROIType {
	placeHolder_0,
	URMRect,
	URMTrace,
	URMEllipse,
	URMShell,
}

class URMMeasureProcessRequest extends URMProcessRequest{
	URMMeasureType urmMeasureType;
	List<UrmPoint>? srcDPoints;
	double? cMlength;
	double phywidth;
	URMROIType rOIType;
	double shellWidth;

	URMMeasureProcessRequest({
		this.urmMeasureType = URMMeasureType.URMCurvature,
		this.srcDPoints,
		this.cMlength,
		this.phywidth = 0,
		this.rOIType = URMROIType.URMRect,
		this.shellWidth = 0,
		String? token,
		String? remedicalCode,
		List<UrmPoint>? urmTraceDPoints,
		String? urmImageType,
		int urmBlend = 0,
		double downsampleIndex = 0,
		double intPowerDen = 0,
		double intPowerDir = 0,
		double sigmaGauss = 0,
		double vessScale = 0,
		double velMaxScaler = 0,
		double velMinScaler = 0,
		double iterations = 0,
		int imgProcessVer = 0,
		bool zoomOn = false,
		double zoomRoix = 0,
		double zoomRoiy = 0,
		double zoomRoiwidth = 0,
		double zoomRoiheight = 0,
		int roix = 0,
		int roiy = 0,
		int roiwidth = 0,
		int roiheight = 0,
		bool leftRight = false,
		bool upDown = false,
		int screenWidth = 0,
		int screenHeight = 0,
	}) : super(
			token: token,
			remedicalCode: remedicalCode,
			urmTraceDPoints: urmTraceDPoints,
			urmImageType: urmImageType,
			urmBlend: urmBlend,
			downsampleIndex: downsampleIndex,
			intPowerDen: intPowerDen,
			intPowerDir: intPowerDir,
			sigmaGauss: sigmaGauss,
			vessScale: vessScale,
			velMaxScaler: velMaxScaler,
			velMinScaler: velMinScaler,
			iterations: iterations,
			imgProcessVer: imgProcessVer,
			zoomOn: zoomOn,
			zoomRoix: zoomRoix,
			zoomRoiy: zoomRoiy,
			zoomRoiwidth: zoomRoiwidth,
			zoomRoiheight: zoomRoiheight,
			roix: roix,
			roiy: roiy,
			roiwidth: roiwidth,
			roiheight: roiheight,
			leftRight: leftRight,
			upDown: upDown,
			screenWidth: screenWidth,
			screenHeight: screenHeight,
		);

	factory URMMeasureProcessRequest.fromJson(Map<String, dynamic> map) {
		final urmTraceDPointsData = map['UrmTraceDPoints'];
		return URMMeasureProcessRequest( 
			urmMeasureType: URMMeasureType.values.firstWhere((e) => e.index == map['UrmMeasureType']),
			srcDPoints: map['SrcDPoints'] != null ? (map['SrcDPoints'] as List).map((e)=>UrmPoint.fromJson(e as Map<String,dynamic>)).toList() : null,
			cMlength: map['CMlength'],
			phywidth: double.parse(map['Phywidth'].toString()),
			rOIType: URMROIType.values.firstWhere((e) => e.index == map['ROIType']),
			shellWidth: double.parse(map['ShellWidth'].toString()),
			token: map['Token'],
			remedicalCode: map['RemedicalCode'],
			urmTraceDPoints: urmTraceDPointsData != null ? (urmTraceDPointsData as List).map((e) => UrmPoint.fromJson(e)).toList(): null,
			urmImageType: map['UrmImageType'],
			urmBlend: map['UrmBlend'],
			downsampleIndex: double.parse(map['DownsampleIndex'].toString()),
			intPowerDen: double.parse(map['IntPowerDen'].toString()),
			intPowerDir: double.parse(map['IntPowerDir'].toString()),
			sigmaGauss: double.parse(map['SigmaGauss'].toString()),
			vessScale: double.parse(map['VessScale'].toString()),
			velMaxScaler: double.parse(map['VelMaxScaler'].toString()),
			velMinScaler: double.parse(map['VelMinScaler'].toString()),
			iterations: double.parse(map['Iterations'].toString()),
			imgProcessVer: map['ImgProcessVer'],
			zoomOn: map['ZoomOn'],
			zoomRoix: double.parse(map['ZoomRoix'].toString()),
			zoomRoiy: double.parse(map['ZoomRoiy'].toString()),
			zoomRoiwidth: double.parse(map['ZoomRoiwidth'].toString()),
			zoomRoiheight: double.parse(map['ZoomRoiheight'].toString()),
			roix: map['Roix'],
			roiy: map['Roiy'],
			roiwidth: map['Roiwidth'],
			roiheight: map['Roiheight'],
			leftRight: map['LeftRight'],
			upDown: map['UpDown'],
			screenWidth: map['ScreenWidth'],
			screenHeight: map['ScreenHeight'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		map['UrmMeasureType'] = urmMeasureType.index;
		if (srcDPoints != null)
			map['SrcDPoints'] = srcDPoints;
		if (cMlength != null)
			map['CMlength'] = cMlength;
		map['Phywidth'] = phywidth;
		map['ROIType'] = rOIType.index;
		map['ShellWidth'] = shellWidth;
		return map;
	}
}

class URMDenMeasureResult {
	double roiDen;
	double roiFractalDim;
	double maxDensity;
	double minDensity;
	double meanDensity;
	double varianceDensity;
	double roiArea;
	double outRoiDen;
	double outRoiFractalDim;
	double outMaxDensity;
	double outMinDensity;
	double outMeanDensity;
	double outVarianceDensity;
	double outRoiArea;
	double inRoiDen;
	double inRoiFractalDim;
	double inMaxDensity;
	double inMinDensity;
	double inMeanDensity;
	double inVarianceDensity;
	double inRoiArea;

	URMDenMeasureResult({
		this.roiDen = 0,
		this.roiFractalDim = 0,
		this.maxDensity = 0,
		this.minDensity = 0,
		this.meanDensity = 0,
		this.varianceDensity = 0,
		this.roiArea = 0,
		this.outRoiDen = 0,
		this.outRoiFractalDim = 0,
		this.outMaxDensity = 0,
		this.outMinDensity = 0,
		this.outMeanDensity = 0,
		this.outVarianceDensity = 0,
		this.outRoiArea = 0,
		this.inRoiDen = 0,
		this.inRoiFractalDim = 0,
		this.inMaxDensity = 0,
		this.inMinDensity = 0,
		this.inMeanDensity = 0,
		this.inVarianceDensity = 0,
		this.inRoiArea = 0,
	});

	factory URMDenMeasureResult.fromJson(Map<String, dynamic> map) {
		return URMDenMeasureResult( 
			roiDen: double.parse(map['RoiDen'].toString()),
			roiFractalDim: double.parse(map['RoiFractalDim'].toString()),
			maxDensity: double.parse(map['MaxDensity'].toString()),
			minDensity: double.parse(map['MinDensity'].toString()),
			meanDensity: double.parse(map['MeanDensity'].toString()),
			varianceDensity: double.parse(map['VarianceDensity'].toString()),
			roiArea: double.parse(map['RoiArea'].toString()),
			outRoiDen: double.parse(map['OutRoiDen'].toString()),
			outRoiFractalDim: double.parse(map['OutRoiFractalDim'].toString()),
			outMaxDensity: double.parse(map['OutMaxDensity'].toString()),
			outMinDensity: double.parse(map['OutMinDensity'].toString()),
			outMeanDensity: double.parse(map['OutMeanDensity'].toString()),
			outVarianceDensity: double.parse(map['OutVarianceDensity'].toString()),
			outRoiArea: double.parse(map['OutRoiArea'].toString()),
			inRoiDen: double.parse(map['InRoiDen'].toString()),
			inRoiFractalDim: double.parse(map['InRoiFractalDim'].toString()),
			inMaxDensity: double.parse(map['InMaxDensity'].toString()),
			inMinDensity: double.parse(map['InMinDensity'].toString()),
			inMeanDensity: double.parse(map['InMeanDensity'].toString()),
			inVarianceDensity: double.parse(map['InVarianceDensity'].toString()),
			inRoiArea: double.parse(map['InRoiArea'].toString()),
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		map['RoiDen'] = roiDen;
		map['RoiFractalDim'] = roiFractalDim;
		map['MaxDensity'] = maxDensity;
		map['MinDensity'] = minDensity;
		map['MeanDensity'] = meanDensity;
		map['VarianceDensity'] = varianceDensity;
		map['RoiArea'] = roiArea;
		map['OutRoiDen'] = outRoiDen;
		map['OutRoiFractalDim'] = outRoiFractalDim;
		map['OutMaxDensity'] = outMaxDensity;
		map['OutMinDensity'] = outMinDensity;
		map['OutMeanDensity'] = outMeanDensity;
		map['OutVarianceDensity'] = outVarianceDensity;
		map['OutRoiArea'] = outRoiArea;
		map['InRoiDen'] = inRoiDen;
		map['InRoiFractalDim'] = inRoiFractalDim;
		map['InMaxDensity'] = inMaxDensity;
		map['InMinDensity'] = inMinDensity;
		map['InMeanDensity'] = inMeanDensity;
		map['InVarianceDensity'] = inVarianceDensity;
		map['InRoiArea'] = inRoiArea;
		return map;
	}
}

class URMVelMeasureResult {
	double maxVel;
	double minVel;
	double meanVel;
	double varianceVel;
	double roiArea;
	double outMaxVel;
	double outMinVel;
	double outMeanVel;
	double outVarianceVel;
	double outRoiArea;
	double inMaxVel;
	double inMinVel;
	double inMeanVel;
	double inVarianceVel;
	double inRoiArea;

	URMVelMeasureResult({
		this.maxVel = 0,
		this.minVel = 0,
		this.meanVel = 0,
		this.varianceVel = 0,
		this.roiArea = 0,
		this.outMaxVel = 0,
		this.outMinVel = 0,
		this.outMeanVel = 0,
		this.outVarianceVel = 0,
		this.outRoiArea = 0,
		this.inMaxVel = 0,
		this.inMinVel = 0,
		this.inMeanVel = 0,
		this.inVarianceVel = 0,
		this.inRoiArea = 0,
	});

	factory URMVelMeasureResult.fromJson(Map<String, dynamic> map) {
		return URMVelMeasureResult( 
			maxVel: double.parse(map['MaxVel'].toString()),
			minVel: double.parse(map['MinVel'].toString()),
			meanVel: double.parse(map['MeanVel'].toString()),
			varianceVel: double.parse(map['VarianceVel'].toString()),
			roiArea: double.parse(map['RoiArea'].toString()),
			outMaxVel: double.parse(map['OutMaxVel'].toString()),
			outMinVel: double.parse(map['OutMinVel'].toString()),
			outMeanVel: double.parse(map['OutMeanVel'].toString()),
			outVarianceVel: double.parse(map['OutVarianceVel'].toString()),
			outRoiArea: double.parse(map['OutRoiArea'].toString()),
			inMaxVel: double.parse(map['InMaxVel'].toString()),
			inMinVel: double.parse(map['InMinVel'].toString()),
			inMeanVel: double.parse(map['InMeanVel'].toString()),
			inVarianceVel: double.parse(map['InVarianceVel'].toString()),
			inRoiArea: double.parse(map['InRoiArea'].toString()),
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		map['MaxVel'] = maxVel;
		map['MinVel'] = minVel;
		map['MeanVel'] = meanVel;
		map['VarianceVel'] = varianceVel;
		map['RoiArea'] = roiArea;
		map['OutMaxVel'] = outMaxVel;
		map['OutMinVel'] = outMinVel;
		map['OutMeanVel'] = outMeanVel;
		map['OutVarianceVel'] = outVarianceVel;
		map['OutRoiArea'] = outRoiArea;
		map['InMaxVel'] = inMaxVel;
		map['InMinVel'] = inMinVel;
		map['InMeanVel'] = inMeanVel;
		map['InVarianceVel'] = inVarianceVel;
		map['InRoiArea'] = inRoiArea;
		return map;
	}
}

class URMVessMeasureResult {
	double maxVessDistance;
	double minVessDistance;
	double meanVessDistacne;
	double varianceVessDistance;
	double maxVessDiameter;
	double minVessDiameter;
	double meanVessDiameter;
	double varianceVessDiameter;
	int maxPos;
	int minPos;
	int vesselCount;

	URMVessMeasureResult({
		this.maxVessDistance = 0,
		this.minVessDistance = 0,
		this.meanVessDistacne = 0,
		this.varianceVessDistance = 0,
		this.maxVessDiameter = 0,
		this.minVessDiameter = 0,
		this.meanVessDiameter = 0,
		this.varianceVessDiameter = 0,
		this.maxPos = 0,
		this.minPos = 0,
		this.vesselCount = 0,
	});

	factory URMVessMeasureResult.fromJson(Map<String, dynamic> map) {
		return URMVessMeasureResult( 
			maxVessDistance: double.parse(map['MaxVessDistance'].toString()),
			minVessDistance: double.parse(map['MinVessDistance'].toString()),
			meanVessDistacne: double.parse(map['MeanVessDistacne'].toString()),
			varianceVessDistance: double.parse(map['VarianceVessDistance'].toString()),
			maxVessDiameter: double.parse(map['MaxVessDiameter'].toString()),
			minVessDiameter: double.parse(map['MinVessDiameter'].toString()),
			meanVessDiameter: double.parse(map['MeanVessDiameter'].toString()),
			varianceVessDiameter: double.parse(map['VarianceVessDiameter'].toString()),
			maxPos: map['MaxPos'],
			minPos: map['MinPos'],
			vesselCount: map['vesselCount'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		map['MaxVessDistance'] = maxVessDistance;
		map['MinVessDistance'] = minVessDistance;
		map['MeanVessDistacne'] = meanVessDistacne;
		map['VarianceVessDistance'] = varianceVessDistance;
		map['MaxVessDiameter'] = maxVessDiameter;
		map['MinVessDiameter'] = minVessDiameter;
		map['MeanVessDiameter'] = meanVessDiameter;
		map['VarianceVessDiameter'] = varianceVessDiameter;
		map['MaxPos'] = maxPos;
		map['MinPos'] = minPos;
		map['vesselCount'] = vesselCount;
		return map;
	}
}

class DSize {
	double width;
	double height;

	DSize({
		this.width = 0,
		this.height = 0,
	});

	factory DSize.fromJson(Map<String, dynamic> map) {
		return DSize( 
			width: double.parse(map['Width'].toString()),
			height: double.parse(map['Height'].toString()),
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		map['Width'] = width;
		map['Height'] = height;
		return map;
	}
}

class DRect {
	double x;
	double y;
	double width;
	double height;
	double left;
	double top;
	double right;
	double bottom;
	UrmPoint? location;
	UrmPoint? topLeft;
	UrmPoint? topRight;
	UrmPoint? bottomLeft;
	UrmPoint? bottomRight;
	DSize? size;

	DRect({
		this.x = 0,
		this.y = 0,
		this.width = 0,
		this.height = 0,
		this.left = 0,
		this.top = 0,
		this.right = 0,
		this.bottom = 0,
		this.location,
		this.topLeft,
		this.topRight,
		this.bottomLeft,
		this.bottomRight,
		this.size,
	});

	factory DRect.fromJson(Map<String, dynamic> map) {
		return DRect( 
			x: double.parse(map['X'].toString()),
			y: double.parse(map['Y'].toString()),
			width: double.parse(map['Width'].toString()),
			height: double.parse(map['Height'].toString()),
			left: double.parse(map['Left'].toString()),
			top: double.parse(map['Top'].toString()),
			right: double.parse(map['Right'].toString()),
			bottom: double.parse(map['Bottom'].toString()),
			location: map['Location'] != null ? UrmPoint.fromJson(map['Location']) : null,
			topLeft: map['TopLeft'] != null ? UrmPoint.fromJson(map['TopLeft']) : null,
			topRight: map['TopRight'] != null ? UrmPoint.fromJson(map['TopRight']) : null,
			bottomLeft: map['BottomLeft'] != null ? UrmPoint.fromJson(map['BottomLeft']) : null,
			bottomRight: map['BottomRight'] != null ? UrmPoint.fromJson(map['BottomRight']) : null,
			size: map['Size'] != null ? DSize.fromJson(map['Size']) : null,
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		map['X'] = x;
		map['Y'] = y;
		map['Width'] = width;
		map['Height'] = height;
		map['Left'] = left;
		map['Top'] = top;
		map['Right'] = right;
		map['Bottom'] = bottom;
		if (location != null)
			map['Location'] = location;
		if (topLeft != null)
			map['TopLeft'] = topLeft;
		if (topRight != null)
			map['TopRight'] = topRight;
		if (bottomLeft != null)
			map['BottomLeft'] = bottomLeft;
		if (bottomRight != null)
			map['BottomRight'] = bottomRight;
		if (size != null)
			map['Size'] = size;
		return map;
	}
}

class IntRect {
	int x;
	int y;
	int width;
	int height;
	int left;
	int top;
	int right;
	int bottom;

	IntRect({
		this.x = 0,
		this.y = 0,
		this.width = 0,
		this.height = 0,
		this.left = 0,
		this.top = 0,
		this.right = 0,
		this.bottom = 0,
	});

	factory IntRect.fromJson(Map<String, dynamic> map) {
		return IntRect( 
			x: map['X'],
			y: map['Y'],
			width: map['Width'],
			height: map['Height'],
			left: map['Left'],
			top: map['Top'],
			right: map['Right'],
			bottom: map['Bottom'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		map['X'] = x;
		map['Y'] = y;
		map['Width'] = width;
		map['Height'] = height;
		map['Left'] = left;
		map['Top'] = top;
		map['Right'] = right;
		map['Bottom'] = bottom;
		return map;
	}
}

class URMMeasureProcessResult {
	bool resultFlag;
	double resultData;
	List<UrmPoint>? resultDPoints;
	URMDenMeasureResult? denMeasureResult;
	URMVelMeasureResult? velMeasureResult;
	URMVessMeasureResult? vessMeasureResult;
	List<UrmPoint>? outerExterPoints;
	DRect? perfusionScaleDRect;
	IntRect? perfusionPiexlRect;
	String? perfusionImgBase64;
	double urmMinVal;
	double urmMaxVal;

	URMMeasureProcessResult({
		this.resultFlag = false,
		this.resultData = 0,
		this.resultDPoints,
		this.denMeasureResult,
		this.velMeasureResult,
		this.vessMeasureResult,
		this.outerExterPoints,
		this.perfusionScaleDRect,
		this.perfusionPiexlRect,
		this.perfusionImgBase64,
		this.urmMinVal = 0,
		this.urmMaxVal = 0,
	});

	factory URMMeasureProcessResult.fromJson(Map<String, dynamic> map) {
		return URMMeasureProcessResult( 
			resultFlag: map['ResultFlag'],
			resultData: double.parse(map['ResultData'].toString()),
			resultDPoints: map['ResultDPoints'] != null ? (map['ResultDPoints'] as List).map((e)=>UrmPoint.fromJson(e as Map<String,dynamic>)).toList() : null,
			denMeasureResult: map['DenMeasureResult'] != null ? URMDenMeasureResult.fromJson(map['DenMeasureResult']) : null,
			velMeasureResult: map['VelMeasureResult'] != null ? URMVelMeasureResult.fromJson(map['VelMeasureResult']) : null,
			vessMeasureResult: map['VessMeasureResult'] != null ? URMVessMeasureResult.fromJson(map['VessMeasureResult']) : null,
			outerExterPoints: map['OuterExterPoints'] != null ? (map['OuterExterPoints'] as List).map((e)=>UrmPoint.fromJson(e as Map<String,dynamic>)).toList() : null,
			perfusionScaleDRect: map['PerfusionScaleDRect'] != null ? DRect.fromJson(map['PerfusionScaleDRect']) : null,
			perfusionPiexlRect: map['PerfusionPiexlRect'] != null ? IntRect.fromJson(map['PerfusionPiexlRect']) : null,
			perfusionImgBase64: map['PerfusionImgBase64'],
			urmMinVal: double.parse(map['UrmMinVal'].toString()),
			urmMaxVal: double.parse(map['UrmMaxVal'].toString()),
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		map['ResultFlag'] = resultFlag;
		map['ResultData'] = resultData;
		if (resultDPoints != null)
			map['ResultDPoints'] = resultDPoints;
		if (denMeasureResult != null)
			map['DenMeasureResult'] = denMeasureResult;
		if (velMeasureResult != null)
			map['VelMeasureResult'] = velMeasureResult;
		if (vessMeasureResult != null)
			map['VessMeasureResult'] = vessMeasureResult;
		if (outerExterPoints != null)
			map['OuterExterPoints'] = outerExterPoints;
		if (perfusionScaleDRect != null)
			map['PerfusionScaleDRect'] = perfusionScaleDRect;
		if (perfusionPiexlRect != null)
			map['PerfusionPiexlRect'] = perfusionPiexlRect;
		if (perfusionImgBase64 != null)
			map['PerfusionImgBase64'] = perfusionImgBase64;
		map['UrmMinVal'] = urmMinVal;
		map['UrmMaxVal'] = urmMaxVal;
		return map;
	}
}

class URMGenerateVideoResult {
	String? videoUrl;
	int videoSize;
	String? coverImgUrl;

	URMGenerateVideoResult({
		this.videoUrl,
		this.videoSize = 0,
		this.coverImgUrl,
	});

	factory URMGenerateVideoResult.fromJson(Map<String, dynamic> map) {
		return URMGenerateVideoResult( 
			videoUrl: map['VideoUrl'],
			videoSize: map['VideoSize'],
			coverImgUrl: map['CoverImgUrl'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		if (videoUrl != null)
			map['VideoUrl'] = videoUrl;
		map['VideoSize'] = videoSize;
		if (coverImgUrl != null)
			map['CoverImgUrl'] = coverImgUrl;
		return map;
	}
}

class URMGenerateVideoRequest extends URMVideoProcessRequest{
	String? backgroundImage;
	double roiXPercent;
	double roiYPercent;
	double roiWPercent;
	double roiHPercent;
	double leftImgTopLeftCornerXPercent;
	double leftImgTopLeftCornerYPercent;
	double rightImgTopLeftCornerXPercent;
	double rightImgTopLeftCornerYPercent;
	double colorBarXPercent;
	double colorBarYPercent;

	URMGenerateVideoRequest({
		this.backgroundImage,
		this.roiXPercent = 0,
		this.roiYPercent = 0,
		this.roiWPercent = 0,
		this.roiHPercent = 0,
		this.leftImgTopLeftCornerXPercent = 0,
		this.leftImgTopLeftCornerYPercent = 0,
		this.rightImgTopLeftCornerXPercent = 0,
		this.rightImgTopLeftCornerYPercent = 0,
		this.colorBarXPercent = 0,
		this.colorBarYPercent = 0,
		String? notifyUserCode,
		int videoFrame = 0,
		double uRMVideoScaler = 0,
		double uRMVideoParameter = 0,
		double uRMVideoType = 0,
		String? token,
		String? remedicalCode,
		List<UrmPoint>? urmTraceDPoints,
		String? urmImageType,
		int urmBlend = 0,
		double downsampleIndex = 0,
		double intPowerDen = 0,
		double intPowerDir = 0,
		double sigmaGauss = 0,
		double vessScale = 0,
		double velMaxScaler = 0,
		double velMinScaler = 0,
		double iterations = 0,
		int imgProcessVer = 0,
		bool zoomOn = false,
		double zoomRoix = 0,
		double zoomRoiy = 0,
		double zoomRoiwidth = 0,
		double zoomRoiheight = 0,
		int roix = 0,
		int roiy = 0,
		int roiwidth = 0,
		int roiheight = 0,
		bool leftRight = false,
		bool upDown = false,
		int screenWidth = 0,
		int screenHeight = 0,
	}) : super(
			notifyUserCode: notifyUserCode,
			videoFrame: videoFrame,
			uRMVideoScaler: uRMVideoScaler,
			uRMVideoParameter: uRMVideoParameter,
			uRMVideoType: uRMVideoType,
			token: token,
			remedicalCode: remedicalCode,
			urmTraceDPoints: urmTraceDPoints,
			urmImageType: urmImageType,
			urmBlend: urmBlend,
			downsampleIndex: downsampleIndex,
			intPowerDen: intPowerDen,
			intPowerDir: intPowerDir,
			sigmaGauss: sigmaGauss,
			vessScale: vessScale,
			velMaxScaler: velMaxScaler,
			velMinScaler: velMinScaler,
			iterations: iterations,
			imgProcessVer: imgProcessVer,
			zoomOn: zoomOn,
			zoomRoix: zoomRoix,
			zoomRoiy: zoomRoiy,
			zoomRoiwidth: zoomRoiwidth,
			zoomRoiheight: zoomRoiheight,
			roix: roix,
			roiy: roiy,
			roiwidth: roiwidth,
			roiheight: roiheight,
			leftRight: leftRight,
			upDown: upDown,
			screenWidth: screenWidth,
			screenHeight: screenHeight,
		);

	factory URMGenerateVideoRequest.fromJson(Map<String, dynamic> map) {
		final urmTraceDPointsData = map['UrmTraceDPoints'];
		return URMGenerateVideoRequest( 
			backgroundImage: map['BackgroundImage'],
			roiXPercent: double.parse(map['RoiXPercent'].toString()),
			roiYPercent: double.parse(map['RoiYPercent'].toString()),
			roiWPercent: double.parse(map['RoiWPercent'].toString()),
			roiHPercent: double.parse(map['RoiHPercent'].toString()),
			leftImgTopLeftCornerXPercent: double.parse(map['LeftImgTopLeftCornerXPercent'].toString()),
			leftImgTopLeftCornerYPercent: double.parse(map['LeftImgTopLeftCornerYPercent'].toString()),
			rightImgTopLeftCornerXPercent: double.parse(map['RightImgTopLeftCornerXPercent'].toString()),
			rightImgTopLeftCornerYPercent: double.parse(map['RightImgTopLeftCornerYPercent'].toString()),
			colorBarXPercent: double.parse(map['ColorBarXPercent'].toString()),
			colorBarYPercent: double.parse(map['ColorBarYPercent'].toString()),
			notifyUserCode: map['NotifyUserCode'],
			videoFrame: map['VideoFrame'],
			uRMVideoScaler: double.parse(map['URMVideoScaler'].toString()),
			uRMVideoParameter: double.parse(map['URMVideoParameter'].toString()),
			uRMVideoType: double.parse(map['URMVideoType'].toString()),
			token: map['Token'],
			remedicalCode: map['RemedicalCode'],
			urmTraceDPoints: urmTraceDPointsData != null ? (urmTraceDPointsData as List).map((e) => UrmPoint.fromJson(e)).toList(): null,
			urmImageType: map['UrmImageType'],
			urmBlend: map['UrmBlend'],
			downsampleIndex: double.parse(map['DownsampleIndex'].toString()),
			intPowerDen: double.parse(map['IntPowerDen'].toString()),
			intPowerDir: double.parse(map['IntPowerDir'].toString()),
			sigmaGauss: double.parse(map['SigmaGauss'].toString()),
			vessScale: double.parse(map['VessScale'].toString()),
			velMaxScaler: double.parse(map['VelMaxScaler'].toString()),
			velMinScaler: double.parse(map['VelMinScaler'].toString()),
			iterations: double.parse(map['Iterations'].toString()),
			imgProcessVer: map['ImgProcessVer'],
			zoomOn: map['ZoomOn'],
			zoomRoix: double.parse(map['ZoomRoix'].toString()),
			zoomRoiy: double.parse(map['ZoomRoiy'].toString()),
			zoomRoiwidth: double.parse(map['ZoomRoiwidth'].toString()),
			zoomRoiheight: double.parse(map['ZoomRoiheight'].toString()),
			roix: map['Roix'],
			roiy: map['Roiy'],
			roiwidth: map['Roiwidth'],
			roiheight: map['Roiheight'],
			leftRight: map['LeftRight'],
			upDown: map['UpDown'],
			screenWidth: map['ScreenWidth'],
			screenHeight: map['ScreenHeight'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (backgroundImage != null)
			map['BackgroundImage'] = backgroundImage;
		map['RoiXPercent'] = roiXPercent;
		map['RoiYPercent'] = roiYPercent;
		map['RoiWPercent'] = roiWPercent;
		map['RoiHPercent'] = roiHPercent;
		map['LeftImgTopLeftCornerXPercent'] = leftImgTopLeftCornerXPercent;
		map['LeftImgTopLeftCornerYPercent'] = leftImgTopLeftCornerYPercent;
		map['RightImgTopLeftCornerXPercent'] = rightImgTopLeftCornerXPercent;
		map['RightImgTopLeftCornerYPercent'] = rightImgTopLeftCornerYPercent;
		map['ColorBarXPercent'] = colorBarXPercent;
		map['ColorBarYPercent'] = colorBarYPercent;
		return map;
	}
}

class PWTracePointDTO {
	int x;
	int y;

	PWTracePointDTO({
		this.x = 0,
		this.y = 0,
	});

	factory PWTracePointDTO.fromJson(Map<String, dynamic> map) {
		return PWTracePointDTO( 
			x: map['X'],
			y: map['Y'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		map['X'] = x;
		map['Y'] = y;
		return map;
	}
}

class PWTraceCycleDTO {
	int cycleStart;
	int cycleEnd;
	int epeak;
	int apeak;

	PWTraceCycleDTO({
		this.cycleStart = 0,
		this.cycleEnd = 0,
		this.epeak = 0,
		this.apeak = 0,
	});

	factory PWTraceCycleDTO.fromJson(Map<String, dynamic> map) {
		return PWTraceCycleDTO( 
			cycleStart: map['CycleStart'],
			cycleEnd: map['CycleEnd'],
			epeak: map['Epeak'],
			apeak: map['Apeak'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		map['CycleStart'] = cycleStart;
		map['CycleEnd'] = cycleEnd;
		map['Epeak'] = epeak;
		map['Apeak'] = apeak;
		return map;
	}
}

class PWTraceBestCycleIndexDTO {
	int bestStart;
	int bestEnd;

	PWTraceBestCycleIndexDTO({
		this.bestStart = 0,
		this.bestEnd = 0,
	});

	factory PWTraceBestCycleIndexDTO.fromJson(Map<String, dynamic> map) {
		return PWTraceBestCycleIndexDTO( 
			bestStart: map['BestStart'],
			bestEnd: map['BestEnd'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		map['BestStart'] = bestStart;
		map['BestEnd'] = bestEnd;
		return map;
	}
}

class PWTraceBestCycleDTO {
	PWTraceBestCycleIndexDTO? oneBestCycle;
	PWTraceBestCycleIndexDTO? twoBestCycle;
	PWTraceBestCycleIndexDTO? threeBestCycle;
	PWTraceBestCycleIndexDTO? fourBestCycle;
	PWTraceBestCycleIndexDTO? fiveBestCycle;

	PWTraceBestCycleDTO({
		this.oneBestCycle,
		this.twoBestCycle,
		this.threeBestCycle,
		this.fourBestCycle,
		this.fiveBestCycle,
	});

	factory PWTraceBestCycleDTO.fromJson(Map<String, dynamic> map) {
		return PWTraceBestCycleDTO( 
			oneBestCycle: map['OneBestCycle'] != null ? PWTraceBestCycleIndexDTO.fromJson(map['OneBestCycle']) : null,
			twoBestCycle: map['TwoBestCycle'] != null ? PWTraceBestCycleIndexDTO.fromJson(map['TwoBestCycle']) : null,
			threeBestCycle: map['ThreeBestCycle'] != null ? PWTraceBestCycleIndexDTO.fromJson(map['ThreeBestCycle']) : null,
			fourBestCycle: map['FourBestCycle'] != null ? PWTraceBestCycleIndexDTO.fromJson(map['FourBestCycle']) : null,
			fiveBestCycle: map['FiveBestCycle'] != null ? PWTraceBestCycleIndexDTO.fromJson(map['FiveBestCycle']) : null,
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		if (oneBestCycle != null)
			map['OneBestCycle'] = oneBestCycle;
		if (twoBestCycle != null)
			map['TwoBestCycle'] = twoBestCycle;
		if (threeBestCycle != null)
			map['ThreeBestCycle'] = threeBestCycle;
		if (fourBestCycle != null)
			map['FourBestCycle'] = fourBestCycle;
		if (fiveBestCycle != null)
			map['FiveBestCycle'] = fiveBestCycle;
		return map;
	}
}

class PWTraceDTO {
	bool enableCalCycle;
	List<PWTracePointDTO>? contour;
	List<PWTraceCycleDTO>? cycleInfos;
	PWTraceBestCycleDTO? bestCycles;

	PWTraceDTO({
		this.enableCalCycle = false,
		this.contour,
		this.cycleInfos,
		this.bestCycles,
	});

	factory PWTraceDTO.fromJson(Map<String, dynamic> map) {
		return PWTraceDTO( 
			enableCalCycle: map['EnableCalCycle'],
			contour: map['Contour'] != null ? (map['Contour'] as List).map((e)=>PWTracePointDTO.fromJson(e as Map<String,dynamic>)).toList() : null,
			cycleInfos: map['CycleInfos'] != null ? (map['CycleInfos'] as List).map((e)=>PWTraceCycleDTO.fromJson(e as Map<String,dynamic>)).toList() : null,
			bestCycles: map['BestCycles'] != null ? PWTraceBestCycleDTO.fromJson(map['BestCycles']) : null,
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		map['EnableCalCycle'] = enableCalCycle;
		if (contour != null)
			map['Contour'] = contour;
		if (cycleInfos != null)
			map['CycleInfos'] = cycleInfos;
		if (bestCycles != null)
			map['BestCycles'] = bestCycles;
		return map;
	}
}

class VetAutoTraceImageResult {
	Map<String,PWTraceDTO>? pWTraceInfos;

	VetAutoTraceImageResult({
		this.pWTraceInfos,
	});

	factory VetAutoTraceImageResult.fromJson(Map<String, dynamic> map) {
		return VetAutoTraceImageResult( 
			pWTraceInfos: map['PWTraceInfos'] != null ? map['PWTraceInfos'] as Map<String,PWTraceDTO> : null,
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		if (pWTraceInfos != null)
			map['PWTraceInfos'] = pWTraceInfos;
		return map;
	}
}

class VetAutoTraceImageDTO {
	List<int>? data;
	String? imageBase64String;
	int width;
	int height;
	int sKColorType;

	VetAutoTraceImageDTO({
		this.data,
		this.imageBase64String,
		this.width = 0,
		this.height = 0,
		this.sKColorType = 0,
	});

	factory VetAutoTraceImageDTO.fromJson(Map<String, dynamic> map) {
		final dataData = map['Data'];
		return VetAutoTraceImageDTO( 
			data: dataData != null ? (dataData as List).map((e) => e as int).toList(): null,
			imageBase64String: map['ImageBase64String'],
			width: map['Width'],
			height: map['Height'],
			sKColorType: map['SKColorType'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		if (data != null)
			map['Data'] = data;
		if (imageBase64String != null)
			map['ImageBase64String'] = imageBase64String;
		map['Width'] = width;
		map['Height'] = height;
		map['SKColorType'] = sKColorType;
		return map;
	}
}

class VetAutoTraceRectDTO {
	int top;
	int bottom;
	int left;
	int right;
	int width;
	int height;

	VetAutoTraceRectDTO({
		this.top = 0,
		this.bottom = 0,
		this.left = 0,
		this.right = 0,
		this.width = 0,
		this.height = 0,
	});

	factory VetAutoTraceRectDTO.fromJson(Map<String, dynamic> map) {
		return VetAutoTraceRectDTO( 
			top: map['Top'],
			bottom: map['Bottom'],
			left: map['Left'],
			right: map['Right'],
			width: map['Width'],
			height: map['Height'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		map['Top'] = top;
		map['Bottom'] = bottom;
		map['Left'] = left;
		map['Right'] = right;
		map['Width'] = width;
		map['Height'] = height;
		return map;
	}
}

class VetAutoTraceImageRequest extends TokenRequest{
	VetAutoTraceImageDTO? imageInfo;
	VetAutoTraceRectDTO? rectInfo;

	VetAutoTraceImageRequest({
		this.imageInfo,
		this.rectInfo,
		String? token,
	}) : super(
			token: token,
		);

	factory VetAutoTraceImageRequest.fromJson(Map<String, dynamic> map) {
		return VetAutoTraceImageRequest( 
			imageInfo: map['ImageInfo'] != null ? VetAutoTraceImageDTO.fromJson(map['ImageInfo']) : null,
			rectInfo: map['RectInfo'] != null ? VetAutoTraceRectDTO.fromJson(map['RectInfo']) : null,
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (imageInfo != null)
			map['ImageInfo'] = imageInfo;
		if (rectInfo != null)
			map['RectInfo'] = rectInfo;
		return map;
	}
}

class VidImageZoomResult {
	String? base64String;

	VidImageZoomResult({
		this.base64String,
	});

	factory VidImageZoomResult.fromJson(Map<String, dynamic> map) {
		return VidImageZoomResult( 
			base64String: map['Base64String'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		if (base64String != null)
			map['Base64String'] = base64String;
		return map;
	}
}

class ImageRect {
	double left;
	double top;
	double width;
	double height;

	ImageRect({
		this.left = 0,
		this.top = 0,
		this.width = 0,
		this.height = 0,
	});

	factory ImageRect.fromJson(Map<String, dynamic> map) {
		return ImageRect( 
			left: double.parse(map['Left'].toString()),
			top: double.parse(map['Top'].toString()),
			width: double.parse(map['Width'].toString()),
			height: double.parse(map['Height'].toString()),
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		map['Left'] = left;
		map['Top'] = top;
		map['Width'] = width;
		map['Height'] = height;
		return map;
	}
}

class VidImageZoomRequest extends TokenRequest{
	String? fileToken;
	String? remedicalCode;
	int frameIndex;
	List<ImageRect>? imageRegion;
	ImageRect? sampleBox;
	int resizeType;

	VidImageZoomRequest({
		this.fileToken,
		this.remedicalCode,
		this.frameIndex = 0,
		this.imageRegion,
		this.sampleBox,
		this.resizeType = 0,
		String? token,
	}) : super(
			token: token,
		);

	factory VidImageZoomRequest.fromJson(Map<String, dynamic> map) {
		return VidImageZoomRequest( 
			fileToken: map['FileToken'],
			remedicalCode: map['RemedicalCode'],
			frameIndex: map['FrameIndex'],
			imageRegion: map['ImageRegion'] != null ? (map['ImageRegion'] as List).map((e)=>ImageRect.fromJson(e as Map<String,dynamic>)).toList() : null,
			sampleBox: map['SampleBox'] != null ? ImageRect.fromJson(map['SampleBox']) : null,
			resizeType: map['ResizeType'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (fileToken != null)
			map['FileToken'] = fileToken;
		if (remedicalCode != null)
			map['RemedicalCode'] = remedicalCode;
		map['FrameIndex'] = frameIndex;
		if (imageRegion != null)
			map['ImageRegion'] = imageRegion;
		if (sampleBox != null)
			map['SampleBox'] = sampleBox;
		map['ResizeType'] = resizeType;
		return map;
	}
}


