import 'dart:core';

import 'package:fis_jsonrpc/client_base.dart';
import 'package:fis_common/json_convert.dart';

import 'deployPlatform.m.dart';


class DeployPlatformService extends JsonRpcClientBase {
	DeployPlatformService(
		String host, {
		String serviceName = "IDeployPlatformService",
		Map<String, String>? headers,
		int? timeout,
	}) : super(
						host,
						serviceName,
						headers: headers,
						timeout: timeout,
				) {
		/// 注册响应实体反序列化处理器
		FJsonConvert.setDecoder((map) => DeployPlatServerInfoDTO.fromJson(map));
		FJsonConvert.setDecoder((map) => DeployPlatOperatorDTO.fromJson(map));
		FJsonConvert.setDecoder((map) => DeployRecordInfoDTO.fromJson(map));
	}

	Future<List<DeployPlatServerInfoDTO>> getServerListAsync() async {
		var rpcRst = await call("GetServerListAsync", );
		var result = (rpcRst as List).map((e)=>DeployPlatServerInfoDTO.fromJson(e as Map<String, dynamic>)).toList();
		return result;
	}

	Future<bool> addServerAsync(AddServerRequest request) async {
		var rpcRst = await call("AddServerAsync", request);
		return rpcRst;
	}

	Future<bool> updateServerAsync(UpdateServerRequest request) async {
		var rpcRst = await call("UpdateServerAsync", request);
		return rpcRst;
	}

	Future<bool> saveLogsAsync(SaveLogsRequest request) async {
		var rpcRst = await call("SaveLogsAsync", request);
		return rpcRst;
	}

	Future<DeployPlatServerInfoDTO> getServerAsync(GetServerRequest request) async {
		var rpcRst = await call("GetServerAsync", request);
		var result = DeployPlatServerInfoDTO.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<List<String>> getUploadLogsAsync(GetServerRequest request) async {
		var rpcRst = await call("GetUploadLogsAsync", request);
		var result = (rpcRst as List).cast<String>().toList();
		return result;
	}

	Future<List<DeployPlatOperatorDTO>> getOperatorListAsync() async {
		var rpcRst = await call("GetOperatorListAsync", );
		var result = (rpcRst as List).map((e)=>DeployPlatOperatorDTO.fromJson(e as Map<String, dynamic>)).toList();
		return result;
	}

	Future<List<DeployRecordInfoDTO>> getRecordListAsync(GetDeployRecordRequest request) async {
		var rpcRst = await call("GetRecordListAsync", request);
		var result = (rpcRst as List).map((e)=>DeployRecordInfoDTO.fromJson(e as Map<String, dynamic>)).toList();
		return result;
	}

	Future<bool> saveRecordAsync(SaveDeployRecordRequest request) async {
		var rpcRst = await call("SaveRecordAsync", request);
		return rpcRst;
	}

	Future<bool> removeRecordAsync(RemoveDeployRecordRequest request) async {
		var rpcRst = await call("RemoveRecordAsync", request);
		return rpcRst;
	}

	Future<bool> addOperatorAsync(AddDeployPlatOperatorRequest request) async {
		var rpcRst = await call("AddOperatorAsync", request);
		return rpcRst;
	}

	Future<bool> modifyperatorAsync(ModifyDeployPlatOperatorRequest request) async {
		var rpcRst = await call("ModifyperatorAsync", request);
		return rpcRst;
	}

	Future<bool> deleteOperatorAsync(DeleteDeployPlatOperatorRequest request) async {
		var rpcRst = await call("DeleteOperatorAsync", request);
		return rpcRst;
	}

	Future<DeployPlatLoginResultEnum> loginAsync(OperatorLoginRequest request) async {
		var rpcRst = await call("LoginAsync", request);
		var result = DeployPlatLoginResultEnum.values.firstWhere((e) => e.index == rpcRst);
		return result;
	}

	Future<List<String>> findTextWithUrlAndPrefixAsync(FindTextWithUrlAndPrefixRequest request) async {
		var rpcRst = await call("FindTextWithUrlAndPrefixAsync", request);
		var result = (rpcRst as List).cast<String>().toList();
		return result;
	}

	Future<bool> generatePackageAsync(GeneratePackageRequest request) async {
		var rpcRst = await call("GeneratePackageAsync", request);
		return rpcRst;
	}

	Future<bool> uploadTotargetServerAsync(UploadTotargetServerRequest request) async {
		var rpcRst = await call("UploadTotargetServerAsync", request);
		return rpcRst;
	}

	Future<List<String>> getRecordUploadLogsAsync(GetPackageRequest request) async {
		var rpcRst = await call("GetRecordUploadLogsAsync", request);
		var result = (rpcRst as List).cast<String>().toList();
		return result;
	}

	Future<bool> uploadForRecordAsync(GetPackageRequest getPackageRequest) async {
		var rpcRst = await call("UploadForRecordAsync", getPackageRequest);
		return rpcRst;
	}

	Future<List<String>> getPackageLogsAsync() async {
		var rpcRst = await call("GetPackageLogsAsync", );
		var result = (rpcRst as List).cast<String>().toList();
		return result;
	}

	Future<DeployRecordInfoDTO> getPackageAsync(GetPackageRequest request) async {
		var rpcRst = await call("GetPackageAsync", request);
		var result = DeployRecordInfoDTO.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<bool> cancelPackagingAsync(CancelPackagingRequest request) async {
		var rpcRst = await call("CancelPackagingAsync", request);
		return rpcRst;
	}

	Future<bool> check() async {
		var rpcRst = await call("Check", );
		return rpcRst;
	}

	Future<bool> getIsPublishing() async {
		var rpcRst = await call("GetIsPublishing", );
		return rpcRst;
	}

	Future<String> readAppSettingsJsonAsync(ReadAppSettingsJsonRequest request) async {
		var rpcRst = await call("ReadAppSettingsJsonAsync", request);
		return rpcRst;
	}

	Future<bool> modifyAppSettingsJsonAsync(ModifyAppSettingsJsonRequest request) async {
		var rpcRst = await call("ModifyAppSettingsJsonAsync", request);
		return rpcRst;
	}

	Future<bool> deployAsync(DeployRequest request) async {
		var rpcRst = await call("DeployAsync", request);
		return rpcRst;
	}

	Future<bool> deployWaitStartAsync(DeployRequest request) async {
		var rpcRst = await call("DeployWaitStartAsync", request);
		return rpcRst;
	}

	Future<bool> start() async {
		var rpcRst = await call("Start", );
		return rpcRst;
	}

	Future<bool> stopServer() async {
		var rpcRst = await call("StopServer", );
		return rpcRst;
	}

	Future<List<String>> getPublishPackageLogsAsync() async {
		var rpcRst = await call("GetPublishPackageLogsAsync", );
		var result = (rpcRst as List).cast<String>().toList();
		return result;
	}

	Future<bool> runAutoTestApplication() async {
		var rpcRst = await call("RunAutoTestApplication", );
		return rpcRst;
	}

}

