import 'notification.m.dart';
import 'vitalHealthExamBooking.m.dart';
import 'report.m.dart';
import 'liveConsultation.m.dart';
import 'researchEdition.m.dart';
import 'appletAPI.m.dart';

import 'package:fis_jsonrpc/utils.dart';

class GetRegisterInfoPageRequest extends PageRequest{
	String? keyword;
	DateTime? startTime;
	DateTime? endTime;

	GetRegisterInfoPageRequest({
		this.keyword,
		this.startTime,
		this.endTime,
		int pageIndex = 0,
		int pageSize = 0,
		String? token,
	}) : super(
			pageIndex: pageIndex,
			pageSize: pageSize,
			token: token,
		);

	factory GetRegisterInfoPageRequest.fromJson(Map<String, dynamic> map) {
		return GetRegisterInfoPageRequest( 
			keyword: map['Keyword'],
			startTime: map['StartTime'] != null ? DateTime.parse(map['StartTime']) : null,
			endTime: map['EndTime'] != null ? DateTime.parse(map['EndTime']) : null,
			pageIndex: map['PageIndex'],
			pageSize: map['PageSize'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (keyword != null)
			map['Keyword'] = keyword;
		if (startTime != null)
			map['StartTime'] = JsonRpcUtils.dateFormat(startTime!);
		if (endTime != null)
			map['EndTime'] = JsonRpcUtils.dateFormat(endTime!);
		return map;
	}
}

class GetRegisterInfoByPhysicalExamNumberRequest extends TokenRequest{
	String? physicalExamNumber;

	GetRegisterInfoByPhysicalExamNumberRequest({
		this.physicalExamNumber,
		String? token,
	}) : super(
			token: token,
		);

	factory GetRegisterInfoByPhysicalExamNumberRequest.fromJson(Map<String, dynamic> map) {
		return GetRegisterInfoByPhysicalExamNumberRequest( 
			physicalExamNumber: map['PhysicalExamNumber'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (physicalExamNumber != null)
			map['PhysicalExamNumber'] = physicalExamNumber;
		return map;
	}
}

class HospitalizationHistory {
	String? id;
	DateTime? admission_Date;
	DateTime? discharge_Date;
	String? reason;
	String? name_Of_Medical_Institution;
	String? patient_Number;

	HospitalizationHistory({
		this.id,
		this.admission_Date,
		this.discharge_Date,
		this.reason,
		this.name_Of_Medical_Institution,
		this.patient_Number,
	});

	factory HospitalizationHistory.fromJson(Map<String, dynamic> map) {
		return HospitalizationHistory( 
			id: map['id'],
			admission_Date: map['Admission_Date'] != null ? DateTime.parse(map['Admission_Date']) : null,
			discharge_Date: map['Discharge_Date'] != null ? DateTime.parse(map['Discharge_Date']) : null,
			reason: map['Reason'],
			name_Of_Medical_Institution: map['Name_Of_Medical_Institution'],
			patient_Number: map['Patient_Number'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		if (id != null)
			map['id'] = id;
		if (admission_Date != null)
			map['Admission_Date'] = JsonRpcUtils.dateFormat(admission_Date!);
		if (discharge_Date != null)
			map['Discharge_Date'] = JsonRpcUtils.dateFormat(discharge_Date!);
		if (reason != null)
			map['Reason'] = reason;
		if (name_Of_Medical_Institution != null)
			map['Name_Of_Medical_Institution'] = name_Of_Medical_Institution;
		if (patient_Number != null)
			map['Patient_Number'] = patient_Number;
		return map;
	}
}

class HospitalAtHome {
	String? id;
	DateTime? bed_Construction_Date;
	DateTime? discharge_Date;
	String? reason;
	String? name_Of_Medical_Institution;
	String? patient_Number;

	HospitalAtHome({
		this.id,
		this.bed_Construction_Date,
		this.discharge_Date,
		this.reason,
		this.name_Of_Medical_Institution,
		this.patient_Number,
	});

	factory HospitalAtHome.fromJson(Map<String, dynamic> map) {
		return HospitalAtHome( 
			id: map['id'],
			bed_Construction_Date: map['Bed_Construction_Date'] != null ? DateTime.parse(map['Bed_Construction_Date']) : null,
			discharge_Date: map['Discharge_Date'] != null ? DateTime.parse(map['Discharge_Date']) : null,
			reason: map['Reason'],
			name_Of_Medical_Institution: map['Name_Of_Medical_Institution'],
			patient_Number: map['Patient_Number'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		if (id != null)
			map['id'] = id;
		if (bed_Construction_Date != null)
			map['Bed_Construction_Date'] = JsonRpcUtils.dateFormat(bed_Construction_Date!);
		if (discharge_Date != null)
			map['Discharge_Date'] = JsonRpcUtils.dateFormat(discharge_Date!);
		if (reason != null)
			map['Reason'] = reason;
		if (name_Of_Medical_Institution != null)
			map['Name_Of_Medical_Institution'] = name_Of_Medical_Institution;
		if (patient_Number != null)
			map['Patient_Number'] = patient_Number;
		return map;
	}
}

class DrugUsage {
	String? id;
	String? medicine_Name;
	String? medicine_Usage;
	String? medicine_Dosage;
	String? medicine_Time;
	String? medicine_Compliance;

	DrugUsage({
		this.id,
		this.medicine_Name,
		this.medicine_Usage,
		this.medicine_Dosage,
		this.medicine_Time,
		this.medicine_Compliance,
	});

	factory DrugUsage.fromJson(Map<String, dynamic> map) {
		return DrugUsage( 
			id: map['id'],
			medicine_Name: map['Medicine_Name'],
			medicine_Usage: map['Medicine_Usage'],
			medicine_Dosage: map['Medicine_Dosage'],
			medicine_Time: map['Medicine_Time'],
			medicine_Compliance: map['Medicine_Compliance'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		if (id != null)
			map['id'] = id;
		if (medicine_Name != null)
			map['Medicine_Name'] = medicine_Name;
		if (medicine_Usage != null)
			map['Medicine_Usage'] = medicine_Usage;
		if (medicine_Dosage != null)
			map['Medicine_Dosage'] = medicine_Dosage;
		if (medicine_Time != null)
			map['Medicine_Time'] = medicine_Time;
		if (medicine_Compliance != null)
			map['Medicine_Compliance'] = medicine_Compliance;
		return map;
	}
}

class InoculateHistory {
	String? id;
	DateTime? vaccination_Date;
	String? vaccination_Facility;
	String? vaccine_Name;

	InoculateHistory({
		this.id,
		this.vaccination_Date,
		this.vaccination_Facility,
		this.vaccine_Name,
	});

	factory InoculateHistory.fromJson(Map<String, dynamic> map) {
		return InoculateHistory( 
			id: map['id'],
			vaccination_Date: map['Vaccination_Date'] != null ? DateTime.parse(map['Vaccination_Date']) : null,
			vaccination_Facility: map['Vaccination_Facility'],
			vaccine_Name: map['Vaccine_Name'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		if (id != null)
			map['id'] = id;
		if (vaccination_Date != null)
			map['Vaccination_Date'] = JsonRpcUtils.dateFormat(vaccination_Date!);
		if (vaccination_Facility != null)
			map['Vaccination_Facility'] = vaccination_Facility;
		if (vaccine_Name != null)
			map['Vaccine_Name'] = vaccine_Name;
		return map;
	}
}

class GetExamInfoByPhysicalExamNumberResult {
	String? code;
	DateTime? createTime;
	DateTime? updateTime;
	String? patientName;
	String? cardNo;
	String? patientGender;
	String? patientAddress;
	DateTime? birthday;
	DateTime? examTime;
	String? physicalExamNumber;
	List<String>? symptom;
	String? temperature;
	String? breathe;
	String? spo2;
	String? pulse_Frequency;
	String? height;
	String? weight;
	String? bmi;
	String? wAISTLINE;
	List<String>? bloodPressureLeft;
	List<String>? bloodPressureRight;
	String? older_Health_State;
	String? older_Living_Ability;
	String? older_Cognitive;
	String? older_Intelligence;
	String? older_Emotional;
	String? older_Depression;
	String? blood_Hgb;
	String? blood_Wbc;
	String? blood_Rlt;
	String? blood_Routine_Other;
	String? urinary_Pro_LEU;
	String? urinary_Pro_BLD;
	String? urinary_Pro_NIT;
	String? urinary_Pro_KET;
	String? urinary_Pro_UBG;
	String? urinary_Pro_BIL;
	String? urinary_Pro_PRO;
	String? urinary_Pro_GLU;
	String? urinary_Pro_PH;
	String? urinary_Pro_SG;
	String? urinary_Pro_VC;
	String? fecal_Bld;
	String? hbsag;
	String? hbalc;
	String? fasting_Glucose_Mmol;
	String? ecg_Img;
	String? liver_Alt;
	String? liver_Ast;
	String? liver_Alb;
	String? liver_Tbil;
	String? liver_Dbil;
	String? renal_Cr;
	String? renal_Bun;
	String? renal_Spc;
	String? renal_Ssc;
	String? lipid_Cho;
	String? lipid_Tg;
	String? lipid_Ldl;
	String? lipid_Hdl;
	String? chest_X_Ray;
	String? b_Ultrasonic;
	String? b_Us_Other;
	String? cervical_Smear;
	String? b_Us_Others;
	String? exercise_Frequency;
	String? exercise_Daily_Time;
	String? exercise_Time;
	String? exercise_Way;
	List<String>? diet;
	String? smoking_State;
	String? smoking_Daily;
	String? smoking_Start_Age;
	String? smoking_Quit_Age;
	String? drinking_Frequency;
	String? drinking_Daily;
	String? drinking_Start_Age;
	String? drinking_Is_Quit;
	String? drinking_Quit_Age;
	String? drinking_Is_Drunk;
	List<String>? drinking_Type;
	String? risk_Working_State;
	String? risk_Working_Type;
	String? risk_Working_Time;
	String? risk_Dust;
	String? risk_Dust_Protect_Type;
	String? risk_Dust_Protect_Label;
	String? risk_Radiate;
	String? risk_Radiate_Protect_Type;
	String? risk_Radiate_Protect_Label;
	String? risk_Physics;
	String? risk_Physics_Protect_Type;
	String? risk_Physics_Protect_Label;
	String? risk_Chemical;
	String? risk_Chemical_Protect_Type;
	String? risk_Chemical_Protect_Label;
	String? risk_Other;
	String? risk_Other_Protect_Type;
	String? risk_Other_Protect_Label;
	String? lip;
	List<String>? dentition;
	List<String>? dentition_A;
	List<String>? dentition_B;
	List<String>? dentition_C;
	String? pharynx;
	String? vision_Left;
	String? vision_Right;
	String? vision_Corrective_Left;
	String? vision_Corrective_Right;
	String? hearing;
	String? athletic;
	String? eye_Ground;
	String? skin;
	String? sclera;
	String? lymph_Node;
	String? barrel_Chest;
	String? breath_Sounds;
	String? rale;
	String? heart_Murmur;
	String? heart_Rhythm;
	String? heart_Rate;
	String? abdominal_Tenderness;
	String? abdominal_Mass;
	String? hepatomegaly;
	String? splenomegalia;
	String? shifting_Dullness;
	String? lower_Limb_Edema;
	String? pedal_Artery;
	String? rectal_Touch;
	List<String>? mammary;
	String? vulvar;
	String? vagina;
	String? cervical;
	String? uteri_Body;
	String? uteri_Adnexa;
	String? examination_Other;
	List<String>? health_Cranial;
	List<String>? health_Renal;
	List<String>? health_Cardiac;
	List<String>? health_Vascular;
	List<String>? health_Eye;
	String? health_Nervous;
	String? health_Nervous_Pro;
	String? health_Other;
	String? health_Other_Pro;
	List<HospitalizationHistory>? hospitalization_History;
	List<HospitalAtHome>? hospital_At_Home;
	List<DrugUsage>? drug_Usage;
	List<InoculateHistory>? inoculate_History;
	String? appraisal_Flag;
	List<String>? appraisal;
	List<String>? guidance;
	List<String>? risk_Control_Values;
	String? risk_Control_WeightLoss;
	String? risk_Control_Vaccinations;
	String? risk_Control_Other;

	GetExamInfoByPhysicalExamNumberResult({
		this.code,
		this.createTime,
		this.updateTime,
		this.patientName,
		this.cardNo,
		this.patientGender,
		this.patientAddress,
		this.birthday,
		this.examTime,
		this.physicalExamNumber,
		this.symptom,
		this.temperature,
		this.breathe,
		this.spo2,
		this.pulse_Frequency,
		this.height,
		this.weight,
		this.bmi,
		this.wAISTLINE,
		this.bloodPressureLeft,
		this.bloodPressureRight,
		this.older_Health_State,
		this.older_Living_Ability,
		this.older_Cognitive,
		this.older_Intelligence,
		this.older_Emotional,
		this.older_Depression,
		this.blood_Hgb,
		this.blood_Wbc,
		this.blood_Rlt,
		this.blood_Routine_Other,
		this.urinary_Pro_LEU,
		this.urinary_Pro_BLD,
		this.urinary_Pro_NIT,
		this.urinary_Pro_KET,
		this.urinary_Pro_UBG,
		this.urinary_Pro_BIL,
		this.urinary_Pro_PRO,
		this.urinary_Pro_GLU,
		this.urinary_Pro_PH,
		this.urinary_Pro_SG,
		this.urinary_Pro_VC,
		this.fecal_Bld,
		this.hbsag,
		this.hbalc,
		this.fasting_Glucose_Mmol,
		this.ecg_Img,
		this.liver_Alt,
		this.liver_Ast,
		this.liver_Alb,
		this.liver_Tbil,
		this.liver_Dbil,
		this.renal_Cr,
		this.renal_Bun,
		this.renal_Spc,
		this.renal_Ssc,
		this.lipid_Cho,
		this.lipid_Tg,
		this.lipid_Ldl,
		this.lipid_Hdl,
		this.chest_X_Ray,
		this.b_Ultrasonic,
		this.b_Us_Other,
		this.cervical_Smear,
		this.b_Us_Others,
		this.exercise_Frequency,
		this.exercise_Daily_Time,
		this.exercise_Time,
		this.exercise_Way,
		this.diet,
		this.smoking_State,
		this.smoking_Daily,
		this.smoking_Start_Age,
		this.smoking_Quit_Age,
		this.drinking_Frequency,
		this.drinking_Daily,
		this.drinking_Start_Age,
		this.drinking_Is_Quit,
		this.drinking_Quit_Age,
		this.drinking_Is_Drunk,
		this.drinking_Type,
		this.risk_Working_State,
		this.risk_Working_Type,
		this.risk_Working_Time,
		this.risk_Dust,
		this.risk_Dust_Protect_Type,
		this.risk_Dust_Protect_Label,
		this.risk_Radiate,
		this.risk_Radiate_Protect_Type,
		this.risk_Radiate_Protect_Label,
		this.risk_Physics,
		this.risk_Physics_Protect_Type,
		this.risk_Physics_Protect_Label,
		this.risk_Chemical,
		this.risk_Chemical_Protect_Type,
		this.risk_Chemical_Protect_Label,
		this.risk_Other,
		this.risk_Other_Protect_Type,
		this.risk_Other_Protect_Label,
		this.lip,
		this.dentition,
		this.dentition_A,
		this.dentition_B,
		this.dentition_C,
		this.pharynx,
		this.vision_Left,
		this.vision_Right,
		this.vision_Corrective_Left,
		this.vision_Corrective_Right,
		this.hearing,
		this.athletic,
		this.eye_Ground,
		this.skin,
		this.sclera,
		this.lymph_Node,
		this.barrel_Chest,
		this.breath_Sounds,
		this.rale,
		this.heart_Murmur,
		this.heart_Rhythm,
		this.heart_Rate,
		this.abdominal_Tenderness,
		this.abdominal_Mass,
		this.hepatomegaly,
		this.splenomegalia,
		this.shifting_Dullness,
		this.lower_Limb_Edema,
		this.pedal_Artery,
		this.rectal_Touch,
		this.mammary,
		this.vulvar,
		this.vagina,
		this.cervical,
		this.uteri_Body,
		this.uteri_Adnexa,
		this.examination_Other,
		this.health_Cranial,
		this.health_Renal,
		this.health_Cardiac,
		this.health_Vascular,
		this.health_Eye,
		this.health_Nervous,
		this.health_Nervous_Pro,
		this.health_Other,
		this.health_Other_Pro,
		this.hospitalization_History,
		this.hospital_At_Home,
		this.drug_Usage,
		this.inoculate_History,
		this.appraisal_Flag,
		this.appraisal,
		this.guidance,
		this.risk_Control_Values,
		this.risk_Control_WeightLoss,
		this.risk_Control_Vaccinations,
		this.risk_Control_Other,
	});

	factory GetExamInfoByPhysicalExamNumberResult.fromJson(Map<String, dynamic> map) {
		return GetExamInfoByPhysicalExamNumberResult( 
			code: map['Code'],
			createTime: map['CreateTime'] != null ? DateTime.parse(map['CreateTime']) : null,
			updateTime: map['UpdateTime'] != null ? DateTime.parse(map['UpdateTime']) : null,
			patientName: map['PatientName'],
			cardNo: map['CardNo'],
			patientGender: map['PatientGender'],
			patientAddress: map['PatientAddress'],
			birthday: map['Birthday'] != null ? DateTime.parse(map['Birthday']) : null,
			examTime: map['ExamTime'] != null ? DateTime.parse(map['ExamTime']) : null,
			physicalExamNumber: map['PhysicalExamNumber'],
			symptom: map['Symptom']?.cast<String>().toList(),
			temperature: map['Temperature'],
			breathe: map['Breathe'],
			spo2: map['Spo2'],
			pulse_Frequency: map['Pulse_Frequency'],
			height: map['Height'],
			weight: map['Weight'],
			bmi: map['Bmi'],
			wAISTLINE: map['WAISTLINE'],
			bloodPressureLeft: map['BloodPressureLeft']?.cast<String>().toList(),
			bloodPressureRight: map['BloodPressureRight']?.cast<String>().toList(),
			older_Health_State: map['Older_Health_State'],
			older_Living_Ability: map['Older_Living_Ability'],
			older_Cognitive: map['Older_Cognitive'],
			older_Intelligence: map['Older_Intelligence'],
			older_Emotional: map['Older_Emotional'],
			older_Depression: map['Older_Depression'],
			blood_Hgb: map['Blood_Hgb'],
			blood_Wbc: map['Blood_Wbc'],
			blood_Rlt: map['Blood_Rlt'],
			blood_Routine_Other: map['Blood_Routine_Other'],
			urinary_Pro_LEU: map['Urinary_Pro_LEU'],
			urinary_Pro_BLD: map['Urinary_Pro_BLD'],
			urinary_Pro_NIT: map['Urinary_Pro_NIT'],
			urinary_Pro_KET: map['Urinary_Pro_KET'],
			urinary_Pro_UBG: map['Urinary_Pro_UBG'],
			urinary_Pro_BIL: map['Urinary_Pro_BIL'],
			urinary_Pro_PRO: map['Urinary_Pro_PRO'],
			urinary_Pro_GLU: map['Urinary_Pro_GLU'],
			urinary_Pro_PH: map['Urinary_Pro_PH'],
			urinary_Pro_SG: map['Urinary_Pro_SG'],
			urinary_Pro_VC: map['Urinary_Pro_VC'],
			fecal_Bld: map['Fecal_Bld'],
			hbsag: map['Hbsag'],
			hbalc: map['Hbalc'],
			fasting_Glucose_Mmol: map['Fasting_Glucose_Mmol'],
			ecg_Img: map['Ecg_Img'],
			liver_Alt: map['Liver_Alt'],
			liver_Ast: map['Liver_Ast'],
			liver_Alb: map['Liver_Alb'],
			liver_Tbil: map['Liver_Tbil'],
			liver_Dbil: map['Liver_Dbil'],
			renal_Cr: map['Renal_Cr'],
			renal_Bun: map['Renal_Bun'],
			renal_Spc: map['Renal_Spc'],
			renal_Ssc: map['Renal_Ssc'],
			lipid_Cho: map['Lipid_Cho'],
			lipid_Tg: map['Lipid_Tg'],
			lipid_Ldl: map['Lipid_Ldl'],
			lipid_Hdl: map['Lipid_Hdl'],
			chest_X_Ray: map['Chest_X_Ray'],
			b_Ultrasonic: map['B_Ultrasonic'],
			b_Us_Other: map['B_Us_Other'],
			cervical_Smear: map['Cervical_Smear'],
			b_Us_Others: map['B_Us_Others'],
			exercise_Frequency: map['Exercise_Frequency'],
			exercise_Daily_Time: map['Exercise_Daily_Time'],
			exercise_Time: map['Exercise_Time'],
			exercise_Way: map['Exercise_Way'],
			diet: map['Diet']?.cast<String>().toList(),
			smoking_State: map['Smoking_State'],
			smoking_Daily: map['Smoking_Daily'],
			smoking_Start_Age: map['Smoking_Start_Age'],
			smoking_Quit_Age: map['Smoking_Quit_Age'],
			drinking_Frequency: map['Drinking_Frequency'],
			drinking_Daily: map['Drinking_Daily'],
			drinking_Start_Age: map['Drinking_Start_Age'],
			drinking_Is_Quit: map['Drinking_Is_Quit'],
			drinking_Quit_Age: map['Drinking_Quit_Age'],
			drinking_Is_Drunk: map['Drinking_Is_Drunk'],
			drinking_Type: map['Drinking_Type']?.cast<String>().toList(),
			risk_Working_State: map['Risk_Working_State'],
			risk_Working_Type: map['Risk_Working_Type'],
			risk_Working_Time: map['Risk_Working_Time'],
			risk_Dust: map['Risk_Dust'],
			risk_Dust_Protect_Type: map['Risk_Dust_Protect_Type'],
			risk_Dust_Protect_Label: map['Risk_Dust_Protect_Label'],
			risk_Radiate: map['Risk_Radiate'],
			risk_Radiate_Protect_Type: map['Risk_Radiate_Protect_Type'],
			risk_Radiate_Protect_Label: map['Risk_Radiate_Protect_Label'],
			risk_Physics: map['Risk_Physics'],
			risk_Physics_Protect_Type: map['Risk_Physics_Protect_Type'],
			risk_Physics_Protect_Label: map['Risk_Physics_Protect_Label'],
			risk_Chemical: map['Risk_Chemical'],
			risk_Chemical_Protect_Type: map['Risk_Chemical_Protect_Type'],
			risk_Chemical_Protect_Label: map['Risk_Chemical_Protect_Label'],
			risk_Other: map['Risk_Other'],
			risk_Other_Protect_Type: map['Risk_Other_Protect_Type'],
			risk_Other_Protect_Label: map['Risk_Other_Protect_Label'],
			lip: map['Lip'],
			dentition: map['Dentition']?.cast<String>().toList(),
			dentition_A: map['Dentition_A']?.cast<String>().toList(),
			dentition_B: map['Dentition_B']?.cast<String>().toList(),
			dentition_C: map['Dentition_C']?.cast<String>().toList(),
			pharynx: map['Pharynx'],
			vision_Left: map['Vision_Left'],
			vision_Right: map['Vision_Right'],
			vision_Corrective_Left: map['Vision_Corrective_Left'],
			vision_Corrective_Right: map['Vision_Corrective_Right'],
			hearing: map['Hearing'],
			athletic: map['Athletic'],
			eye_Ground: map['Eye_Ground'],
			skin: map['Skin'],
			sclera: map['Sclera'],
			lymph_Node: map['Lymph_Node'],
			barrel_Chest: map['Barrel_Chest'],
			breath_Sounds: map['Breath_Sounds'],
			rale: map['Rale'],
			heart_Murmur: map['Heart_Murmur'],
			heart_Rhythm: map['Heart_Rhythm'],
			heart_Rate: map['Heart_Rate'],
			abdominal_Tenderness: map['Abdominal_Tenderness'],
			abdominal_Mass: map['Abdominal_Mass'],
			hepatomegaly: map['Hepatomegaly'],
			splenomegalia: map['Splenomegalia'],
			shifting_Dullness: map['Shifting_Dullness'],
			lower_Limb_Edema: map['Lower_Limb_Edema'],
			pedal_Artery: map['Pedal_Artery'],
			rectal_Touch: map['Rectal_Touch'],
			mammary: map['Mammary']?.cast<String>().toList(),
			vulvar: map['Vulvar'],
			vagina: map['Vagina'],
			cervical: map['Cervical'],
			uteri_Body: map['Uteri_Body'],
			uteri_Adnexa: map['Uteri_Adnexa'],
			examination_Other: map['Examination_Other'],
			health_Cranial: map['Health_Cranial']?.cast<String>().toList(),
			health_Renal: map['Health_Renal']?.cast<String>().toList(),
			health_Cardiac: map['Health_Cardiac']?.cast<String>().toList(),
			health_Vascular: map['Health_Vascular']?.cast<String>().toList(),
			health_Eye: map['Health_Eye']?.cast<String>().toList(),
			health_Nervous: map['Health_Nervous'],
			health_Nervous_Pro: map['Health_Nervous_Pro'],
			health_Other: map['Health_Other'],
			health_Other_Pro: map['Health_Other_Pro'],
			hospitalization_History: map['Hospitalization_History'] != null ? (map['Hospitalization_History'] as List).map((e)=>HospitalizationHistory.fromJson(e as Map<String,dynamic>)).toList() : null,
			hospital_At_Home: map['Hospital_At_Home'] != null ? (map['Hospital_At_Home'] as List).map((e)=>HospitalAtHome.fromJson(e as Map<String,dynamic>)).toList() : null,
			drug_Usage: map['Drug_Usage'] != null ? (map['Drug_Usage'] as List).map((e)=>DrugUsage.fromJson(e as Map<String,dynamic>)).toList() : null,
			inoculate_History: map['Inoculate_History'] != null ? (map['Inoculate_History'] as List).map((e)=>InoculateHistory.fromJson(e as Map<String,dynamic>)).toList() : null,
			appraisal_Flag: map['Appraisal_Flag'],
			appraisal: map['Appraisal']?.cast<String>().toList(),
			guidance: map['Guidance']?.cast<String>().toList(),
			risk_Control_Values: map['Risk_Control_Values']?.cast<String>().toList(),
			risk_Control_WeightLoss: map['Risk_Control_WeightLoss'],
			risk_Control_Vaccinations: map['Risk_Control_Vaccinations'],
			risk_Control_Other: map['Risk_Control_Other'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		if (code != null)
			map['Code'] = code;
		if (createTime != null)
			map['CreateTime'] = JsonRpcUtils.dateFormat(createTime!);
		if (updateTime != null)
			map['UpdateTime'] = JsonRpcUtils.dateFormat(updateTime!);
		if (patientName != null)
			map['PatientName'] = patientName;
		if (cardNo != null)
			map['CardNo'] = cardNo;
		if (patientGender != null)
			map['PatientGender'] = patientGender;
		if (patientAddress != null)
			map['PatientAddress'] = patientAddress;
		if (birthday != null)
			map['Birthday'] = JsonRpcUtils.dateFormat(birthday!);
		if (examTime != null)
			map['ExamTime'] = JsonRpcUtils.dateFormat(examTime!);
		if (physicalExamNumber != null)
			map['PhysicalExamNumber'] = physicalExamNumber;
		if (symptom != null)
			map['Symptom'] = symptom;
		if (temperature != null)
			map['Temperature'] = temperature;
		if (breathe != null)
			map['Breathe'] = breathe;
		if (spo2 != null)
			map['Spo2'] = spo2;
		if (pulse_Frequency != null)
			map['Pulse_Frequency'] = pulse_Frequency;
		if (height != null)
			map['Height'] = height;
		if (weight != null)
			map['Weight'] = weight;
		if (bmi != null)
			map['Bmi'] = bmi;
		if (wAISTLINE != null)
			map['WAISTLINE'] = wAISTLINE;
		if (bloodPressureLeft != null)
			map['BloodPressureLeft'] = bloodPressureLeft;
		if (bloodPressureRight != null)
			map['BloodPressureRight'] = bloodPressureRight;
		if (older_Health_State != null)
			map['Older_Health_State'] = older_Health_State;
		if (older_Living_Ability != null)
			map['Older_Living_Ability'] = older_Living_Ability;
		if (older_Cognitive != null)
			map['Older_Cognitive'] = older_Cognitive;
		if (older_Intelligence != null)
			map['Older_Intelligence'] = older_Intelligence;
		if (older_Emotional != null)
			map['Older_Emotional'] = older_Emotional;
		if (older_Depression != null)
			map['Older_Depression'] = older_Depression;
		if (blood_Hgb != null)
			map['Blood_Hgb'] = blood_Hgb;
		if (blood_Wbc != null)
			map['Blood_Wbc'] = blood_Wbc;
		if (blood_Rlt != null)
			map['Blood_Rlt'] = blood_Rlt;
		if (blood_Routine_Other != null)
			map['Blood_Routine_Other'] = blood_Routine_Other;
		if (urinary_Pro_LEU != null)
			map['Urinary_Pro_LEU'] = urinary_Pro_LEU;
		if (urinary_Pro_BLD != null)
			map['Urinary_Pro_BLD'] = urinary_Pro_BLD;
		if (urinary_Pro_NIT != null)
			map['Urinary_Pro_NIT'] = urinary_Pro_NIT;
		if (urinary_Pro_KET != null)
			map['Urinary_Pro_KET'] = urinary_Pro_KET;
		if (urinary_Pro_UBG != null)
			map['Urinary_Pro_UBG'] = urinary_Pro_UBG;
		if (urinary_Pro_BIL != null)
			map['Urinary_Pro_BIL'] = urinary_Pro_BIL;
		if (urinary_Pro_PRO != null)
			map['Urinary_Pro_PRO'] = urinary_Pro_PRO;
		if (urinary_Pro_GLU != null)
			map['Urinary_Pro_GLU'] = urinary_Pro_GLU;
		if (urinary_Pro_PH != null)
			map['Urinary_Pro_PH'] = urinary_Pro_PH;
		if (urinary_Pro_SG != null)
			map['Urinary_Pro_SG'] = urinary_Pro_SG;
		if (urinary_Pro_VC != null)
			map['Urinary_Pro_VC'] = urinary_Pro_VC;
		if (fecal_Bld != null)
			map['Fecal_Bld'] = fecal_Bld;
		if (hbsag != null)
			map['Hbsag'] = hbsag;
		if (hbalc != null)
			map['Hbalc'] = hbalc;
		if (fasting_Glucose_Mmol != null)
			map['Fasting_Glucose_Mmol'] = fasting_Glucose_Mmol;
		if (ecg_Img != null)
			map['Ecg_Img'] = ecg_Img;
		if (liver_Alt != null)
			map['Liver_Alt'] = liver_Alt;
		if (liver_Ast != null)
			map['Liver_Ast'] = liver_Ast;
		if (liver_Alb != null)
			map['Liver_Alb'] = liver_Alb;
		if (liver_Tbil != null)
			map['Liver_Tbil'] = liver_Tbil;
		if (liver_Dbil != null)
			map['Liver_Dbil'] = liver_Dbil;
		if (renal_Cr != null)
			map['Renal_Cr'] = renal_Cr;
		if (renal_Bun != null)
			map['Renal_Bun'] = renal_Bun;
		if (renal_Spc != null)
			map['Renal_Spc'] = renal_Spc;
		if (renal_Ssc != null)
			map['Renal_Ssc'] = renal_Ssc;
		if (lipid_Cho != null)
			map['Lipid_Cho'] = lipid_Cho;
		if (lipid_Tg != null)
			map['Lipid_Tg'] = lipid_Tg;
		if (lipid_Ldl != null)
			map['Lipid_Ldl'] = lipid_Ldl;
		if (lipid_Hdl != null)
			map['Lipid_Hdl'] = lipid_Hdl;
		if (chest_X_Ray != null)
			map['Chest_X_Ray'] = chest_X_Ray;
		if (b_Ultrasonic != null)
			map['B_Ultrasonic'] = b_Ultrasonic;
		if (b_Us_Other != null)
			map['B_Us_Other'] = b_Us_Other;
		if (cervical_Smear != null)
			map['Cervical_Smear'] = cervical_Smear;
		if (b_Us_Others != null)
			map['B_Us_Others'] = b_Us_Others;
		if (exercise_Frequency != null)
			map['Exercise_Frequency'] = exercise_Frequency;
		if (exercise_Daily_Time != null)
			map['Exercise_Daily_Time'] = exercise_Daily_Time;
		if (exercise_Time != null)
			map['Exercise_Time'] = exercise_Time;
		if (exercise_Way != null)
			map['Exercise_Way'] = exercise_Way;
		if (diet != null)
			map['Diet'] = diet;
		if (smoking_State != null)
			map['Smoking_State'] = smoking_State;
		if (smoking_Daily != null)
			map['Smoking_Daily'] = smoking_Daily;
		if (smoking_Start_Age != null)
			map['Smoking_Start_Age'] = smoking_Start_Age;
		if (smoking_Quit_Age != null)
			map['Smoking_Quit_Age'] = smoking_Quit_Age;
		if (drinking_Frequency != null)
			map['Drinking_Frequency'] = drinking_Frequency;
		if (drinking_Daily != null)
			map['Drinking_Daily'] = drinking_Daily;
		if (drinking_Start_Age != null)
			map['Drinking_Start_Age'] = drinking_Start_Age;
		if (drinking_Is_Quit != null)
			map['Drinking_Is_Quit'] = drinking_Is_Quit;
		if (drinking_Quit_Age != null)
			map['Drinking_Quit_Age'] = drinking_Quit_Age;
		if (drinking_Is_Drunk != null)
			map['Drinking_Is_Drunk'] = drinking_Is_Drunk;
		if (drinking_Type != null)
			map['Drinking_Type'] = drinking_Type;
		if (risk_Working_State != null)
			map['Risk_Working_State'] = risk_Working_State;
		if (risk_Working_Type != null)
			map['Risk_Working_Type'] = risk_Working_Type;
		if (risk_Working_Time != null)
			map['Risk_Working_Time'] = risk_Working_Time;
		if (risk_Dust != null)
			map['Risk_Dust'] = risk_Dust;
		if (risk_Dust_Protect_Type != null)
			map['Risk_Dust_Protect_Type'] = risk_Dust_Protect_Type;
		if (risk_Dust_Protect_Label != null)
			map['Risk_Dust_Protect_Label'] = risk_Dust_Protect_Label;
		if (risk_Radiate != null)
			map['Risk_Radiate'] = risk_Radiate;
		if (risk_Radiate_Protect_Type != null)
			map['Risk_Radiate_Protect_Type'] = risk_Radiate_Protect_Type;
		if (risk_Radiate_Protect_Label != null)
			map['Risk_Radiate_Protect_Label'] = risk_Radiate_Protect_Label;
		if (risk_Physics != null)
			map['Risk_Physics'] = risk_Physics;
		if (risk_Physics_Protect_Type != null)
			map['Risk_Physics_Protect_Type'] = risk_Physics_Protect_Type;
		if (risk_Physics_Protect_Label != null)
			map['Risk_Physics_Protect_Label'] = risk_Physics_Protect_Label;
		if (risk_Chemical != null)
			map['Risk_Chemical'] = risk_Chemical;
		if (risk_Chemical_Protect_Type != null)
			map['Risk_Chemical_Protect_Type'] = risk_Chemical_Protect_Type;
		if (risk_Chemical_Protect_Label != null)
			map['Risk_Chemical_Protect_Label'] = risk_Chemical_Protect_Label;
		if (risk_Other != null)
			map['Risk_Other'] = risk_Other;
		if (risk_Other_Protect_Type != null)
			map['Risk_Other_Protect_Type'] = risk_Other_Protect_Type;
		if (risk_Other_Protect_Label != null)
			map['Risk_Other_Protect_Label'] = risk_Other_Protect_Label;
		if (lip != null)
			map['Lip'] = lip;
		if (dentition != null)
			map['Dentition'] = dentition;
		if (dentition_A != null)
			map['Dentition_A'] = dentition_A;
		if (dentition_B != null)
			map['Dentition_B'] = dentition_B;
		if (dentition_C != null)
			map['Dentition_C'] = dentition_C;
		if (pharynx != null)
			map['Pharynx'] = pharynx;
		if (vision_Left != null)
			map['Vision_Left'] = vision_Left;
		if (vision_Right != null)
			map['Vision_Right'] = vision_Right;
		if (vision_Corrective_Left != null)
			map['Vision_Corrective_Left'] = vision_Corrective_Left;
		if (vision_Corrective_Right != null)
			map['Vision_Corrective_Right'] = vision_Corrective_Right;
		if (hearing != null)
			map['Hearing'] = hearing;
		if (athletic != null)
			map['Athletic'] = athletic;
		if (eye_Ground != null)
			map['Eye_Ground'] = eye_Ground;
		if (skin != null)
			map['Skin'] = skin;
		if (sclera != null)
			map['Sclera'] = sclera;
		if (lymph_Node != null)
			map['Lymph_Node'] = lymph_Node;
		if (barrel_Chest != null)
			map['Barrel_Chest'] = barrel_Chest;
		if (breath_Sounds != null)
			map['Breath_Sounds'] = breath_Sounds;
		if (rale != null)
			map['Rale'] = rale;
		if (heart_Murmur != null)
			map['Heart_Murmur'] = heart_Murmur;
		if (heart_Rhythm != null)
			map['Heart_Rhythm'] = heart_Rhythm;
		if (heart_Rate != null)
			map['Heart_Rate'] = heart_Rate;
		if (abdominal_Tenderness != null)
			map['Abdominal_Tenderness'] = abdominal_Tenderness;
		if (abdominal_Mass != null)
			map['Abdominal_Mass'] = abdominal_Mass;
		if (hepatomegaly != null)
			map['Hepatomegaly'] = hepatomegaly;
		if (splenomegalia != null)
			map['Splenomegalia'] = splenomegalia;
		if (shifting_Dullness != null)
			map['Shifting_Dullness'] = shifting_Dullness;
		if (lower_Limb_Edema != null)
			map['Lower_Limb_Edema'] = lower_Limb_Edema;
		if (pedal_Artery != null)
			map['Pedal_Artery'] = pedal_Artery;
		if (rectal_Touch != null)
			map['Rectal_Touch'] = rectal_Touch;
		if (mammary != null)
			map['Mammary'] = mammary;
		if (vulvar != null)
			map['Vulvar'] = vulvar;
		if (vagina != null)
			map['Vagina'] = vagina;
		if (cervical != null)
			map['Cervical'] = cervical;
		if (uteri_Body != null)
			map['Uteri_Body'] = uteri_Body;
		if (uteri_Adnexa != null)
			map['Uteri_Adnexa'] = uteri_Adnexa;
		if (examination_Other != null)
			map['Examination_Other'] = examination_Other;
		if (health_Cranial != null)
			map['Health_Cranial'] = health_Cranial;
		if (health_Renal != null)
			map['Health_Renal'] = health_Renal;
		if (health_Cardiac != null)
			map['Health_Cardiac'] = health_Cardiac;
		if (health_Vascular != null)
			map['Health_Vascular'] = health_Vascular;
		if (health_Eye != null)
			map['Health_Eye'] = health_Eye;
		if (health_Nervous != null)
			map['Health_Nervous'] = health_Nervous;
		if (health_Nervous_Pro != null)
			map['Health_Nervous_Pro'] = health_Nervous_Pro;
		if (health_Other != null)
			map['Health_Other'] = health_Other;
		if (health_Other_Pro != null)
			map['Health_Other_Pro'] = health_Other_Pro;
		if (hospitalization_History != null)
			map['Hospitalization_History'] = hospitalization_History;
		if (hospital_At_Home != null)
			map['Hospital_At_Home'] = hospital_At_Home;
		if (drug_Usage != null)
			map['Drug_Usage'] = drug_Usage;
		if (inoculate_History != null)
			map['Inoculate_History'] = inoculate_History;
		if (appraisal_Flag != null)
			map['Appraisal_Flag'] = appraisal_Flag;
		if (appraisal != null)
			map['Appraisal'] = appraisal;
		if (guidance != null)
			map['Guidance'] = guidance;
		if (risk_Control_Values != null)
			map['Risk_Control_Values'] = risk_Control_Values;
		if (risk_Control_WeightLoss != null)
			map['Risk_Control_WeightLoss'] = risk_Control_WeightLoss;
		if (risk_Control_Vaccinations != null)
			map['Risk_Control_Vaccinations'] = risk_Control_Vaccinations;
		if (risk_Control_Other != null)
			map['Risk_Control_Other'] = risk_Control_Other;
		return map;
	}
}

class GetExamInfoByPhysicalExamNumberRequest extends TokenRequest{
	String? physicalExamNumber;

	GetExamInfoByPhysicalExamNumberRequest({
		this.physicalExamNumber,
		String? token,
	}) : super(
			token: token,
		);

	factory GetExamInfoByPhysicalExamNumberRequest.fromJson(Map<String, dynamic> map) {
		return GetExamInfoByPhysicalExamNumberRequest( 
			physicalExamNumber: map['PhysicalExamNumber'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (physicalExamNumber != null)
			map['PhysicalExamNumber'] = physicalExamNumber;
		return map;
	}
}

class GetVitalReportInfoRequest extends TokenRequest{
	String? physicalExamNumber;

	GetVitalReportInfoRequest({
		this.physicalExamNumber,
		String? token,
	}) : super(
			token: token,
		);

	factory GetVitalReportInfoRequest.fromJson(Map<String, dynamic> map) {
		return GetVitalReportInfoRequest( 
			physicalExamNumber: map['PhysicalExamNumber'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (physicalExamNumber != null)
			map['PhysicalExamNumber'] = physicalExamNumber;
		return map;
	}
}

enum GenderEnum {
	Unknown,
	Male,
	Female,
	placeHolder_3,
	placeHolder_4,
	placeHolder_5,
	placeHolder_6,
	placeHolder_7,
	placeHolder_8,
	Unspecified,
}

class ExamDTO extends BaseDTO{
	String? code;
	String? key;
	String? patientCode;
	String? contractedDoctor;
	String? examData;
	String? patientName;
	String? cardNo;
	GenderEnum patientGender;
	String? patientAddress;
	DateTime? birthday;
	ExamStateEnum examState;
	DateTime? examTime;
	String? templateCode;
	String? examDoctor;
	String? examSign;
	String? batchNumber;
	String? physicalExamNumber;
	String? createdTeamCode;
	String? createdDoctor;
	String? createdOrgCode;
	String? examDoctorName;

	ExamDTO({
		this.code,
		this.key,
		this.patientCode,
		this.contractedDoctor,
		this.examData,
		this.patientName,
		this.cardNo,
		this.patientGender = GenderEnum.Unknown,
		this.patientAddress,
		this.birthday,
		this.examState = ExamStateEnum.Unchecked,
		this.examTime,
		this.templateCode,
		this.examDoctor,
		this.examSign,
		this.batchNumber,
		this.physicalExamNumber,
		this.createdTeamCode,
		this.createdDoctor,
		this.createdOrgCode,
		DateTime? updateTime,
		this.examDoctorName,
		bool isDelete = false,
		DateTime? createTime,
	}) : super(
			isDelete: isDelete,
			createTime: createTime,
			updateTime: updateTime,
		);

	factory ExamDTO.fromJson(Map<String, dynamic> map) {
		return ExamDTO( 
			code: map['Code'],
			key: map['Key'],
			patientCode: map['PatientCode'],
			contractedDoctor: map['ContractedDoctor'],
			examData: map['ExamData'],
			patientName: map['PatientName'],
			cardNo: map['CardNo'],
			patientGender: GenderEnum.values.firstWhere((e) => e.index == map['PatientGender']),
			patientAddress: map['PatientAddress'],
			birthday: map['Birthday'] != null ? DateTime.parse(map['Birthday']) : null,
			examState: ExamStateEnum.values.firstWhere((e) => e.index == map['ExamState']),
			examTime: map['ExamTime'] != null ? DateTime.parse(map['ExamTime']) : null,
			templateCode: map['TemplateCode'],
			examDoctor: map['ExamDoctor'],
			examSign: map['ExamSign'],
			batchNumber: map['BatchNumber'],
			physicalExamNumber: map['PhysicalExamNumber'],
			createdTeamCode: map['CreatedTeamCode'],
			createdDoctor: map['CreatedDoctor'],
			createdOrgCode: map['CreatedOrgCode'],
			updateTime: map['UpdateTime'] != null ? DateTime.parse(map['UpdateTime']) : null,
			examDoctorName: map['ExamDoctorName'],
			isDelete: map['IsDelete'],
			createTime: map['CreateTime'] != null ? DateTime.parse(map['CreateTime']) : null,
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		if (key != null)
			map['Key'] = key;
		if (patientCode != null)
			map['PatientCode'] = patientCode;
		if (contractedDoctor != null)
			map['ContractedDoctor'] = contractedDoctor;
		if (examData != null)
			map['ExamData'] = examData;
		if (patientName != null)
			map['PatientName'] = patientName;
		if (cardNo != null)
			map['CardNo'] = cardNo;
		map['PatientGender'] = patientGender.index;
		if (patientAddress != null)
			map['PatientAddress'] = patientAddress;
		if (birthday != null)
			map['Birthday'] = JsonRpcUtils.dateFormat(birthday!);
		map['ExamState'] = examState.index;
		if (examTime != null)
			map['ExamTime'] = JsonRpcUtils.dateFormat(examTime!);
		if (templateCode != null)
			map['TemplateCode'] = templateCode;
		if (examDoctor != null)
			map['ExamDoctor'] = examDoctor;
		if (examSign != null)
			map['ExamSign'] = examSign;
		if (batchNumber != null)
			map['BatchNumber'] = batchNumber;
		if (physicalExamNumber != null)
			map['PhysicalExamNumber'] = physicalExamNumber;
		if (createdTeamCode != null)
			map['CreatedTeamCode'] = createdTeamCode;
		if (createdDoctor != null)
			map['CreatedDoctor'] = createdDoctor;
		if (createdOrgCode != null)
			map['CreatedOrgCode'] = createdOrgCode;
		if (examDoctorName != null)
			map['ExamDoctorName'] = examDoctorName;
		return map;
	}
}

class ExamConclusionDTO extends ExamDTO{
	String? tcmConclusion;

	ExamConclusionDTO({
		this.tcmConclusion,
		String? code,
		String? key,
		String? patientCode,
		String? contractedDoctor,
		String? examData,
		String? patientName,
		String? cardNo,
		GenderEnum patientGender = GenderEnum.Unknown,
		String? patientAddress,
		DateTime? birthday,
		ExamStateEnum examState = ExamStateEnum.Unchecked,
		DateTime? examTime,
		String? templateCode,
		String? examDoctor,
		String? examSign,
		String? batchNumber,
		String? physicalExamNumber,
		String? createdTeamCode,
		String? createdDoctor,
		String? createdOrgCode,
		DateTime? updateTime,
		String? examDoctorName,
		bool isDelete = false,
		DateTime? createTime,
	}) : super(
			code: code,
			key: key,
			patientCode: patientCode,
			contractedDoctor: contractedDoctor,
			examData: examData,
			patientName: patientName,
			cardNo: cardNo,
			patientGender: patientGender,
			patientAddress: patientAddress,
			birthday: birthday,
			examState: examState,
			examTime: examTime,
			templateCode: templateCode,
			examDoctor: examDoctor,
			examSign: examSign,
			batchNumber: batchNumber,
			physicalExamNumber: physicalExamNumber,
			createdTeamCode: createdTeamCode,
			createdDoctor: createdDoctor,
			createdOrgCode: createdOrgCode,
			updateTime: updateTime,
			examDoctorName: examDoctorName,
			isDelete: isDelete,
			createTime: createTime,
		);

	factory ExamConclusionDTO.fromJson(Map<String, dynamic> map) {
		return ExamConclusionDTO( 
			tcmConclusion: map['TcmConclusion'],
			code: map['Code'],
			key: map['Key'],
			patientCode: map['PatientCode'],
			contractedDoctor: map['ContractedDoctor'],
			examData: map['ExamData'],
			patientName: map['PatientName'],
			cardNo: map['CardNo'],
			patientGender: GenderEnum.values.firstWhere((e) => e.index == map['PatientGender']),
			patientAddress: map['PatientAddress'],
			birthday: map['Birthday'] != null ? DateTime.parse(map['Birthday']) : null,
			examState: ExamStateEnum.values.firstWhere((e) => e.index == map['ExamState']),
			examTime: map['ExamTime'] != null ? DateTime.parse(map['ExamTime']) : null,
			templateCode: map['TemplateCode'],
			examDoctor: map['ExamDoctor'],
			examSign: map['ExamSign'],
			batchNumber: map['BatchNumber'],
			physicalExamNumber: map['PhysicalExamNumber'],
			createdTeamCode: map['CreatedTeamCode'],
			createdDoctor: map['CreatedDoctor'],
			createdOrgCode: map['CreatedOrgCode'],
			updateTime: map['UpdateTime'] != null ? DateTime.parse(map['UpdateTime']) : null,
			examDoctorName: map['ExamDoctorName'],
			isDelete: map['IsDelete'],
			createTime: map['CreateTime'] != null ? DateTime.parse(map['CreateTime']) : null,
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (tcmConclusion != null)
			map['TcmConclusion'] = tcmConclusion;
		return map;
	}
}

class ExamTileConslusionDTO extends ExamConclusionDTO{
	List<String>? healthGuidance;
	String? selfCareScore;
	String? ping_Score;
	String? qi_Score;
	String? yin_Score;
	String? tan_Score;
	String? shi_Score;
	String? yang_Score;
	String? te_Score;
	String? qiyu_Score;
	String? xue_Score;
	String? question1;
	String? question2;
	String? question3;
	String? question4;
	String? question5;
	String? question6;
	String? question7;
	String? question8;
	String? question9;
	String? question10;
	String? question11;
	String? question12;
	String? question13;
	String? question14;
	String? question15;
	String? question16;
	String? question17;
	String? question18;
	String? question19;
	String? question20;
	String? question21;
	String? question22;
	String? question23;
	String? question24;
	String? question25;
	String? question26;
	String? question27;
	String? question28;
	String? question29;
	String? question30;
	String? question31;
	String? question32;
	String? question33;

	ExamTileConslusionDTO({
		this.healthGuidance,
		this.selfCareScore,
		this.ping_Score,
		this.qi_Score,
		this.yin_Score,
		this.tan_Score,
		this.shi_Score,
		this.yang_Score,
		this.te_Score,
		this.qiyu_Score,
		this.xue_Score,
		this.question1,
		this.question2,
		this.question3,
		this.question4,
		this.question5,
		this.question6,
		this.question7,
		this.question8,
		this.question9,
		this.question10,
		this.question11,
		this.question12,
		this.question13,
		this.question14,
		this.question15,
		this.question16,
		this.question17,
		this.question18,
		this.question19,
		this.question20,
		this.question21,
		this.question22,
		this.question23,
		this.question24,
		this.question25,
		this.question26,
		this.question27,
		this.question28,
		this.question29,
		this.question30,
		this.question31,
		this.question32,
		this.question33,
		String? tcmConclusion,
		String? code,
		String? key,
		String? patientCode,
		String? contractedDoctor,
		String? examData,
		String? patientName,
		String? cardNo,
		GenderEnum patientGender = GenderEnum.Unknown,
		String? patientAddress,
		DateTime? birthday,
		ExamStateEnum examState = ExamStateEnum.Unchecked,
		DateTime? examTime,
		String? templateCode,
		String? examDoctor,
		String? examSign,
		String? batchNumber,
		String? physicalExamNumber,
		String? createdTeamCode,
		String? createdDoctor,
		String? createdOrgCode,
		DateTime? updateTime,
		String? examDoctorName,
		bool isDelete = false,
		DateTime? createTime,
	}) : super(
			tcmConclusion: tcmConclusion,
			code: code,
			key: key,
			patientCode: patientCode,
			contractedDoctor: contractedDoctor,
			examData: examData,
			patientName: patientName,
			cardNo: cardNo,
			patientGender: patientGender,
			patientAddress: patientAddress,
			birthday: birthday,
			examState: examState,
			examTime: examTime,
			templateCode: templateCode,
			examDoctor: examDoctor,
			examSign: examSign,
			batchNumber: batchNumber,
			physicalExamNumber: physicalExamNumber,
			createdTeamCode: createdTeamCode,
			createdDoctor: createdDoctor,
			createdOrgCode: createdOrgCode,
			updateTime: updateTime,
			examDoctorName: examDoctorName,
			isDelete: isDelete,
			createTime: createTime,
		);

	factory ExamTileConslusionDTO.fromJson(Map<String, dynamic> map) {
		return ExamTileConslusionDTO( 
			healthGuidance: map['HealthGuidance']?.cast<String>().toList(),
			selfCareScore: map['SelfCareScore'],
			ping_Score: map['Ping_Score'],
			qi_Score: map['Qi_Score'],
			yin_Score: map['Yin_Score'],
			tan_Score: map['Tan_Score'],
			shi_Score: map['Shi_Score'],
			yang_Score: map['Yang_Score'],
			te_Score: map['Te_Score'],
			qiyu_Score: map['Qiyu_Score'],
			xue_Score: map['Xue_Score'],
			question1: map['Question1'],
			question2: map['Question2'],
			question3: map['Question3'],
			question4: map['Question4'],
			question5: map['Question5'],
			question6: map['Question6'],
			question7: map['Question7'],
			question8: map['Question8'],
			question9: map['Question9'],
			question10: map['Question10'],
			question11: map['Question11'],
			question12: map['Question12'],
			question13: map['Question13'],
			question14: map['Question14'],
			question15: map['Question15'],
			question16: map['Question16'],
			question17: map['Question17'],
			question18: map['Question18'],
			question19: map['Question19'],
			question20: map['Question20'],
			question21: map['Question21'],
			question22: map['Question22'],
			question23: map['Question23'],
			question24: map['Question24'],
			question25: map['Question25'],
			question26: map['Question26'],
			question27: map['Question27'],
			question28: map['Question28'],
			question29: map['Question29'],
			question30: map['Question30'],
			question31: map['Question31'],
			question32: map['Question32'],
			question33: map['Question33'],
			tcmConclusion: map['TcmConclusion'],
			code: map['Code'],
			key: map['Key'],
			patientCode: map['PatientCode'],
			contractedDoctor: map['ContractedDoctor'],
			examData: map['ExamData'],
			patientName: map['PatientName'],
			cardNo: map['CardNo'],
			patientGender: GenderEnum.values.firstWhere((e) => e.index == map['PatientGender']),
			patientAddress: map['PatientAddress'],
			birthday: map['Birthday'] != null ? DateTime.parse(map['Birthday']) : null,
			examState: ExamStateEnum.values.firstWhere((e) => e.index == map['ExamState']),
			examTime: map['ExamTime'] != null ? DateTime.parse(map['ExamTime']) : null,
			templateCode: map['TemplateCode'],
			examDoctor: map['ExamDoctor'],
			examSign: map['ExamSign'],
			batchNumber: map['BatchNumber'],
			physicalExamNumber: map['PhysicalExamNumber'],
			createdTeamCode: map['CreatedTeamCode'],
			createdDoctor: map['CreatedDoctor'],
			createdOrgCode: map['CreatedOrgCode'],
			updateTime: map['UpdateTime'] != null ? DateTime.parse(map['UpdateTime']) : null,
			examDoctorName: map['ExamDoctorName'],
			isDelete: map['IsDelete'],
			createTime: map['CreateTime'] != null ? DateTime.parse(map['CreateTime']) : null,
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (healthGuidance != null)
			map['HealthGuidance'] = healthGuidance;
		if (selfCareScore != null)
			map['SelfCareScore'] = selfCareScore;
		if (ping_Score != null)
			map['Ping_Score'] = ping_Score;
		if (qi_Score != null)
			map['Qi_Score'] = qi_Score;
		if (yin_Score != null)
			map['Yin_Score'] = yin_Score;
		if (tan_Score != null)
			map['Tan_Score'] = tan_Score;
		if (shi_Score != null)
			map['Shi_Score'] = shi_Score;
		if (yang_Score != null)
			map['Yang_Score'] = yang_Score;
		if (te_Score != null)
			map['Te_Score'] = te_Score;
		if (qiyu_Score != null)
			map['Qiyu_Score'] = qiyu_Score;
		if (xue_Score != null)
			map['Xue_Score'] = xue_Score;
		if (question1 != null)
			map['Question1'] = question1;
		if (question2 != null)
			map['Question2'] = question2;
		if (question3 != null)
			map['Question3'] = question3;
		if (question4 != null)
			map['Question4'] = question4;
		if (question5 != null)
			map['Question5'] = question5;
		if (question6 != null)
			map['Question6'] = question6;
		if (question7 != null)
			map['Question7'] = question7;
		if (question8 != null)
			map['Question8'] = question8;
		if (question9 != null)
			map['Question9'] = question9;
		if (question10 != null)
			map['Question10'] = question10;
		if (question11 != null)
			map['Question11'] = question11;
		if (question12 != null)
			map['Question12'] = question12;
		if (question13 != null)
			map['Question13'] = question13;
		if (question14 != null)
			map['Question14'] = question14;
		if (question15 != null)
			map['Question15'] = question15;
		if (question16 != null)
			map['Question16'] = question16;
		if (question17 != null)
			map['Question17'] = question17;
		if (question18 != null)
			map['Question18'] = question18;
		if (question19 != null)
			map['Question19'] = question19;
		if (question20 != null)
			map['Question20'] = question20;
		if (question21 != null)
			map['Question21'] = question21;
		if (question22 != null)
			map['Question22'] = question22;
		if (question23 != null)
			map['Question23'] = question23;
		if (question24 != null)
			map['Question24'] = question24;
		if (question25 != null)
			map['Question25'] = question25;
		if (question26 != null)
			map['Question26'] = question26;
		if (question27 != null)
			map['Question27'] = question27;
		if (question28 != null)
			map['Question28'] = question28;
		if (question29 != null)
			map['Question29'] = question29;
		if (question30 != null)
			map['Question30'] = question30;
		if (question31 != null)
			map['Question31'] = question31;
		if (question32 != null)
			map['Question32'] = question32;
		if (question33 != null)
			map['Question33'] = question33;
		return map;
	}
}

class GetExamByPatientPageRequest extends PageRequest{
	String? patientCode;
	String? examKey;
	String? keyword;
	DateTime? startTime;
	DateTime? endTime;

	GetExamByPatientPageRequest({
		this.patientCode,
		this.examKey,
		this.keyword,
		this.startTime,
		this.endTime,
		int pageIndex = 0,
		int pageSize = 0,
		String? token,
	}) : super(
			pageIndex: pageIndex,
			pageSize: pageSize,
			token: token,
		);

	factory GetExamByPatientPageRequest.fromJson(Map<String, dynamic> map) {
		return GetExamByPatientPageRequest( 
			patientCode: map['PatientCode'],
			examKey: map['ExamKey'],
			keyword: map['Keyword'],
			startTime: map['StartTime'] != null ? DateTime.parse(map['StartTime']) : null,
			endTime: map['EndTime'] != null ? DateTime.parse(map['EndTime']) : null,
			pageIndex: map['PageIndex'],
			pageSize: map['PageSize'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (patientCode != null)
			map['PatientCode'] = patientCode;
		if (examKey != null)
			map['ExamKey'] = examKey;
		if (keyword != null)
			map['Keyword'] = keyword;
		if (startTime != null)
			map['StartTime'] = JsonRpcUtils.dateFormat(startTime!);
		if (endTime != null)
			map['EndTime'] = JsonRpcUtils.dateFormat(endTime!);
		return map;
	}
}

class UploadElectrocardiogramReportRequest extends TokenRequest{
	String? physicalExamNumber;
	String? reportBase64;
	String? reportPdfUrl;
	String? reportJpgUrl;
	String? hR;
	String? pWidth;
	String? pAxis;
	String? qRSAxis;
	String? pRInterval;
	String? qTInterval;
	String? qTCInterval;
	String? qRSDuration;
	String? rV5SV;
	String? rV5SV1;
	String? tAxis;
	String? diagnosis;
	String? pDuration;
	String? tDuration;
	String? ecgImgBase64;
	String? ecgImgJpgUrl;
	String? ecgLongImgBase64;
	String? ecgLongImgJpgUrl;
	String? diagnosticEleSignature;
	String? reviewEleSignature;

	UploadElectrocardiogramReportRequest({
		this.physicalExamNumber,
		this.reportBase64,
		this.reportPdfUrl,
		this.reportJpgUrl,
		this.hR,
		this.pWidth,
		this.pAxis,
		this.qRSAxis,
		this.pRInterval,
		this.qTInterval,
		this.qTCInterval,
		this.qRSDuration,
		this.rV5SV,
		this.rV5SV1,
		this.tAxis,
		this.diagnosis,
		this.pDuration,
		this.tDuration,
		this.ecgImgBase64,
		this.ecgImgJpgUrl,
		this.ecgLongImgBase64,
		this.ecgLongImgJpgUrl,
		this.diagnosticEleSignature,
		this.reviewEleSignature,
		String? token,
	}) : super(
			token: token,
		);

	factory UploadElectrocardiogramReportRequest.fromJson(Map<String, dynamic> map) {
		return UploadElectrocardiogramReportRequest( 
			physicalExamNumber: map['PhysicalExamNumber'],
			reportBase64: map['ReportBase64'],
			reportPdfUrl: map['ReportPdfUrl'],
			reportJpgUrl: map['ReportJpgUrl'],
			hR: map['HR'],
			pWidth: map['PWidth'],
			pAxis: map['PAxis'],
			qRSAxis: map['QRSAxis'],
			pRInterval: map['PRInterval'],
			qTInterval: map['QTInterval'],
			qTCInterval: map['QTCInterval'],
			qRSDuration: map['QRSDuration'],
			rV5SV: map['RV5SV'],
			rV5SV1: map['RV5SV1'],
			tAxis: map['TAxis'],
			diagnosis: map['Diagnosis'],
			pDuration: map['PDuration'],
			tDuration: map['TDuration'],
			ecgImgBase64: map['EcgImgBase64'],
			ecgImgJpgUrl: map['EcgImgJpgUrl'],
			ecgLongImgBase64: map['EcgLongImgBase64'],
			ecgLongImgJpgUrl: map['EcgLongImgJpgUrl'],
			diagnosticEleSignature: map['DiagnosticEleSignature'],
			reviewEleSignature: map['ReviewEleSignature'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (physicalExamNumber != null)
			map['PhysicalExamNumber'] = physicalExamNumber;
		if (reportBase64 != null)
			map['ReportBase64'] = reportBase64;
		if (reportPdfUrl != null)
			map['ReportPdfUrl'] = reportPdfUrl;
		if (reportJpgUrl != null)
			map['ReportJpgUrl'] = reportJpgUrl;
		if (hR != null)
			map['HR'] = hR;
		if (pWidth != null)
			map['PWidth'] = pWidth;
		if (pAxis != null)
			map['PAxis'] = pAxis;
		if (qRSAxis != null)
			map['QRSAxis'] = qRSAxis;
		if (pRInterval != null)
			map['PRInterval'] = pRInterval;
		if (qTInterval != null)
			map['QTInterval'] = qTInterval;
		if (qTCInterval != null)
			map['QTCInterval'] = qTCInterval;
		if (qRSDuration != null)
			map['QRSDuration'] = qRSDuration;
		if (rV5SV != null)
			map['RV5SV'] = rV5SV;
		if (rV5SV1 != null)
			map['RV5SV1'] = rV5SV1;
		if (tAxis != null)
			map['TAxis'] = tAxis;
		if (diagnosis != null)
			map['Diagnosis'] = diagnosis;
		if (pDuration != null)
			map['PDuration'] = pDuration;
		if (tDuration != null)
			map['TDuration'] = tDuration;
		if (ecgImgBase64 != null)
			map['EcgImgBase64'] = ecgImgBase64;
		if (ecgImgJpgUrl != null)
			map['EcgImgJpgUrl'] = ecgImgJpgUrl;
		if (ecgLongImgBase64 != null)
			map['EcgLongImgBase64'] = ecgLongImgBase64;
		if (ecgLongImgJpgUrl != null)
			map['EcgLongImgJpgUrl'] = ecgLongImgJpgUrl;
		if (diagnosticEleSignature != null)
			map['DiagnosticEleSignature'] = diagnosticEleSignature;
		if (reviewEleSignature != null)
			map['ReviewEleSignature'] = reviewEleSignature;
		return map;
	}
}


