import 'dart:core';

import 'package:fis_jsonrpc/client_base.dart';
import 'package:fis_common/json_convert.dart';

import 'payment.m.dart';

import 'liveConsultation.m.dart';


class PaymentService extends JsonRpcClientBase {
	PaymentService(
		String host, {
		String serviceName = "IPaymentService",
		Map<String, String>? headers,
		int? timeout,
	}) : super(
						host,
						serviceName,
						headers: headers,
						timeout: timeout,
				) {
		/// 注册响应实体反序列化处理器
		FJsonConvert.setDecoder((map) => CreateOrderResultDTO.fromJson(map));
		FJsonConvert.setDecoder((map) => OrderDetailDTO.fromJson(map));
		FJsonConvert.setDecoder((map) => PageResult<OrderDetailDTO>.fromJson(map));
		FJsonConvert.setDecoder((map) => PayInfoDTO.fromJson(map));
		FJsonConvert.setDecoder((map) => PayCallbackDTO.fromJson(map));
		FJsonConvert.setDecoder((map) => PayableTypeDTO.fromJson(map));
	}

	Future<CreateOrderResultDTO> createOrderAsync(CreateOrderRequest request) async {
		var rpcRst = await call("CreateOrderAsync", request);
		var result = CreateOrderResultDTO.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<OrderDetailDTO> getOrderDetailAsync(GetOrderDetailRequest request) async {
		var rpcRst = await call("GetOrderDetailAsync", request);
		var result = OrderDetailDTO.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<PageResult<OrderDetailDTO>> getOrderPagesAsync(GetOrderPagesRequest request) async {
		var rpcRst = await call("GetOrderPagesAsync", request);
		var result = PageResult<OrderDetailDTO>.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<PayInfoDTO> goToPayAsync(GoToPayRequest request) async {
		var rpcRst = await call("GoToPayAsync", request);
		var result = PayInfoDTO.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<PayCallbackDTO> payCallbackAsync(String src,String request) async {
		var rpcRst = await call("PayCallbackAsync", [src,request]);
		var result = PayCallbackDTO.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<PayableTypeDTO> getPayableTypes() async {
		var rpcRst = await call("GetPayableTypes", );
		var result = PayableTypeDTO.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

}

