import 'notification.m.dart';
import 'researchEdition.m.dart';

class RankDTO extends BaseDTO{
	String? rankCode;
	String? rankName;
	String? organizationCode;

	RankDTO({
		this.rankCode,
		this.rankName,
		this.organizationCode,
		bool isDelete = false,
		DateTime? createTime,
		DateTime? updateTime,
	}) : super(
			isDelete: isDelete,
			createTime: createTime,
			updateTime: updateTime,
		);

	factory RankDTO.fromJson(Map<String, dynamic> map) {
		return RankDTO( 
			rankCode: map['RankCode'],
			rankName: map['RankName'],
			organizationCode: map['OrganizationCode'],
			isDelete: map['IsDelete'],
			createTime: map['CreateTime'] != null ? DateTime.parse(map['CreateTime']) : null,
			updateTime: map['UpdateTime'] != null ? DateTime.parse(map['UpdateTime']) : null,
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (rankCode != null)
			map['RankCode'] = rankCode;
		if (rankName != null)
			map['RankName'] = rankName;
		if (organizationCode != null)
			map['OrganizationCode'] = organizationCode;
		return map;
	}
}

class GetRankByCodeRequest extends TokenRequest{
	String? rankCode;

	GetRankByCodeRequest({
		this.rankCode,
		String? token,
	}) : super(
			token: token,
		);

	factory GetRankByCodeRequest.fromJson(Map<String, dynamic> map) {
		return GetRankByCodeRequest( 
			rankCode: map['RankCode'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (rankCode != null)
			map['RankCode'] = rankCode;
		return map;
	}
}

class GetRanksRequest extends TokenRequest{
	List<String>? rankCodes;
	List<String>? organizationCodes;

	GetRanksRequest({
		this.rankCodes,
		this.organizationCodes,
		String? token,
	}) : super(
			token: token,
		);

	factory GetRanksRequest.fromJson(Map<String, dynamic> map) {
		return GetRanksRequest( 
			rankCodes: map['RankCodes']?.cast<String>().toList(),
			organizationCodes: map['OrganizationCodes']?.cast<String>().toList(),
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (rankCodes != null)
			map['RankCodes'] = rankCodes;
		if (organizationCodes != null)
			map['OrganizationCodes'] = organizationCodes;
		return map;
	}
}

class RankItemDTO {
	String? rankName;
	String? organizationCode;
	String? extendsData;

	RankItemDTO({
		this.rankName,
		this.organizationCode,
		this.extendsData,
	});

	factory RankItemDTO.fromJson(Map<String, dynamic> map) {
		return RankItemDTO( 
			rankName: map['RankName'],
			organizationCode: map['OrganizationCode'],
			extendsData: map['ExtendsData'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		if (rankName != null)
			map['RankName'] = rankName;
		if (organizationCode != null)
			map['OrganizationCode'] = organizationCode;
		if (extendsData != null)
			map['ExtendsData'] = extendsData;
		return map;
	}
}

class AddRanksRequest extends TokenRequest{
	List<RankItemDTO>? rankInfos;

	AddRanksRequest({
		this.rankInfos,
		String? token,
	}) : super(
			token: token,
		);

	factory AddRanksRequest.fromJson(Map<String, dynamic> map) {
		return AddRanksRequest( 
			rankInfos: map['RankInfos'] != null ? (map['RankInfos'] as List).map((e)=>RankItemDTO.fromJson(e as Map<String,dynamic>)).toList() : null,
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (rankInfos != null)
			map['RankInfos'] = rankInfos;
		return map;
	}
}

class RemoveRanksRequest extends TokenRequest{
	List<String>? rankCodes;

	RemoveRanksRequest({
		this.rankCodes,
		String? token,
	}) : super(
			token: token,
		);

	factory RemoveRanksRequest.fromJson(Map<String, dynamic> map) {
		return RemoveRanksRequest( 
			rankCodes: map['RankCodes']?.cast<String>().toList(),
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (rankCodes != null)
			map['RankCodes'] = rankCodes;
		return map;
	}
}

class UpdateRankNameRequest extends TokenRequest{
	String? rankCode;
	String? rankName;

	UpdateRankNameRequest({
		this.rankCode,
		this.rankName,
		String? token,
	}) : super(
			token: token,
		);

	factory UpdateRankNameRequest.fromJson(Map<String, dynamic> map) {
		return UpdateRankNameRequest( 
			rankCode: map['RankCode'],
			rankName: map['RankName'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (rankCode != null)
			map['RankCode'] = rankCode;
		if (rankName != null)
			map['RankName'] = rankName;
		return map;
	}
}


