import 'dart:core';

import 'package:fis_jsonrpc/client_base.dart';
import 'package:fis_common/json_convert.dart';

import 'recognition.m.dart';


class RecognitionService extends JsonRpcClientBase {
	RecognitionService(
		String host, {
		String serviceName = "IRecognitionService",
		Map<String, String>? headers,
		int? timeout,
	}) : super(
						host,
						serviceName,
						headers: headers,
						timeout: timeout,
				) {
		/// 注册响应实体反序列化处理器
		FJsonConvert.setDecoder((map) => RecognitionResult.fromJson(map));
		FJsonConvert.setDecoder((map) => SearchPersonsResult.fromJson(map));
		FJsonConvert.setDecoder((map) => SavePersonResult.fromJson(map));
		FJsonConvert.setDecoder((map) => DeletePersonResult.fromJson(map));
		FJsonConvert.setDecoder((map) => FaceRecognitionDTO.fromJson(map));
	}

	Future<RecognitionResult> getIDCardInfoAsync(IDCardInfoRequest request) async {
		var rpcRst = await call("GetIDCardInfoAsync", request);
		var result = RecognitionResult.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<bool> addOrUpdatePersonAsync(AddOrUpdatePersonRequest request) async {
		var rpcRst = await call("AddOrUpdatePersonAsync", request);
		return rpcRst;
	}

	Future<SearchPersonsResult> searchPersonsAsync(SearchPersonsRequest request) async {
		var rpcRst = await call("SearchPersonsAsync", request);
		var result = SearchPersonsResult.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<SavePersonResult> savePersonAsync(SavePersonRequest request) async {
		var rpcRst = await call("SavePersonAsync", request);
		var result = SavePersonResult.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<DeletePersonResult> deletePersonAsync(DeletePersonRequest request) async {
		var rpcRst = await call("DeletePersonAsync", request);
		var result = DeletePersonResult.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<bool> savePersonFaceLocalAsync(AddPersonFaceRequest request) async {
		var rpcRst = await call("SavePersonFaceLocalAsync", request);
		return rpcRst;
	}

	Future<List<FaceRecognitionDTO>> getAllPersonListLocalAsync(GetPersonListRequest request) async {
		var rpcRst = await call("GetAllPersonListLocalAsync", request);
		var result = (rpcRst as List).map((e)=>FaceRecognitionDTO.fromJson(e as Map<String, dynamic>)).toList();
		return result;
	}

	Future<bool> deletePersonLocalAsync(DeletePersonRequest request) async {
		var rpcRst = await call("DeletePersonLocalAsync", request);
		return rpcRst;
	}

}

