import 'dart:core';

import 'package:fis_jsonrpc/client_base.dart';
import 'package:fis_common/json_convert.dart';

import 'recordInfo.m.dart';

import 'liveConsultation.m.dart';
import 'researchEdition.m.dart';
import 'patient.m.dart';


class RecordInfoService extends JsonRpcClientBase {
	RecordInfoService(
		String host, {
		String serviceName = "IRecordInfoService",
		Map<String, String>? headers,
		int? timeout,
	}) : super(
						host,
						serviceName,
						headers: headers,
						timeout: timeout,
				) {
		/// 注册响应实体反序列化处理器
		FJsonConvert.setDecoder((map) => PageResult<GetRecordsPageDTO>.fromJson(map));
		FJsonConvert.setDecoder((map) => GetRecordsPageDTO.fromJson(map));
		FJsonConvert.setDecoder((map) => QueryRecordResult.fromJson(map));
		FJsonConvert.setDecoder((map) => ProcessRecordDataResult.fromJson(map));
		FJsonConvert.setDecoder((map) => RemedicalMeasuredInfoDTO.fromJson(map));
		FJsonConvert.setDecoder((map) => PageResult<SimpleRecordInfoDTO>.fromJson(map));
		FJsonConvert.setDecoder((map) => SimpleRecordInfoDTO.fromJson(map));
		FJsonConvert.setDecoder((map) => ReferralHistoryDetail.fromJson(map));
	}

	Future<bool> createRecordInfoAsync(CreateRecordRequest request) async {
		var rpcRst = await call("CreateRecordInfoAsync", request);
		return rpcRst;
	}

	Future<String> createPatientRecordInfoAsync(CreateRecordRequest request) async {
		var rpcRst = await call("CreatePatientRecordInfoAsync", request);
		return rpcRst;
	}

	Future<bool> createExamDataAsync(CreateExamDataRequest request) async {
		var rpcRst = await call("CreateExamDataAsync", request);
		return rpcRst;
	}

	Future<PageResult<GetRecordsPageDTO>> getRecordInfoPagesAsync(GetRecordsPageRequest request) async {
		var rpcRst = await call("GetRecordInfoPagesAsync", request);
		var result = PageResult<GetRecordsPageDTO>.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<QueryRecordResult> queryRecordInfoAsync(QueryRecordRequest request) async {
		var rpcRst = await call("QueryRecordInfoAsync", request);
		var result = QueryRecordResult.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<int> getUnReadExamNumAsync(TokenRequest request) async {
		var rpcRst = await call("GetUnReadExamNumAsync", request);
		return rpcRst;
	}

	Future<ProcessRecordDataResult> processRecordDataAsync(ProcessRecordDataRequest request) async {
		var rpcRst = await call("ProcessRecordDataAsync", request);
		var result = ProcessRecordDataResult.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<bool> relevanceRecordAsync(RelevanceRecordRequest request) async {
		var rpcRst = await call("RelevanceRecordAsync", request);
		return rpcRst;
	}

	Future<bool> deleteRecordAsync(DeleteRecordRequest request) async {
		var rpcRst = await call("DeleteRecordAsync", request);
		return rpcRst;
	}

	Future<bool> finishRecordAsync(FinishRecordRequest request) async {
		var rpcRst = await call("FinishRecordAsync", request);
		return rpcRst;
	}

	Future<bool> addRemedicalMeasuredInfoAsync(AddRemedicalMeasuredInfoRequest request) async {
		var rpcRst = await call("AddRemedicalMeasuredInfoAsync", request);
		return rpcRst;
	}

	Future<List<RemedicalMeasuredInfoDTO>> findRemedicalMeasuredInfoAsync(FindRemedicalMeasuredInfoRequest request) async {
		var rpcRst = await call("FindRemedicalMeasuredInfoAsync", request);
		var result = (rpcRst as List).map((e)=>RemedicalMeasuredInfoDTO.fromJson(e as Map<String, dynamic>)).toList();
		return result;
	}

	Future<List<RemedicalMeasuredInfoDTO>> findRemedicalMeasuredInfoByRemedicalCodeAsync(FindRemedicalMeasuredInfoByRemedicalCodeRequest request) async {
		var rpcRst = await call("FindRemedicalMeasuredInfoByRemedicalCodeAsync", request);
		var result = (rpcRst as List).map((e)=>RemedicalMeasuredInfoDTO.fromJson(e as Map<String, dynamic>)).toList();
		return result;
	}

	Future<bool> checkCollectingImgAsync(CheckCollectingImgRequest request) async {
		var rpcRst = await call("CheckCollectingImgAsync", request);
		return rpcRst;
	}

	Future<bool> startCollectingImgAsync(StartCollectingImgRequest request) async {
		var rpcRst = await call("StartCollectingImgAsync", request);
		return rpcRst;
	}

	Future<PageResult<SimpleRecordInfoDTO>> findRecordPagesAsync(FindRecordPagesRequest request) async {
		var rpcRst = await call("FindRecordPagesAsync", request);
		var result = PageResult<SimpleRecordInfoDTO>.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<bool> createForRecordInfoListAsync(CreateRecordNewRequest request) async {
		var rpcRst = await call("CreateForRecordInfoListAsync", request);
		return rpcRst;
	}

	Future<bool> applyReferralForRecordInfoListAsync(CreateReferralRecordNewRequest request) async {
		var rpcRst = await call("ApplyReferralForRecordInfoListAsync", request);
		return rpcRst;
	}

	Future<bool> withdrawReferralForRecordInfoListAsync(WithdrawReferralForRecordListRequest request) async {
		var rpcRst = await call("WithdrawReferralForRecordInfoListAsync", request);
		return rpcRst;
	}

	Future<List<ReferralHistoryDetail>> findReferralHistoryAsync(FindReferralHistoryRequest request) async {
		var rpcRst = await call("FindReferralHistoryAsync", request);
		var result = (rpcRst as List).map((e)=>ReferralHistoryDetail.fromJson(e as Map<String, dynamic>)).toList();
		return result;
	}

	Future<bool> addRemedicalQualityAsync(AddRemedicalQualityRequest request) async {
		var rpcRst = await call("AddRemedicalQualityAsync", request);
		return rpcRst;
	}

	Future<bool> modifyRemedicalQualityAsync(ModifyRemedicalQualityRequest request) async {
		var rpcRst = await call("ModifyRemedicalQualityAsync", request);
		return rpcRst;
	}

	Future<bool> deleteRemedicalQualityAsync(DeleteRemedicalQualityRequest request) async {
		var rpcRst = await call("DeleteRemedicalQualityAsync", request);
		return rpcRst;
	}

	Future<bool> addRecordReportQualityAsync(AddRecordReportQualityRequest request) async {
		var rpcRst = await call("AddRecordReportQualityAsync", request);
		return rpcRst;
	}

	Future<bool> modifyRecordReportQualityAsync(ModifyRecordReportQualityRequest request) async {
		var rpcRst = await call("ModifyRecordReportQualityAsync", request);
		return rpcRst;
	}

	Future<bool> deleteRecordReportQualityAsync(DeleteRecordReportQualityRequest request) async {
		var rpcRst = await call("DeleteRecordReportQualityAsync", request);
		return rpcRst;
	}

}

