import 'dart:core';

import 'package:fis_jsonrpc/client_base.dart';
import 'package:fis_common/json_convert.dart';

import 'register.m.dart';

import 'researchEdition.m.dart';


class RegisterService extends JsonRpcClientBase {
	RegisterService(
		String host, {
		String serviceName = "IRegisterService",
		Map<String, String>? headers,
		int? timeout,
	}) : super(
						host,
						serviceName,
						headers: headers,
						timeout: timeout,
				) {
		/// 注册响应实体反序列化处理器
		FJsonConvert.setDecoder((map) => PersonInfoByFaceImageDTO.fromJson(map));
		FJsonConvert.setDecoder((map) => PageCollection<PersonInfoFullDTO>.fromJson(map));
		FJsonConvert.setDecoder((map) => PersonInfoFullDTO.fromJson(map));
		FJsonConvert.setDecoder((map) => EnterPersonFaceQueryResult.fromJson(map));
	}

	Future<bool> getUserInfoByOpenIdAsync(GetUserInfoByVitalOpenIdRequest request) async {
		var rpcRst = await call("GetUserInfoByOpenIdAsync", request);
		return rpcRst;
	}

	Future<bool> loginOutAsync(TokenRequest request) async {
		var rpcRst = await call("LoginOutAsync", request);
		return rpcRst;
	}

	Future<PersonInfoByFaceImageDTO> getPersonInfoByFaceImageAsync(GetPersonInfoByFaceImageRequest request) async {
		var rpcRst = await call("GetPersonInfoByFaceImageAsync", request);
		var result = PersonInfoByFaceImageDTO.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<bool> registerConfirmAsync(RegisterConfirmRequest request) async {
		var rpcRst = await call("RegisterConfirmAsync", request);
		return rpcRst;
	}

	Future<PageCollection<PersonInfoFullDTO>> getPersonInfoListAsync(GetPersonPageRequest request) async {
		var rpcRst = await call("GetPersonInfoListAsync", request);
		var result = PageCollection<PersonInfoFullDTO>.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<PersonInfoFullDTO> getPersonInfoByCodeAsync(GetPersonRequest request) async {
		var rpcRst = await call("GetPersonInfoByCodeAsync", request);
		var result = PersonInfoFullDTO.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<bool> deletePersonAsync(DeletePersonRequest2 request) async {
		var rpcRst = await call("DeletePersonAsync", request);
		return rpcRst;
	}

	Future<EnterPersonFaceQueryResult> enterPersonFaceQueryAsync(EnterPersonFaceQueryRequest request) async {
		var rpcRst = await call("EnterPersonFaceQueryAsync", request);
		var result = EnterPersonFaceQueryResult.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<bool> enterPersonFaceAsync(EnterPersonFaceRequest request) async {
		var rpcRst = await call("EnterPersonFaceAsync", request);
		return rpcRst;
	}

}

