import 'researchEdition.m.dart';
import 'appletAPI.m.dart';

import 'package:fis_jsonrpc/utils.dart';

class GetUserInfoByVitalOpenIdRequest {
	String? openId;

	GetUserInfoByVitalOpenIdRequest({
		this.openId,
	});

	factory GetUserInfoByVitalOpenIdRequest.fromJson(Map<String, dynamic> map) {
		return GetUserInfoByVitalOpenIdRequest( 
			openId: map['OpenId'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		if (openId != null)
			map['OpenId'] = openId;
		return map;
	}
}

class PersonInfoBaseDTO {
	String? name;
	String? headImg;
	PatientGenderEnum sex;
	String? age;
	String? cardID;
	String? remarks;
	String? code;
	String? organization;
	String? nautical;
	String? government;

	PersonInfoBaseDTO({
		this.name,
		this.headImg,
		this.sex = PatientGenderEnum.NotFilled,
		this.age,
		this.cardID,
		this.remarks,
		this.code,
		this.organization,
		this.nautical,
		this.government,
	});

	factory PersonInfoBaseDTO.fromJson(Map<String, dynamic> map) {
		return PersonInfoBaseDTO( 
			name: map['Name'],
			headImg: map['HeadImg'],
			sex: PatientGenderEnum.values.firstWhere((e) => e.index == map['Sex']),
			age: map['Age'],
			cardID: map['CardID'],
			remarks: map['Remarks'],
			code: map['Code'],
			organization: map['Organization'],
			nautical: map['Nautical'],
			government: map['Government'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		if (name != null)
			map['Name'] = name;
		if (headImg != null)
			map['HeadImg'] = headImg;
		map['Sex'] = sex.index;
		if (age != null)
			map['Age'] = age;
		if (cardID != null)
			map['CardID'] = cardID;
		if (remarks != null)
			map['Remarks'] = remarks;
		if (code != null)
			map['Code'] = code;
		if (organization != null)
			map['Organization'] = organization;
		if (nautical != null)
			map['Nautical'] = nautical;
		if (government != null)
			map['Government'] = government;
		return map;
	}
}

enum FaceScanErrorTypeEnum {
	Success,
	NoCreated,
	APIError,
}

class PersonInfoByFaceImageDTO extends PersonInfoBaseDTO{
	bool isSuccess;
	FaceScanErrorTypeEnum faceScanErrorType;
	String? errorMessage;

	PersonInfoByFaceImageDTO({
		this.isSuccess = false,
		this.faceScanErrorType = FaceScanErrorTypeEnum.Success,
		this.errorMessage,
		String? name,
		String? headImg,
		PatientGenderEnum sex = PatientGenderEnum.NotFilled,
		String? age,
		String? cardID,
		String? remarks,
		String? code,
		String? organization,
		String? nautical,
		String? government,
	}) : super(
			name: name,
			headImg: headImg,
			sex: sex,
			age: age,
			cardID: cardID,
			remarks: remarks,
			code: code,
			organization: organization,
			nautical: nautical,
			government: government,
		);

	factory PersonInfoByFaceImageDTO.fromJson(Map<String, dynamic> map) {
		return PersonInfoByFaceImageDTO( 
			isSuccess: map['IsSuccess'],
			faceScanErrorType: FaceScanErrorTypeEnum.values.firstWhere((e) => e.index == map['FaceScanErrorType']),
			errorMessage: map['ErrorMessage'],
			name: map['Name'],
			headImg: map['HeadImg'],
			sex: PatientGenderEnum.values.firstWhere((e) => e.index == map['Sex']),
			age: map['Age'],
			cardID: map['CardID'],
			remarks: map['Remarks'],
			code: map['Code'],
			organization: map['Organization'],
			nautical: map['Nautical'],
			government: map['Government'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		map['IsSuccess'] = isSuccess;
		map['FaceScanErrorType'] = faceScanErrorType.index;
		if (errorMessage != null)
			map['ErrorMessage'] = errorMessage;
		return map;
	}
}

class GetPersonInfoByFaceImageRequest extends TokenRequest{
	String? image;

	GetPersonInfoByFaceImageRequest({
		this.image,
		String? token,
	}) : super(
			token: token,
		);

	factory GetPersonInfoByFaceImageRequest.fromJson(Map<String, dynamic> map) {
		return GetPersonInfoByFaceImageRequest( 
			image: map['Image'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (image != null)
			map['Image'] = image;
		return map;
	}
}

class RegisterConfirmRequest extends TokenRequest{
	bool isNormal;
	String? code;
	String? organization;
	String? nautical;
	String? government;

	RegisterConfirmRequest({
		this.isNormal = false,
		this.code,
		this.organization,
		this.nautical,
		this.government,
		String? token,
	}) : super(
			token: token,
		);

	factory RegisterConfirmRequest.fromJson(Map<String, dynamic> map) {
		return RegisterConfirmRequest( 
			isNormal: map['IsNormal'],
			code: map['Code'],
			organization: map['Organization'],
			nautical: map['Nautical'],
			government: map['Government'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		map['IsNormal'] = isNormal;
		if (code != null)
			map['Code'] = code;
		if (organization != null)
			map['Organization'] = organization;
		if (nautical != null)
			map['Nautical'] = nautical;
		if (government != null)
			map['Government'] = government;
		return map;
	}
}

class PersonRegisterDTO {
	bool isNormal;
	DateTime? registerTime;
	String? organization;
	String? nautical;

	PersonRegisterDTO({
		this.isNormal = false,
		this.registerTime,
		this.organization,
		this.nautical,
	});

	factory PersonRegisterDTO.fromJson(Map<String, dynamic> map) {
		return PersonRegisterDTO( 
			isNormal: map['IsNormal'],
			registerTime: map['RegisterTime'] != null ? DateTime.parse(map['RegisterTime']) : null,
			organization: map['Organization'],
			nautical: map['Nautical'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		map['IsNormal'] = isNormal;
		if (registerTime != null)
			map['RegisterTime'] = JsonRpcUtils.dateFormat(registerTime!);
		if (organization != null)
			map['Organization'] = organization;
		if (nautical != null)
			map['Nautical'] = nautical;
		return map;
	}
}

class PersonInfoFullDTO extends PersonInfoBaseDTO{
	List<PersonRegisterDTO>? personRegisterRecordList;

	PersonInfoFullDTO({
		this.personRegisterRecordList,
		String? name,
		String? headImg,
		PatientGenderEnum sex = PatientGenderEnum.NotFilled,
		String? age,
		String? cardID,
		String? remarks,
		String? code,
		String? organization,
		String? nautical,
		String? government,
	}) : super(
			name: name,
			headImg: headImg,
			sex: sex,
			age: age,
			cardID: cardID,
			remarks: remarks,
			code: code,
			organization: organization,
			nautical: nautical,
			government: government,
		);

	factory PersonInfoFullDTO.fromJson(Map<String, dynamic> map) {
		return PersonInfoFullDTO( 
			personRegisterRecordList: map['PersonRegisterRecordList'] != null ? (map['PersonRegisterRecordList'] as List).map((e)=>PersonRegisterDTO.fromJson(e as Map<String,dynamic>)).toList() : null,
			name: map['Name'],
			headImg: map['HeadImg'],
			sex: PatientGenderEnum.values.firstWhere((e) => e.index == map['Sex']),
			age: map['Age'],
			cardID: map['CardID'],
			remarks: map['Remarks'],
			code: map['Code'],
			organization: map['Organization'],
			nautical: map['Nautical'],
			government: map['Government'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (personRegisterRecordList != null)
			map['PersonRegisterRecordList'] = personRegisterRecordList;
		return map;
	}
}

class GetPersonPageRequest extends PageRequest{
	String? keyword;
	String? government;

	GetPersonPageRequest({
		this.keyword,
		this.government,
		int pageIndex = 0,
		int pageSize = 0,
		String? token,
	}) : super(
			pageIndex: pageIndex,
			pageSize: pageSize,
			token: token,
		);

	factory GetPersonPageRequest.fromJson(Map<String, dynamic> map) {
		return GetPersonPageRequest( 
			keyword: map['Keyword'],
			government: map['Government'],
			pageIndex: map['PageIndex'],
			pageSize: map['PageSize'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (keyword != null)
			map['Keyword'] = keyword;
		if (government != null)
			map['Government'] = government;
		return map;
	}
}

class GetPersonRequest extends TokenRequest{
	String? code;

	GetPersonRequest({
		this.code,
		String? token,
	}) : super(
			token: token,
		);

	factory GetPersonRequest.fromJson(Map<String, dynamic> map) {
		return GetPersonRequest( 
			code: map['Code'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		return map;
	}
}

class DeletePersonRequest2 extends TokenRequest{
	String? code;

	DeletePersonRequest2({
		this.code,
		String? token,
	}) : super(
			token: token,
		);

	factory DeletePersonRequest2.fromJson(Map<String, dynamic> map) {
		return DeletePersonRequest2( 
			code: map['Code'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		return map;
	}
}

class EnterPersonFaceQueryResult {
	FaceScanErrorTypeEnum faceScanErrorType;
	String? errorMessage;
	String? name;

	EnterPersonFaceQueryResult({
		this.faceScanErrorType = FaceScanErrorTypeEnum.Success,
		this.errorMessage,
		this.name,
	});

	factory EnterPersonFaceQueryResult.fromJson(Map<String, dynamic> map) {
		return EnterPersonFaceQueryResult( 
			faceScanErrorType: FaceScanErrorTypeEnum.values.firstWhere((e) => e.index == map['FaceScanErrorType']),
			errorMessage: map['ErrorMessage'],
			name: map['Name'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		map['FaceScanErrorType'] = faceScanErrorType.index;
		if (errorMessage != null)
			map['ErrorMessage'] = errorMessage;
		if (name != null)
			map['Name'] = name;
		return map;
	}
}

class EnterPersonFaceQueryRequest extends TokenRequest{
	String? image;

	EnterPersonFaceQueryRequest({
		this.image,
		String? token,
	}) : super(
			token: token,
		);

	factory EnterPersonFaceQueryRequest.fromJson(Map<String, dynamic> map) {
		return EnterPersonFaceQueryRequest( 
			image: map['Image'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (image != null)
			map['Image'] = image;
		return map;
	}
}

class EnterPersonFaceRequest extends TokenRequest{
	String? name;
	String? headImg;
	PatientGenderEnum sex;
	String? age;
	String? cardID;
	String? remarks;
	bool isNormal;
	String? organization;
	String? nautical;
	String? government;

	EnterPersonFaceRequest({
		this.name,
		this.headImg,
		this.sex = PatientGenderEnum.NotFilled,
		this.age,
		this.cardID,
		this.remarks,
		this.isNormal = false,
		this.organization,
		this.nautical,
		this.government,
		String? token,
	}) : super(
			token: token,
		);

	factory EnterPersonFaceRequest.fromJson(Map<String, dynamic> map) {
		return EnterPersonFaceRequest( 
			name: map['Name'],
			headImg: map['HeadImg'],
			sex: PatientGenderEnum.values.firstWhere((e) => e.index == map['Sex']),
			age: map['Age'],
			cardID: map['CardID'],
			remarks: map['Remarks'],
			isNormal: map['IsNormal'],
			organization: map['Organization'],
			nautical: map['Nautical'],
			government: map['Government'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (name != null)
			map['Name'] = name;
		if (headImg != null)
			map['HeadImg'] = headImg;
		map['Sex'] = sex.index;
		if (age != null)
			map['Age'] = age;
		if (cardID != null)
			map['CardID'] = cardID;
		if (remarks != null)
			map['Remarks'] = remarks;
		map['IsNormal'] = isNormal;
		if (organization != null)
			map['Organization'] = organization;
		if (nautical != null)
			map['Nautical'] = nautical;
		if (government != null)
			map['Government'] = government;
		return map;
	}
}


