import 'dart:core';

import 'package:fis_jsonrpc/client_base.dart';
import 'package:fis_common/json_convert.dart';

import 'researchEdition.m.dart';


class ResearchEditionService extends JsonRpcClientBase {
	ResearchEditionService(
		String host, {
		String serviceName = "IResearchEditionService",
		Map<String, String>? headers,
		int? timeout,
	}) : super(
						host,
						serviceName,
						headers: headers,
						timeout: timeout,
				) {
		/// 注册响应实体反序列化处理器
		FJsonConvert.setDecoder((map) => ResearchProjectBaseDTO.fromJson(map));
		FJsonConvert.setDecoder((map) => ResearchProjectDTO.fromJson(map));
		FJsonConvert.setDecoder((map) => PageCollection<ResearchProjectDataDTO>.fromJson(map));
		FJsonConvert.setDecoder((map) => ResearchProjectDataDTO.fromJson(map));
		FJsonConvert.setDecoder((map) => SampleDetail.fromJson(map));
		FJsonConvert.setDecoder((map) => SampleRemedicalInfoDTO.fromJson(map));
		FJsonConvert.setDecoder((map) => TaskBaseDTO.fromJson(map));
		FJsonConvert.setDecoder((map) => MainTaskDTO.fromJson(map));
		FJsonConvert.setDecoder((map) => TaskDTO.fromJson(map));
		FJsonConvert.setDecoder((map) => TimeAxisDetail.fromJson(map));
		FJsonConvert.setDecoder((map) => PageCollection<UserBaseDTO>.fromJson(map));
		FJsonConvert.setDecoder((map) => UserBaseDTO.fromJson(map));
		FJsonConvert.setDecoder((map) => SaveAnalysisVideoResult.fromJson(map));
		FJsonConvert.setDecoder((map) => BaseSampleDetail.fromJson(map));
		FJsonConvert.setDecoder((map) => UserFeatureInfoResult.fromJson(map));
		FJsonConvert.setDecoder((map) => LicenseInfoDTO.fromJson(map));
		FJsonConvert.setDecoder((map) => ProjectSampleDataExportResult.fromJson(map));
		FJsonConvert.setDecoder((map) => SaveUserUrmConfigResult.fromJson(map));
		FJsonConvert.setDecoder((map) => UserUrmConfigDTO.fromJson(map));
	}

	Future<List<ResearchProjectBaseDTO>> getDeviceResearchProjectListAsync(GetDeviceResearchProjectListRequest request) async {
		var rpcRst = await call("GetDeviceResearchProjectListAsync", request);
		var result = (rpcRst as List).map((e)=>ResearchProjectBaseDTO.fromJson(e as Map<String, dynamic>)).toList();
		return result;
	}

	Future<List<ResearchProjectBaseDTO>> getResearchProjectListAsync(GetResearchProjectListRequest request) async {
		var rpcRst = await call("GetResearchProjectListAsync", request);
		var result = (rpcRst as List).map((e)=>ResearchProjectBaseDTO.fromJson(e as Map<String, dynamic>)).toList();
		return result;
	}

	Future<ResearchProjectDTO> getResearchProjectDetailAsync(GetResearchProjectDetailRequest request) async {
		var rpcRst = await call("GetResearchProjectDetailAsync", request);
		var result = ResearchProjectDTO.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<String> createResearchProjectAsync(CreateResearchProjectRequest request) async {
		var rpcRst = await call("CreateResearchProjectAsync", request);
		return rpcRst;
	}

	Future<bool> updateResearchProjectAsync(UpdateResearchProjectRequest request) async {
		var rpcRst = await call("UpdateResearchProjectAsync", request);
		return rpcRst;
	}

	Future<bool> deleteResearchProjectAsync(DeleteResearchProjectRequest request) async {
		var rpcRst = await call("DeleteResearchProjectAsync", request);
		return rpcRst;
	}

	Future<bool> deleteSampleAsync(DeletePatientSampleRequest request) async {
		var rpcRst = await call("DeleteSampleAsync", request);
		return rpcRst;
	}

	Future<bool> inviteResearchProjectMembersAsync(InviteResearchProjectMembersRequest request) async {
		var rpcRst = await call("InviteResearchProjectMembersAsync", request);
		return rpcRst;
	}

	Future<bool> removeResearchProjectMembersAsync(RemoveResearchProjectMembersRequest request) async {
		var rpcRst = await call("RemoveResearchProjectMembersAsync", request);
		return rpcRst;
	}

	Future<String> createResearchProjectTaskAsync(CreateResearchProjectTaskRequest request) async {
		var rpcRst = await call("CreateResearchProjectTaskAsync", request);
		return rpcRst;
	}

	Future<bool> updateResearchProjectTaskAsync(UpdateResearchProjectTaskRequest request) async {
		var rpcRst = await call("UpdateResearchProjectTaskAsync", request);
		return rpcRst;
	}

	Future<bool> cancelMainTaskAsync(BatchAnalysisTaskRequest request) async {
		var rpcRst = await call("CancelMainTaskAsync", request);
		return rpcRst;
	}

	Future<PageCollection<ResearchProjectDataDTO>> getResearchProjectDataPagesAsync(GetResearchProjectDatasRequest request) async {
		var rpcRst = await call("GetResearchProjectDataPagesAsync", request);
		var result = PageCollection<ResearchProjectDataDTO>.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<List<SampleDetail>> getSampleDetailList(GetSampleDetailsRequest request) async {
		var rpcRst = await call("GetSampleDetailList", request);
		var result = (rpcRst as List).map((e)=>SampleDetail.fromJson(e as Map<String, dynamic>)).toList();
		return result;
	}

	Future<List<SampleRemedicalInfoDTO>> getSampleImgList(GetSampleDetailsRequest request) async {
		var rpcRst = await call("GetSampleImgList", request);
		var result = (rpcRst as List).map((e)=>SampleRemedicalInfoDTO.fromJson(e as Map<String, dynamic>)).toList();
		return result;
	}

	Future<List<SampleRemedicalInfoDTO>> getUrmRemedicalInfosAsync(GetUrmRemedicalInfosRequest request) async {
		var rpcRst = await call("GetUrmRemedicalInfosAsync", request);
		var result = (rpcRst as List).map((e)=>SampleRemedicalInfoDTO.fromJson(e as Map<String, dynamic>)).toList();
		return result;
	}

	Future<List<TaskBaseDTO>> getTaskListAsync(GetTaskListRequest request) async {
		var rpcRst = await call("GetTaskListAsync", request);
		var result = (rpcRst as List).map((e)=>TaskBaseDTO.fromJson(e as Map<String, dynamic>)).toList();
		return result;
	}

	Future<MainTaskDTO> getMainTaskDetailAsync(GetMainTaskDetailRequest request) async {
		var rpcRst = await call("GetMainTaskDetailAsync", request);
		var result = MainTaskDTO.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<TaskDTO> getTaskDetailAsync(GetTaskDetailRequest request) async {
		var rpcRst = await call("GetTaskDetailAsync", request);
		var result = TaskDTO.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<List<TimeAxisDetail>> getTimeAxisByProjectAsync(GetTaskListByProjectRequest request) async {
		var rpcRst = await call("GetTimeAxisByProjectAsync", request);
		var result = (rpcRst as List).map((e)=>TimeAxisDetail.fromJson(e as Map<String, dynamic>)).toList();
		return result;
	}

	Future<PageCollection<UserBaseDTO>> getUserBaseInfoPagesAsync(GetRRUserPagesRequest request) async {
		var rpcRst = await call("GetUserBaseInfoPagesAsync", request);
		var result = PageCollection<UserBaseDTO>.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<String> batchAnalysisAsync(BatchAnalysisRequest request) async {
		var rpcRst = await call("BatchAnalysisAsync", request);
		return rpcRst;
	}

	Future<String> batchJumpQueueAnalysisAsync(BatchAnalysisRequest request) async {
		var rpcRst = await call("BatchJumpQueueAnalysisAsync", request);
		return rpcRst;
	}

	Future<bool> pauseAnalysisAsync(AnalysisTaskRequest request) async {
		var rpcRst = await call("PauseAnalysisAsync", request);
		return rpcRst;
	}

	Future<bool> pauseBatchAnalysisAsync(BatchAnalysisTaskRequest request) async {
		var rpcRst = await call("PauseBatchAnalysisAsync", request);
		return rpcRst;
	}

	Future<bool> cancelAnalysisAsync(AnalysisTaskRequest request) async {
		var rpcRst = await call("CancelAnalysisAsync", request);
		return rpcRst;
	}

	Future<bool> cancelBatchAnalysisAsync(BatchAnalysisTaskRequest request) async {
		var rpcRst = await call("CancelBatchAnalysisAsync", request);
		return rpcRst;
	}

	Future<bool> continueAnalysisAsync(AnalysisTaskRequest request) async {
		var rpcRst = await call("ContinueAnalysisAsync", request);
		return rpcRst;
	}

	Future<bool> continueBatchAnalysisAsync(BatchAnalysisTaskRequest request) async {
		var rpcRst = await call("ContinueBatchAnalysisAsync", request);
		return rpcRst;
	}

	Future<String> saveAnalysisVideoByTaskAsync(SaveAnalysisVideoRequest request) async {
		var rpcRst = await call("SaveAnalysisVideoByTaskAsync", request);
		return rpcRst;
	}

	Future<SaveAnalysisVideoResult> saveAnalysisVideoAsync(SaveAnalysisVideoRequest request) async {
		var rpcRst = await call("SaveAnalysisVideoAsync", request);
		var result = SaveAnalysisVideoResult.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<int> activationLicenseAsync(ActivationLicenseRequest request) async {
		var rpcRst = await call("ActivationLicenseAsync", request);
		return rpcRst;
	}

	Future<BaseSampleDetail> getSampleDetailAsync(GetSampleDetailRequest request) async {
		var rpcRst = await call("GetSampleDetailAsync", request);
		var result = BaseSampleDetail.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<bool> modifySampleDetailAsync(ModifySampleDetailRequest request) async {
		var rpcRst = await call("ModifySampleDetailAsync", request);
		return rpcRst;
	}

	Future<List<UserFeatureInfoResult>> getResearchProjectUserFeatureListAsync(TokenRequest request) async {
		var rpcRst = await call("GetResearchProjectUserFeatureListAsync", request);
		var result = (rpcRst as List).map((e)=>UserFeatureInfoResult.fromJson(e as Map<String, dynamic>)).toList();
		return result;
	}

	Future<LicenseInfoDTO> getLicenseInfoAsync(TokenRequest request) async {
		var rpcRst = await call("GetLicenseInfoAsync", request);
		var result = LicenseInfoDTO.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<ProjectSampleDataExportResult> getProjectSampleDataExportAsync(GetProjectSampleDataExportRequest request) async {
		var rpcRst = await call("GetProjectSampleDataExportAsync", request);
		var result = ProjectSampleDataExportResult.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<String> getMachaineIdAsync(TokenRequest request) async {
		var rpcRst = await call("GetMachaineIdAsync", request);
		return rpcRst;
	}

	Future<String> getServerHostUrlAsync(TokenRequest request) async {
		var rpcRst = await call("GetServerHostUrlAsync", request);
		return rpcRst;
	}

	Future<SaveUserUrmConfigResult> saveUserUrmConfigAsync(SaveUserUrmConfigRequest request) async {
		var rpcRst = await call("SaveUserUrmConfigAsync", request);
		var result = SaveUserUrmConfigResult.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<bool> deletePatientUrmConfigAsync(DeletePatientUrmConfigRequest request) async {
		var rpcRst = await call("DeletePatientUrmConfigAsync", request);
		return rpcRst;
	}

	Future<bool> setDefaultPatientUrmConfigAsync(SetDefaultPatientUrmConfigRequest request) async {
		var rpcRst = await call("SetDefaultPatientUrmConfigAsync", request);
		return rpcRst;
	}

	Future<List<UserUrmConfigDTO>> getUserUrmConfigsAsync(GetUserUrmConfigsRequest request) async {
		var rpcRst = await call("GetUserUrmConfigsAsync", request);
		var result = (rpcRst as List).map((e)=>UserUrmConfigDTO.fromJson(e as Map<String, dynamic>)).toList();
		return result;
	}

	Future<bool> validateResearchProjectAuthAsync(GetResearchProjectDetailRequest request) async {
		var rpcRst = await call("ValidateResearchProjectAuthAsync", request);
		return rpcRst;
	}

}

