import 'notification.m.dart';

import 'package:fis_jsonrpc/utils.dart';

import 'package:fis_common/json_convert.dart';

enum OrganizationPatientTypeEnum {
	Person,
	Animals,
}

class ResearchProjectBaseDTO {
	String? code;
	String? creatorCode;
	String? creatorName;
	DateTime? createTime;
	String? operatorCode;
	String? operatorName;
	DateTime? operateTime;
	String? name;
	String? belongUserCode;
	OrganizationPatientTypeEnum patientType;
	String? introduction;

	ResearchProjectBaseDTO({
		this.code,
		this.creatorCode,
		this.creatorName,
		this.createTime,
		this.operatorCode,
		this.operatorName,
		this.operateTime,
		this.name,
		this.belongUserCode,
		this.patientType = OrganizationPatientTypeEnum.Person,
		this.introduction,
	});

	factory ResearchProjectBaseDTO.fromJson(Map<String, dynamic> map) {
		return ResearchProjectBaseDTO( 
			code: map['Code'],
			creatorCode: map['CreatorCode'],
			creatorName: map['CreatorName'],
			createTime: map['CreateTime'] != null ? DateTime.parse(map['CreateTime']) : null,
			operatorCode: map['OperatorCode'],
			operatorName: map['OperatorName'],
			operateTime: map['OperateTime'] != null ? DateTime.parse(map['OperateTime']) : null,
			name: map['Name'],
			belongUserCode: map['BelongUserCode'],
			patientType: OrganizationPatientTypeEnum.values.firstWhere((e) => e.index == map['PatientType']),
			introduction: map['Introduction'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		if (code != null)
			map['Code'] = code;
		if (creatorCode != null)
			map['CreatorCode'] = creatorCode;
		if (creatorName != null)
			map['CreatorName'] = creatorName;
		if (createTime != null)
			map['CreateTime'] = JsonRpcUtils.dateFormat(createTime!);
		if (operatorCode != null)
			map['OperatorCode'] = operatorCode;
		if (operatorName != null)
			map['OperatorName'] = operatorName;
		if (operateTime != null)
			map['OperateTime'] = JsonRpcUtils.dateFormat(operateTime!);
		if (name != null)
			map['Name'] = name;
		if (belongUserCode != null)
			map['BelongUserCode'] = belongUserCode;
		map['PatientType'] = patientType.index;
		if (introduction != null)
			map['Introduction'] = introduction;
		return map;
	}
}

class BaseRequest {

	BaseRequest();

	factory BaseRequest.fromJson(Map<String, dynamic> map) {
		return BaseRequest( 
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		return map;
	}
}

class TokenRequest extends BaseRequest{
	String? token;

	TokenRequest({
		this.token,
	}) : super(
		);

	factory TokenRequest.fromJson(Map<String, dynamic> map) {
		return TokenRequest( 
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (token != null)
			map['Token'] = token;
		return map;
	}
}

class GetDeviceResearchProjectListRequest extends TokenRequest{
	String? keyword;

	GetDeviceResearchProjectListRequest({
		this.keyword,
		String? token,
	}) : super(
			token: token,
		);

	factory GetDeviceResearchProjectListRequest.fromJson(Map<String, dynamic> map) {
		return GetDeviceResearchProjectListRequest( 
			keyword: map['Keyword'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (keyword != null)
			map['Keyword'] = keyword;
		return map;
	}
}

enum ResearchProjectSearchTypeEnum {
	Undefined,
	ICreated,
	IJoined,
}

class GetResearchProjectListRequest extends TokenRequest{
	ResearchProjectSearchTypeEnum searchType;
	String? keyword;

	GetResearchProjectListRequest({
		this.searchType = ResearchProjectSearchTypeEnum.Undefined,
		this.keyword,
		String? token,
	}) : super(
			token: token,
		);

	factory GetResearchProjectListRequest.fromJson(Map<String, dynamic> map) {
		return GetResearchProjectListRequest( 
			searchType: ResearchProjectSearchTypeEnum.values.firstWhere((e) => e.index == map['SearchType']),
			keyword: map['Keyword'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		map['SearchType'] = searchType.index;
		if (keyword != null)
			map['Keyword'] = keyword;
		return map;
	}
}

class UserBaseDTO extends BaseDTO{
	String? phone;
	String? email;
	String? userCode;
	String? userName;
	String? fullName;
	String? headImageUrl;
	String? displayName;

	UserBaseDTO({
		this.phone,
		this.email,
		this.userCode,
		this.userName,
		this.fullName,
		this.headImageUrl,
		this.displayName,
		bool isDelete = false,
		DateTime? createTime,
		DateTime? updateTime,
	}) : super(
			isDelete: isDelete,
			createTime: createTime,
			updateTime: updateTime,
		);

	factory UserBaseDTO.fromJson(Map<String, dynamic> map) {
		return UserBaseDTO( 
			phone: map['Phone'],
			email: map['Email'],
			userCode: map['UserCode'],
			userName: map['UserName'],
			fullName: map['FullName'],
			headImageUrl: map['HeadImageUrl'],
			displayName: map['DisplayName'],
			isDelete: map['IsDelete'],
			createTime: map['CreateTime'] != null ? DateTime.parse(map['CreateTime']) : null,
			updateTime: map['UpdateTime'] != null ? DateTime.parse(map['UpdateTime']) : null,
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (phone != null)
			map['Phone'] = phone;
		if (email != null)
			map['Email'] = email;
		if (userCode != null)
			map['UserCode'] = userCode;
		if (userName != null)
			map['UserName'] = userName;
		if (fullName != null)
			map['FullName'] = fullName;
		if (headImageUrl != null)
			map['HeadImageUrl'] = headImageUrl;
		if (displayName != null)
			map['DisplayName'] = displayName;
		return map;
	}
}

class ResearchProjectDataDTO {
	String? patientCode;
	String? patientName;
	String? devicePatientId;
	String? fileSize;
	DateTime? createTime;
	bool isUrm;

	ResearchProjectDataDTO({
		this.patientCode,
		this.patientName,
		this.devicePatientId,
		this.fileSize,
		this.createTime,
		this.isUrm = false,
	});

	factory ResearchProjectDataDTO.fromJson(Map<String, dynamic> map) {
		return ResearchProjectDataDTO( 
			patientCode: map['PatientCode'],
			patientName: map['PatientName'],
			devicePatientId: map['DevicePatientId'],
			fileSize: map['FileSize'],
			createTime: map['CreateTime'] != null ? DateTime.parse(map['CreateTime']) : null,
			isUrm: map['IsUrm'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		if (patientCode != null)
			map['PatientCode'] = patientCode;
		if (patientName != null)
			map['PatientName'] = patientName;
		if (devicePatientId != null)
			map['DevicePatientId'] = devicePatientId;
		if (fileSize != null)
			map['FileSize'] = fileSize;
		if (createTime != null)
			map['CreateTime'] = JsonRpcUtils.dateFormat(createTime!);
		map['IsUrm'] = isUrm;
		return map;
	}
}

class ResearchProjectDTO extends ResearchProjectBaseDTO{
	List<UserBaseDTO>? users;
	List<ResearchProjectDataDTO>? researchProjectDataList;

	ResearchProjectDTO({
		this.users,
		this.researchProjectDataList,
		String? code,
		String? creatorCode,
		String? creatorName,
		DateTime? createTime,
		String? operatorCode,
		String? operatorName,
		DateTime? operateTime,
		String? name,
		String? belongUserCode,
		OrganizationPatientTypeEnum patientType = OrganizationPatientTypeEnum.Person,
		String? introduction,
	}) : super(
			code: code,
			creatorCode: creatorCode,
			creatorName: creatorName,
			createTime: createTime,
			operatorCode: operatorCode,
			operatorName: operatorName,
			operateTime: operateTime,
			name: name,
			belongUserCode: belongUserCode,
			patientType: patientType,
			introduction: introduction,
		);

	factory ResearchProjectDTO.fromJson(Map<String, dynamic> map) {
		return ResearchProjectDTO( 
			users: map['Users'] != null ? (map['Users'] as List).map((e)=>UserBaseDTO.fromJson(e as Map<String,dynamic>)).toList() : null,
			researchProjectDataList: map['ResearchProjectDataList'] != null ? (map['ResearchProjectDataList'] as List).map((e)=>ResearchProjectDataDTO.fromJson(e as Map<String,dynamic>)).toList() : null,
			code: map['Code'],
			creatorCode: map['CreatorCode'],
			creatorName: map['CreatorName'],
			createTime: map['CreateTime'] != null ? DateTime.parse(map['CreateTime']) : null,
			operatorCode: map['OperatorCode'],
			operatorName: map['OperatorName'],
			operateTime: map['OperateTime'] != null ? DateTime.parse(map['OperateTime']) : null,
			name: map['Name'],
			belongUserCode: map['BelongUserCode'],
			patientType: OrganizationPatientTypeEnum.values.firstWhere((e) => e.index == map['PatientType']),
			introduction: map['Introduction'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (users != null)
			map['Users'] = users;
		if (researchProjectDataList != null)
			map['ResearchProjectDataList'] = researchProjectDataList;
		return map;
	}
}

class GetResearchProjectDetailRequest extends TokenRequest{
	String? code;
	String? userCode;

	GetResearchProjectDetailRequest({
		this.code,
		this.userCode,
		String? token,
	}) : super(
			token: token,
		);

	factory GetResearchProjectDetailRequest.fromJson(Map<String, dynamic> map) {
		return GetResearchProjectDetailRequest( 
			code: map['Code'],
			userCode: map['UserCode'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		if (userCode != null)
			map['UserCode'] = userCode;
		return map;
	}
}

class CreateResearchProjectRequest extends TokenRequest{
	String? name;
	OrganizationPatientTypeEnum patientType;
	String? introduction;

	CreateResearchProjectRequest({
		this.name,
		this.patientType = OrganizationPatientTypeEnum.Person,
		this.introduction,
		String? token,
	}) : super(
			token: token,
		);

	factory CreateResearchProjectRequest.fromJson(Map<String, dynamic> map) {
		return CreateResearchProjectRequest( 
			name: map['Name'],
			patientType: OrganizationPatientTypeEnum.values.firstWhere((e) => e.index == map['PatientType']),
			introduction: map['Introduction'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (name != null)
			map['Name'] = name;
		map['PatientType'] = patientType.index;
		if (introduction != null)
			map['Introduction'] = introduction;
		return map;
	}
}

class UpdateResearchProjectRequest extends TokenRequest{
	String? code;
	String? name;
	OrganizationPatientTypeEnum patientType;
	String? introduction;

	UpdateResearchProjectRequest({
		this.code,
		this.name,
		this.patientType = OrganizationPatientTypeEnum.Person,
		this.introduction,
		String? token,
	}) : super(
			token: token,
		);

	factory UpdateResearchProjectRequest.fromJson(Map<String, dynamic> map) {
		return UpdateResearchProjectRequest( 
			code: map['Code'],
			name: map['Name'],
			patientType: OrganizationPatientTypeEnum.values.firstWhere((e) => e.index == map['PatientType']),
			introduction: map['Introduction'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		if (name != null)
			map['Name'] = name;
		map['PatientType'] = patientType.index;
		if (introduction != null)
			map['Introduction'] = introduction;
		return map;
	}
}

class DeleteResearchProjectRequest extends TokenRequest{
	String? code;

	DeleteResearchProjectRequest({
		this.code,
		String? token,
	}) : super(
			token: token,
		);

	factory DeleteResearchProjectRequest.fromJson(Map<String, dynamic> map) {
		return DeleteResearchProjectRequest( 
			code: map['Code'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		return map;
	}
}

class DeletePatientSampleRequest extends TokenRequest{
	String? projectCode;
	String? patientCode;
	String? userName;
	String? userCode;

	DeletePatientSampleRequest({
		this.projectCode,
		this.patientCode,
		this.userName,
		this.userCode,
		String? token,
	}) : super(
			token: token,
		);

	factory DeletePatientSampleRequest.fromJson(Map<String, dynamic> map) {
		return DeletePatientSampleRequest( 
			projectCode: map['ProjectCode'],
			patientCode: map['PatientCode'],
			userName: map['UserName'],
			userCode: map['UserCode'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (projectCode != null)
			map['ProjectCode'] = projectCode;
		if (patientCode != null)
			map['PatientCode'] = patientCode;
		if (userName != null)
			map['UserName'] = userName;
		if (userCode != null)
			map['UserCode'] = userCode;
		return map;
	}
}

class InviteResearchProjectMembersRequest extends TokenRequest{
	String? code;
	List<String>? memberCodes;

	InviteResearchProjectMembersRequest({
		this.code,
		this.memberCodes,
		String? token,
	}) : super(
			token: token,
		);

	factory InviteResearchProjectMembersRequest.fromJson(Map<String, dynamic> map) {
		return InviteResearchProjectMembersRequest( 
			code: map['Code'],
			memberCodes: map['MemberCodes']?.cast<String>().toList(),
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		if (memberCodes != null)
			map['MemberCodes'] = memberCodes;
		return map;
	}
}

class RemoveResearchProjectMembersRequest extends TokenRequest{
	String? code;
	List<String>? memberCodes;

	RemoveResearchProjectMembersRequest({
		this.code,
		this.memberCodes,
		String? token,
	}) : super(
			token: token,
		);

	factory RemoveResearchProjectMembersRequest.fromJson(Map<String, dynamic> map) {
		return RemoveResearchProjectMembersRequest( 
			code: map['Code'],
			memberCodes: map['MemberCodes']?.cast<String>().toList(),
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		if (memberCodes != null)
			map['MemberCodes'] = memberCodes;
		return map;
	}
}

class CreateTaskDetailInfo {
	String? id;
	String? name;
	String? description;

	CreateTaskDetailInfo({
		this.id,
		this.name,
		this.description,
	});

	factory CreateTaskDetailInfo.fromJson(Map<String, dynamic> map) {
		return CreateTaskDetailInfo( 
			id: map['Id'],
			name: map['Name'],
			description: map['Description'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		if (id != null)
			map['Id'] = id;
		if (name != null)
			map['Name'] = name;
		if (description != null)
			map['Description'] = description;
		return map;
	}
}

class CreateResearchProjectTaskRequest extends TokenRequest{
	String? businessCode;
	VTaskType taskType;
	String? name;
	List<CreateTaskDetailInfo>? taskDetailList;

	CreateResearchProjectTaskRequest({
		this.businessCode,
		this.taskType = VTaskType.Undefined,
		this.name,
		this.taskDetailList,
		String? token,
	}) : super(
			token: token,
		);

	factory CreateResearchProjectTaskRequest.fromJson(Map<String, dynamic> map) {
		return CreateResearchProjectTaskRequest( 
			businessCode: map['BusinessCode'],
			taskType: VTaskType.values.firstWhere((e) => e.index == map['TaskType']),
			name: map['Name'],
			taskDetailList: map['TaskDetailList'] != null ? (map['TaskDetailList'] as List).map((e)=>CreateTaskDetailInfo.fromJson(e as Map<String,dynamic>)).toList() : null,
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (businessCode != null)
			map['BusinessCode'] = businessCode;
		map['TaskType'] = taskType.index;
		if (name != null)
			map['Name'] = name;
		if (taskDetailList != null)
			map['TaskDetailList'] = taskDetailList;
		return map;
	}
}

enum VTaskStatus {
	Unhandled,
	Processing,
	Completed,
	Stopped,
	Canceled,
}

class UpdateResearchProjectTaskRequest extends TokenRequest{
	String? mainTaskCode;
	String? id;
	bool result;
	VTaskStatus status;
	double rate;

	UpdateResearchProjectTaskRequest({
		this.mainTaskCode,
		this.id,
		this.result = false,
		this.status = VTaskStatus.Unhandled,
		this.rate = 0,
		String? token,
	}) : super(
			token: token,
		);

	factory UpdateResearchProjectTaskRequest.fromJson(Map<String, dynamic> map) {
		return UpdateResearchProjectTaskRequest( 
			mainTaskCode: map['MainTaskCode'],
			id: map['Id'],
			result: map['Result'],
			status: VTaskStatus.values.firstWhere((e) => e.index == map['Status']),
			rate: double.parse(map['Rate'].toString()),
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (mainTaskCode != null)
			map['MainTaskCode'] = mainTaskCode;
		if (id != null)
			map['Id'] = id;
		map['Result'] = result;
		map['Status'] = status.index;
		map['Rate'] = rate;
		return map;
	}
}

class BatchAnalysisTaskRequest extends TokenRequest{
	String? mainTaskCode;

	BatchAnalysisTaskRequest({
		this.mainTaskCode,
		String? token,
	}) : super(
			token: token,
		);

	factory BatchAnalysisTaskRequest.fromJson(Map<String, dynamic> map) {
		return BatchAnalysisTaskRequest( 
			mainTaskCode: map['MainTaskCode'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (mainTaskCode != null)
			map['MainTaskCode'] = mainTaskCode;
		return map;
	}
}

class PageCollection<T> {
	int currentPage;
	int pageIndex;
	int pageSize;
	int dataCount;
	int totalCount;
	List<T>? pageData;

	PageCollection({
		this.currentPage = 0,
		this.pageIndex = 0,
		this.pageSize = 0,
		this.dataCount = 0,
		this.totalCount = 0,
		this.pageData,
	});

	factory PageCollection.fromJson(Map<String, dynamic> map) {
		List<T> pageDataList = [];
		if (map['PageData'] != null) {
			pageDataList.addAll(
					(map['PageData'] as List).map((e) => FJsonConvert.fromJson<T>(e)!));
		}
		return PageCollection( 
			currentPage: map['CurrentPage'],
			pageIndex: map['PageIndex'],
			pageSize: map['PageSize'],
			dataCount: map['DataCount'],
			totalCount: map['TotalCount'],
			pageData: pageDataList,
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		map['CurrentPage'] = currentPage;
		map['PageIndex'] = pageIndex;
		map['PageSize'] = pageSize;
		map['DataCount'] = dataCount;
		map['TotalCount'] = totalCount;
		if (pageData != null)
			map['PageData'] = pageData;
		return map;
	}
}

class PageRequest extends TokenRequest{
	int pageIndex;
	int pageSize;

	PageRequest({
		this.pageIndex = 0,
		this.pageSize = 0,
		String? token,
	}) : super(
			token: token,
		);

	factory PageRequest.fromJson(Map<String, dynamic> map) {
		return PageRequest( 
			pageIndex: map['PageIndex'],
			pageSize: map['PageSize'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		map['PageIndex'] = pageIndex;
		map['PageSize'] = pageSize;
		return map;
	}
}

class GetResearchProjectDatasRequest extends PageRequest{
	String? keyWord;
	int sort;
	String? projectCode;

	GetResearchProjectDatasRequest({
		this.keyWord,
		this.sort = 0,
		this.projectCode,
		int pageIndex = 0,
		int pageSize = 0,
		String? token,
	}) : super(
			pageIndex: pageIndex,
			pageSize: pageSize,
			token: token,
		);

	factory GetResearchProjectDatasRequest.fromJson(Map<String, dynamic> map) {
		return GetResearchProjectDatasRequest( 
			keyWord: map['KeyWord'],
			sort: map['Sort'],
			projectCode: map['ProjectCode'],
			pageIndex: map['PageIndex'],
			pageSize: map['PageSize'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (keyWord != null)
			map['KeyWord'] = keyWord;
		map['Sort'] = sort;
		if (projectCode != null)
			map['ProjectCode'] = projectCode;
		return map;
	}
}

class DataItemDTO {
	String? key;
	String? value;

	DataItemDTO({
		this.key,
		this.value,
	});

	factory DataItemDTO.fromJson(Map<String, dynamic> map) {
		return DataItemDTO( 
			key: map['Key'],
			value: map['Value'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		if (key != null)
			map['Key'] = key;
		if (value != null)
			map['Value'] = value;
		return map;
	}
}

class PatientInfoExt {
	String? patientScanType;
	List<DataItemDTO>? content;

	PatientInfoExt({
		this.patientScanType,
		this.content,
	});

	factory PatientInfoExt.fromJson(Map<String, dynamic> map) {
		return PatientInfoExt( 
			patientScanType: map['PatientScanType'],
			content: map['Content'] != null ? (map['Content'] as List).map((e)=>DataItemDTO.fromJson(e as Map<String,dynamic>)).toList() : null,
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		if (patientScanType != null)
			map['PatientScanType'] = patientScanType;
		if (content != null)
			map['Content'] = content;
		return map;
	}
}

class BaseSampleDetail {
	String? recordCode;
	DateTime? recordTime;
	List<DataItemDTO>? patientInfo;
	List<PatientInfoExt>? patientInfoExtList;

	BaseSampleDetail({
		this.recordCode,
		this.recordTime,
		this.patientInfo,
		this.patientInfoExtList,
	});

	factory BaseSampleDetail.fromJson(Map<String, dynamic> map) {
		return BaseSampleDetail( 
			recordCode: map['RecordCode'],
			recordTime: map['RecordTime'] != null ? DateTime.parse(map['RecordTime']) : null,
			patientInfo: map['PatientInfo'] != null ? (map['PatientInfo'] as List).map((e)=>DataItemDTO.fromJson(e as Map<String,dynamic>)).toList() : null,
			patientInfoExtList: map['PatientInfoExtList'] != null ? (map['PatientInfoExtList'] as List).map((e)=>PatientInfoExt.fromJson(e as Map<String,dynamic>)).toList() : null,
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		if (recordCode != null)
			map['RecordCode'] = recordCode;
		if (recordTime != null)
			map['RecordTime'] = JsonRpcUtils.dateFormat(recordTime!);
		if (patientInfo != null)
			map['PatientInfo'] = patientInfo;
		if (patientInfoExtList != null)
			map['PatientInfoExtList'] = patientInfoExtList;
		return map;
	}
}

enum SampleRemedicalFileDataTypeEnum {
	VinnoVidSingle,
	ThirdVidSingle,
	VinnoVidMovie,
	ThirdVidMovie,
	Image,
	AnalysisImage,
	AnalysisVideo,
	MeasurementImage,
}

class ImgItem {
	int imgType;
	String? fileToken;
	int fileSize;
	bool isShow;
	String? previewFileUrl;
	String? coverImgUrl;
	int width;
	int height;
	DateTime? createTime;

	ImgItem({
		this.imgType = 0,
		this.fileToken,
		this.fileSize = 0,
		this.isShow = false,
		this.previewFileUrl,
		this.coverImgUrl,
		this.width = 0,
		this.height = 0,
		this.createTime,
	});

	factory ImgItem.fromJson(Map<String, dynamic> map) {
		return ImgItem( 
			imgType: map['ImgType'],
			fileToken: map['FileToken'],
			fileSize: map['FileSize'],
			isShow: map['IsShow'],
			previewFileUrl: map['PreviewFileUrl'],
			coverImgUrl: map['CoverImgUrl'],
			width: map['Width'],
			height: map['Height'],
			createTime: map['CreateTime'] != null ? DateTime.parse(map['CreateTime']) : null,
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		map['ImgType'] = imgType;
		if (fileToken != null)
			map['FileToken'] = fileToken;
		map['FileSize'] = fileSize;
		map['IsShow'] = isShow;
		if (previewFileUrl != null)
			map['PreviewFileUrl'] = previewFileUrl;
		if (coverImgUrl != null)
			map['CoverImgUrl'] = coverImgUrl;
		map['Width'] = width;
		map['Height'] = height;
		if (createTime != null)
			map['CreateTime'] = JsonRpcUtils.dateFormat(createTime!);
		return map;
	}
}

class SampleRemedicalMeasuredInfoDTO extends BaseDTO{
	String? remedicalMeasuredInfoCode;
	int frameIndex;
	String? measuredFileToken;
	String? previewFileToken;
	String? measuredData;
	String? model;

	SampleRemedicalMeasuredInfoDTO({
		this.remedicalMeasuredInfoCode,
		this.frameIndex = 0,
		this.measuredFileToken,
		this.previewFileToken,
		this.measuredData,
		this.model,
		bool isDelete = false,
		DateTime? createTime,
		DateTime? updateTime,
	}) : super(
			isDelete: isDelete,
			createTime: createTime,
			updateTime: updateTime,
		);

	factory SampleRemedicalMeasuredInfoDTO.fromJson(Map<String, dynamic> map) {
		return SampleRemedicalMeasuredInfoDTO( 
			remedicalMeasuredInfoCode: map['RemedicalMeasuredInfoCode'],
			frameIndex: map['FrameIndex'],
			measuredFileToken: map['MeasuredFileToken'],
			previewFileToken: map['PreviewFileToken'],
			measuredData: map['MeasuredData'],
			model: map['Model'],
			isDelete: map['IsDelete'],
			createTime: map['CreateTime'] != null ? DateTime.parse(map['CreateTime']) : null,
			updateTime: map['UpdateTime'] != null ? DateTime.parse(map['UpdateTime']) : null,
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (remedicalMeasuredInfoCode != null)
			map['RemedicalMeasuredInfoCode'] = remedicalMeasuredInfoCode;
		map['FrameIndex'] = frameIndex;
		if (measuredFileToken != null)
			map['MeasuredFileToken'] = measuredFileToken;
		if (previewFileToken != null)
			map['PreviewFileToken'] = previewFileToken;
		if (measuredData != null)
			map['MeasuredData'] = measuredData;
		if (model != null)
			map['Model'] = model;
		return map;
	}
}

class SampleRemedicalInfoDTO extends BaseDTO{
	String? businessCode;
	bool isURM;
	String? applicationCategory;
	String? application;
	String? previewUrl;
	String? coverImgUrl;
	String? imageUrl;
	int imageSize;
	SampleRemedicalFileDataTypeEnum fileDataType;
	List<ImgItem>? imgList;
	bool isAnalysisResult;
	List<SampleRemedicalMeasuredInfoDTO>? sampleRemedicalMeasuredList;
	String? urmOriginalCode;
	String? remedicalOriginalCode;
	int uRMSrcWidth;
	int uRMSrcHeight;
	double uRMRes;

	SampleRemedicalInfoDTO({
		this.businessCode,
		this.isURM = false,
		this.applicationCategory,
		this.application,
		this.previewUrl,
		this.coverImgUrl,
		this.imageUrl,
		this.imageSize = 0,
		this.fileDataType = SampleRemedicalFileDataTypeEnum.VinnoVidSingle,
		this.imgList,
		this.isAnalysisResult = false,
		this.sampleRemedicalMeasuredList,
		this.urmOriginalCode,
		this.remedicalOriginalCode,
		this.uRMSrcWidth = 0,
		this.uRMSrcHeight = 0,
		this.uRMRes = 0,
		bool isDelete = false,
		DateTime? createTime,
		DateTime? updateTime,
	}) : super(
			isDelete: isDelete,
			createTime: createTime,
			updateTime: updateTime,
		);

	factory SampleRemedicalInfoDTO.fromJson(Map<String, dynamic> map) {
		return SampleRemedicalInfoDTO( 
			businessCode: map['BusinessCode'],
			isURM: map['IsURM'],
			applicationCategory: map['ApplicationCategory'],
			application: map['Application'],
			previewUrl: map['PreviewUrl'],
			coverImgUrl: map['CoverImgUrl'],
			imageUrl: map['ImageUrl'],
			imageSize: map['ImageSize'],
			fileDataType: SampleRemedicalFileDataTypeEnum.values.firstWhere((e) => e.index == map['FileDataType']),
			imgList: map['ImgList'] != null ? (map['ImgList'] as List).map((e)=>ImgItem.fromJson(e as Map<String,dynamic>)).toList() : null,
			isAnalysisResult: map['IsAnalysisResult'],
			sampleRemedicalMeasuredList: map['SampleRemedicalMeasuredList'] != null ? (map['SampleRemedicalMeasuredList'] as List).map((e)=>SampleRemedicalMeasuredInfoDTO.fromJson(e as Map<String,dynamic>)).toList() : null,
			urmOriginalCode: map['UrmOriginalCode'],
			remedicalOriginalCode: map['RemedicalOriginalCode'],
			uRMSrcWidth: map['URMSrcWidth'],
			uRMSrcHeight: map['URMSrcHeight'],
			uRMRes: double.parse(map['URMRes'].toString()),
			isDelete: map['IsDelete'],
			createTime: map['CreateTime'] != null ? DateTime.parse(map['CreateTime']) : null,
			updateTime: map['UpdateTime'] != null ? DateTime.parse(map['UpdateTime']) : null,
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (businessCode != null)
			map['BusinessCode'] = businessCode;
		map['IsURM'] = isURM;
		if (applicationCategory != null)
			map['ApplicationCategory'] = applicationCategory;
		if (application != null)
			map['Application'] = application;
		if (previewUrl != null)
			map['PreviewUrl'] = previewUrl;
		if (coverImgUrl != null)
			map['CoverImgUrl'] = coverImgUrl;
		if (imageUrl != null)
			map['ImageUrl'] = imageUrl;
		map['ImageSize'] = imageSize;
		map['FileDataType'] = fileDataType.index;
		if (imgList != null)
			map['ImgList'] = imgList;
		map['IsAnalysisResult'] = isAnalysisResult;
		if (sampleRemedicalMeasuredList != null)
			map['SampleRemedicalMeasuredList'] = sampleRemedicalMeasuredList;
		if (urmOriginalCode != null)
			map['UrmOriginalCode'] = urmOriginalCode;
		if (remedicalOriginalCode != null)
			map['RemedicalOriginalCode'] = remedicalOriginalCode;
		map['URMSrcWidth'] = uRMSrcWidth;
		map['URMSrcHeight'] = uRMSrcHeight;
		map['URMRes'] = uRMRes;
		return map;
	}
}

class SampleDetail extends BaseSampleDetail{
	int dataCount;
	List<SampleRemedicalInfoDTO>? sampleRemedicalInfoList;

	SampleDetail({
		this.dataCount = 0,
		this.sampleRemedicalInfoList,
		String? recordCode,
		DateTime? recordTime,
		List<DataItemDTO>? patientInfo,
		List<PatientInfoExt>? patientInfoExtList,
	}) : super(
			recordCode: recordCode,
			recordTime: recordTime,
			patientInfo: patientInfo,
			patientInfoExtList: patientInfoExtList,
		);

	factory SampleDetail.fromJson(Map<String, dynamic> map) {
		return SampleDetail( 
			dataCount: map['DataCount'],
			sampleRemedicalInfoList: map['SampleRemedicalInfoList'] != null ? (map['SampleRemedicalInfoList'] as List).map((e)=>SampleRemedicalInfoDTO.fromJson(e as Map<String,dynamic>)).toList() : null,
			recordCode: map['RecordCode'],
			recordTime: map['RecordTime'] != null ? DateTime.parse(map['RecordTime']) : null,
			patientInfo: map['PatientInfo'] != null ? (map['PatientInfo'] as List).map((e)=>DataItemDTO.fromJson(e as Map<String,dynamic>)).toList() : null,
			patientInfoExtList: map['PatientInfoExtList'] != null ? (map['PatientInfoExtList'] as List).map((e)=>PatientInfoExt.fromJson(e as Map<String,dynamic>)).toList() : null,
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		map['DataCount'] = dataCount;
		if (sampleRemedicalInfoList != null)
			map['SampleRemedicalInfoList'] = sampleRemedicalInfoList;
		return map;
	}
}

class GetSampleDetailsRequest extends TokenRequest{
	String? patientCode;

	GetSampleDetailsRequest({
		this.patientCode,
		String? token,
	}) : super(
			token: token,
		);

	factory GetSampleDetailsRequest.fromJson(Map<String, dynamic> map) {
		return GetSampleDetailsRequest( 
			patientCode: map['PatientCode'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (patientCode != null)
			map['PatientCode'] = patientCode;
		return map;
	}
}

class GetUrmRemedicalInfosRequest extends TokenRequest{
	String? urmRemedicalCode;

	GetUrmRemedicalInfosRequest({
		this.urmRemedicalCode,
		String? token,
	}) : super(
			token: token,
		);

	factory GetUrmRemedicalInfosRequest.fromJson(Map<String, dynamic> map) {
		return GetUrmRemedicalInfosRequest( 
			urmRemedicalCode: map['UrmRemedicalCode'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (urmRemedicalCode != null)
			map['UrmRemedicalCode'] = urmRemedicalCode;
		return map;
	}
}

class TaskBaseDTO {
	String? code;
	String? creatorCode;
	String? creatorName;
	DateTime? createTime;
	String? operatorCode;
	String? operatorName;
	DateTime? operateTime;
	DateTime? endTime;
	VTaskStatus status;
	VTaskType taskType;
	String? taskName;
	String? businessCode;
	String? patientCode;

	TaskBaseDTO({
		this.code,
		this.creatorCode,
		this.creatorName,
		this.createTime,
		this.operatorCode,
		this.operatorName,
		this.operateTime,
		this.endTime,
		this.status = VTaskStatus.Unhandled,
		this.taskType = VTaskType.Undefined,
		this.taskName,
		this.businessCode,
		this.patientCode,
	});

	factory TaskBaseDTO.fromJson(Map<String, dynamic> map) {
		return TaskBaseDTO( 
			code: map['Code'],
			creatorCode: map['CreatorCode'],
			creatorName: map['CreatorName'],
			createTime: map['CreateTime'] != null ? DateTime.parse(map['CreateTime']) : null,
			operatorCode: map['OperatorCode'],
			operatorName: map['OperatorName'],
			operateTime: map['OperateTime'] != null ? DateTime.parse(map['OperateTime']) : null,
			endTime: map['EndTime'] != null ? DateTime.parse(map['EndTime']) : null,
			status: VTaskStatus.values.firstWhere((e) => e.index == map['Status']),
			taskType: VTaskType.values.firstWhere((e) => e.index == map['TaskType']),
			taskName: map['TaskName'],
			businessCode: map['BusinessCode'],
			patientCode: map['PatientCode'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		if (code != null)
			map['Code'] = code;
		if (creatorCode != null)
			map['CreatorCode'] = creatorCode;
		if (creatorName != null)
			map['CreatorName'] = creatorName;
		if (createTime != null)
			map['CreateTime'] = JsonRpcUtils.dateFormat(createTime!);
		if (operatorCode != null)
			map['OperatorCode'] = operatorCode;
		if (operatorName != null)
			map['OperatorName'] = operatorName;
		if (operateTime != null)
			map['OperateTime'] = JsonRpcUtils.dateFormat(operateTime!);
		if (endTime != null)
			map['EndTime'] = JsonRpcUtils.dateFormat(endTime!);
		map['Status'] = status.index;
		map['TaskType'] = taskType.index;
		if (taskName != null)
			map['TaskName'] = taskName;
		if (businessCode != null)
			map['BusinessCode'] = businessCode;
		if (patientCode != null)
			map['PatientCode'] = patientCode;
		return map;
	}
}

class GetTaskListRequest extends TokenRequest{
	String? keyWord;
	VTaskStatus status;

	GetTaskListRequest({
		this.keyWord,
		this.status = VTaskStatus.Unhandled,
		String? token,
	}) : super(
			token: token,
		);

	factory GetTaskListRequest.fromJson(Map<String, dynamic> map) {
		return GetTaskListRequest( 
			keyWord: map['KeyWord'],
			status: VTaskStatus.values.firstWhere((e) => e.index == map['Status']),
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (keyWord != null)
			map['KeyWord'] = keyWord;
		map['Status'] = status.index;
		return map;
	}
}

class TaskDetail {
	String? taskCode;
	String? id;
	String? name;
	String? description;
	bool result;
	VTaskStatus status;
	double rate;
	String? businessCode;

	TaskDetail({
		this.taskCode,
		this.id,
		this.name,
		this.description,
		this.result = false,
		this.status = VTaskStatus.Unhandled,
		this.rate = 0,
		this.businessCode,
	});

	factory TaskDetail.fromJson(Map<String, dynamic> map) {
		return TaskDetail( 
			taskCode: map['TaskCode'],
			id: map['Id'],
			name: map['Name'],
			description: map['Description'],
			result: map['Result'],
			status: VTaskStatus.values.firstWhere((e) => e.index == map['Status']),
			rate: double.parse(map['Rate'].toString()),
			businessCode: map['BusinessCode'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		if (taskCode != null)
			map['TaskCode'] = taskCode;
		if (id != null)
			map['Id'] = id;
		if (name != null)
			map['Name'] = name;
		if (description != null)
			map['Description'] = description;
		map['Result'] = result;
		map['Status'] = status.index;
		map['Rate'] = rate;
		if (businessCode != null)
			map['BusinessCode'] = businessCode;
		return map;
	}
}

class MainTaskDTO extends TaskBaseDTO{
	List<TaskDetail>? taskDetailList;

	MainTaskDTO({
		this.taskDetailList,
		String? code,
		String? creatorCode,
		String? creatorName,
		DateTime? createTime,
		String? operatorCode,
		String? operatorName,
		DateTime? operateTime,
		DateTime? endTime,
		VTaskStatus status = VTaskStatus.Unhandled,
		VTaskType taskType = VTaskType.Undefined,
		String? taskName,
		String? businessCode,
		String? patientCode,
	}) : super(
			code: code,
			creatorCode: creatorCode,
			creatorName: creatorName,
			createTime: createTime,
			operatorCode: operatorCode,
			operatorName: operatorName,
			operateTime: operateTime,
			endTime: endTime,
			status: status,
			taskType: taskType,
			taskName: taskName,
			businessCode: businessCode,
			patientCode: patientCode,
		);

	factory MainTaskDTO.fromJson(Map<String, dynamic> map) {
		return MainTaskDTO( 
			taskDetailList: map['TaskDetailList'] != null ? (map['TaskDetailList'] as List).map((e)=>TaskDetail.fromJson(e as Map<String,dynamic>)).toList() : null,
			code: map['Code'],
			creatorCode: map['CreatorCode'],
			creatorName: map['CreatorName'],
			createTime: map['CreateTime'] != null ? DateTime.parse(map['CreateTime']) : null,
			operatorCode: map['OperatorCode'],
			operatorName: map['OperatorName'],
			operateTime: map['OperateTime'] != null ? DateTime.parse(map['OperateTime']) : null,
			endTime: map['EndTime'] != null ? DateTime.parse(map['EndTime']) : null,
			status: VTaskStatus.values.firstWhere((e) => e.index == map['Status']),
			taskType: VTaskType.values.firstWhere((e) => e.index == map['TaskType']),
			taskName: map['TaskName'],
			businessCode: map['BusinessCode'],
			patientCode: map['PatientCode'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (taskDetailList != null)
			map['TaskDetailList'] = taskDetailList;
		return map;
	}
}

class GetMainTaskDetailRequest extends TokenRequest{
	String? mainTaskCode;

	GetMainTaskDetailRequest({
		this.mainTaskCode,
		String? token,
	}) : super(
			token: token,
		);

	factory GetMainTaskDetailRequest.fromJson(Map<String, dynamic> map) {
		return GetMainTaskDetailRequest( 
			mainTaskCode: map['MainTaskCode'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (mainTaskCode != null)
			map['MainTaskCode'] = mainTaskCode;
		return map;
	}
}

class TaskDTO extends TaskBaseDTO{
	bool result;
	String? description;
	String? mainTaskCode;
	bool isJumpQueue;
	double rate;
	bool isJoinQueue;
	String? businessId;
	DateTime? updateTime;
	String? jsonData;

	TaskDTO({
		this.result = false,
		this.description,
		this.mainTaskCode,
		this.isJumpQueue = false,
		this.rate = 0,
		this.isJoinQueue = false,
		this.businessId,
		this.updateTime,
		this.jsonData,
		String? code,
		String? creatorCode,
		String? creatorName,
		DateTime? createTime,
		String? operatorCode,
		String? operatorName,
		DateTime? operateTime,
		DateTime? endTime,
		VTaskStatus status = VTaskStatus.Unhandled,
		VTaskType taskType = VTaskType.Undefined,
		String? taskName,
		String? businessCode,
		String? patientCode,
	}) : super(
			code: code,
			creatorCode: creatorCode,
			creatorName: creatorName,
			createTime: createTime,
			operatorCode: operatorCode,
			operatorName: operatorName,
			operateTime: operateTime,
			endTime: endTime,
			status: status,
			taskType: taskType,
			taskName: taskName,
			businessCode: businessCode,
			patientCode: patientCode,
		);

	factory TaskDTO.fromJson(Map<String, dynamic> map) {
		return TaskDTO( 
			result: map['Result'],
			description: map['Description'],
			mainTaskCode: map['MainTaskCode'],
			isJumpQueue: map['IsJumpQueue'],
			rate: double.parse(map['Rate'].toString()),
			isJoinQueue: map['IsJoinQueue'],
			businessId: map['BusinessId'],
			updateTime: map['UpdateTime'] != null ? DateTime.parse(map['UpdateTime']) : null,
			jsonData: map['JsonData'],
			code: map['Code'],
			creatorCode: map['CreatorCode'],
			creatorName: map['CreatorName'],
			createTime: map['CreateTime'] != null ? DateTime.parse(map['CreateTime']) : null,
			operatorCode: map['OperatorCode'],
			operatorName: map['OperatorName'],
			operateTime: map['OperateTime'] != null ? DateTime.parse(map['OperateTime']) : null,
			endTime: map['EndTime'] != null ? DateTime.parse(map['EndTime']) : null,
			status: VTaskStatus.values.firstWhere((e) => e.index == map['Status']),
			taskType: VTaskType.values.firstWhere((e) => e.index == map['TaskType']),
			taskName: map['TaskName'],
			businessCode: map['BusinessCode'],
			patientCode: map['PatientCode'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		map['Result'] = result;
		if (description != null)
			map['Description'] = description;
		if (mainTaskCode != null)
			map['MainTaskCode'] = mainTaskCode;
		map['IsJumpQueue'] = isJumpQueue;
		map['Rate'] = rate;
		map['IsJoinQueue'] = isJoinQueue;
		if (businessId != null)
			map['BusinessId'] = businessId;
		if (updateTime != null)
			map['UpdateTime'] = JsonRpcUtils.dateFormat(updateTime!);
		if (jsonData != null)
			map['JsonData'] = jsonData;
		return map;
	}
}

class GetTaskDetailRequest extends TokenRequest{
	String? taskCode;

	GetTaskDetailRequest({
		this.taskCode,
		String? token,
	}) : super(
			token: token,
		);

	factory GetTaskDetailRequest.fromJson(Map<String, dynamic> map) {
		return GetTaskDetailRequest( 
			taskCode: map['TaskCode'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (taskCode != null)
			map['TaskCode'] = taskCode;
		return map;
	}
}

enum TimeAxisDetailEnum {
	ProjectCreate,
	DeviceUpload,
	InviteUser,
	RemoveUser,
	UserImport,
	UserExport,
	Startanalysis,
	NalysisComplete,
	DeleteSample,
	DeleteRecord,
	ProjectUpdate,
}

class TimeAxisDetail {
	String? operatorName;
	DateTime? operateTime;
	TimeAxisDetailEnum timeAxisType;
	String? dataJson;

	TimeAxisDetail({
		this.operatorName,
		this.operateTime,
		this.timeAxisType = TimeAxisDetailEnum.ProjectCreate,
		this.dataJson,
	});

	factory TimeAxisDetail.fromJson(Map<String, dynamic> map) {
		return TimeAxisDetail( 
			operatorName: map['OperatorName'],
			operateTime: map['OperateTime'] != null ? DateTime.parse(map['OperateTime']) : null,
			timeAxisType: TimeAxisDetailEnum.values.firstWhere((e) => e.index == map['TimeAxisType']),
			dataJson: map['DataJson'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		if (operatorName != null)
			map['OperatorName'] = operatorName;
		if (operateTime != null)
			map['OperateTime'] = JsonRpcUtils.dateFormat(operateTime!);
		map['TimeAxisType'] = timeAxisType.index;
		if (dataJson != null)
			map['DataJson'] = dataJson;
		return map;
	}
}

class GetTaskListByProjectRequest extends TokenRequest{
	String? projectCode;

	GetTaskListByProjectRequest({
		this.projectCode,
		String? token,
	}) : super(
			token: token,
		);

	factory GetTaskListByProjectRequest.fromJson(Map<String, dynamic> map) {
		return GetTaskListByProjectRequest( 
			projectCode: map['ProjectCode'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (projectCode != null)
			map['ProjectCode'] = projectCode;
		return map;
	}
}

class GetRRUserPagesRequest extends PageRequest{
	String? keyWord;

	GetRRUserPagesRequest({
		this.keyWord,
		int pageIndex = 0,
		int pageSize = 0,
		String? token,
	}) : super(
			pageIndex: pageIndex,
			pageSize: pageSize,
			token: token,
		);

	factory GetRRUserPagesRequest.fromJson(Map<String, dynamic> map) {
		return GetRRUserPagesRequest( 
			keyWord: map['KeyWord'],
			pageIndex: map['PageIndex'],
			pageSize: map['PageSize'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (keyWord != null)
			map['KeyWord'] = keyWord;
		return map;
	}
}

class AnalysisItem {
	double x;
	double y;
	double width;
	double height;
	String? remedicalCode;
	int? customizedStartFrame;
	int? customizedEndFrame;
	double roiXPercent;
	double roiYPercent;
	double roiWPercent;
	double roiHPercent;

	AnalysisItem({
		this.x = 0,
		this.y = 0,
		this.width = 0,
		this.height = 0,
		this.remedicalCode,
		this.customizedStartFrame,
		this.customizedEndFrame,
		this.roiXPercent = 0,
		this.roiYPercent = 0,
		this.roiWPercent = 0,
		this.roiHPercent = 0,
	});

	factory AnalysisItem.fromJson(Map<String, dynamic> map) {
		return AnalysisItem( 
			x: double.parse(map['X'].toString()),
			y: double.parse(map['Y'].toString()),
			width: double.parse(map['Width'].toString()),
			height: double.parse(map['Height'].toString()),
			remedicalCode: map['RemedicalCode'],
			customizedStartFrame: map['CustomizedStartFrame'],
			customizedEndFrame: map['CustomizedEndFrame'],
			roiXPercent: double.parse(map['RoiXPercent'].toString()),
			roiYPercent: double.parse(map['RoiYPercent'].toString()),
			roiWPercent: double.parse(map['RoiWPercent'].toString()),
			roiHPercent: double.parse(map['RoiHPercent'].toString()),
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		map['X'] = x;
		map['Y'] = y;
		map['Width'] = width;
		map['Height'] = height;
		if (remedicalCode != null)
			map['RemedicalCode'] = remedicalCode;
		if (customizedStartFrame != null)
			map['CustomizedStartFrame'] = customizedStartFrame;
		if (customizedEndFrame != null)
			map['CustomizedEndFrame'] = customizedEndFrame;
		map['RoiXPercent'] = roiXPercent;
		map['RoiYPercent'] = roiYPercent;
		map['RoiWPercent'] = roiWPercent;
		map['RoiHPercent'] = roiHPercent;
		return map;
	}
}

class BatchAnalysisRequest extends TokenRequest{
	List<AnalysisItem>? analysisList;

	BatchAnalysisRequest({
		this.analysisList,
		String? token,
	}) : super(
			token: token,
		);

	factory BatchAnalysisRequest.fromJson(Map<String, dynamic> map) {
		return BatchAnalysisRequest( 
			analysisList: map['AnalysisList'] != null ? (map['AnalysisList'] as List).map((e)=>AnalysisItem.fromJson(e as Map<String,dynamic>)).toList() : null,
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (analysisList != null)
			map['AnalysisList'] = analysisList;
		return map;
	}
}

class AnalysisTaskRequest extends TokenRequest{
	String? taskCode;

	AnalysisTaskRequest({
		this.taskCode,
		String? token,
	}) : super(
			token: token,
		);

	factory AnalysisTaskRequest.fromJson(Map<String, dynamic> map) {
		return AnalysisTaskRequest( 
			taskCode: map['TaskCode'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (taskCode != null)
			map['TaskCode'] = taskCode;
		return map;
	}
}

class URMProcessBaseRequest {
	String? urmImageType;
	int urmBlend;
	double downsampleIndex;
	double intPowerDen;
	double intPowerDir;
	double sigmaGauss;
	double vessScale;
	double velMaxScaler;
	double velMinScaler;
	double iterations;
	int imgProcessVer;
	bool zoomOn;
	double zoomRoix;
	double zoomRoiy;
	double zoomRoiwidth;
	double zoomRoiheight;
	int roix;
	int roiy;
	int roiwidth;
	int roiheight;
	bool leftRight;
	bool upDown;
	int screenWidth;
	int screenHeight;

	URMProcessBaseRequest({
		this.urmImageType,
		this.urmBlend = 0,
		this.downsampleIndex = 0,
		this.intPowerDen = 0,
		this.intPowerDir = 0,
		this.sigmaGauss = 0,
		this.vessScale = 0,
		this.velMaxScaler = 0,
		this.velMinScaler = 0,
		this.iterations = 0,
		this.imgProcessVer = 0,
		this.zoomOn = false,
		this.zoomRoix = 0,
		this.zoomRoiy = 0,
		this.zoomRoiwidth = 0,
		this.zoomRoiheight = 0,
		this.roix = 0,
		this.roiy = 0,
		this.roiwidth = 0,
		this.roiheight = 0,
		this.leftRight = false,
		this.upDown = false,
		this.screenWidth = 0,
		this.screenHeight = 0,
	});

	factory URMProcessBaseRequest.fromJson(Map<String, dynamic> map) {
		return URMProcessBaseRequest( 
			urmImageType: map['UrmImageType'],
			urmBlend: map['UrmBlend'],
			downsampleIndex: double.parse(map['DownsampleIndex'].toString()),
			intPowerDen: double.parse(map['IntPowerDen'].toString()),
			intPowerDir: double.parse(map['IntPowerDir'].toString()),
			sigmaGauss: double.parse(map['SigmaGauss'].toString()),
			vessScale: double.parse(map['VessScale'].toString()),
			velMaxScaler: double.parse(map['VelMaxScaler'].toString()),
			velMinScaler: double.parse(map['VelMinScaler'].toString()),
			iterations: double.parse(map['Iterations'].toString()),
			imgProcessVer: map['ImgProcessVer'],
			zoomOn: map['ZoomOn'],
			zoomRoix: double.parse(map['ZoomRoix'].toString()),
			zoomRoiy: double.parse(map['ZoomRoiy'].toString()),
			zoomRoiwidth: double.parse(map['ZoomRoiwidth'].toString()),
			zoomRoiheight: double.parse(map['ZoomRoiheight'].toString()),
			roix: map['Roix'],
			roiy: map['Roiy'],
			roiwidth: map['Roiwidth'],
			roiheight: map['Roiheight'],
			leftRight: map['LeftRight'],
			upDown: map['UpDown'],
			screenWidth: map['ScreenWidth'],
			screenHeight: map['ScreenHeight'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		if (urmImageType != null)
			map['UrmImageType'] = urmImageType;
		map['UrmBlend'] = urmBlend;
		map['DownsampleIndex'] = downsampleIndex;
		map['IntPowerDen'] = intPowerDen;
		map['IntPowerDir'] = intPowerDir;
		map['SigmaGauss'] = sigmaGauss;
		map['VessScale'] = vessScale;
		map['VelMaxScaler'] = velMaxScaler;
		map['VelMinScaler'] = velMinScaler;
		map['Iterations'] = iterations;
		map['ImgProcessVer'] = imgProcessVer;
		map['ZoomOn'] = zoomOn;
		map['ZoomRoix'] = zoomRoix;
		map['ZoomRoiy'] = zoomRoiy;
		map['ZoomRoiwidth'] = zoomRoiwidth;
		map['ZoomRoiheight'] = zoomRoiheight;
		map['Roix'] = roix;
		map['Roiy'] = roiy;
		map['Roiwidth'] = roiwidth;
		map['Roiheight'] = roiheight;
		map['LeftRight'] = leftRight;
		map['UpDown'] = upDown;
		map['ScreenWidth'] = screenWidth;
		map['ScreenHeight'] = screenHeight;
		return map;
	}
}

class UrmPoint {
	double x;
	double y;

	UrmPoint({
		this.x = 0,
		this.y = 0,
	});

	factory UrmPoint.fromJson(Map<String, dynamic> map) {
		return UrmPoint( 
			x: double.parse(map['X'].toString()),
			y: double.parse(map['Y'].toString()),
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		map['X'] = x;
		map['Y'] = y;
		return map;
	}
}

class URMProcessRequest extends URMProcessBaseRequest{
	String? token;
	String? remedicalCode;
	List<UrmPoint>? urmTraceDPoints;

	URMProcessRequest({
		this.token,
		this.remedicalCode,
		this.urmTraceDPoints,
		String? urmImageType,
		int urmBlend = 0,
		double downsampleIndex = 0,
		double intPowerDen = 0,
		double intPowerDir = 0,
		double sigmaGauss = 0,
		double vessScale = 0,
		double velMaxScaler = 0,
		double velMinScaler = 0,
		double iterations = 0,
		int imgProcessVer = 0,
		bool zoomOn = false,
		double zoomRoix = 0,
		double zoomRoiy = 0,
		double zoomRoiwidth = 0,
		double zoomRoiheight = 0,
		int roix = 0,
		int roiy = 0,
		int roiwidth = 0,
		int roiheight = 0,
		bool leftRight = false,
		bool upDown = false,
		int screenWidth = 0,
		int screenHeight = 0,
	}) : super(
			urmImageType: urmImageType,
			urmBlend: urmBlend,
			downsampleIndex: downsampleIndex,
			intPowerDen: intPowerDen,
			intPowerDir: intPowerDir,
			sigmaGauss: sigmaGauss,
			vessScale: vessScale,
			velMaxScaler: velMaxScaler,
			velMinScaler: velMinScaler,
			iterations: iterations,
			imgProcessVer: imgProcessVer,
			zoomOn: zoomOn,
			zoomRoix: zoomRoix,
			zoomRoiy: zoomRoiy,
			zoomRoiwidth: zoomRoiwidth,
			zoomRoiheight: zoomRoiheight,
			roix: roix,
			roiy: roiy,
			roiwidth: roiwidth,
			roiheight: roiheight,
			leftRight: leftRight,
			upDown: upDown,
			screenWidth: screenWidth,
			screenHeight: screenHeight,
		);

	factory URMProcessRequest.fromJson(Map<String, dynamic> map) {
		final urmTraceDPointsData = map['UrmTraceDPoints'];
		return URMProcessRequest( 
			token: map['Token'],
			remedicalCode: map['RemedicalCode'],
			urmTraceDPoints: urmTraceDPointsData != null ? (urmTraceDPointsData as List).map((e) => UrmPoint.fromJson(e)).toList(): null,
			urmImageType: map['UrmImageType'],
			urmBlend: map['UrmBlend'],
			downsampleIndex: double.parse(map['DownsampleIndex'].toString()),
			intPowerDen: double.parse(map['IntPowerDen'].toString()),
			intPowerDir: double.parse(map['IntPowerDir'].toString()),
			sigmaGauss: double.parse(map['SigmaGauss'].toString()),
			vessScale: double.parse(map['VessScale'].toString()),
			velMaxScaler: double.parse(map['VelMaxScaler'].toString()),
			velMinScaler: double.parse(map['VelMinScaler'].toString()),
			iterations: double.parse(map['Iterations'].toString()),
			imgProcessVer: map['ImgProcessVer'],
			zoomOn: map['ZoomOn'],
			zoomRoix: double.parse(map['ZoomRoix'].toString()),
			zoomRoiy: double.parse(map['ZoomRoiy'].toString()),
			zoomRoiwidth: double.parse(map['ZoomRoiwidth'].toString()),
			zoomRoiheight: double.parse(map['ZoomRoiheight'].toString()),
			roix: map['Roix'],
			roiy: map['Roiy'],
			roiwidth: map['Roiwidth'],
			roiheight: map['Roiheight'],
			leftRight: map['LeftRight'],
			upDown: map['UpDown'],
			screenWidth: map['ScreenWidth'],
			screenHeight: map['ScreenHeight'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (token != null)
			map['Token'] = token;
		if (remedicalCode != null)
			map['RemedicalCode'] = remedicalCode;
		if (urmTraceDPoints != null)
			map['UrmTraceDPoints'] = urmTraceDPoints;
		return map;
	}
}

class URMVideoProcessRequest extends URMProcessRequest{
	String? notifyUserCode;
	int videoFrame;
	double uRMVideoScaler;
	double uRMVideoParameter;
	double uRMVideoType;

	URMVideoProcessRequest({
		this.notifyUserCode,
		this.videoFrame = 0,
		this.uRMVideoScaler = 0,
		this.uRMVideoParameter = 0,
		this.uRMVideoType = 0,
		String? token,
		String? remedicalCode,
		List<UrmPoint>? urmTraceDPoints,
		String? urmImageType,
		int urmBlend = 0,
		double downsampleIndex = 0,
		double intPowerDen = 0,
		double intPowerDir = 0,
		double sigmaGauss = 0,
		double vessScale = 0,
		double velMaxScaler = 0,
		double velMinScaler = 0,
		double iterations = 0,
		int imgProcessVer = 0,
		bool zoomOn = false,
		double zoomRoix = 0,
		double zoomRoiy = 0,
		double zoomRoiwidth = 0,
		double zoomRoiheight = 0,
		int roix = 0,
		int roiy = 0,
		int roiwidth = 0,
		int roiheight = 0,
		bool leftRight = false,
		bool upDown = false,
		int screenWidth = 0,
		int screenHeight = 0,
	}) : super(
			token: token,
			remedicalCode: remedicalCode,
			urmTraceDPoints: urmTraceDPoints,
			urmImageType: urmImageType,
			urmBlend: urmBlend,
			downsampleIndex: downsampleIndex,
			intPowerDen: intPowerDen,
			intPowerDir: intPowerDir,
			sigmaGauss: sigmaGauss,
			vessScale: vessScale,
			velMaxScaler: velMaxScaler,
			velMinScaler: velMinScaler,
			iterations: iterations,
			imgProcessVer: imgProcessVer,
			zoomOn: zoomOn,
			zoomRoix: zoomRoix,
			zoomRoiy: zoomRoiy,
			zoomRoiwidth: zoomRoiwidth,
			zoomRoiheight: zoomRoiheight,
			roix: roix,
			roiy: roiy,
			roiwidth: roiwidth,
			roiheight: roiheight,
			leftRight: leftRight,
			upDown: upDown,
			screenWidth: screenWidth,
			screenHeight: screenHeight,
		);

	factory URMVideoProcessRequest.fromJson(Map<String, dynamic> map) {
		final urmTraceDPointsData = map['UrmTraceDPoints'];
		return URMVideoProcessRequest( 
			notifyUserCode: map['NotifyUserCode'],
			videoFrame: map['VideoFrame'],
			uRMVideoScaler: double.parse(map['URMVideoScaler'].toString()),
			uRMVideoParameter: double.parse(map['URMVideoParameter'].toString()),
			uRMVideoType: double.parse(map['URMVideoType'].toString()),
			token: map['Token'],
			remedicalCode: map['RemedicalCode'],
			urmTraceDPoints: urmTraceDPointsData != null ? (urmTraceDPointsData as List).map((e) => UrmPoint.fromJson(e)).toList(): null,
			urmImageType: map['UrmImageType'],
			urmBlend: map['UrmBlend'],
			downsampleIndex: double.parse(map['DownsampleIndex'].toString()),
			intPowerDen: double.parse(map['IntPowerDen'].toString()),
			intPowerDir: double.parse(map['IntPowerDir'].toString()),
			sigmaGauss: double.parse(map['SigmaGauss'].toString()),
			vessScale: double.parse(map['VessScale'].toString()),
			velMaxScaler: double.parse(map['VelMaxScaler'].toString()),
			velMinScaler: double.parse(map['VelMinScaler'].toString()),
			iterations: double.parse(map['Iterations'].toString()),
			imgProcessVer: map['ImgProcessVer'],
			zoomOn: map['ZoomOn'],
			zoomRoix: double.parse(map['ZoomRoix'].toString()),
			zoomRoiy: double.parse(map['ZoomRoiy'].toString()),
			zoomRoiwidth: double.parse(map['ZoomRoiwidth'].toString()),
			zoomRoiheight: double.parse(map['ZoomRoiheight'].toString()),
			roix: map['Roix'],
			roiy: map['Roiy'],
			roiwidth: map['Roiwidth'],
			roiheight: map['Roiheight'],
			leftRight: map['LeftRight'],
			upDown: map['UpDown'],
			screenWidth: map['ScreenWidth'],
			screenHeight: map['ScreenHeight'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (notifyUserCode != null)
			map['NotifyUserCode'] = notifyUserCode;
		map['VideoFrame'] = videoFrame;
		map['URMVideoScaler'] = uRMVideoScaler;
		map['URMVideoParameter'] = uRMVideoParameter;
		map['URMVideoType'] = uRMVideoType;
		return map;
	}
}

class SaveAnalysisVideoRequest extends URMVideoProcessRequest{
	String? backgroundImage;
	double roiXPercent;
	double roiYPercent;
	double roiWPercent;
	double roiHPercent;
	double leftImgTopLeftCornerXPercent;
	double leftImgTopLeftCornerYPercent;
	double rightImgTopLeftCornerXPercent;
	double rightImgTopLeftCornerYPercent;
	double colorBarXPercent;
	double colorBarYPercent;

	SaveAnalysisVideoRequest({
		this.backgroundImage,
		this.roiXPercent = 0,
		this.roiYPercent = 0,
		this.roiWPercent = 0,
		this.roiHPercent = 0,
		this.leftImgTopLeftCornerXPercent = 0,
		this.leftImgTopLeftCornerYPercent = 0,
		this.rightImgTopLeftCornerXPercent = 0,
		this.rightImgTopLeftCornerYPercent = 0,
		this.colorBarXPercent = 0,
		this.colorBarYPercent = 0,
		String? notifyUserCode,
		int videoFrame = 0,
		double uRMVideoScaler = 0,
		double uRMVideoParameter = 0,
		double uRMVideoType = 0,
		String? token,
		String? remedicalCode,
		List<UrmPoint>? urmTraceDPoints,
		String? urmImageType,
		int urmBlend = 0,
		double downsampleIndex = 0,
		double intPowerDen = 0,
		double intPowerDir = 0,
		double sigmaGauss = 0,
		double vessScale = 0,
		double velMaxScaler = 0,
		double velMinScaler = 0,
		double iterations = 0,
		int imgProcessVer = 0,
		bool zoomOn = false,
		double zoomRoix = 0,
		double zoomRoiy = 0,
		double zoomRoiwidth = 0,
		double zoomRoiheight = 0,
		int roix = 0,
		int roiy = 0,
		int roiwidth = 0,
		int roiheight = 0,
		bool leftRight = false,
		bool upDown = false,
		int screenWidth = 0,
		int screenHeight = 0,
	}) : super(
			notifyUserCode: notifyUserCode,
			videoFrame: videoFrame,
			uRMVideoScaler: uRMVideoScaler,
			uRMVideoParameter: uRMVideoParameter,
			uRMVideoType: uRMVideoType,
			token: token,
			remedicalCode: remedicalCode,
			urmTraceDPoints: urmTraceDPoints,
			urmImageType: urmImageType,
			urmBlend: urmBlend,
			downsampleIndex: downsampleIndex,
			intPowerDen: intPowerDen,
			intPowerDir: intPowerDir,
			sigmaGauss: sigmaGauss,
			vessScale: vessScale,
			velMaxScaler: velMaxScaler,
			velMinScaler: velMinScaler,
			iterations: iterations,
			imgProcessVer: imgProcessVer,
			zoomOn: zoomOn,
			zoomRoix: zoomRoix,
			zoomRoiy: zoomRoiy,
			zoomRoiwidth: zoomRoiwidth,
			zoomRoiheight: zoomRoiheight,
			roix: roix,
			roiy: roiy,
			roiwidth: roiwidth,
			roiheight: roiheight,
			leftRight: leftRight,
			upDown: upDown,
			screenWidth: screenWidth,
			screenHeight: screenHeight,
		);

	factory SaveAnalysisVideoRequest.fromJson(Map<String, dynamic> map) {
		final urmTraceDPointsData = map['UrmTraceDPoints'];
		return SaveAnalysisVideoRequest( 
			backgroundImage: map['BackgroundImage'],
			roiXPercent: double.parse(map['RoiXPercent'].toString()),
			roiYPercent: double.parse(map['RoiYPercent'].toString()),
			roiWPercent: double.parse(map['RoiWPercent'].toString()),
			roiHPercent: double.parse(map['RoiHPercent'].toString()),
			leftImgTopLeftCornerXPercent: double.parse(map['LeftImgTopLeftCornerXPercent'].toString()),
			leftImgTopLeftCornerYPercent: double.parse(map['LeftImgTopLeftCornerYPercent'].toString()),
			rightImgTopLeftCornerXPercent: double.parse(map['RightImgTopLeftCornerXPercent'].toString()),
			rightImgTopLeftCornerYPercent: double.parse(map['RightImgTopLeftCornerYPercent'].toString()),
			colorBarXPercent: double.parse(map['ColorBarXPercent'].toString()),
			colorBarYPercent: double.parse(map['ColorBarYPercent'].toString()),
			notifyUserCode: map['NotifyUserCode'],
			videoFrame: map['VideoFrame'],
			uRMVideoScaler: double.parse(map['URMVideoScaler'].toString()),
			uRMVideoParameter: double.parse(map['URMVideoParameter'].toString()),
			uRMVideoType: double.parse(map['URMVideoType'].toString()),
			token: map['Token'],
			remedicalCode: map['RemedicalCode'],
			urmTraceDPoints: urmTraceDPointsData != null ? (urmTraceDPointsData as List).map((e) => UrmPoint.fromJson(e)).toList(): null,
			urmImageType: map['UrmImageType'],
			urmBlend: map['UrmBlend'],
			downsampleIndex: double.parse(map['DownsampleIndex'].toString()),
			intPowerDen: double.parse(map['IntPowerDen'].toString()),
			intPowerDir: double.parse(map['IntPowerDir'].toString()),
			sigmaGauss: double.parse(map['SigmaGauss'].toString()),
			vessScale: double.parse(map['VessScale'].toString()),
			velMaxScaler: double.parse(map['VelMaxScaler'].toString()),
			velMinScaler: double.parse(map['VelMinScaler'].toString()),
			iterations: double.parse(map['Iterations'].toString()),
			imgProcessVer: map['ImgProcessVer'],
			zoomOn: map['ZoomOn'],
			zoomRoix: double.parse(map['ZoomRoix'].toString()),
			zoomRoiy: double.parse(map['ZoomRoiy'].toString()),
			zoomRoiwidth: double.parse(map['ZoomRoiwidth'].toString()),
			zoomRoiheight: double.parse(map['ZoomRoiheight'].toString()),
			roix: map['Roix'],
			roiy: map['Roiy'],
			roiwidth: map['Roiwidth'],
			roiheight: map['Roiheight'],
			leftRight: map['LeftRight'],
			upDown: map['UpDown'],
			screenWidth: map['ScreenWidth'],
			screenHeight: map['ScreenHeight'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (backgroundImage != null)
			map['BackgroundImage'] = backgroundImage;
		map['RoiXPercent'] = roiXPercent;
		map['RoiYPercent'] = roiYPercent;
		map['RoiWPercent'] = roiWPercent;
		map['RoiHPercent'] = roiHPercent;
		map['LeftImgTopLeftCornerXPercent'] = leftImgTopLeftCornerXPercent;
		map['LeftImgTopLeftCornerYPercent'] = leftImgTopLeftCornerYPercent;
		map['RightImgTopLeftCornerXPercent'] = rightImgTopLeftCornerXPercent;
		map['RightImgTopLeftCornerYPercent'] = rightImgTopLeftCornerYPercent;
		map['ColorBarXPercent'] = colorBarXPercent;
		map['ColorBarYPercent'] = colorBarYPercent;
		return map;
	}
}

class SaveAnalysisVideoResult {
	String? videoUrl;
	int videoSize;
	String? coverImgUrl;

	SaveAnalysisVideoResult({
		this.videoUrl,
		this.videoSize = 0,
		this.coverImgUrl,
	});

	factory SaveAnalysisVideoResult.fromJson(Map<String, dynamic> map) {
		return SaveAnalysisVideoResult( 
			videoUrl: map['VideoUrl'],
			videoSize: map['VideoSize'],
			coverImgUrl: map['CoverImgUrl'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		if (videoUrl != null)
			map['VideoUrl'] = videoUrl;
		map['VideoSize'] = videoSize;
		if (coverImgUrl != null)
			map['CoverImgUrl'] = coverImgUrl;
		return map;
	}
}

class ActivationLicenseRequest extends TokenRequest{
	String? licenseCode;

	ActivationLicenseRequest({
		this.licenseCode,
		String? token,
	}) : super(
			token: token,
		);

	factory ActivationLicenseRequest.fromJson(Map<String, dynamic> map) {
		return ActivationLicenseRequest( 
			licenseCode: map['LicenseCode'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (licenseCode != null)
			map['LicenseCode'] = licenseCode;
		return map;
	}
}

class GetSampleDetailRequest extends TokenRequest{
	String? recordCode;

	GetSampleDetailRequest({
		this.recordCode,
		String? token,
	}) : super(
			token: token,
		);

	factory GetSampleDetailRequest.fromJson(Map<String, dynamic> map) {
		return GetSampleDetailRequest( 
			recordCode: map['RecordCode'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (recordCode != null)
			map['RecordCode'] = recordCode;
		return map;
	}
}

class ModifySampleDetailRequest extends TokenRequest{
	String? recordCode;
	List<DataItemDTO>? patientInfo;
	List<PatientInfoExt>? patientInfoExtList;

	ModifySampleDetailRequest({
		this.recordCode,
		this.patientInfo,
		this.patientInfoExtList,
		String? token,
	}) : super(
			token: token,
		);

	factory ModifySampleDetailRequest.fromJson(Map<String, dynamic> map) {
		return ModifySampleDetailRequest( 
			recordCode: map['RecordCode'],
			patientInfo: map['PatientInfo'] != null ? (map['PatientInfo'] as List).map((e)=>DataItemDTO.fromJson(e as Map<String,dynamic>)).toList() : null,
			patientInfoExtList: map['PatientInfoExtList'] != null ? (map['PatientInfoExtList'] as List).map((e)=>PatientInfoExt.fromJson(e as Map<String,dynamic>)).toList() : null,
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (recordCode != null)
			map['RecordCode'] = recordCode;
		if (patientInfo != null)
			map['PatientInfo'] = patientInfo;
		if (patientInfoExtList != null)
			map['PatientInfoExtList'] = patientInfoExtList;
		return map;
	}
}

class UserFeatureInfoResult {
	String? featureCode;
	String? featureName;
	String? fatherCode;
	String? uniqueCode;

	UserFeatureInfoResult({
		this.featureCode,
		this.featureName,
		this.fatherCode,
		this.uniqueCode,
	});

	factory UserFeatureInfoResult.fromJson(Map<String, dynamic> map) {
		return UserFeatureInfoResult( 
			featureCode: map['FeatureCode'],
			featureName: map['FeatureName'],
			fatherCode: map['FatherCode'],
			uniqueCode: map['UniqueCode'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		if (featureCode != null)
			map['FeatureCode'] = featureCode;
		if (featureName != null)
			map['FeatureName'] = featureName;
		if (fatherCode != null)
			map['FatherCode'] = fatherCode;
		if (uniqueCode != null)
			map['UniqueCode'] = uniqueCode;
		return map;
	}
}

class LicenseInfoDTO {
	String? licenseId;
	int licenseType;
	int maxAccountCount;
	int maxUsCount;
	DateTime? expirationUtcDate;
	bool isExpired;
	String? machineId;
	bool isDongleOn;
	String? authorityInfos;

	LicenseInfoDTO({
		this.licenseId,
		this.licenseType = 0,
		this.maxAccountCount = 0,
		this.maxUsCount = 0,
		this.expirationUtcDate,
		this.isExpired = false,
		this.machineId,
		this.isDongleOn = false,
		this.authorityInfos,
	});

	factory LicenseInfoDTO.fromJson(Map<String, dynamic> map) {
		return LicenseInfoDTO( 
			licenseId: map['LicenseId'],
			licenseType: map['LicenseType'],
			maxAccountCount: map['MaxAccountCount'],
			maxUsCount: map['MaxUsCount'],
			expirationUtcDate: map['ExpirationUtcDate'] != null ? DateTime.parse(map['ExpirationUtcDate']) : null,
			isExpired: map['IsExpired'],
			machineId: map['MachineId'],
			isDongleOn: map['IsDongleOn'],
			authorityInfos: map['AuthorityInfos'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		if (licenseId != null)
			map['LicenseId'] = licenseId;
		map['LicenseType'] = licenseType;
		map['MaxAccountCount'] = maxAccountCount;
		map['MaxUsCount'] = maxUsCount;
		if (expirationUtcDate != null)
			map['ExpirationUtcDate'] = JsonRpcUtils.dateFormat(expirationUtcDate!);
		map['IsExpired'] = isExpired;
		if (machineId != null)
			map['MachineId'] = machineId;
		map['IsDongleOn'] = isDongleOn;
		if (authorityInfos != null)
			map['AuthorityInfos'] = authorityInfos;
		return map;
	}
}

class SampleRemedicalBasicInfo {
	String? recordCode;
	String? remedicalName;
	List<SampleRemedicalInfoDTO>? sampleRemedicalInfoList;

	SampleRemedicalBasicInfo({
		this.recordCode,
		this.remedicalName,
		this.sampleRemedicalInfoList,
	});

	factory SampleRemedicalBasicInfo.fromJson(Map<String, dynamic> map) {
		return SampleRemedicalBasicInfo( 
			recordCode: map['RecordCode'],
			remedicalName: map['RemedicalName'],
			sampleRemedicalInfoList: map['SampleRemedicalInfoList'] != null ? (map['SampleRemedicalInfoList'] as List).map((e)=>SampleRemedicalInfoDTO.fromJson(e as Map<String,dynamic>)).toList() : null,
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		if (recordCode != null)
			map['RecordCode'] = recordCode;
		if (remedicalName != null)
			map['RemedicalName'] = remedicalName;
		if (sampleRemedicalInfoList != null)
			map['SampleRemedicalInfoList'] = sampleRemedicalInfoList;
		return map;
	}
}

class SampleDetailInfo extends BaseSampleDetail{
	List<SampleRemedicalBasicInfo>? sampleRemedicalBasicList;

	SampleDetailInfo({
		this.sampleRemedicalBasicList,
		String? recordCode,
		DateTime? recordTime,
		List<DataItemDTO>? patientInfo,
		List<PatientInfoExt>? patientInfoExtList,
	}) : super(
			recordCode: recordCode,
			recordTime: recordTime,
			patientInfo: patientInfo,
			patientInfoExtList: patientInfoExtList,
		);

	factory SampleDetailInfo.fromJson(Map<String, dynamic> map) {
		return SampleDetailInfo( 
			sampleRemedicalBasicList: map['SampleRemedicalBasicList'] != null ? (map['SampleRemedicalBasicList'] as List).map((e)=>SampleRemedicalBasicInfo.fromJson(e as Map<String,dynamic>)).toList() : null,
			recordCode: map['RecordCode'],
			recordTime: map['RecordTime'] != null ? DateTime.parse(map['RecordTime']) : null,
			patientInfo: map['PatientInfo'] != null ? (map['PatientInfo'] as List).map((e)=>DataItemDTO.fromJson(e as Map<String,dynamic>)).toList() : null,
			patientInfoExtList: map['PatientInfoExtList'] != null ? (map['PatientInfoExtList'] as List).map((e)=>PatientInfoExt.fromJson(e as Map<String,dynamic>)).toList() : null,
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (sampleRemedicalBasicList != null)
			map['SampleRemedicalBasicList'] = sampleRemedicalBasicList;
		return map;
	}
}

class ProjectSampleDataExportResult {
	DateTime? createTime;
	String? name;
	OrganizationPatientTypeEnum patientType;
	String? exportExcelUrl;
	List<SampleDetailInfo>? sampleDetailList;

	ProjectSampleDataExportResult({
		this.createTime,
		this.name,
		this.patientType = OrganizationPatientTypeEnum.Person,
		this.exportExcelUrl,
		this.sampleDetailList,
	});

	factory ProjectSampleDataExportResult.fromJson(Map<String, dynamic> map) {
		return ProjectSampleDataExportResult( 
			createTime: map['CreateTime'] != null ? DateTime.parse(map['CreateTime']) : null,
			name: map['Name'],
			patientType: OrganizationPatientTypeEnum.values.firstWhere((e) => e.index == map['PatientType']),
			exportExcelUrl: map['ExportExcelUrl'],
			sampleDetailList: map['SampleDetailList'] != null ? (map['SampleDetailList'] as List).map((e)=>SampleDetailInfo.fromJson(e as Map<String,dynamic>)).toList() : null,
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		if (createTime != null)
			map['CreateTime'] = JsonRpcUtils.dateFormat(createTime!);
		if (name != null)
			map['Name'] = name;
		map['PatientType'] = patientType.index;
		if (exportExcelUrl != null)
			map['ExportExcelUrl'] = exportExcelUrl;
		if (sampleDetailList != null)
			map['SampleDetailList'] = sampleDetailList;
		return map;
	}
}

class GetProjectSampleDataExportRequest extends TokenRequest{
	String? projectCode;
	List<String>? patientCodes;

	GetProjectSampleDataExportRequest({
		this.projectCode,
		this.patientCodes,
		String? token,
	}) : super(
			token: token,
		);

	factory GetProjectSampleDataExportRequest.fromJson(Map<String, dynamic> map) {
		return GetProjectSampleDataExportRequest( 
			projectCode: map['ProjectCode'],
			patientCodes: map['PatientCodes']?.cast<String>().toList(),
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (projectCode != null)
			map['ProjectCode'] = projectCode;
		if (patientCodes != null)
			map['PatientCodes'] = patientCodes;
		return map;
	}
}

class SaveUserUrmConfigResult {
	String? code;

	SaveUserUrmConfigResult({
		this.code,
	});

	factory SaveUserUrmConfigResult.fromJson(Map<String, dynamic> map) {
		return SaveUserUrmConfigResult( 
			code: map['Code'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		if (code != null)
			map['Code'] = code;
		return map;
	}
}

class UrmProcessConfigDTO {
	double downsampleIndex;
	double intPowerDen;
	double intPowerDir;
	double sigmaGauss;
	double vessScale;
	double velMaxScaler;
	double velMinScaler;
	double iterations;
	double uRMVideoParameter;
	double uRMVideoType;

	UrmProcessConfigDTO({
		this.downsampleIndex = 0,
		this.intPowerDen = 0,
		this.intPowerDir = 0,
		this.sigmaGauss = 0,
		this.vessScale = 0,
		this.velMaxScaler = 0,
		this.velMinScaler = 0,
		this.iterations = 0,
		this.uRMVideoParameter = 0,
		this.uRMVideoType = 0,
	});

	factory UrmProcessConfigDTO.fromJson(Map<String, dynamic> map) {
		return UrmProcessConfigDTO( 
			downsampleIndex: double.parse(map['DownsampleIndex'].toString()),
			intPowerDen: double.parse(map['IntPowerDen'].toString()),
			intPowerDir: double.parse(map['IntPowerDir'].toString()),
			sigmaGauss: double.parse(map['SigmaGauss'].toString()),
			vessScale: double.parse(map['VessScale'].toString()),
			velMaxScaler: double.parse(map['VelMaxScaler'].toString()),
			velMinScaler: double.parse(map['VelMinScaler'].toString()),
			iterations: double.parse(map['Iterations'].toString()),
			uRMVideoParameter: double.parse(map['URMVideoParameter'].toString()),
			uRMVideoType: double.parse(map['URMVideoType'].toString()),
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		map['DownsampleIndex'] = downsampleIndex;
		map['IntPowerDen'] = intPowerDen;
		map['IntPowerDir'] = intPowerDir;
		map['SigmaGauss'] = sigmaGauss;
		map['VessScale'] = vessScale;
		map['VelMaxScaler'] = velMaxScaler;
		map['VelMinScaler'] = velMinScaler;
		map['Iterations'] = iterations;
		map['URMVideoParameter'] = uRMVideoParameter;
		map['URMVideoType'] = uRMVideoType;
		return map;
	}
}

class SaveUserUrmConfigRequest extends TokenRequest{
	String? code;
	String? configName;
	bool isDefault;
	int configType;
	List<UrmProcessConfigDTO>? configInfo;

	SaveUserUrmConfigRequest({
		this.code,
		this.configName,
		this.isDefault = false,
		this.configType = 0,
		this.configInfo,
		String? token,
	}) : super(
			token: token,
		);

	factory SaveUserUrmConfigRequest.fromJson(Map<String, dynamic> map) {
		return SaveUserUrmConfigRequest( 
			code: map['Code'],
			configName: map['ConfigName'],
			isDefault: map['IsDefault'],
			configType: map['ConfigType'],
			configInfo: map['ConfigInfo'] != null ? (map['ConfigInfo'] as List).map((e)=>UrmProcessConfigDTO.fromJson(e as Map<String,dynamic>)).toList() : null,
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		if (configName != null)
			map['ConfigName'] = configName;
		map['IsDefault'] = isDefault;
		map['ConfigType'] = configType;
		if (configInfo != null)
			map['ConfigInfo'] = configInfo;
		return map;
	}
}

class DeletePatientUrmConfigRequest extends TokenRequest{
	String? code;

	DeletePatientUrmConfigRequest({
		this.code,
		String? token,
	}) : super(
			token: token,
		);

	factory DeletePatientUrmConfigRequest.fromJson(Map<String, dynamic> map) {
		return DeletePatientUrmConfigRequest( 
			code: map['Code'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		return map;
	}
}

class SetDefaultPatientUrmConfigRequest extends TokenRequest{
	String? code;

	SetDefaultPatientUrmConfigRequest({
		this.code,
		String? token,
	}) : super(
			token: token,
		);

	factory SetDefaultPatientUrmConfigRequest.fromJson(Map<String, dynamic> map) {
		return SetDefaultPatientUrmConfigRequest( 
			code: map['Code'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		return map;
	}
}

class UserUrmConfigDTO extends BaseDTO{
	String? code;
	String? userCode;
	String? configName;
	bool isDefault;
	int configType;
	String? configData;
	List<UrmProcessConfigDTO>? configInfo;

	UserUrmConfigDTO({
		this.code,
		this.userCode,
		this.configName,
		this.isDefault = false,
		this.configType = 0,
		this.configData,
		this.configInfo,
		bool isDelete = false,
		DateTime? createTime,
		DateTime? updateTime,
	}) : super(
			isDelete: isDelete,
			createTime: createTime,
			updateTime: updateTime,
		);

	factory UserUrmConfigDTO.fromJson(Map<String, dynamic> map) {
		return UserUrmConfigDTO( 
			code: map['Code'],
			userCode: map['UserCode'],
			configName: map['ConfigName'],
			isDefault: map['IsDefault'],
			configType: map['ConfigType'],
			configData: map['ConfigData'],
			configInfo: map['ConfigInfo'] != null ? (map['ConfigInfo'] as List).map((e)=>UrmProcessConfigDTO.fromJson(e as Map<String,dynamic>)).toList() : null,
			isDelete: map['IsDelete'],
			createTime: map['CreateTime'] != null ? DateTime.parse(map['CreateTime']) : null,
			updateTime: map['UpdateTime'] != null ? DateTime.parse(map['UpdateTime']) : null,
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		if (userCode != null)
			map['UserCode'] = userCode;
		if (configName != null)
			map['ConfigName'] = configName;
		map['IsDefault'] = isDefault;
		map['ConfigType'] = configType;
		if (configData != null)
			map['ConfigData'] = configData;
		if (configInfo != null)
			map['ConfigInfo'] = configInfo;
		return map;
	}
}

class GetUserUrmConfigsRequest extends TokenRequest{

	GetUserUrmConfigsRequest({
		String? token,
	}) : super(
			token: token,
		);

	factory GetUserUrmConfigsRequest.fromJson(Map<String, dynamic> map) {
		return GetUserUrmConfigsRequest( 
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		return map;
	}
}


