import 'researchEdition.m.dart';

class StorageRequest {
	List<int>? file;
	String? authorization;

	StorageRequest({
		this.file,
		this.authorization,
	});

	factory StorageRequest.fromJson(Map<String, dynamic> map) {
		final fileData = map['File'];
		return StorageRequest( 
			file: fileData != null ? (fileData as List).map((e) => e as int).toList(): null,
			authorization: map['Authorization'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		if (file != null)
			map['File'] = file;
		if (authorization != null)
			map['Authorization'] = authorization;
		return map;
	}
}

class StorageServiceSettingDTO {
	String? authorization;
	String? contentType;
	String? storageUrl;

	StorageServiceSettingDTO({
		this.authorization,
		this.contentType,
		this.storageUrl,
	});

	factory StorageServiceSettingDTO.fromJson(Map<String, dynamic> map) {
		return StorageServiceSettingDTO( 
			authorization: map['Authorization'],
			contentType: map['ContentType'],
			storageUrl: map['StorageUrl'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		if (authorization != null)
			map['Authorization'] = authorization;
		if (contentType != null)
			map['ContentType'] = contentType;
		if (storageUrl != null)
			map['StorageUrl'] = storageUrl;
		return map;
	}
}

class FileServiceRequest extends TokenRequest{
	String? fileName;
	bool isRechristen;
	bool isUpgradePackage;
	List<DataItemDTO>? urlParams;
	List<DataItemDTO>? headerParams;
	String? requestMethod;
	bool isCompleted;

	FileServiceRequest({
		this.fileName,
		this.isRechristen = false,
		this.isUpgradePackage = false,
		this.urlParams,
		this.headerParams,
		this.requestMethod,
		this.isCompleted = false,
		String? token,
	}) : super(
			token: token,
		);

	factory FileServiceRequest.fromJson(Map<String, dynamic> map) {
		return FileServiceRequest( 
			fileName: map['FileName'],
			isRechristen: map['IsRechristen'],
			isUpgradePackage: map['IsUpgradePackage'],
			urlParams: map['UrlParams'] != null ? (map['UrlParams'] as List).map((e)=>DataItemDTO.fromJson(e as Map<String,dynamic>)).toList() : null,
			headerParams: map['HeaderParams'] != null ? (map['HeaderParams'] as List).map((e)=>DataItemDTO.fromJson(e as Map<String,dynamic>)).toList() : null,
			requestMethod: map['RequestMethod'],
			isCompleted: map['IsCompleted'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (fileName != null)
			map['FileName'] = fileName;
		map['IsRechristen'] = isRechristen;
		map['IsUpgradePackage'] = isUpgradePackage;
		if (urlParams != null)
			map['UrlParams'] = urlParams;
		if (headerParams != null)
			map['HeaderParams'] = headerParams;
		if (requestMethod != null)
			map['RequestMethod'] = requestMethod;
		map['IsCompleted'] = isCompleted;
		return map;
	}
}

class CheckStorageRequest {
	String? fileName;

	CheckStorageRequest({
		this.fileName,
	});

	factory CheckStorageRequest.fromJson(Map<String, dynamic> map) {
		return CheckStorageRequest( 
			fileName: map['FileName'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		if (fileName != null)
			map['FileName'] = fileName;
		return map;
	}
}

class CheckFileIsExistRequest {
	String? oriFileName;
	int fileSize;
	bool isNeedPartUpload;
	bool isUpgradePackage;

	CheckFileIsExistRequest({
		this.oriFileName,
		this.fileSize = 0,
		this.isNeedPartUpload = false,
		this.isUpgradePackage = false,
	});

	factory CheckFileIsExistRequest.fromJson(Map<String, dynamic> map) {
		return CheckFileIsExistRequest( 
			oriFileName: map['OriFileName'],
			fileSize: map['FileSize'],
			isNeedPartUpload: map['IsNeedPartUpload'],
			isUpgradePackage: map['IsUpgradePackage'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		if (oriFileName != null)
			map['OriFileName'] = oriFileName;
		map['FileSize'] = fileSize;
		map['IsNeedPartUpload'] = isNeedPartUpload;
		map['IsUpgradePackage'] = isUpgradePackage;
		return map;
	}
}

class CopyToOtherNodeRequest extends TokenRequest{
	String? fileName;
	String? fileUrl;

	CopyToOtherNodeRequest({
		this.fileName,
		this.fileUrl,
		String? token,
	}) : super(
			token: token,
		);

	factory CopyToOtherNodeRequest.fromJson(Map<String, dynamic> map) {
		return CopyToOtherNodeRequest( 
			fileName: map['FileName'],
			fileUrl: map['FileUrl'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (fileName != null)
			map['FileName'] = fileName;
		if (fileUrl != null)
			map['FileUrl'] = fileUrl;
		return map;
	}
}

class UploadFileTransferRequest extends TokenRequest{
	String? sourceFilePath;
	bool isRechristen;
	bool isNeedPartUpload;
	bool isCopy;

	UploadFileTransferRequest({
		this.sourceFilePath,
		this.isRechristen = false,
		this.isNeedPartUpload = false,
		this.isCopy = false,
		String? token,
	}) : super(
			token: token,
		);

	factory UploadFileTransferRequest.fromJson(Map<String, dynamic> map) {
		return UploadFileTransferRequest( 
			sourceFilePath: map['SourceFilePath'],
			isRechristen: map['IsRechristen'],
			isNeedPartUpload: map['IsNeedPartUpload'],
			isCopy: map['IsCopy'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (sourceFilePath != null)
			map['SourceFilePath'] = sourceFilePath;
		map['IsRechristen'] = isRechristen;
		map['IsNeedPartUpload'] = isNeedPartUpload;
		map['IsCopy'] = isCopy;
		return map;
	}
}

class DeleteStorageRequest {
	String? fileUrl;

	DeleteStorageRequest({
		this.fileUrl,
	});

	factory DeleteStorageRequest.fromJson(Map<String, dynamic> map) {
		return DeleteStorageRequest( 
			fileUrl: map['FileUrl'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		if (fileUrl != null)
			map['FileUrl'] = fileUrl;
		return map;
	}
}


