import 'dart:core';

import 'package:fis_jsonrpc/client_base.dart';
import 'package:fis_common/json_convert.dart';

import 'ultrasoundReport.m.dart';

import 'remedical.m.dart';
import 'report.m.dart';
import 'liveConsultation.m.dart';


class UltrasoundReportService extends JsonRpcClientBase {
	UltrasoundReportService(
		String host, {
		String serviceName = "IUltrasoundReportService",
		Map<String, String>? headers,
		int? timeout,
	}) : super(
						host,
						serviceName,
						headers: headers,
						timeout: timeout,
				) {
		/// 注册响应实体反序列化处理器
		FJsonConvert.setDecoder((map) => ReportDTO.fromJson(map));
		FJsonConvert.setDecoder((map) => ThesaurusAllDTO.fromJson(map));
		FJsonConvert.setDecoder((map) => ThesaurusItemDTO.fromJson(map));
		FJsonConvert.setDecoder((map) => PageResult<ThesaurusDTO>.fromJson(map));
		FJsonConvert.setDecoder((map) => ThesaurusDTO.fromJson(map));
		FJsonConvert.setDecoder((map) => PageResult<ReportTemplateDTO>.fromJson(map));
		FJsonConvert.setDecoder((map) => ReportTemplateDTO.fromJson(map));
	}

	Future<List<ReportDTO>> vitalFindReportsAsync(FindReportsRequest request) async {
		var rpcRst = await call("VitalFindReportsAsync", request);
		var result = (rpcRst as List).map((e)=>ReportDTO.fromJson(e as Map<String, dynamic>)).toList();
		return result;
	}

	Future<ReportDTO> vitalFindReportByCodeAsync(FindReportByCodeRequest request) async {
		var rpcRst = await call("VitalFindReportByCodeAsync", request);
		var result = ReportDTO.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<String> vitalAddReportAsync(AddReportRequest request) async {
		var rpcRst = await call("VitalAddReportAsync", request);
		return rpcRst;
	}

	Future<bool> vitalModifyReportAsync(ModifyReportRequest request) async {
		var rpcRst = await call("VitalModifyReportAsync", request);
		return rpcRst;
	}

	Future<ThesaurusAllDTO> vitalGetDefaultThesaurusContentAsync(GetDefaultThesaurusContentRequest request) async {
		var rpcRst = await call("VitalGetDefaultThesaurusContentAsync", request);
		var result = ThesaurusAllDTO.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<List<ThesaurusItemDTO>> vitalGetThesaurusItemsAsync(GetThesaurusItemsRequest request) async {
		var rpcRst = await call("VitalGetThesaurusItemsAsync", request);
		var result = (rpcRst as List).map((e)=>ThesaurusItemDTO.fromJson(e as Map<String, dynamic>)).toList();
		return result;
	}

	Future<PageResult<ThesaurusDTO>> vitalGetThesaurusPageAsync(GetThesaurusPageRequest request) async {
		var rpcRst = await call("VitalGetThesaurusPageAsync", request);
		var result = PageResult<ThesaurusDTO>.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<PageResult<ReportTemplateDTO>> vitalGetReportTemplatePageAsync(FindReportTemplatePagesRequest request) async {
		var rpcRst = await call("VitalGetReportTemplatePageAsync", request);
		var result = PageResult<ReportTemplateDTO>.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<ReportTemplateDTO> vitalGetDefaultReportTemplateContentAsync(GetDefaultReportTemplateContentRequest request) async {
		var rpcRst = await call("VitalGetDefaultReportTemplateContentAsync", request);
		var result = ReportTemplateDTO.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<ReportTemplateDTO> vitalFindReportTemplateByCodeAsync(FindReportTemplateByCodeRequest request) async {
		var rpcRst = await call("VitalFindReportTemplateByCodeAsync", request);
		var result = ReportTemplateDTO.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<String> vitalAddEcgReportAsync(AddEcgReportRequest request) async {
		var rpcRst = await call("VitalAddEcgReportAsync", request);
		return rpcRst;
	}

	Future<bool> vitalModifyEcgReportAsync(ModifyEcgReportRequest request) async {
		var rpcRst = await call("VitalModifyEcgReportAsync", request);
		return rpcRst;
	}

}

