import 'dart:core';

import 'package:fis_jsonrpc/client_base.dart';
import 'package:fis_common/json_convert.dart';

import 'upgrade.m.dart';

import 'organization.m.dart';
import 'liveConsultation.m.dart';


class UpgradeService extends JsonRpcClientBase {
	UpgradeService(
		String host, {
		String serviceName = "IUpgradeService",
		Map<String, String>? headers,
		int? timeout,
	}) : super(
						host,
						serviceName,
						headers: headers,
						timeout: timeout,
				) {
		/// 注册响应实体反序列化处理器
		FJsonConvert.setDecoder((map) => GetUpgradeInfoResult.fromJson(map));
		FJsonConvert.setDecoder((map) => OrganizationDTO.fromJson(map));
		FJsonConvert.setDecoder((map) => UserExtendDTO.fromJson(map));
	}

	Future<GetUpgradeInfoResult> getUpgradeInfoAsync(GetUpgradeInfoRequest request) async {
		var rpcRst = await call("GetUpgradeInfoAsync", request);
		var result = GetUpgradeInfoResult.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<bool> updateClientVersion(SetUpgradeInfoRequest request) async {
		var rpcRst = await call("UpdateClientVersion", request);
		return rpcRst;
	}

	Future<bool> reloadUpgradeConfig() async {
		var rpcRst = await call("ReloadUpgradeConfig", );
		return rpcRst;
	}

	Future<List<OrganizationDTO>> searchGrayscaleOrganizationsAsync(SearchOrganizationsRequest request) async {
		var rpcRst = await call("SearchGrayscaleOrganizationsAsync", request);
		var result = (rpcRst as List).map((e)=>OrganizationDTO.fromJson(e as Map<String, dynamic>)).toList();
		return result;
	}

	Future<List<UserExtendDTO>> getGrayscaleUserListAsync(GetUserListRequest request) async {
		var rpcRst = await call("GetGrayscaleUserListAsync", request);
		var result = (rpcRst as List).map((e)=>UserExtendDTO.fromJson(e as Map<String, dynamic>)).toList();
		return result;
	}

	Future<String> getFlyinsonoVersionAsync(GetFlyinsonoVersionRequest request) async {
		var rpcRst = await call("GetFlyinsonoVersionAsync", request);
		return rpcRst;
	}

}

