import 'researchEdition.m.dart';
import 'liveConsultation.m.dart';
import 'connect.m.dart';
import 'user.m.dart';
import 'notification.m.dart';

import 'package:fis_jsonrpc/utils.dart';

class IOTDeviceCarouselsResult {
	String? id;
	String? title;
	String? content;
	String? titleImage;

	IOTDeviceCarouselsResult({
		this.id,
		this.title,
		this.content,
		this.titleImage,
	});

	factory IOTDeviceCarouselsResult.fromJson(Map<String, dynamic> map) {
		return IOTDeviceCarouselsResult( 
			id: map['Id'],
			title: map['Title'],
			content: map['Content'],
			titleImage: map['TitleImage'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		if (id != null)
			map['Id'] = id;
		if (title != null)
			map['Title'] = title;
		if (content != null)
			map['Content'] = content;
		if (titleImage != null)
			map['TitleImage'] = titleImage;
		return map;
	}
}

class IOTDeviceNewsResult extends IOTDeviceCarouselsResult{

	IOTDeviceNewsResult({
		String? id,
		String? title,
		String? content,
		String? titleImage,
	}) : super(
			id: id,
			title: title,
			content: content,
			titleImage: titleImage,
		);

	factory IOTDeviceNewsResult.fromJson(Map<String, dynamic> map) {
		return IOTDeviceNewsResult( 
			id: map['Id'],
			title: map['Title'],
			content: map['Content'],
			titleImage: map['TitleImage'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		return map;
	}
}

class GetIOTDeviceNewsPageRequest extends PageRequest{
	String? keyword;

	GetIOTDeviceNewsPageRequest({
		this.keyword,
		int pageIndex = 0,
		int pageSize = 0,
		String? token,
	}) : super(
			pageIndex: pageIndex,
			pageSize: pageSize,
			token: token,
		);

	factory GetIOTDeviceNewsPageRequest.fromJson(Map<String, dynamic> map) {
		return GetIOTDeviceNewsPageRequest( 
			keyword: map['Keyword'],
			pageIndex: map['PageIndex'],
			pageSize: map['PageSize'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (keyword != null)
			map['Keyword'] = keyword;
		return map;
	}
}

class IOTDeviceOperateGuidesResult {
	String? id;
	String? title;
	String? content;
	String? titleImage;
	String? titleVideo;
	int orderNo;
	DateTime? createTime;

	IOTDeviceOperateGuidesResult({
		this.id,
		this.title,
		this.content,
		this.titleImage,
		this.titleVideo,
		this.orderNo = 0,
		this.createTime,
	});

	factory IOTDeviceOperateGuidesResult.fromJson(Map<String, dynamic> map) {
		return IOTDeviceOperateGuidesResult( 
			id: map['Id'],
			title: map['Title'],
			content: map['Content'],
			titleImage: map['TitleImage'],
			titleVideo: map['TitleVideo'],
			orderNo: map['OrderNo'],
			createTime: map['CreateTime'] != null ? DateTime.parse(map['CreateTime']) : null,
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		if (id != null)
			map['Id'] = id;
		if (title != null)
			map['Title'] = title;
		if (content != null)
			map['Content'] = content;
		if (titleImage != null)
			map['TitleImage'] = titleImage;
		if (titleVideo != null)
			map['TitleVideo'] = titleVideo;
		map['OrderNo'] = orderNo;
		if (createTime != null)
			map['CreateTime'] = JsonRpcUtils.dateFormat(createTime!);
		return map;
	}
}

class GetOperateGuidesPageRequest extends PageRequest{
	String? keyword;
	int deviceType;
	int tagType;

	GetOperateGuidesPageRequest({
		this.keyword,
		this.deviceType = 0,
		this.tagType = 0,
		int pageIndex = 0,
		int pageSize = 0,
		String? token,
	}) : super(
			pageIndex: pageIndex,
			pageSize: pageSize,
			token: token,
		);

	factory GetOperateGuidesPageRequest.fromJson(Map<String, dynamic> map) {
		return GetOperateGuidesPageRequest( 
			keyword: map['Keyword'],
			deviceType: map['DeviceType'],
			tagType: map['TagType'],
			pageIndex: map['PageIndex'],
			pageSize: map['PageSize'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (keyword != null)
			map['Keyword'] = keyword;
		map['DeviceType'] = deviceType;
		map['TagType'] = tagType;
		return map;
	}
}

class IOTDeviceDetailResult {
	String? id;
	String? deviceName;
	String? areaCode;
	String? wifiName;
	bool isAuto;
	String? machineNo;
	String? productNo;
	int type;
	int connectStatus;
	int activityStatus;
	DateTime? createdTime;
	DateTime? updatedTime;
	int modeType;
	int totalScore;
	double useHour;
	String? leakLevel;
	double ahi;
	String? cartridge;
	String? pip;
	String? mask;
	double oxygenConc;
	bool? treatPwr;

	IOTDeviceDetailResult({
		this.id,
		this.deviceName,
		this.areaCode,
		this.wifiName,
		this.isAuto = false,
		this.machineNo,
		this.productNo,
		this.type = 0,
		this.connectStatus = 0,
		this.activityStatus = 0,
		this.createdTime,
		this.updatedTime,
		this.modeType = 0,
		this.totalScore = 0,
		this.useHour = 0,
		this.leakLevel,
		this.ahi = 0,
		this.cartridge,
		this.pip,
		this.mask,
		this.oxygenConc = 0,
		this.treatPwr,
	});

	factory IOTDeviceDetailResult.fromJson(Map<String, dynamic> map) {
		return IOTDeviceDetailResult( 
			id: map['Id'],
			deviceName: map['DeviceName'],
			areaCode: map['AreaCode'],
			wifiName: map['WifiName'],
			isAuto: map['IsAuto'],
			machineNo: map['MachineNo'],
			productNo: map['ProductNo'],
			type: map['Type'],
			connectStatus: map['ConnectStatus'],
			activityStatus: map['ActivityStatus'],
			createdTime: map['CreatedTime'] != null ? DateTime.parse(map['CreatedTime']) : null,
			updatedTime: map['UpdatedTime'] != null ? DateTime.parse(map['UpdatedTime']) : null,
			modeType: map['ModeType'],
			totalScore: map['TotalScore'],
			useHour: double.parse(map['UseHour'].toString()),
			leakLevel: map['LeakLevel'],
			ahi: double.parse(map['Ahi'].toString()),
			cartridge: map['Cartridge'],
			pip: map['Pip'],
			mask: map['Mask'],
			oxygenConc: double.parse(map['OxygenConc'].toString()),
			treatPwr: map['TreatPwr'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		if (id != null)
			map['Id'] = id;
		if (deviceName != null)
			map['DeviceName'] = deviceName;
		if (areaCode != null)
			map['AreaCode'] = areaCode;
		if (wifiName != null)
			map['WifiName'] = wifiName;
		map['IsAuto'] = isAuto;
		if (machineNo != null)
			map['MachineNo'] = machineNo;
		if (productNo != null)
			map['ProductNo'] = productNo;
		map['Type'] = type;
		map['ConnectStatus'] = connectStatus;
		map['ActivityStatus'] = activityStatus;
		if (createdTime != null)
			map['CreatedTime'] = JsonRpcUtils.dateFormat(createdTime!);
		if (updatedTime != null)
			map['UpdatedTime'] = JsonRpcUtils.dateFormat(updatedTime!);
		map['ModeType'] = modeType;
		map['TotalScore'] = totalScore;
		map['UseHour'] = useHour;
		if (leakLevel != null)
			map['LeakLevel'] = leakLevel;
		map['Ahi'] = ahi;
		if (cartridge != null)
			map['Cartridge'] = cartridge;
		if (pip != null)
			map['Pip'] = pip;
		if (mask != null)
			map['Mask'] = mask;
		map['OxygenConc'] = oxygenConc;
		if (treatPwr != null)
			map['TreatPwr'] = treatPwr;
		return map;
	}
}

enum ModeType {
	CPAP,
	APAP,
	AUTOS,
	BPAPS,
	BPAPT,
	BPAPST,
}

class GetIOTDevicBaseRequest extends TokenRequest{
	String? deviceId;
	ModeType mode;

	GetIOTDevicBaseRequest({
		this.deviceId,
		this.mode = ModeType.CPAP,
		String? token,
	}) : super(
			token: token,
		);

	factory GetIOTDevicBaseRequest.fromJson(Map<String, dynamic> map) {
		return GetIOTDevicBaseRequest( 
			deviceId: map['DeviceId'],
			mode: ModeType.values.firstWhere((e) => e.index == map['Mode']),
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (deviceId != null)
			map['DeviceId'] = deviceId;
		map['Mode'] = mode.index;
		return map;
	}
}

class GetIOTDeviceDetailRequest extends GetIOTDevicBaseRequest{
	DateTime? date;
	String? userCode;

	GetIOTDeviceDetailRequest({
		this.date,
		this.userCode,
		String? deviceId,
		ModeType mode = ModeType.CPAP,
		String? token,
	}) : super(
			deviceId: deviceId,
			mode: mode,
			token: token,
		);

	factory GetIOTDeviceDetailRequest.fromJson(Map<String, dynamic> map) {
		return GetIOTDeviceDetailRequest( 
			date: map['Date'] != null ? DateTime.parse(map['Date']) : null,
			userCode: map['UserCode'],
			deviceId: map['DeviceId'],
			mode: ModeType.values.firstWhere((e) => e.index == map['Mode']),
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (date != null)
			map['Date'] = JsonRpcUtils.dateFormat(date!);
		if (userCode != null)
			map['UserCode'] = userCode;
		return map;
	}
}

enum ReportType {
	Day,
	Week,
	Month,
	Month_3,
	Month_6,
	Year,
}

class GetIOTDeviceReportRequest extends GetIOTDevicBaseRequest{
	ReportType reportType;

	GetIOTDeviceReportRequest({
		this.reportType = ReportType.Day,
		String? deviceId,
		ModeType mode = ModeType.CPAP,
		String? token,
	}) : super(
			deviceId: deviceId,
			mode: mode,
			token: token,
		);

	factory GetIOTDeviceReportRequest.fromJson(Map<String, dynamic> map) {
		return GetIOTDeviceReportRequest( 
			reportType: ReportType.values.firstWhere((e) => e.index == map['ReportType']),
			deviceId: map['DeviceId'],
			mode: ModeType.values.firstWhere((e) => e.index == map['Mode']),
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		map['ReportType'] = reportType.index;
		return map;
	}
}

class GetIOTDeviceUseDateRequest extends GetIOTDevicBaseRequest{
	DateTime? start;
	DateTime? end;

	GetIOTDeviceUseDateRequest({
		this.start,
		this.end,
		String? deviceId,
		ModeType mode = ModeType.CPAP,
		String? token,
	}) : super(
			deviceId: deviceId,
			mode: mode,
			token: token,
		);

	factory GetIOTDeviceUseDateRequest.fromJson(Map<String, dynamic> map) {
		return GetIOTDeviceUseDateRequest( 
			start: map['Start'] != null ? DateTime.parse(map['Start']) : null,
			end: map['End'] != null ? DateTime.parse(map['End']) : null,
			deviceId: map['DeviceId'],
			mode: ModeType.values.firstWhere((e) => e.index == map['Mode']),
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (start != null)
			map['Start'] = JsonRpcUtils.dateFormat(start!);
		if (end != null)
			map['End'] = JsonRpcUtils.dateFormat(end!);
		return map;
	}
}

enum AjaxResultTypeEnum {
	placeHolder_0,
	placeHolder_1,
	placeHolder_2,
	placeHolder_3,
	placeHolder_4,
	placeHolder_5,
	placeHolder_6,
	placeHolder_7,
	placeHolder_8,
	placeHolder_9,
	placeHolder_10,
	placeHolder_11,
	placeHolder_12,
	placeHolder_13,
	placeHolder_14,
	placeHolder_15,
	placeHolder_16,
	placeHolder_17,
	placeHolder_18,
	placeHolder_19,
	placeHolder_20,
	placeHolder_21,
	placeHolder_22,
	placeHolder_23,
	placeHolder_24,
	placeHolder_25,
	placeHolder_26,
	placeHolder_27,
	placeHolder_28,
	placeHolder_29,
	placeHolder_30,
	placeHolder_31,
	placeHolder_32,
	placeHolder_33,
	placeHolder_34,
	placeHolder_35,
	placeHolder_36,
	placeHolder_37,
	placeHolder_38,
	placeHolder_39,
	placeHolder_40,
	placeHolder_41,
	placeHolder_42,
	placeHolder_43,
	placeHolder_44,
	placeHolder_45,
	placeHolder_46,
	placeHolder_47,
	placeHolder_48,
	placeHolder_49,
	placeHolder_50,
	placeHolder_51,
	placeHolder_52,
	placeHolder_53,
	placeHolder_54,
	placeHolder_55,
	placeHolder_56,
	placeHolder_57,
	placeHolder_58,
	placeHolder_59,
	placeHolder_60,
	placeHolder_61,
	placeHolder_62,
	placeHolder_63,
	placeHolder_64,
	placeHolder_65,
	placeHolder_66,
	placeHolder_67,
	placeHolder_68,
	placeHolder_69,
	placeHolder_70,
	placeHolder_71,
	placeHolder_72,
	placeHolder_73,
	placeHolder_74,
	placeHolder_75,
	placeHolder_76,
	placeHolder_77,
	placeHolder_78,
	placeHolder_79,
	placeHolder_80,
	placeHolder_81,
	placeHolder_82,
	placeHolder_83,
	placeHolder_84,
	placeHolder_85,
	placeHolder_86,
	placeHolder_87,
	placeHolder_88,
	placeHolder_89,
	placeHolder_90,
	placeHolder_91,
	placeHolder_92,
	placeHolder_93,
	placeHolder_94,
	placeHolder_95,
	placeHolder_96,
	placeHolder_97,
	placeHolder_98,
	placeHolder_99,
	placeHolder_100,
	placeHolder_101,
	placeHolder_102,
	placeHolder_103,
	placeHolder_104,
	placeHolder_105,
	placeHolder_106,
	placeHolder_107,
	placeHolder_108,
	placeHolder_109,
	placeHolder_110,
	placeHolder_111,
	placeHolder_112,
	placeHolder_113,
	placeHolder_114,
	placeHolder_115,
	placeHolder_116,
	placeHolder_117,
	placeHolder_118,
	placeHolder_119,
	placeHolder_120,
	placeHolder_121,
	placeHolder_122,
	placeHolder_123,
	placeHolder_124,
	placeHolder_125,
	placeHolder_126,
	placeHolder_127,
	placeHolder_128,
	placeHolder_129,
	placeHolder_130,
	placeHolder_131,
	placeHolder_132,
	placeHolder_133,
	placeHolder_134,
	placeHolder_135,
	placeHolder_136,
	placeHolder_137,
	placeHolder_138,
	placeHolder_139,
	placeHolder_140,
	placeHolder_141,
	placeHolder_142,
	placeHolder_143,
	placeHolder_144,
	placeHolder_145,
	placeHolder_146,
	placeHolder_147,
	placeHolder_148,
	placeHolder_149,
	placeHolder_150,
	placeHolder_151,
	placeHolder_152,
	placeHolder_153,
	placeHolder_154,
	placeHolder_155,
	placeHolder_156,
	placeHolder_157,
	placeHolder_158,
	placeHolder_159,
	placeHolder_160,
	placeHolder_161,
	placeHolder_162,
	placeHolder_163,
	placeHolder_164,
	placeHolder_165,
	placeHolder_166,
	placeHolder_167,
	placeHolder_168,
	placeHolder_169,
	placeHolder_170,
	placeHolder_171,
	placeHolder_172,
	placeHolder_173,
	placeHolder_174,
	placeHolder_175,
	placeHolder_176,
	placeHolder_177,
	placeHolder_178,
	placeHolder_179,
	placeHolder_180,
	placeHolder_181,
	placeHolder_182,
	placeHolder_183,
	placeHolder_184,
	placeHolder_185,
	placeHolder_186,
	placeHolder_187,
	placeHolder_188,
	placeHolder_189,
	placeHolder_190,
	placeHolder_191,
	placeHolder_192,
	placeHolder_193,
	placeHolder_194,
	placeHolder_195,
	placeHolder_196,
	placeHolder_197,
	placeHolder_198,
	placeHolder_199,
	Success,
	placeHolder_201,
	placeHolder_202,
	placeHolder_203,
	placeHolder_204,
	placeHolder_205,
	placeHolder_206,
	placeHolder_207,
	placeHolder_208,
	placeHolder_209,
	placeHolder_210,
	placeHolder_211,
	placeHolder_212,
	placeHolder_213,
	placeHolder_214,
	placeHolder_215,
	placeHolder_216,
	placeHolder_217,
	placeHolder_218,
	placeHolder_219,
	placeHolder_220,
	placeHolder_221,
	placeHolder_222,
	placeHolder_223,
	placeHolder_224,
	placeHolder_225,
	placeHolder_226,
	placeHolder_227,
	placeHolder_228,
	placeHolder_229,
	placeHolder_230,
	placeHolder_231,
	placeHolder_232,
	placeHolder_233,
	placeHolder_234,
	placeHolder_235,
	placeHolder_236,
	placeHolder_237,
	placeHolder_238,
	placeHolder_239,
	placeHolder_240,
	placeHolder_241,
	placeHolder_242,
	placeHolder_243,
	placeHolder_244,
	placeHolder_245,
	placeHolder_246,
	placeHolder_247,
	placeHolder_248,
	placeHolder_249,
	placeHolder_250,
	placeHolder_251,
	placeHolder_252,
	placeHolder_253,
	placeHolder_254,
	placeHolder_255,
	placeHolder_256,
	placeHolder_257,
	placeHolder_258,
	placeHolder_259,
	placeHolder_260,
	placeHolder_261,
	placeHolder_262,
	placeHolder_263,
	placeHolder_264,
	placeHolder_265,
	placeHolder_266,
	placeHolder_267,
	placeHolder_268,
	placeHolder_269,
	placeHolder_270,
	placeHolder_271,
	placeHolder_272,
	placeHolder_273,
	placeHolder_274,
	placeHolder_275,
	placeHolder_276,
	placeHolder_277,
	placeHolder_278,
	placeHolder_279,
	placeHolder_280,
	placeHolder_281,
	placeHolder_282,
	placeHolder_283,
	placeHolder_284,
	placeHolder_285,
	placeHolder_286,
	placeHolder_287,
	placeHolder_288,
	placeHolder_289,
	placeHolder_290,
	placeHolder_291,
	placeHolder_292,
	placeHolder_293,
	placeHolder_294,
	placeHolder_295,
	placeHolder_296,
	placeHolder_297,
	placeHolder_298,
	placeHolder_299,
	placeHolder_300,
	placeHolder_301,
	placeHolder_302,
	placeHolder_303,
	placeHolder_304,
	placeHolder_305,
	placeHolder_306,
	placeHolder_307,
	placeHolder_308,
	placeHolder_309,
	placeHolder_310,
	placeHolder_311,
	placeHolder_312,
	placeHolder_313,
	placeHolder_314,
	placeHolder_315,
	placeHolder_316,
	placeHolder_317,
	placeHolder_318,
	placeHolder_319,
	placeHolder_320,
	placeHolder_321,
	placeHolder_322,
	placeHolder_323,
	placeHolder_324,
	placeHolder_325,
	placeHolder_326,
	placeHolder_327,
	placeHolder_328,
	placeHolder_329,
	placeHolder_330,
	placeHolder_331,
	placeHolder_332,
	placeHolder_333,
	placeHolder_334,
	placeHolder_335,
	placeHolder_336,
	placeHolder_337,
	placeHolder_338,
	placeHolder_339,
	placeHolder_340,
	placeHolder_341,
	placeHolder_342,
	placeHolder_343,
	placeHolder_344,
	placeHolder_345,
	placeHolder_346,
	placeHolder_347,
	placeHolder_348,
	placeHolder_349,
	placeHolder_350,
	placeHolder_351,
	placeHolder_352,
	placeHolder_353,
	placeHolder_354,
	placeHolder_355,
	placeHolder_356,
	placeHolder_357,
	placeHolder_358,
	placeHolder_359,
	placeHolder_360,
	placeHolder_361,
	placeHolder_362,
	placeHolder_363,
	placeHolder_364,
	placeHolder_365,
	placeHolder_366,
	placeHolder_367,
	placeHolder_368,
	placeHolder_369,
	placeHolder_370,
	placeHolder_371,
	placeHolder_372,
	placeHolder_373,
	placeHolder_374,
	placeHolder_375,
	placeHolder_376,
	placeHolder_377,
	placeHolder_378,
	placeHolder_379,
	placeHolder_380,
	placeHolder_381,
	placeHolder_382,
	placeHolder_383,
	placeHolder_384,
	placeHolder_385,
	placeHolder_386,
	placeHolder_387,
	placeHolder_388,
	placeHolder_389,
	placeHolder_390,
	placeHolder_391,
	placeHolder_392,
	placeHolder_393,
	placeHolder_394,
	placeHolder_395,
	placeHolder_396,
	placeHolder_397,
	placeHolder_398,
	placeHolder_399,
	Error,
	Unauthorized,
	placeHolder_402,
	Forbidden,
	NotFound,
	NotAllowed,
	placeHolder_406,
	placeHolder_407,
	placeHolder_408,
	placeHolder_409,
	placeHolder_410,
	placeHolder_411,
	placeHolder_412,
	placeHolder_413,
	placeHolder_414,
	Unsupported,
	placeHolder_416,
	placeHolder_417,
	placeHolder_418,
	placeHolder_419,
	placeHolder_420,
	placeHolder_421,
	placeHolder_422,
	Locked,
	placeHolder_424,
	placeHolder_425,
	placeHolder_426,
	placeHolder_427,
	placeHolder_428,
	placeHolder_429,
	placeHolder_430,
	placeHolder_431,
	placeHolder_432,
	placeHolder_433,
	placeHolder_434,
	placeHolder_435,
	placeHolder_436,
	placeHolder_437,
	placeHolder_438,
	placeHolder_439,
	placeHolder_440,
	placeHolder_441,
	placeHolder_442,
	placeHolder_443,
	placeHolder_444,
	placeHolder_445,
	placeHolder_446,
	placeHolder_447,
	placeHolder_448,
	placeHolder_449,
	placeHolder_450,
	placeHolder_451,
	placeHolder_452,
	placeHolder_453,
	placeHolder_454,
	placeHolder_455,
	placeHolder_456,
	placeHolder_457,
	placeHolder_458,
	placeHolder_459,
	placeHolder_460,
	placeHolder_461,
	placeHolder_462,
	placeHolder_463,
	placeHolder_464,
	placeHolder_465,
	placeHolder_466,
	placeHolder_467,
	placeHolder_468,
	placeHolder_469,
	placeHolder_470,
	placeHolder_471,
	placeHolder_472,
	placeHolder_473,
	placeHolder_474,
	placeHolder_475,
	placeHolder_476,
	placeHolder_477,
	placeHolder_478,
	placeHolder_479,
	placeHolder_480,
	placeHolder_481,
	placeHolder_482,
	placeHolder_483,
	placeHolder_484,
	placeHolder_485,
	placeHolder_486,
	placeHolder_487,
	placeHolder_488,
	placeHolder_489,
	placeHolder_490,
	placeHolder_491,
	placeHolder_492,
	placeHolder_493,
	placeHolder_494,
	placeHolder_495,
	placeHolder_496,
	placeHolder_497,
	placeHolder_498,
	placeHolder_499,
	InternalError,
	NotImplemented,
}

class IOTDeviceOperateResult {
	bool succeeded;
	String? data;
	String? content;
	AjaxResultTypeEnum type;

	IOTDeviceOperateResult({
		this.succeeded = false,
		this.data,
		this.content,
		this.type = AjaxResultTypeEnum.Success,
	});

	factory IOTDeviceOperateResult.fromJson(Map<String, dynamic> map) {
		return IOTDeviceOperateResult( 
			succeeded: map['Succeeded'],
			data: map['Data'],
			content: map['Content'],
			type: AjaxResultTypeEnum.values.firstWhere((e) => e.index == map['Type']),
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		map['Succeeded'] = succeeded;
		if (data != null)
			map['Data'] = data;
		if (content != null)
			map['Content'] = content;
		map['Type'] = type.index;
		return map;
	}
}

class UserBindDeviceRequest extends TokenRequest{
	String? userCode;
	String? machineNo;
	String? machineAddress;
	int type;
	String? userDeviceName;
	String? wifiName;
	int modeType;
	bool isAuto;
	String? areaCode;

	UserBindDeviceRequest({
		this.userCode,
		this.machineNo,
		this.machineAddress,
		this.type = 0,
		this.userDeviceName,
		this.wifiName,
		this.modeType = 0,
		this.isAuto = false,
		this.areaCode,
		String? token,
	}) : super(
			token: token,
		);

	factory UserBindDeviceRequest.fromJson(Map<String, dynamic> map) {
		return UserBindDeviceRequest( 
			userCode: map['UserCode'],
			machineNo: map['MachineNo'],
			machineAddress: map['MachineAddress'],
			type: map['Type'],
			userDeviceName: map['UserDeviceName'],
			wifiName: map['WifiName'],
			modeType: map['ModeType'],
			isAuto: map['IsAuto'],
			areaCode: map['AreaCode'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (userCode != null)
			map['UserCode'] = userCode;
		if (machineNo != null)
			map['MachineNo'] = machineNo;
		if (machineAddress != null)
			map['MachineAddress'] = machineAddress;
		map['Type'] = type;
		if (userDeviceName != null)
			map['UserDeviceName'] = userDeviceName;
		if (wifiName != null)
			map['WifiName'] = wifiName;
		map['ModeType'] = modeType;
		map['IsAuto'] = isAuto;
		if (areaCode != null)
			map['AreaCode'] = areaCode;
		return map;
	}
}

class DeleteDeviceInfoRequest extends TokenRequest{
	String? id;

	DeleteDeviceInfoRequest({
		this.id,
		String? token,
	}) : super(
			token: token,
		);

	factory DeleteDeviceInfoRequest.fromJson(Map<String, dynamic> map) {
		return DeleteDeviceInfoRequest( 
			id: map['Id'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (id != null)
			map['Id'] = id;
		return map;
	}
}

class UserDeviceInfoResult {
	String? id;
	String? userId;
	String? deviceId;
	String? userDeviceName;
	String? wifiName;
	bool isAuto;
	String? areaCode;
	String? machineAddress;
	String? machineNo;
	String? productNo;
	int type;
	int connectStatus;
	int activityStatus;
	DateTime? createdTime;
	DateTime? lastTreatTime;
	int modeType;
	int score;
	double useHour;

	UserDeviceInfoResult({
		this.id,
		this.userId,
		this.deviceId,
		this.userDeviceName,
		this.wifiName,
		this.isAuto = false,
		this.areaCode,
		this.machineAddress,
		this.machineNo,
		this.productNo,
		this.type = 0,
		this.connectStatus = 0,
		this.activityStatus = 0,
		this.createdTime,
		this.lastTreatTime,
		this.modeType = 0,
		this.score = 0,
		this.useHour = 0,
	});

	factory UserDeviceInfoResult.fromJson(Map<String, dynamic> map) {
		return UserDeviceInfoResult( 
			id: map['Id'],
			userId: map['UserId'],
			deviceId: map['DeviceId'],
			userDeviceName: map['UserDeviceName'],
			wifiName: map['WifiName'],
			isAuto: map['IsAuto'],
			areaCode: map['AreaCode'],
			machineAddress: map['MachineAddress'],
			machineNo: map['MachineNo'],
			productNo: map['ProductNo'],
			type: map['Type'],
			connectStatus: map['ConnectStatus'],
			activityStatus: map['ActivityStatus'],
			createdTime: map['CreatedTime'] != null ? DateTime.parse(map['CreatedTime']) : null,
			lastTreatTime: map['LastTreatTime'] != null ? DateTime.parse(map['LastTreatTime']) : null,
			modeType: map['ModeType'],
			score: map['Score'],
			useHour: double.parse(map['UseHour'].toString()),
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		if (id != null)
			map['Id'] = id;
		if (userId != null)
			map['UserId'] = userId;
		if (deviceId != null)
			map['DeviceId'] = deviceId;
		if (userDeviceName != null)
			map['UserDeviceName'] = userDeviceName;
		if (wifiName != null)
			map['WifiName'] = wifiName;
		map['IsAuto'] = isAuto;
		if (areaCode != null)
			map['AreaCode'] = areaCode;
		if (machineAddress != null)
			map['MachineAddress'] = machineAddress;
		if (machineNo != null)
			map['MachineNo'] = machineNo;
		if (productNo != null)
			map['ProductNo'] = productNo;
		map['Type'] = type;
		map['ConnectStatus'] = connectStatus;
		map['ActivityStatus'] = activityStatus;
		if (createdTime != null)
			map['CreatedTime'] = JsonRpcUtils.dateFormat(createdTime!);
		if (lastTreatTime != null)
			map['LastTreatTime'] = JsonRpcUtils.dateFormat(lastTreatTime!);
		map['ModeType'] = modeType;
		map['Score'] = score;
		map['UseHour'] = useHour;
		return map;
	}
}

class IOTDeviceSumaryYearInfo {
	int totalUseDay;
	double totalUseHour;
	String? avgUseHour;
	int avgSocre;

	IOTDeviceSumaryYearInfo({
		this.totalUseDay = 0,
		this.totalUseHour = 0,
		this.avgUseHour,
		this.avgSocre = 0,
	});

	factory IOTDeviceSumaryYearInfo.fromJson(Map<String, dynamic> map) {
		return IOTDeviceSumaryYearInfo( 
			totalUseDay: map['TotalUseDay'],
			totalUseHour: double.parse(map['TotalUseHour'].toString()),
			avgUseHour: map['AvgUseHour'],
			avgSocre: map['AvgSocre'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		map['TotalUseDay'] = totalUseDay;
		map['TotalUseHour'] = totalUseHour;
		if (avgUseHour != null)
			map['AvgUseHour'] = avgUseHour;
		map['AvgSocre'] = avgSocre;
		return map;
	}
}

class IOTDeviceSumaryWeekInfo {
	int totalUseDay;
	double totalUseHour;
	Map<DateTime,double>? dayHours;

	IOTDeviceSumaryWeekInfo({
		this.totalUseDay = 0,
		this.totalUseHour = 0,
		this.dayHours,
	});

	factory IOTDeviceSumaryWeekInfo.fromJson(Map<String, dynamic> map) {
		return IOTDeviceSumaryWeekInfo( 
			totalUseDay: map['TotalUseDay'],
			totalUseHour: double.parse(map['TotalUseHour'].toString()),
			dayHours: map['DayHours']?.cast<DateTime,double>(),
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		map['TotalUseDay'] = totalUseDay;
		map['TotalUseHour'] = totalUseHour;
		if (dayHours != null)
			map['DayHours'] = dayHours;
		return map;
	}
}

class IOTDeviceSumaryResult {
	IOTDeviceSumaryYearInfo? year;
	IOTDeviceSumaryWeekInfo? week;
	DateTime? lastTreatTime;
	List<UserDeviceInfoResult>? bindDeviceList;

	IOTDeviceSumaryResult({
		this.year,
		this.week,
		this.lastTreatTime,
		this.bindDeviceList,
	});

	factory IOTDeviceSumaryResult.fromJson(Map<String, dynamic> map) {
		return IOTDeviceSumaryResult( 
			year: map['Year'] != null ? IOTDeviceSumaryYearInfo.fromJson(map['Year']) : null,
			week: map['Week'] != null ? IOTDeviceSumaryWeekInfo.fromJson(map['Week']) : null,
			lastTreatTime: map['LastTreatTime'] != null ? DateTime.parse(map['LastTreatTime']) : null,
			bindDeviceList: map['BindDeviceList'] != null ? (map['BindDeviceList'] as List).map((e)=>UserDeviceInfoResult.fromJson(e as Map<String,dynamic>)).toList() : null,
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		if (year != null)
			map['Year'] = year;
		if (week != null)
			map['Week'] = week;
		if (lastTreatTime != null)
			map['LastTreatTime'] = JsonRpcUtils.dateFormat(lastTreatTime!);
		if (bindDeviceList != null)
			map['BindDeviceList'] = bindDeviceList;
		return map;
	}
}

class GetSummaryRequest extends TokenRequest{
	int type;
	String? userCode;

	GetSummaryRequest({
		this.type = 0,
		this.userCode,
		String? token,
	}) : super(
			token: token,
		);

	factory GetSummaryRequest.fromJson(Map<String, dynamic> map) {
		return GetSummaryRequest( 
			type: map['Type'],
			userCode: map['UserCode'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		map['Type'] = type;
		if (userCode != null)
			map['UserCode'] = userCode;
		return map;
	}
}

class FirmwareInfoResult {
	int fw_type;
	int fw_hw_type;
	String? fw_version;
	String? fw_url;
	int fw_build;

	FirmwareInfoResult({
		this.fw_type = 0,
		this.fw_hw_type = 0,
		this.fw_version,
		this.fw_url,
		this.fw_build = 0,
	});

	factory FirmwareInfoResult.fromJson(Map<String, dynamic> map) {
		return FirmwareInfoResult( 
			fw_type: map['fw_type'],
			fw_hw_type: map['fw_hw_type'],
			fw_version: map['fw_version'],
			fw_url: map['fw_url'],
			fw_build: map['fw_build'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		map['fw_type'] = fw_type;
		map['fw_hw_type'] = fw_hw_type;
		if (fw_version != null)
			map['fw_version'] = fw_version;
		if (fw_url != null)
			map['fw_url'] = fw_url;
		map['fw_build'] = fw_build;
		return map;
	}
}

class DeviceOTAResult {
	int pack_type;
	String? pack_version;
	List<FirmwareInfoResult>? firmware;

	DeviceOTAResult({
		this.pack_type = 0,
		this.pack_version,
		this.firmware,
	});

	factory DeviceOTAResult.fromJson(Map<String, dynamic> map) {
		return DeviceOTAResult( 
			pack_type: map['pack_type'],
			pack_version: map['pack_version'],
			firmware: map['firmware'] != null ? (map['firmware'] as List).map((e)=>FirmwareInfoResult.fromJson(e as Map<String,dynamic>)).toList() : null,
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		map['pack_type'] = pack_type;
		if (pack_version != null)
			map['pack_version'] = pack_version;
		if (firmware != null)
			map['firmware'] = firmware;
		return map;
	}
}

class IOTDeviceVersionResult {
	DeviceOTAResult? ota;

	IOTDeviceVersionResult({
		this.ota,
	});

	factory IOTDeviceVersionResult.fromJson(Map<String, dynamic> map) {
		return IOTDeviceVersionResult( 
			ota: map['ota'] != null ? DeviceOTAResult.fromJson(map['ota']) : null,
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		if (ota != null)
			map['ota'] = ota;
		return map;
	}
}

class GetDeviceVersionRequest extends GetSummaryRequest{
	String? id;

	GetDeviceVersionRequest({
		this.id,
		int type = 0,
		String? userCode,
		String? token,
	}) : super(
			type: type,
			userCode: userCode,
			token: token,
		);

	factory GetDeviceVersionRequest.fromJson(Map<String, dynamic> map) {
		return GetDeviceVersionRequest( 
			id: map['Id'],
			type: map['Type'],
			userCode: map['UserCode'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (id != null)
			map['Id'] = id;
		return map;
	}
}

class IOTDeviceAttributeEscalationRequest extends TokenRequest{
	String? userCode;
	String? id;
	int type;
	String? deviceAttributesJson;
	String? deviceConsumableAttributes;

	IOTDeviceAttributeEscalationRequest({
		this.userCode,
		this.id,
		this.type = 0,
		this.deviceAttributesJson,
		this.deviceConsumableAttributes,
		String? token,
	}) : super(
			token: token,
		);

	factory IOTDeviceAttributeEscalationRequest.fromJson(Map<String, dynamic> map) {
		return IOTDeviceAttributeEscalationRequest( 
			userCode: map['UserCode'],
			id: map['Id'],
			type: map['Type'],
			deviceAttributesJson: map['DeviceAttributesJson'],
			deviceConsumableAttributes: map['DeviceConsumableAttributes'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (userCode != null)
			map['UserCode'] = userCode;
		if (id != null)
			map['Id'] = id;
		map['Type'] = type;
		if (deviceAttributesJson != null)
			map['DeviceAttributesJson'] = deviceAttributesJson;
		if (deviceConsumableAttributes != null)
			map['DeviceConsumableAttributes'] = deviceConsumableAttributes;
		return map;
	}
}

class IOTDeviceTopicInfoRequest extends TokenRequest{
	String? deviceId;
	bool deviceOpen;

	IOTDeviceTopicInfoRequest({
		this.deviceId,
		this.deviceOpen = false,
		String? token,
	}) : super(
			token: token,
		);

	factory IOTDeviceTopicInfoRequest.fromJson(Map<String, dynamic> map) {
		return IOTDeviceTopicInfoRequest( 
			deviceId: map['DeviceId'],
			deviceOpen: map['DeviceOpen'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (deviceId != null)
			map['DeviceId'] = deviceId;
		map['DeviceOpen'] = deviceOpen;
		return map;
	}
}

class IOTReportAttributeEscalationRequest extends TokenRequest{
	String? id;
	int type;
	String? reportAttributesJson;

	IOTReportAttributeEscalationRequest({
		this.id,
		this.type = 0,
		this.reportAttributesJson,
		String? token,
	}) : super(
			token: token,
		);

	factory IOTReportAttributeEscalationRequest.fromJson(Map<String, dynamic> map) {
		return IOTReportAttributeEscalationRequest( 
			id: map['Id'],
			type: map['Type'],
			reportAttributesJson: map['ReportAttributesJson'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (id != null)
			map['Id'] = id;
		map['Type'] = type;
		if (reportAttributesJson != null)
			map['ReportAttributesJson'] = reportAttributesJson;
		return map;
	}
}

class IOTDeviceRegisterRequest extends TokenRequest{
	String? deviceModel;
	String? deviceSN;
	String? deviceMac;
	String? deviceKey;
	String? name;
	String? description;

	IOTDeviceRegisterRequest({
		this.deviceModel,
		this.deviceSN,
		this.deviceMac,
		this.deviceKey,
		this.name,
		this.description,
		String? token,
	}) : super(
			token: token,
		);

	factory IOTDeviceRegisterRequest.fromJson(Map<String, dynamic> map) {
		return IOTDeviceRegisterRequest( 
			deviceModel: map['DeviceModel'],
			deviceSN: map['DeviceSN'],
			deviceMac: map['DeviceMac'],
			deviceKey: map['DeviceKey'],
			name: map['Name'],
			description: map['Description'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (deviceModel != null)
			map['DeviceModel'] = deviceModel;
		if (deviceSN != null)
			map['DeviceSN'] = deviceSN;
		if (deviceMac != null)
			map['DeviceMac'] = deviceMac;
		if (deviceKey != null)
			map['DeviceKey'] = deviceKey;
		if (name != null)
			map['Name'] = name;
		if (description != null)
			map['Description'] = description;
		return map;
	}
}

class IOTDeviceBasicDataResult {
	int timestamp;

	IOTDeviceBasicDataResult({
		this.timestamp = 0,
	});

	factory IOTDeviceBasicDataResult.fromJson(Map<String, dynamic> map) {
		return IOTDeviceBasicDataResult( 
			timestamp: map['Timestamp'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		map['Timestamp'] = timestamp;
		return map;
	}
}

class IOTDeviceBasicWeatherResult {
	double weatherType;
	double temperature;
	double humidity;
	String? location;

	IOTDeviceBasicWeatherResult({
		this.weatherType = 0,
		this.temperature = 0,
		this.humidity = 0,
		this.location,
	});

	factory IOTDeviceBasicWeatherResult.fromJson(Map<String, dynamic> map) {
		return IOTDeviceBasicWeatherResult( 
			weatherType: double.parse(map['WeatherType'].toString()),
			temperature: double.parse(map['Temperature'].toString()),
			humidity: double.parse(map['Humidity'].toString()),
			location: map['Location'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		map['WeatherType'] = weatherType;
		map['Temperature'] = temperature;
		map['Humidity'] = humidity;
		if (location != null)
			map['Location'] = location;
		return map;
	}
}

class IOTWeatherRequest extends TokenRequest{
	String? deviceId;
	String? iP;

	IOTWeatherRequest({
		this.deviceId,
		this.iP,
		String? token,
	}) : super(
			token: token,
		);

	factory IOTWeatherRequest.fromJson(Map<String, dynamic> map) {
		return IOTWeatherRequest( 
			deviceId: map['DeviceId'],
			iP: map['IP'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (deviceId != null)
			map['DeviceId'] = deviceId;
		if (iP != null)
			map['IP'] = iP;
		return map;
	}
}

class IOTDeviceConnectRequest extends IOTDeviceRegisterRequest{
	int deviceType;
	String? iP;

	IOTDeviceConnectRequest({
		this.deviceType = 0,
		this.iP,
		String? deviceModel,
		String? deviceSN,
		String? deviceMac,
		String? deviceKey,
		String? name,
		String? description,
		String? token,
	}) : super(
			deviceModel: deviceModel,
			deviceSN: deviceSN,
			deviceMac: deviceMac,
			deviceKey: deviceKey,
			name: name,
			description: description,
			token: token,
		);

	factory IOTDeviceConnectRequest.fromJson(Map<String, dynamic> map) {
		return IOTDeviceConnectRequest( 
			deviceType: map['DeviceType'],
			iP: map['IP'],
			deviceModel: map['DeviceModel'],
			deviceSN: map['DeviceSN'],
			deviceMac: map['DeviceMac'],
			deviceKey: map['DeviceKey'],
			name: map['Name'],
			description: map['Description'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		map['DeviceType'] = deviceType;
		if (iP != null)
			map['IP'] = iP;
		return map;
	}
}

enum CommonDictionaryTypeEnum {
	All,
	Event,
	NounInterpretation,
}

class CommonDictionaryDTO {
	String? code;
	String? key;
	String? name;
	CommonDictionaryTypeEnum type;
	String? description;
	String? parentCode;
	DateTime? createTime;
	String? valueStr;
	double valueF;

	CommonDictionaryDTO({
		this.code,
		this.key,
		this.name,
		this.type = CommonDictionaryTypeEnum.All,
		this.description,
		this.parentCode,
		this.createTime,
		this.valueStr,
		this.valueF = 0,
	});

	factory CommonDictionaryDTO.fromJson(Map<String, dynamic> map) {
		return CommonDictionaryDTO( 
			code: map['Code'],
			key: map['Key'],
			name: map['Name'],
			type: CommonDictionaryTypeEnum.values.firstWhere((e) => e.index == map['Type']),
			description: map['Description'],
			parentCode: map['ParentCode'],
			createTime: map['CreateTime'] != null ? DateTime.parse(map['CreateTime']) : null,
			valueStr: map['ValueStr'],
			valueF: double.parse(map['ValueF'].toString()),
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		if (code != null)
			map['Code'] = code;
		if (key != null)
			map['Key'] = key;
		if (name != null)
			map['Name'] = name;
		map['Type'] = type.index;
		if (description != null)
			map['Description'] = description;
		if (parentCode != null)
			map['ParentCode'] = parentCode;
		if (createTime != null)
			map['CreateTime'] = JsonRpcUtils.dateFormat(createTime!);
		if (valueStr != null)
			map['ValueStr'] = valueStr;
		map['ValueF'] = valueF;
		return map;
	}
}

class CommonDictionaryRequest extends TokenRequest{
	String? code;
	String? key;
	String? name;
	CommonDictionaryTypeEnum type;
	String? parentCode;

	CommonDictionaryRequest({
		this.code,
		this.key,
		this.name,
		this.type = CommonDictionaryTypeEnum.All,
		this.parentCode,
		String? token,
	}) : super(
			token: token,
		);

	factory CommonDictionaryRequest.fromJson(Map<String, dynamic> map) {
		return CommonDictionaryRequest( 
			code: map['Code'],
			key: map['Key'],
			name: map['Name'],
			type: CommonDictionaryTypeEnum.values.firstWhere((e) => e.index == map['Type']),
			parentCode: map['ParentCode'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		if (key != null)
			map['Key'] = key;
		if (name != null)
			map['Name'] = name;
		map['Type'] = type.index;
		if (parentCode != null)
			map['ParentCode'] = parentCode;
		return map;
	}
}

class AlterUserInfoExtendRequest extends AlterUserInfoRequest{
	String? birthday;
	int gender;
	double neckGirth;
	double height;
	double weight;
	double bMI;

	AlterUserInfoExtendRequest({
		this.birthday,
		this.gender = 0,
		this.neckGirth = 0,
		this.height = 0,
		this.weight = 0,
		this.bMI = 0,
		String? phone,
		String? email,
		String? nickName,
		String? fullName,
		String? headImageUrl,
		String? organizationCode,
		String? extensionData,
		String? shortCode,
		String? languageCode,
		String? token,
	}) : super(
			phone: phone,
			email: email,
			nickName: nickName,
			fullName: fullName,
			headImageUrl: headImageUrl,
			organizationCode: organizationCode,
			extensionData: extensionData,
			shortCode: shortCode,
			languageCode: languageCode,
			token: token,
		);

	factory AlterUserInfoExtendRequest.fromJson(Map<String, dynamic> map) {
		return AlterUserInfoExtendRequest( 
			birthday: map['Birthday'],
			gender: map['Gender'],
			neckGirth: double.parse(map['NeckGirth'].toString()),
			height: double.parse(map['Height'].toString()),
			weight: double.parse(map['Weight'].toString()),
			bMI: double.parse(map['BMI'].toString()),
			phone: map['Phone'],
			email: map['Email'],
			nickName: map['NickName'],
			fullName: map['FullName'],
			headImageUrl: map['HeadImageUrl'],
			organizationCode: map['OrganizationCode'],
			extensionData: map['ExtensionData'],
			shortCode: map['ShortCode'],
			languageCode: map['LanguageCode'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (birthday != null)
			map['Birthday'] = birthday;
		map['Gender'] = gender;
		map['NeckGirth'] = neckGirth;
		map['Height'] = height;
		map['Weight'] = weight;
		map['BMI'] = bMI;
		return map;
	}
}

class IOTDeviceFileDataRecordDTO {
	String? id;
	DateTime? createTime;
	DateTime? treatTime;
	int dataFileType;
	String? dataDesc;
	String? originalFileName;
	String? fileToken;
	bool isCompleted;

	IOTDeviceFileDataRecordDTO({
		this.id,
		this.createTime,
		this.treatTime,
		this.dataFileType = 0,
		this.dataDesc,
		this.originalFileName,
		this.fileToken,
		this.isCompleted = false,
	});

	factory IOTDeviceFileDataRecordDTO.fromJson(Map<String, dynamic> map) {
		return IOTDeviceFileDataRecordDTO( 
			id: map['Id'],
			createTime: map['CreateTime'] != null ? DateTime.parse(map['CreateTime']) : null,
			treatTime: map['TreatTime'] != null ? DateTime.parse(map['TreatTime']) : null,
			dataFileType: map['DataFileType'],
			dataDesc: map['DataDesc'],
			originalFileName: map['OriginalFileName'],
			fileToken: map['FileToken'],
			isCompleted: map['IsCompleted'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		if (id != null)
			map['Id'] = id;
		if (createTime != null)
			map['CreateTime'] = JsonRpcUtils.dateFormat(createTime!);
		if (treatTime != null)
			map['TreatTime'] = JsonRpcUtils.dateFormat(treatTime!);
		map['DataFileType'] = dataFileType;
		if (dataDesc != null)
			map['DataDesc'] = dataDesc;
		if (originalFileName != null)
			map['OriginalFileName'] = originalFileName;
		if (fileToken != null)
			map['FileToken'] = fileToken;
		map['IsCompleted'] = isCompleted;
		return map;
	}
}

class IOTDeviceDataFolderDTO {
	String? id;
	String? folderName;
	List<IOTDeviceFileDataRecordDTO>? dataFileList;
	DateTime? createTime;

	IOTDeviceDataFolderDTO({
		this.id,
		this.folderName,
		this.dataFileList,
		this.createTime,
	});

	factory IOTDeviceDataFolderDTO.fromJson(Map<String, dynamic> map) {
		return IOTDeviceDataFolderDTO( 
			id: map['Id'],
			folderName: map['FolderName'],
			dataFileList: map['DataFileList'] != null ? (map['DataFileList'] as List).map((e)=>IOTDeviceFileDataRecordDTO.fromJson(e as Map<String,dynamic>)).toList() : null,
			createTime: map['CreateTime'] != null ? DateTime.parse(map['CreateTime']) : null,
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		if (id != null)
			map['Id'] = id;
		if (folderName != null)
			map['FolderName'] = folderName;
		if (dataFileList != null)
			map['DataFileList'] = dataFileList;
		if (createTime != null)
			map['CreateTime'] = JsonRpcUtils.dateFormat(createTime!);
		return map;
	}
}

class IOTDeviceUserExtendInfoDTO {
	String? userCode;
	ModeType mode;
	String? name;
	String? sex;
	int gender;
	int age;
	DateTime? birthday;
	int height;
	double weight;
	double neck;
	double bMI;
	List<IOTDeviceDataFolderDTO>? folderList;

	IOTDeviceUserExtendInfoDTO({
		this.userCode,
		this.mode = ModeType.CPAP,
		this.name,
		this.sex,
		this.gender = 0,
		this.age = 0,
		this.birthday,
		this.height = 0,
		this.weight = 0,
		this.neck = 0,
		this.bMI = 0,
		this.folderList,
	});

	factory IOTDeviceUserExtendInfoDTO.fromJson(Map<String, dynamic> map) {
		return IOTDeviceUserExtendInfoDTO( 
			userCode: map['UserCode'],
			mode: ModeType.values.firstWhere((e) => e.index == map['Mode']),
			name: map['Name'],
			sex: map['Sex'],
			gender: map['Gender'],
			age: map['Age'],
			birthday: map['Birthday'] != null ? DateTime.parse(map['Birthday']) : null,
			height: map['Height'],
			weight: double.parse(map['Weight'].toString()),
			neck: double.parse(map['Neck'].toString()),
			bMI: double.parse(map['BMI'].toString()),
			folderList: map['FolderList'] != null ? (map['FolderList'] as List).map((e)=>IOTDeviceDataFolderDTO.fromJson(e as Map<String,dynamic>)).toList() : null,
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		if (userCode != null)
			map['UserCode'] = userCode;
		map['Mode'] = mode.index;
		if (name != null)
			map['Name'] = name;
		if (sex != null)
			map['Sex'] = sex;
		map['Gender'] = gender;
		map['Age'] = age;
		if (birthday != null)
			map['Birthday'] = JsonRpcUtils.dateFormat(birthday!);
		map['Height'] = height;
		map['Weight'] = weight;
		map['Neck'] = neck;
		map['BMI'] = bMI;
		if (folderList != null)
			map['FolderList'] = folderList;
		return map;
	}
}

class IOTDeviceUserListDTO extends BaseDTO{
	String? code;
	String? deviceCode;
	String? deviceSN;
	String? deviceMAC;
	List<IOTDeviceUserExtendInfoDTO>? userDataList;

	IOTDeviceUserListDTO({
		this.code,
		this.deviceCode,
		this.deviceSN,
		this.deviceMAC,
		this.userDataList,
		bool isDelete = false,
		DateTime? createTime,
		DateTime? updateTime,
	}) : super(
			isDelete: isDelete,
			createTime: createTime,
			updateTime: updateTime,
		);

	factory IOTDeviceUserListDTO.fromJson(Map<String, dynamic> map) {
		return IOTDeviceUserListDTO( 
			code: map['Code'],
			deviceCode: map['DeviceCode'],
			deviceSN: map['DeviceSN'],
			deviceMAC: map['DeviceMAC'],
			userDataList: map['UserDataList'] != null ? (map['UserDataList'] as List).map((e)=>IOTDeviceUserExtendInfoDTO.fromJson(e as Map<String,dynamic>)).toList() : null,
			isDelete: map['IsDelete'],
			createTime: map['CreateTime'] != null ? DateTime.parse(map['CreateTime']) : null,
			updateTime: map['UpdateTime'] != null ? DateTime.parse(map['UpdateTime']) : null,
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		if (deviceCode != null)
			map['DeviceCode'] = deviceCode;
		if (deviceSN != null)
			map['DeviceSN'] = deviceSN;
		if (deviceMAC != null)
			map['DeviceMAC'] = deviceMAC;
		if (userDataList != null)
			map['UserDataList'] = userDataList;
		return map;
	}
}

class GetIOTDeviceFileDataRequest extends TokenRequest{
	String? deviceSN;
	String? userInfo;
	DateTime? beginTreatTime;
	DateTime? endTreatTime;
	DateTime? createTimeFrom;
	DateTime? createTimeTo;

	GetIOTDeviceFileDataRequest({
		this.deviceSN,
		this.userInfo,
		this.beginTreatTime,
		this.endTreatTime,
		this.createTimeFrom,
		this.createTimeTo,
		String? token,
	}) : super(
			token: token,
		);

	factory GetIOTDeviceFileDataRequest.fromJson(Map<String, dynamic> map) {
		return GetIOTDeviceFileDataRequest( 
			deviceSN: map['DeviceSN'],
			userInfo: map['UserInfo'],
			beginTreatTime: map['BeginTreatTime'] != null ? DateTime.parse(map['BeginTreatTime']) : null,
			endTreatTime: map['EndTreatTime'] != null ? DateTime.parse(map['EndTreatTime']) : null,
			createTimeFrom: map['CreateTimeFrom'] != null ? DateTime.parse(map['CreateTimeFrom']) : null,
			createTimeTo: map['CreateTimeTo'] != null ? DateTime.parse(map['CreateTimeTo']) : null,
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (deviceSN != null)
			map['DeviceSN'] = deviceSN;
		if (userInfo != null)
			map['UserInfo'] = userInfo;
		if (beginTreatTime != null)
			map['BeginTreatTime'] = JsonRpcUtils.dateFormat(beginTreatTime!);
		if (endTreatTime != null)
			map['EndTreatTime'] = JsonRpcUtils.dateFormat(endTreatTime!);
		if (createTimeFrom != null)
			map['CreateTimeFrom'] = JsonRpcUtils.dateFormat(createTimeFrom!);
		if (createTimeTo != null)
			map['CreateTimeTo'] = JsonRpcUtils.dateFormat(createTimeTo!);
		return map;
	}
}

class SaveIOTDeviceDataRequest extends TokenRequest{
	DateTime? treatTime;
	String? dataDesc;
	List<int>? fileData;
	bool isNeedReturnFileUrl;
	String? folderName;
	String? originalFileName;
	String? deviceSN;
	String? deviceMac;
	String? userCode;

	SaveIOTDeviceDataRequest({
		this.treatTime,
		this.dataDesc,
		this.fileData,
		this.isNeedReturnFileUrl = false,
		this.folderName,
		this.originalFileName,
		this.deviceSN,
		this.deviceMac,
		this.userCode,
		String? token,
	}) : super(
			token: token,
		);

	factory SaveIOTDeviceDataRequest.fromJson(Map<String, dynamic> map) {
		final fileDataData = map['FileData'];
		return SaveIOTDeviceDataRequest( 
			treatTime: map['TreatTime'] != null ? DateTime.parse(map['TreatTime']) : null,
			dataDesc: map['DataDesc'],
			fileData: fileDataData != null ? (fileDataData as List).map((e) => e as int).toList(): null,
			isNeedReturnFileUrl: map['IsNeedReturnFileUrl'],
			folderName: map['FolderName'],
			originalFileName: map['OriginalFileName'],
			deviceSN: map['DeviceSN'],
			deviceMac: map['DeviceMac'],
			userCode: map['UserCode'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (treatTime != null)
			map['TreatTime'] = JsonRpcUtils.dateFormat(treatTime!);
		if (dataDesc != null)
			map['DataDesc'] = dataDesc;
		if (fileData != null)
			map['FileData'] = fileData;
		map['IsNeedReturnFileUrl'] = isNeedReturnFileUrl;
		if (folderName != null)
			map['FolderName'] = folderName;
		if (originalFileName != null)
			map['OriginalFileName'] = originalFileName;
		if (deviceSN != null)
			map['DeviceSN'] = deviceSN;
		if (deviceMac != null)
			map['DeviceMac'] = deviceMac;
		if (userCode != null)
			map['UserCode'] = userCode;
		return map;
	}
}

class GetIOTDeviceUsersRequest extends TokenRequest{
	List<String>? deviceSNList;
	List<String>? userList;

	GetIOTDeviceUsersRequest({
		this.deviceSNList,
		this.userList,
		String? token,
	}) : super(
			token: token,
		);

	factory GetIOTDeviceUsersRequest.fromJson(Map<String, dynamic> map) {
		return GetIOTDeviceUsersRequest( 
			deviceSNList: map['DeviceSNList']?.cast<String>().toList(),
			userList: map['UserList']?.cast<String>().toList(),
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (deviceSNList != null)
			map['DeviceSNList'] = deviceSNList;
		if (userList != null)
			map['UserList'] = userList;
		return map;
	}
}

class SaveIOTDeviceUserDataRequest extends TokenRequest{
	String? deviceUserCode;
	String? name;
	DateTime? birthday;
	int gender;
	double bMI;
	int height;
	double weight;
	double neck;

	SaveIOTDeviceUserDataRequest({
		this.deviceUserCode,
		this.name,
		this.birthday,
		this.gender = 0,
		this.bMI = 0,
		this.height = 0,
		this.weight = 0,
		this.neck = 0,
		String? token,
	}) : super(
			token: token,
		);

	factory SaveIOTDeviceUserDataRequest.fromJson(Map<String, dynamic> map) {
		return SaveIOTDeviceUserDataRequest( 
			deviceUserCode: map['DeviceUserCode'],
			name: map['Name'],
			birthday: map['Birthday'] != null ? DateTime.parse(map['Birthday']) : null,
			gender: map['Gender'],
			bMI: double.parse(map['BMI'].toString()),
			height: map['Height'],
			weight: double.parse(map['Weight'].toString()),
			neck: double.parse(map['Neck'].toString()),
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (deviceUserCode != null)
			map['DeviceUserCode'] = deviceUserCode;
		if (name != null)
			map['Name'] = name;
		if (birthday != null)
			map['Birthday'] = JsonRpcUtils.dateFormat(birthday!);
		map['Gender'] = gender;
		map['BMI'] = bMI;
		map['Height'] = height;
		map['Weight'] = weight;
		map['Neck'] = neck;
		return map;
	}
}

class IOTDeviceUserDTO extends BaseDTO{
	String? code;
	String? name;
	int gender;
	String? sex;
	DateTime? birthday;
	int height;
	int weight;
	int neck;
	double bMI;
	String? headImageUrl;
	String? fullName;
	String? nickName;
	String? openId;

	IOTDeviceUserDTO({
		this.code,
		this.name,
		this.gender = 0,
		this.sex,
		this.birthday,
		this.height = 0,
		this.weight = 0,
		this.neck = 0,
		this.bMI = 0,
		this.headImageUrl,
		this.fullName,
		this.nickName,
		this.openId,
		bool isDelete = false,
		DateTime? createTime,
		DateTime? updateTime,
	}) : super(
			isDelete: isDelete,
			createTime: createTime,
			updateTime: updateTime,
		);

	factory IOTDeviceUserDTO.fromJson(Map<String, dynamic> map) {
		return IOTDeviceUserDTO( 
			code: map['Code'],
			name: map['Name'],
			gender: map['Gender'],
			sex: map['Sex'],
			birthday: map['Birthday'] != null ? DateTime.parse(map['Birthday']) : null,
			height: map['Height'],
			weight: map['Weight'],
			neck: map['Neck'],
			bMI: double.parse(map['BMI'].toString()),
			headImageUrl: map['HeadImageUrl'],
			fullName: map['FullName'],
			nickName: map['NickName'],
			openId: map['OpenId'],
			isDelete: map['IsDelete'],
			createTime: map['CreateTime'] != null ? DateTime.parse(map['CreateTime']) : null,
			updateTime: map['UpdateTime'] != null ? DateTime.parse(map['UpdateTime']) : null,
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		if (name != null)
			map['Name'] = name;
		map['Gender'] = gender;
		if (sex != null)
			map['Sex'] = sex;
		if (birthday != null)
			map['Birthday'] = JsonRpcUtils.dateFormat(birthday!);
		map['Height'] = height;
		map['Weight'] = weight;
		map['Neck'] = neck;
		map['BMI'] = bMI;
		if (headImageUrl != null)
			map['HeadImageUrl'] = headImageUrl;
		if (fullName != null)
			map['FullName'] = fullName;
		if (nickName != null)
			map['NickName'] = nickName;
		if (openId != null)
			map['OpenId'] = openId;
		return map;
	}
}

class GetIOTDeviceUserDataPageRequest extends PageRequest{
	String? deviceSN;
	DateTime? beginTreatTime;
	DateTime? endTreatTime;
	String? name;
	int beginAge;
	int endAge;
	int gender;
	double beginBMI;
	double endBMI;
	int height;
	double weight;
	double neck;

	GetIOTDeviceUserDataPageRequest({
		this.deviceSN,
		this.beginTreatTime,
		this.endTreatTime,
		this.name,
		this.beginAge = 0,
		this.endAge = 0,
		this.gender = 0,
		this.beginBMI = 0,
		this.endBMI = 0,
		this.height = 0,
		this.weight = 0,
		this.neck = 0,
		int pageIndex = 0,
		int pageSize = 0,
		String? token,
	}) : super(
			pageIndex: pageIndex,
			pageSize: pageSize,
			token: token,
		);

	factory GetIOTDeviceUserDataPageRequest.fromJson(Map<String, dynamic> map) {
		return GetIOTDeviceUserDataPageRequest( 
			deviceSN: map['DeviceSN'],
			beginTreatTime: map['BeginTreatTime'] != null ? DateTime.parse(map['BeginTreatTime']) : null,
			endTreatTime: map['EndTreatTime'] != null ? DateTime.parse(map['EndTreatTime']) : null,
			name: map['Name'],
			beginAge: map['BeginAge'],
			endAge: map['EndAge'],
			gender: map['Gender'],
			beginBMI: double.parse(map['BeginBMI'].toString()),
			endBMI: double.parse(map['EndBMI'].toString()),
			height: map['Height'],
			weight: double.parse(map['Weight'].toString()),
			neck: double.parse(map['Neck'].toString()),
			pageIndex: map['PageIndex'],
			pageSize: map['PageSize'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (deviceSN != null)
			map['DeviceSN'] = deviceSN;
		if (beginTreatTime != null)
			map['BeginTreatTime'] = JsonRpcUtils.dateFormat(beginTreatTime!);
		if (endTreatTime != null)
			map['EndTreatTime'] = JsonRpcUtils.dateFormat(endTreatTime!);
		if (name != null)
			map['Name'] = name;
		map['BeginAge'] = beginAge;
		map['EndAge'] = endAge;
		map['Gender'] = gender;
		map['BeginBMI'] = beginBMI;
		map['EndBMI'] = endBMI;
		map['Height'] = height;
		map['Weight'] = weight;
		map['Neck'] = neck;
		return map;
	}
}

class IOTDeviceUseRecordBaseDTO extends BaseDTO{
	String? code;
	String? userCode;
	String? deviceCode;
	String? deviceSN;
	String? deviceMAC;
	List<IOTDeviceDataFolderDTO>? folderList;

	IOTDeviceUseRecordBaseDTO({
		this.code,
		this.userCode,
		this.deviceCode,
		this.deviceSN,
		this.deviceMAC,
		this.folderList,
		bool isDelete = false,
		DateTime? createTime,
		DateTime? updateTime,
	}) : super(
			isDelete: isDelete,
			createTime: createTime,
			updateTime: updateTime,
		);

	factory IOTDeviceUseRecordBaseDTO.fromJson(Map<String, dynamic> map) {
		return IOTDeviceUseRecordBaseDTO( 
			code: map['Code'],
			userCode: map['UserCode'],
			deviceCode: map['DeviceCode'],
			deviceSN: map['DeviceSN'],
			deviceMAC: map['DeviceMAC'],
			folderList: map['FolderList'] != null ? (map['FolderList'] as List).map((e)=>IOTDeviceDataFolderDTO.fromJson(e as Map<String,dynamic>)).toList() : null,
			isDelete: map['IsDelete'],
			createTime: map['CreateTime'] != null ? DateTime.parse(map['CreateTime']) : null,
			updateTime: map['UpdateTime'] != null ? DateTime.parse(map['UpdateTime']) : null,
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		if (userCode != null)
			map['UserCode'] = userCode;
		if (deviceCode != null)
			map['DeviceCode'] = deviceCode;
		if (deviceSN != null)
			map['DeviceSN'] = deviceSN;
		if (deviceMAC != null)
			map['DeviceMAC'] = deviceMAC;
		if (folderList != null)
			map['FolderList'] = folderList;
		return map;
	}
}

class IOTDeviceUserInfoDTO extends IOTDeviceUseRecordBaseDTO{
	ModeType mode;
	String? name;
	String? sex;
	int age;
	DateTime? birthday;
	int height;
	double weight;
	double neck;
	double bMI;

	IOTDeviceUserInfoDTO({
		this.mode = ModeType.CPAP,
		this.name,
		this.sex,
		this.age = 0,
		this.birthday,
		this.height = 0,
		this.weight = 0,
		this.neck = 0,
		this.bMI = 0,
		String? code,
		String? userCode,
		String? deviceCode,
		String? deviceSN,
		String? deviceMAC,
		List<IOTDeviceDataFolderDTO>? folderList,
		bool isDelete = false,
		DateTime? createTime,
		DateTime? updateTime,
	}) : super(
			code: code,
			userCode: userCode,
			deviceCode: deviceCode,
			deviceSN: deviceSN,
			deviceMAC: deviceMAC,
			folderList: folderList,
			isDelete: isDelete,
			createTime: createTime,
			updateTime: updateTime,
		);

	factory IOTDeviceUserInfoDTO.fromJson(Map<String, dynamic> map) {
		return IOTDeviceUserInfoDTO( 
			mode: ModeType.values.firstWhere((e) => e.index == map['Mode']),
			name: map['Name'],
			sex: map['Sex'],
			age: map['Age'],
			birthday: map['Birthday'] != null ? DateTime.parse(map['Birthday']) : null,
			height: map['Height'],
			weight: double.parse(map['Weight'].toString()),
			neck: double.parse(map['Neck'].toString()),
			bMI: double.parse(map['BMI'].toString()),
			code: map['Code'],
			userCode: map['UserCode'],
			deviceCode: map['DeviceCode'],
			deviceSN: map['DeviceSN'],
			deviceMAC: map['DeviceMAC'],
			folderList: map['FolderList'] != null ? (map['FolderList'] as List).map((e)=>IOTDeviceDataFolderDTO.fromJson(e as Map<String,dynamic>)).toList() : null,
			isDelete: map['IsDelete'],
			createTime: map['CreateTime'] != null ? DateTime.parse(map['CreateTime']) : null,
			updateTime: map['UpdateTime'] != null ? DateTime.parse(map['UpdateTime']) : null,
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		map['Mode'] = mode.index;
		if (name != null)
			map['Name'] = name;
		if (sex != null)
			map['Sex'] = sex;
		map['Age'] = age;
		if (birthday != null)
			map['Birthday'] = JsonRpcUtils.dateFormat(birthday!);
		map['Height'] = height;
		map['Weight'] = weight;
		map['Neck'] = neck;
		map['BMI'] = bMI;
		return map;
	}
}

class GetIOTDeviceBindUserDataPageRequest extends PageRequest{
	String? deviceSN;
	String? userName;

	GetIOTDeviceBindUserDataPageRequest({
		this.deviceSN,
		this.userName,
		int pageIndex = 0,
		int pageSize = 0,
		String? token,
	}) : super(
			pageIndex: pageIndex,
			pageSize: pageSize,
			token: token,
		);

	factory GetIOTDeviceBindUserDataPageRequest.fromJson(Map<String, dynamic> map) {
		return GetIOTDeviceBindUserDataPageRequest( 
			deviceSN: map['DeviceSN'],
			userName: map['UserName'],
			pageIndex: map['PageIndex'],
			pageSize: map['PageSize'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (deviceSN != null)
			map['DeviceSN'] = deviceSN;
		if (userName != null)
			map['UserName'] = userName;
		return map;
	}
}

class IOTDeviceBindUserDataRequest extends TokenRequest{
	String? deviceBindUserCode;
	String? userCode;
	String? deviceCode;

	IOTDeviceBindUserDataRequest({
		this.deviceBindUserCode,
		this.userCode,
		this.deviceCode,
		String? token,
	}) : super(
			token: token,
		);

	factory IOTDeviceBindUserDataRequest.fromJson(Map<String, dynamic> map) {
		return IOTDeviceBindUserDataRequest( 
			deviceBindUserCode: map['DeviceBindUserCode'],
			userCode: map['UserCode'],
			deviceCode: map['DeviceCode'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (deviceBindUserCode != null)
			map['DeviceBindUserCode'] = deviceBindUserCode;
		if (userCode != null)
			map['UserCode'] = userCode;
		if (deviceCode != null)
			map['DeviceCode'] = deviceCode;
		return map;
	}
}

class UpdateIOTDeviceDataResult {
	String? dataCode;
	String? folderCode;
	String? fileUrl;
	String? useRecordCode;

	UpdateIOTDeviceDataResult({
		this.dataCode,
		this.folderCode,
		this.fileUrl,
		this.useRecordCode,
	});

	factory UpdateIOTDeviceDataResult.fromJson(Map<String, dynamic> map) {
		return UpdateIOTDeviceDataResult( 
			dataCode: map['DataCode'],
			folderCode: map['FolderCode'],
			fileUrl: map['FileUrl'],
			useRecordCode: map['UseRecordCode'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		if (dataCode != null)
			map['DataCode'] = dataCode;
		if (folderCode != null)
			map['FolderCode'] = folderCode;
		if (fileUrl != null)
			map['FileUrl'] = fileUrl;
		if (useRecordCode != null)
			map['UseRecordCode'] = useRecordCode;
		return map;
	}
}

class BindIOTDeviceBasicInfo {
	String? deviceSN;
	String? deviceMac;

	BindIOTDeviceBasicInfo({
		this.deviceSN,
		this.deviceMac,
	});

	factory BindIOTDeviceBasicInfo.fromJson(Map<String, dynamic> map) {
		return BindIOTDeviceBasicInfo( 
			deviceSN: map['DeviceSN'],
			deviceMac: map['DeviceMac'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		if (deviceSN != null)
			map['DeviceSN'] = deviceSN;
		if (deviceMac != null)
			map['DeviceMac'] = deviceMac;
		return map;
	}
}

class CheckIOTDeviceBeenBoundResult extends BindIOTDeviceBasicInfo{
	bool isBound;
	String? deviceCode;

	CheckIOTDeviceBeenBoundResult({
		this.isBound = false,
		this.deviceCode,
		String? deviceSN,
		String? deviceMac,
	}) : super(
			deviceSN: deviceSN,
			deviceMac: deviceMac,
		);

	factory CheckIOTDeviceBeenBoundResult.fromJson(Map<String, dynamic> map) {
		return CheckIOTDeviceBeenBoundResult( 
			isBound: map['IsBound'],
			deviceCode: map['DeviceCode'],
			deviceSN: map['DeviceSN'],
			deviceMac: map['DeviceMac'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		map['IsBound'] = isBound;
		if (deviceCode != null)
			map['DeviceCode'] = deviceCode;
		return map;
	}
}

class CheckIOTDeviceBeenBoundRequest extends TokenRequest{
	String? userCode;
	List<BindIOTDeviceBasicInfo>? deviceList;

	CheckIOTDeviceBeenBoundRequest({
		this.userCode,
		this.deviceList,
		String? token,
	}) : super(
			token: token,
		);

	factory CheckIOTDeviceBeenBoundRequest.fromJson(Map<String, dynamic> map) {
		return CheckIOTDeviceBeenBoundRequest( 
			userCode: map['UserCode'],
			deviceList: map['DeviceList'] != null ? (map['DeviceList'] as List).map((e)=>BindIOTDeviceBasicInfo.fromJson(e as Map<String,dynamic>)).toList() : null,
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (userCode != null)
			map['UserCode'] = userCode;
		if (deviceList != null)
			map['DeviceList'] = deviceList;
		return map;
	}
}

class IOTDeviceReportAttributeDTO {
	double value;
	String? explain;

	IOTDeviceReportAttributeDTO({
		this.value = 0,
		this.explain,
	});

	factory IOTDeviceReportAttributeDTO.fromJson(Map<String, dynamic> map) {
		return IOTDeviceReportAttributeDTO( 
			value: double.parse(map['Value'].toString()),
			explain: map['Explain'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		map['Value'] = value;
		if (explain != null)
			map['Explain'] = explain;
		return map;
	}
}

class IOTDeviceStageReportResult {
	String? treatmentEffect;
	ModeType mode;
	int totalUseDay;
	int goodStateUseDay;
	int gteFourHoursUseDay;
	double totalUseHour;
	double avgUseHour;
	double avgSocre;
	double avgTreatmentPressure;
	double treatmentPressure95;
	double treatmentPressure90;
	double avgLeak;
	double leak95;
	double leak90;
	double spo2Ave;
	double spo2Min;
	double prAve;
	IOTDeviceReportAttributeDTO? aHI;
	IOTDeviceReportAttributeDTO? hI;
	IOTDeviceReportAttributeDTO? aI;
	IOTDeviceReportAttributeDTO? oAI;
	IOTDeviceReportAttributeDTO? cAI;
	IOTDeviceReportAttributeDTO? snoringEvent;

	IOTDeviceStageReportResult({
		this.treatmentEffect,
		this.mode = ModeType.CPAP,
		this.totalUseDay = 0,
		this.goodStateUseDay = 0,
		this.gteFourHoursUseDay = 0,
		this.totalUseHour = 0,
		this.avgUseHour = 0,
		this.avgSocre = 0,
		this.avgTreatmentPressure = 0,
		this.treatmentPressure95 = 0,
		this.treatmentPressure90 = 0,
		this.avgLeak = 0,
		this.leak95 = 0,
		this.leak90 = 0,
		this.spo2Ave = 0,
		this.spo2Min = 0,
		this.prAve = 0,
		this.aHI,
		this.hI,
		this.aI,
		this.oAI,
		this.cAI,
		this.snoringEvent,
	});

	factory IOTDeviceStageReportResult.fromJson(Map<String, dynamic> map) {
		return IOTDeviceStageReportResult( 
			treatmentEffect: map['TreatmentEffect'],
			mode: ModeType.values.firstWhere((e) => e.index == map['Mode']),
			totalUseDay: map['TotalUseDay'],
			goodStateUseDay: map['GoodStateUseDay'],
			gteFourHoursUseDay: map['GteFourHoursUseDay'],
			totalUseHour: double.parse(map['TotalUseHour'].toString()),
			avgUseHour: double.parse(map['AvgUseHour'].toString()),
			avgSocre: double.parse(map['AvgSocre'].toString()),
			avgTreatmentPressure: double.parse(map['AvgTreatmentPressure'].toString()),
			treatmentPressure95: double.parse(map['TreatmentPressure95'].toString()),
			treatmentPressure90: double.parse(map['TreatmentPressure90'].toString()),
			avgLeak: double.parse(map['AvgLeak'].toString()),
			leak95: double.parse(map['Leak95'].toString()),
			leak90: double.parse(map['Leak90'].toString()),
			spo2Ave: double.parse(map['Spo2Ave'].toString()),
			spo2Min: double.parse(map['Spo2Min'].toString()),
			prAve: double.parse(map['PrAve'].toString()),
			aHI: map['AHI'] != null ? IOTDeviceReportAttributeDTO.fromJson(map['AHI']) : null,
			hI: map['HI'] != null ? IOTDeviceReportAttributeDTO.fromJson(map['HI']) : null,
			aI: map['AI'] != null ? IOTDeviceReportAttributeDTO.fromJson(map['AI']) : null,
			oAI: map['OAI'] != null ? IOTDeviceReportAttributeDTO.fromJson(map['OAI']) : null,
			cAI: map['CAI'] != null ? IOTDeviceReportAttributeDTO.fromJson(map['CAI']) : null,
			snoringEvent: map['SnoringEvent'] != null ? IOTDeviceReportAttributeDTO.fromJson(map['SnoringEvent']) : null,
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		if (treatmentEffect != null)
			map['TreatmentEffect'] = treatmentEffect;
		map['Mode'] = mode.index;
		map['TotalUseDay'] = totalUseDay;
		map['GoodStateUseDay'] = goodStateUseDay;
		map['GteFourHoursUseDay'] = gteFourHoursUseDay;
		map['TotalUseHour'] = totalUseHour;
		map['AvgUseHour'] = avgUseHour;
		map['AvgSocre'] = avgSocre;
		map['AvgTreatmentPressure'] = avgTreatmentPressure;
		map['TreatmentPressure95'] = treatmentPressure95;
		map['TreatmentPressure90'] = treatmentPressure90;
		map['AvgLeak'] = avgLeak;
		map['Leak95'] = leak95;
		map['Leak90'] = leak90;
		map['Spo2Ave'] = spo2Ave;
		map['Spo2Min'] = spo2Min;
		map['PrAve'] = prAve;
		if (aHI != null)
			map['AHI'] = aHI;
		if (hI != null)
			map['HI'] = hI;
		if (aI != null)
			map['AI'] = aI;
		if (oAI != null)
			map['OAI'] = oAI;
		if (cAI != null)
			map['CAI'] = cAI;
		if (snoringEvent != null)
			map['SnoringEvent'] = snoringEvent;
		return map;
	}
}

enum IOTDeviceStageReportTypeEnum {
	Day,
	Week,
	Month,
	Year,
}

class IOTDeviceStageReportRequest extends TokenRequest{
	String? deviceCode;
	DateTime? reportDate;
	IOTDeviceStageReportTypeEnum reportType;
	ModeType mode;

	IOTDeviceStageReportRequest({
		this.deviceCode,
		this.reportDate,
		this.reportType = IOTDeviceStageReportTypeEnum.Day,
		this.mode = ModeType.CPAP,
		String? token,
	}) : super(
			token: token,
		);

	factory IOTDeviceStageReportRequest.fromJson(Map<String, dynamic> map) {
		return IOTDeviceStageReportRequest( 
			deviceCode: map['DeviceCode'],
			reportDate: map['ReportDate'] != null ? DateTime.parse(map['ReportDate']) : null,
			reportType: IOTDeviceStageReportTypeEnum.values.firstWhere((e) => e.index == map['ReportType']),
			mode: ModeType.values.firstWhere((e) => e.index == map['Mode']),
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (deviceCode != null)
			map['DeviceCode'] = deviceCode;
		if (reportDate != null)
			map['ReportDate'] = JsonRpcUtils.dateFormat(reportDate!);
		map['ReportType'] = reportType.index;
		map['Mode'] = mode.index;
		return map;
	}
}

class IOTDeviceStageReportTrendChartResult {
	List<DataItemDTO>? useTimeChartData;
	List<DataItemDTO>? aHIChartData;
	List<DataItemDTO>? hIChartData;
	List<DataItemDTO>? aIChartData;
	List<DataItemDTO>? oAIChartData;
	List<DataItemDTO>? cAIChartData;
	List<DataItemDTO>? snoreEventChartData;
	List<DataItemDTO>? spo2AveChartData;

	IOTDeviceStageReportTrendChartResult({
		this.useTimeChartData,
		this.aHIChartData,
		this.hIChartData,
		this.aIChartData,
		this.oAIChartData,
		this.cAIChartData,
		this.snoreEventChartData,
		this.spo2AveChartData,
	});

	factory IOTDeviceStageReportTrendChartResult.fromJson(Map<String, dynamic> map) {
		return IOTDeviceStageReportTrendChartResult( 
			useTimeChartData: map['UseTimeChartData'] != null ? (map['UseTimeChartData'] as List).map((e)=>DataItemDTO.fromJson(e as Map<String,dynamic>)).toList() : null,
			aHIChartData: map['AHIChartData'] != null ? (map['AHIChartData'] as List).map((e)=>DataItemDTO.fromJson(e as Map<String,dynamic>)).toList() : null,
			hIChartData: map['HIChartData'] != null ? (map['HIChartData'] as List).map((e)=>DataItemDTO.fromJson(e as Map<String,dynamic>)).toList() : null,
			aIChartData: map['AIChartData'] != null ? (map['AIChartData'] as List).map((e)=>DataItemDTO.fromJson(e as Map<String,dynamic>)).toList() : null,
			oAIChartData: map['OAIChartData'] != null ? (map['OAIChartData'] as List).map((e)=>DataItemDTO.fromJson(e as Map<String,dynamic>)).toList() : null,
			cAIChartData: map['CAIChartData'] != null ? (map['CAIChartData'] as List).map((e)=>DataItemDTO.fromJson(e as Map<String,dynamic>)).toList() : null,
			snoreEventChartData: map['SnoreEventChartData'] != null ? (map['SnoreEventChartData'] as List).map((e)=>DataItemDTO.fromJson(e as Map<String,dynamic>)).toList() : null,
			spo2AveChartData: map['Spo2AveChartData'] != null ? (map['Spo2AveChartData'] as List).map((e)=>DataItemDTO.fromJson(e as Map<String,dynamic>)).toList() : null,
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		if (useTimeChartData != null)
			map['UseTimeChartData'] = useTimeChartData;
		if (aHIChartData != null)
			map['AHIChartData'] = aHIChartData;
		if (hIChartData != null)
			map['HIChartData'] = hIChartData;
		if (aIChartData != null)
			map['AIChartData'] = aIChartData;
		if (oAIChartData != null)
			map['OAIChartData'] = oAIChartData;
		if (cAIChartData != null)
			map['CAIChartData'] = cAIChartData;
		if (snoreEventChartData != null)
			map['SnoreEventChartData'] = snoreEventChartData;
		if (spo2AveChartData != null)
			map['Spo2AveChartData'] = spo2AveChartData;
		return map;
	}
}

class IOTDeviceStageReportTrendChartRequest extends IOTDeviceStageReportRequest{

	IOTDeviceStageReportTrendChartRequest({
		String? deviceCode,
		DateTime? reportDate,
		IOTDeviceStageReportTypeEnum reportType = IOTDeviceStageReportTypeEnum.Day,
		ModeType mode = ModeType.CPAP,
		String? token,
	}) : super(
			deviceCode: deviceCode,
			reportDate: reportDate,
			reportType: reportType,
			mode: mode,
			token: token,
		);

	factory IOTDeviceStageReportTrendChartRequest.fromJson(Map<String, dynamic> map) {
		return IOTDeviceStageReportTrendChartRequest( 
			deviceCode: map['DeviceCode'],
			reportDate: map['ReportDate'] != null ? DateTime.parse(map['ReportDate']) : null,
			reportType: IOTDeviceStageReportTypeEnum.values.firstWhere((e) => e.index == map['ReportType']),
			mode: ModeType.values.firstWhere((e) => e.index == map['Mode']),
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		return map;
	}
}


