import 'dart:core';

import 'package:fis_jsonrpc/client_base.dart';
import 'package:fis_common/json_convert.dart';

import 'vitalCompletionRecord.m.dart';

import 'researchEdition.m.dart';


class VitalCompletionRecordService extends JsonRpcClientBase {
	VitalCompletionRecordService(
		String host, {
		String serviceName = "IVitalCompletionRecordService",
		Map<String, String>? headers,
		int? timeout,
	}) : super(
						host,
						serviceName,
						headers: headers,
						timeout: timeout,
				) {
		/// 注册响应实体反序列化处理器
		FJsonConvert.setDecoder((map) => CompletionRecordDTO.fromJson(map));
		FJsonConvert.setDecoder((map) => PageCollection<CompletionRecordDTO>.fromJson(map));
	}

	Future<String> createCompletionRecordAsync(CreateCompletionRecordRequest request) async {
		var rpcRst = await call("CreateCompletionRecordAsync", request);
		return rpcRst;
	}

	Future<CompletionRecordDTO> getCompletionRecordDetailAsync(GetCompletionRecordRequest request) async {
		var rpcRst = await call("GetCompletionRecordDetailAsync", request);
		var result = CompletionRecordDTO.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<CompletionRecordDTO> getCompletionRecordDetailByKeyAsync(GetCompletionRecordByKeyRequest request) async {
		var rpcRst = await call("GetCompletionRecordDetailByKeyAsync", request);
		var result = CompletionRecordDTO.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<PageCollection<CompletionRecordDTO>> getCompletionRecordPageAsync(CompletionRecordPageRequest request) async {
		var rpcRst = await call("GetCompletionRecordPageAsync", request);
		var result = PageCollection<CompletionRecordDTO>.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<bool> removeCompletionRecordAsync(RemoveCompletionRecordRequest request) async {
		var rpcRst = await call("RemoveCompletionRecordAsync", request);
		return rpcRst;
	}

	Future<List<CompletionRecordDTO>> getCompletionRecordListAsync(GetCompletionRecordListRequest request) async {
		var rpcRst = await call("GetCompletionRecordListAsync", request);
		var result = (rpcRst as List).map((e)=>CompletionRecordDTO.fromJson(e as Map<String, dynamic>)).toList();
		return result;
	}

	Future<bool> updateCompletionRecordAsync(UpdateCompletionRecordRequest request) async {
		var rpcRst = await call("UpdateCompletionRecordAsync", request);
		return rpcRst;
	}

}

