import 'researchEdition.m.dart';
import 'notification.m.dart';

import 'package:fis_jsonrpc/utils.dart';

class CreateCompletionRecordRequest extends TokenRequest{
	String? code;
	String? completionDoctor;
	String? patientCode;
	String? servicePackCode;
	String? servicePackName;
	String? serviceItemCode;
	String? serviceItemName;
	String? completionContent;
	String? notes;
	DateTime? completionTime;
	DateTime? nextCompletionTime;

	CreateCompletionRecordRequest({
		this.code,
		this.completionDoctor,
		this.patientCode,
		this.servicePackCode,
		this.servicePackName,
		this.serviceItemCode,
		this.serviceItemName,
		this.completionContent,
		this.notes,
		this.completionTime,
		this.nextCompletionTime,
		String? token,
	}) : super(
			token: token,
		);

	factory CreateCompletionRecordRequest.fromJson(Map<String, dynamic> map) {
		return CreateCompletionRecordRequest( 
			code: map['Code'],
			completionDoctor: map['CompletionDoctor'],
			patientCode: map['PatientCode'],
			servicePackCode: map['ServicePackCode'],
			servicePackName: map['ServicePackName'],
			serviceItemCode: map['ServiceItemCode'],
			serviceItemName: map['ServiceItemName'],
			completionContent: map['CompletionContent'],
			notes: map['Notes'],
			completionTime: map['CompletionTime'] != null ? DateTime.parse(map['CompletionTime']) : null,
			nextCompletionTime: map['NextCompletionTime'] != null ? DateTime.parse(map['NextCompletionTime']) : null,
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		if (completionDoctor != null)
			map['CompletionDoctor'] = completionDoctor;
		if (patientCode != null)
			map['PatientCode'] = patientCode;
		if (servicePackCode != null)
			map['ServicePackCode'] = servicePackCode;
		if (servicePackName != null)
			map['ServicePackName'] = servicePackName;
		if (serviceItemCode != null)
			map['ServiceItemCode'] = serviceItemCode;
		if (serviceItemName != null)
			map['ServiceItemName'] = serviceItemName;
		if (completionContent != null)
			map['CompletionContent'] = completionContent;
		if (notes != null)
			map['Notes'] = notes;
		if (completionTime != null)
			map['CompletionTime'] = JsonRpcUtils.dateFormat(completionTime!);
		if (nextCompletionTime != null)
			map['NextCompletionTime'] = JsonRpcUtils.dateFormat(nextCompletionTime!);
		return map;
	}
}

class CompletionRecordDTO extends BaseDTO{
	String? code;
	String? completionDoctor;
	String? completionDoctorName;
	String? patientCode;
	String? patientName;
	String? servicePackCode;
	String? servicePackName;
	String? serviceItemCode;
	String? serviceItemName;
	String? completionContent;
	String? notes;
	DateTime? completionTime;
	DateTime? nextCompletionTime;

	CompletionRecordDTO({
		this.code,
		this.completionDoctor,
		this.completionDoctorName,
		this.patientCode,
		this.patientName,
		this.servicePackCode,
		this.servicePackName,
		this.serviceItemCode,
		this.serviceItemName,
		this.completionContent,
		this.notes,
		this.completionTime,
		this.nextCompletionTime,
		bool isDelete = false,
		DateTime? createTime,
		DateTime? updateTime,
	}) : super(
			isDelete: isDelete,
			createTime: createTime,
			updateTime: updateTime,
		);

	factory CompletionRecordDTO.fromJson(Map<String, dynamic> map) {
		return CompletionRecordDTO( 
			code: map['Code'],
			completionDoctor: map['CompletionDoctor'],
			completionDoctorName: map['CompletionDoctorName'],
			patientCode: map['PatientCode'],
			patientName: map['PatientName'],
			servicePackCode: map['ServicePackCode'],
			servicePackName: map['ServicePackName'],
			serviceItemCode: map['ServiceItemCode'],
			serviceItemName: map['ServiceItemName'],
			completionContent: map['CompletionContent'],
			notes: map['Notes'],
			completionTime: map['CompletionTime'] != null ? DateTime.parse(map['CompletionTime']) : null,
			nextCompletionTime: map['NextCompletionTime'] != null ? DateTime.parse(map['NextCompletionTime']) : null,
			isDelete: map['IsDelete'],
			createTime: map['CreateTime'] != null ? DateTime.parse(map['CreateTime']) : null,
			updateTime: map['UpdateTime'] != null ? DateTime.parse(map['UpdateTime']) : null,
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		if (completionDoctor != null)
			map['CompletionDoctor'] = completionDoctor;
		if (completionDoctorName != null)
			map['CompletionDoctorName'] = completionDoctorName;
		if (patientCode != null)
			map['PatientCode'] = patientCode;
		if (patientName != null)
			map['PatientName'] = patientName;
		if (servicePackCode != null)
			map['ServicePackCode'] = servicePackCode;
		if (servicePackName != null)
			map['ServicePackName'] = servicePackName;
		if (serviceItemCode != null)
			map['ServiceItemCode'] = serviceItemCode;
		if (serviceItemName != null)
			map['ServiceItemName'] = serviceItemName;
		if (completionContent != null)
			map['CompletionContent'] = completionContent;
		if (notes != null)
			map['Notes'] = notes;
		if (completionTime != null)
			map['CompletionTime'] = JsonRpcUtils.dateFormat(completionTime!);
		if (nextCompletionTime != null)
			map['NextCompletionTime'] = JsonRpcUtils.dateFormat(nextCompletionTime!);
		return map;
	}
}

class GetCompletionRecordRequest extends TokenRequest{
	String? code;

	GetCompletionRecordRequest({
		this.code,
		String? token,
	}) : super(
			token: token,
		);

	factory GetCompletionRecordRequest.fromJson(Map<String, dynamic> map) {
		return GetCompletionRecordRequest( 
			code: map['Code'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		return map;
	}
}

class GetCompletionRecordByKeyRequest extends TokenRequest{
	String? key;
	String? value;

	GetCompletionRecordByKeyRequest({
		this.key,
		this.value,
		String? token,
	}) : super(
			token: token,
		);

	factory GetCompletionRecordByKeyRequest.fromJson(Map<String, dynamic> map) {
		return GetCompletionRecordByKeyRequest( 
			key: map['Key'],
			value: map['Value'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (key != null)
			map['Key'] = key;
		if (value != null)
			map['Value'] = value;
		return map;
	}
}

class CompletionRecordPageRequest extends PageRequest{
	String? keyword;
	DateTime? startTime;
	DateTime? endTime;

	CompletionRecordPageRequest({
		this.keyword,
		this.startTime,
		this.endTime,
		int pageIndex = 0,
		int pageSize = 0,
		String? token,
	}) : super(
			pageIndex: pageIndex,
			pageSize: pageSize,
			token: token,
		);

	factory CompletionRecordPageRequest.fromJson(Map<String, dynamic> map) {
		return CompletionRecordPageRequest( 
			keyword: map['Keyword'],
			startTime: map['StartTime'] != null ? DateTime.parse(map['StartTime']) : null,
			endTime: map['EndTime'] != null ? DateTime.parse(map['EndTime']) : null,
			pageIndex: map['PageIndex'],
			pageSize: map['PageSize'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (keyword != null)
			map['Keyword'] = keyword;
		if (startTime != null)
			map['StartTime'] = JsonRpcUtils.dateFormat(startTime!);
		if (endTime != null)
			map['EndTime'] = JsonRpcUtils.dateFormat(endTime!);
		return map;
	}
}

class RemoveCompletionRecordRequest extends TokenRequest{
	String? code;

	RemoveCompletionRecordRequest({
		this.code,
		String? token,
	}) : super(
			token: token,
		);

	factory RemoveCompletionRecordRequest.fromJson(Map<String, dynamic> map) {
		return RemoveCompletionRecordRequest( 
			code: map['Code'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		return map;
	}
}

class GetCompletionRecordListRequest extends TokenRequest{
	List<String>? codes;

	GetCompletionRecordListRequest({
		this.codes,
		String? token,
	}) : super(
			token: token,
		);

	factory GetCompletionRecordListRequest.fromJson(Map<String, dynamic> map) {
		return GetCompletionRecordListRequest( 
			codes: map['Codes']?.cast<String>().toList(),
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (codes != null)
			map['Codes'] = codes;
		return map;
	}
}

class UpdateCompletionRecordRequest extends TokenRequest{
	String? code;
	String? completionDoctor;
	String? patientCode;
	String? servicePackCode;
	String? servicePackName;
	String? serviceItemCode;
	String? serviceItemName;
	String? completionContent;
	String? notes;
	DateTime? completionTime;
	DateTime? nextCompletionTime;

	UpdateCompletionRecordRequest({
		this.code,
		this.completionDoctor,
		this.patientCode,
		this.servicePackCode,
		this.servicePackName,
		this.serviceItemCode,
		this.serviceItemName,
		this.completionContent,
		this.notes,
		this.completionTime,
		this.nextCompletionTime,
		String? token,
	}) : super(
			token: token,
		);

	factory UpdateCompletionRecordRequest.fromJson(Map<String, dynamic> map) {
		return UpdateCompletionRecordRequest( 
			code: map['Code'],
			completionDoctor: map['CompletionDoctor'],
			patientCode: map['PatientCode'],
			servicePackCode: map['ServicePackCode'],
			servicePackName: map['ServicePackName'],
			serviceItemCode: map['ServiceItemCode'],
			serviceItemName: map['ServiceItemName'],
			completionContent: map['CompletionContent'],
			notes: map['Notes'],
			completionTime: map['CompletionTime'] != null ? DateTime.parse(map['CompletionTime']) : null,
			nextCompletionTime: map['NextCompletionTime'] != null ? DateTime.parse(map['NextCompletionTime']) : null,
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		if (completionDoctor != null)
			map['CompletionDoctor'] = completionDoctor;
		if (patientCode != null)
			map['PatientCode'] = patientCode;
		if (servicePackCode != null)
			map['ServicePackCode'] = servicePackCode;
		if (servicePackName != null)
			map['ServicePackName'] = servicePackName;
		if (serviceItemCode != null)
			map['ServiceItemCode'] = serviceItemCode;
		if (serviceItemName != null)
			map['ServiceItemName'] = serviceItemName;
		if (completionContent != null)
			map['CompletionContent'] = completionContent;
		if (notes != null)
			map['Notes'] = notes;
		if (completionTime != null)
			map['CompletionTime'] = JsonRpcUtils.dateFormat(completionTime!);
		if (nextCompletionTime != null)
			map['NextCompletionTime'] = JsonRpcUtils.dateFormat(nextCompletionTime!);
		return map;
	}
}


