import 'dart:core';

import 'package:fis_jsonrpc/client_base.dart';
import 'package:fis_common/json_convert.dart';

import 'vitalContractRecord.m.dart';

import 'researchEdition.m.dart';


class VitalContractRecordService extends JsonRpcClientBase {
	VitalContractRecordService(
		String host, {
		String serviceName = "IVitalContractRecordService",
		Map<String, String>? headers,
		int? timeout,
	}) : super(
						host,
						serviceName,
						headers: headers,
						timeout: timeout,
				) {
		/// 注册响应实体反序列化处理器
		FJsonConvert.setDecoder((map) => ContractRecordDTO.fromJson(map));
		FJsonConvert.setDecoder((map) => PageCollection<ContractRecordDTO>.fromJson(map));
	}

	Future<String> createContractRecordAsync(CreateContractRecordRequest request) async {
		var rpcRst = await call("CreateContractRecordAsync", request);
		return rpcRst;
	}

	Future<ContractRecordDTO> getContractRecordDetailAsync(GetContractRecordRequest request) async {
		var rpcRst = await call("GetContractRecordDetailAsync", request);
		var result = ContractRecordDTO.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<ContractRecordDTO> getContractRecordDetailByKeyAsync(GetContractRecordByKeyRequest request) async {
		var rpcRst = await call("GetContractRecordDetailByKeyAsync", request);
		var result = ContractRecordDTO.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<PageCollection<ContractRecordDTO>> getContractRecordPageAsync(ContractRecordPageRequest request) async {
		var rpcRst = await call("GetContractRecordPageAsync", request);
		var result = PageCollection<ContractRecordDTO>.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<bool> removeContractRecordAsync(RemoveContractRecordRequest request) async {
		var rpcRst = await call("RemoveContractRecordAsync", request);
		return rpcRst;
	}

	Future<List<ContractRecordDTO>> getContractRecordListAsync(GetContractRecordListRequest request) async {
		var rpcRst = await call("GetContractRecordListAsync", request);
		var result = (rpcRst as List).map((e)=>ContractRecordDTO.fromJson(e as Map<String, dynamic>)).toList();
		return result;
	}

	Future<bool> updateContractRecordAsync(UpdateContractRecordRequest request) async {
		var rpcRst = await call("UpdateContractRecordAsync", request);
		return rpcRst;
	}

	Future<PageCollection<ContractRecordDTO>> getContractRecordPageByPatientCodeAsync(GetContractRecordPageByPatientCodeRequest request) async {
		var rpcRst = await call("GetContractRecordPageByPatientCodeAsync", request);
		var result = PageCollection<ContractRecordDTO>.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<PageCollection<ContractRecordDTO>> getContractPatientPageAsync(GetContractPatientPageRequest request) async {
		var rpcRst = await call("GetContractPatientPageAsync", request);
		var result = PageCollection<ContractRecordDTO>.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<bool> updateContractRecordStateAsync(UpdateContractRecordStateRequest request) async {
		var rpcRst = await call("UpdateContractRecordStateAsync", request);
		return rpcRst;
	}

	Future<String> renewalContractRecordAsync(RenewalContractRecordRequest request) async {
		var rpcRst = await call("RenewalContractRecordAsync", request);
		return rpcRst;
	}

	Future<ContractRecordDTO> getDoctorContractRecordAsync(GetDoctorContractRecordRequest request) async {
		var rpcRst = await call("GetDoctorContractRecordAsync", request);
		var result = ContractRecordDTO.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

}

