import 'researchEdition.m.dart';
import 'notification.m.dart';
import 'exam.m.dart';

import 'package:fis_jsonrpc/utils.dart';

enum ContractStateEnum {
	Unsigned,
	Cancelled,
	Expired,
	Signed,
	Voided,
	Refused,
}

class CreateContractRecordRequest extends TokenRequest{
	String? code;
	String? contractRecordNo;
	String? contractedDoctor;
	String? contractedPatient;
	String? contractedTeam;
	DateTime? contractedTime;
	String? contractedFileUrl;
	List<String>? servicePacks;
	DateTime? serviceStartDate;
	DateTime? serviceEndDate;
	List<String>? photos;
	String? notes;
	ContractStateEnum? contractState;
	String? reason;
	String? contractedDoctorName;
	String? contractedDoctorPhone;
	String? teamLeaderName;
	String? preceptorName;
	String? renewalContractCode;

	CreateContractRecordRequest({
		this.code,
		this.contractRecordNo,
		this.contractedDoctor,
		this.contractedPatient,
		this.contractedTeam,
		this.contractedTime,
		this.contractedFileUrl,
		this.servicePacks,
		this.serviceStartDate,
		this.serviceEndDate,
		this.photos,
		this.notes,
		this.contractState,
		this.reason,
		this.contractedDoctorName,
		this.contractedDoctorPhone,
		this.teamLeaderName,
		this.preceptorName,
		this.renewalContractCode,
		String? token,
	}) : super(
			token: token,
		);

	factory CreateContractRecordRequest.fromJson(Map<String, dynamic> map) {
		return CreateContractRecordRequest( 
			code: map['Code'],
			contractRecordNo: map['ContractRecordNo'],
			contractedDoctor: map['ContractedDoctor'],
			contractedPatient: map['ContractedPatient'],
			contractedTeam: map['ContractedTeam'],
			contractedTime: map['ContractedTime'] != null ? DateTime.parse(map['ContractedTime']) : null,
			contractedFileUrl: map['ContractedFileUrl'],
			servicePacks: map['ServicePacks']?.cast<String>().toList(),
			serviceStartDate: map['ServiceStartDate'] != null ? DateTime.parse(map['ServiceStartDate']) : null,
			serviceEndDate: map['ServiceEndDate'] != null ? DateTime.parse(map['ServiceEndDate']) : null,
			photos: map['Photos']?.cast<String>().toList(),
			notes: map['Notes'],
			contractState: map['ContractState'] != null ? ContractStateEnum.values.firstWhere((e) => e.index == map['ContractState']) : null,
			reason: map['Reason'],
			contractedDoctorName: map['ContractedDoctorName'],
			contractedDoctorPhone: map['ContractedDoctorPhone'],
			teamLeaderName: map['TeamLeaderName'],
			preceptorName: map['PreceptorName'],
			renewalContractCode: map['RenewalContractCode'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		if (contractRecordNo != null)
			map['ContractRecordNo'] = contractRecordNo;
		if (contractedDoctor != null)
			map['ContractedDoctor'] = contractedDoctor;
		if (contractedPatient != null)
			map['ContractedPatient'] = contractedPatient;
		if (contractedTeam != null)
			map['ContractedTeam'] = contractedTeam;
		if (contractedTime != null)
			map['ContractedTime'] = JsonRpcUtils.dateFormat(contractedTime!);
		if (contractedFileUrl != null)
			map['ContractedFileUrl'] = contractedFileUrl;
		if (servicePacks != null)
			map['ServicePacks'] = servicePacks;
		if (serviceStartDate != null)
			map['ServiceStartDate'] = JsonRpcUtils.dateFormat(serviceStartDate!);
		if (serviceEndDate != null)
			map['ServiceEndDate'] = JsonRpcUtils.dateFormat(serviceEndDate!);
		if (photos != null)
			map['Photos'] = photos;
		if (notes != null)
			map['Notes'] = notes;
		if (contractState != null)
		map['ContractState'] = contractState?.index;
		if (reason != null)
			map['Reason'] = reason;
		if (contractedDoctorName != null)
			map['ContractedDoctorName'] = contractedDoctorName;
		if (contractedDoctorPhone != null)
			map['ContractedDoctorPhone'] = contractedDoctorPhone;
		if (teamLeaderName != null)
			map['TeamLeaderName'] = teamLeaderName;
		if (preceptorName != null)
			map['PreceptorName'] = preceptorName;
		if (renewalContractCode != null)
			map['RenewalContractCode'] = renewalContractCode;
		return map;
	}
}

enum AuditStateEnum {
	Unaudited,
	Approve,
	Rejection,
}

enum ServicePackTypeEnum {
	BasePack,
	PrimaryPack,
	IntermediatePack,
	SeniorPack,
	LocalPack,
	OrganizationPack,
}

class ServicePackDTO extends BaseDTO{
	String? code;
	String? name;
	ServicePackTypeEnum servicePackType;
	String? content;
	List<String>? items;
	List<String>? labels;
	String? organizationCode;
	String? organizationName;

	ServicePackDTO({
		this.code,
		this.name,
		this.servicePackType = ServicePackTypeEnum.BasePack,
		this.content,
		this.items,
		this.labels,
		this.organizationCode,
		this.organizationName,
		bool isDelete = false,
		DateTime? createTime,
		DateTime? updateTime,
	}) : super(
			isDelete: isDelete,
			createTime: createTime,
			updateTime: updateTime,
		);

	factory ServicePackDTO.fromJson(Map<String, dynamic> map) {
		return ServicePackDTO( 
			code: map['Code'],
			name: map['Name'],
			servicePackType: ServicePackTypeEnum.values.firstWhere((e) => e.index == map['ServicePackType']),
			content: map['Content'],
			items: map['Items']?.cast<String>().toList(),
			labels: map['Labels']?.cast<String>().toList(),
			organizationCode: map['OrganizationCode'],
			organizationName: map['OrganizationName'],
			isDelete: map['IsDelete'],
			createTime: map['CreateTime'] != null ? DateTime.parse(map['CreateTime']) : null,
			updateTime: map['UpdateTime'] != null ? DateTime.parse(map['UpdateTime']) : null,
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		if (name != null)
			map['Name'] = name;
		map['ServicePackType'] = servicePackType.index;
		if (content != null)
			map['Content'] = content;
		if (items != null)
			map['Items'] = items;
		if (labels != null)
			map['Labels'] = labels;
		if (organizationCode != null)
			map['OrganizationCode'] = organizationCode;
		if (organizationName != null)
			map['OrganizationName'] = organizationName;
		return map;
	}
}

class ContractRecordDTO extends BaseDTO{
	String? code;
	String? contractRecordNo;
	ContractStateEnum contractState;
	bool contractIsValid;
	String? contractedDoctor;
	String? contractedDoctorCode;
	String? contractedPatient;
	String? contractedTeam;
	String? contractedTeamCode;
	String? supervisingPhysician;
	DateTime? contractedTime;
	AuditStateEnum auditState;
	String? contractedFileUrl;
	List<ServicePackDTO>? servicePacks;
	DateTime? serviceStartDate;
	DateTime? serviceEndDate;
	String? patientName;
	GenderEnum patientGender;
	String? phone;
	String? cardNo;
	DateTime? birthday;
	String? patientAddress;
	String? nationality;
	List<String>? crowdLabels;
	List<String>? labelNames;
	String? organizationName;
	List<String>? photos;
	String? notes;
	String? reason;
	String? contractedDoctorName;
	String? contractedDoctorPhone;
	String? teamLeaderName;
	String? preceptorName;
	String? renewalContractCode;

	ContractRecordDTO({
		this.code,
		this.contractRecordNo,
		this.contractState = ContractStateEnum.Unsigned,
		this.contractIsValid = false,
		this.contractedDoctor,
		this.contractedDoctorCode,
		this.contractedPatient,
		this.contractedTeam,
		this.contractedTeamCode,
		this.supervisingPhysician,
		this.contractedTime,
		this.auditState = AuditStateEnum.Unaudited,
		this.contractedFileUrl,
		this.servicePacks,
		this.serviceStartDate,
		this.serviceEndDate,
		this.patientName,
		this.patientGender = GenderEnum.Unknown,
		this.phone,
		this.cardNo,
		this.birthday,
		this.patientAddress,
		this.nationality,
		this.crowdLabels,
		this.labelNames,
		this.organizationName,
		this.photos,
		this.notes,
		this.reason,
		this.contractedDoctorName,
		this.contractedDoctorPhone,
		this.teamLeaderName,
		this.preceptorName,
		this.renewalContractCode,
		bool isDelete = false,
		DateTime? createTime,
		DateTime? updateTime,
	}) : super(
			isDelete: isDelete,
			createTime: createTime,
			updateTime: updateTime,
		);

	factory ContractRecordDTO.fromJson(Map<String, dynamic> map) {
		return ContractRecordDTO( 
			code: map['Code'],
			contractRecordNo: map['ContractRecordNo'],
			contractState: ContractStateEnum.values.firstWhere((e) => e.index == map['ContractState']),
			contractIsValid: map['ContractIsValid'],
			contractedDoctor: map['ContractedDoctor'],
			contractedDoctorCode: map['ContractedDoctorCode'],
			contractedPatient: map['ContractedPatient'],
			contractedTeam: map['ContractedTeam'],
			contractedTeamCode: map['ContractedTeamCode'],
			supervisingPhysician: map['SupervisingPhysician'],
			contractedTime: map['ContractedTime'] != null ? DateTime.parse(map['ContractedTime']) : null,
			auditState: AuditStateEnum.values.firstWhere((e) => e.index == map['AuditState']),
			contractedFileUrl: map['ContractedFileUrl'],
			servicePacks: map['ServicePacks'] != null ? (map['ServicePacks'] as List).map((e)=>ServicePackDTO.fromJson(e as Map<String,dynamic>)).toList() : null,
			serviceStartDate: map['ServiceStartDate'] != null ? DateTime.parse(map['ServiceStartDate']) : null,
			serviceEndDate: map['ServiceEndDate'] != null ? DateTime.parse(map['ServiceEndDate']) : null,
			patientName: map['PatientName'],
			patientGender: GenderEnum.values.firstWhere((e) => e.index == map['PatientGender']),
			phone: map['Phone'],
			cardNo: map['CardNo'],
			birthday: map['Birthday'] != null ? DateTime.parse(map['Birthday']) : null,
			patientAddress: map['PatientAddress'],
			nationality: map['Nationality'],
			crowdLabels: map['CrowdLabels']?.cast<String>().toList(),
			labelNames: map['LabelNames']?.cast<String>().toList(),
			organizationName: map['OrganizationName'],
			photos: map['Photos']?.cast<String>().toList(),
			notes: map['Notes'],
			reason: map['Reason'],
			contractedDoctorName: map['ContractedDoctorName'],
			contractedDoctorPhone: map['ContractedDoctorPhone'],
			teamLeaderName: map['TeamLeaderName'],
			preceptorName: map['PreceptorName'],
			renewalContractCode: map['RenewalContractCode'],
			isDelete: map['IsDelete'],
			createTime: map['CreateTime'] != null ? DateTime.parse(map['CreateTime']) : null,
			updateTime: map['UpdateTime'] != null ? DateTime.parse(map['UpdateTime']) : null,
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		if (contractRecordNo != null)
			map['ContractRecordNo'] = contractRecordNo;
		map['ContractState'] = contractState.index;
		map['ContractIsValid'] = contractIsValid;
		if (contractedDoctor != null)
			map['ContractedDoctor'] = contractedDoctor;
		if (contractedDoctorCode != null)
			map['ContractedDoctorCode'] = contractedDoctorCode;
		if (contractedPatient != null)
			map['ContractedPatient'] = contractedPatient;
		if (contractedTeam != null)
			map['ContractedTeam'] = contractedTeam;
		if (contractedTeamCode != null)
			map['ContractedTeamCode'] = contractedTeamCode;
		if (supervisingPhysician != null)
			map['SupervisingPhysician'] = supervisingPhysician;
		if (contractedTime != null)
			map['ContractedTime'] = JsonRpcUtils.dateFormat(contractedTime!);
		map['AuditState'] = auditState.index;
		if (contractedFileUrl != null)
			map['ContractedFileUrl'] = contractedFileUrl;
		if (servicePacks != null)
			map['ServicePacks'] = servicePacks;
		if (serviceStartDate != null)
			map['ServiceStartDate'] = JsonRpcUtils.dateFormat(serviceStartDate!);
		if (serviceEndDate != null)
			map['ServiceEndDate'] = JsonRpcUtils.dateFormat(serviceEndDate!);
		if (patientName != null)
			map['PatientName'] = patientName;
		map['PatientGender'] = patientGender.index;
		if (phone != null)
			map['Phone'] = phone;
		if (cardNo != null)
			map['CardNo'] = cardNo;
		if (birthday != null)
			map['Birthday'] = JsonRpcUtils.dateFormat(birthday!);
		if (patientAddress != null)
			map['PatientAddress'] = patientAddress;
		if (nationality != null)
			map['Nationality'] = nationality;
		if (crowdLabels != null)
			map['CrowdLabels'] = crowdLabels;
		if (labelNames != null)
			map['LabelNames'] = labelNames;
		if (organizationName != null)
			map['OrganizationName'] = organizationName;
		if (photos != null)
			map['Photos'] = photos;
		if (notes != null)
			map['Notes'] = notes;
		if (reason != null)
			map['Reason'] = reason;
		if (contractedDoctorName != null)
			map['ContractedDoctorName'] = contractedDoctorName;
		if (contractedDoctorPhone != null)
			map['ContractedDoctorPhone'] = contractedDoctorPhone;
		if (teamLeaderName != null)
			map['TeamLeaderName'] = teamLeaderName;
		if (preceptorName != null)
			map['PreceptorName'] = preceptorName;
		if (renewalContractCode != null)
			map['RenewalContractCode'] = renewalContractCode;
		return map;
	}
}

class GetContractRecordRequest extends TokenRequest{
	String? code;

	GetContractRecordRequest({
		this.code,
		String? token,
	}) : super(
			token: token,
		);

	factory GetContractRecordRequest.fromJson(Map<String, dynamic> map) {
		return GetContractRecordRequest( 
			code: map['Code'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		return map;
	}
}

class GetContractRecordByKeyRequest extends TokenRequest{
	String? key;
	String? value;

	GetContractRecordByKeyRequest({
		this.key,
		this.value,
		String? token,
	}) : super(
			token: token,
		);

	factory GetContractRecordByKeyRequest.fromJson(Map<String, dynamic> map) {
		return GetContractRecordByKeyRequest( 
			key: map['Key'],
			value: map['Value'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (key != null)
			map['Key'] = key;
		if (value != null)
			map['Value'] = value;
		return map;
	}
}

class ContractRecordPageRequest extends PageRequest{
	String? keyword;
	DateTime? startTime;
	DateTime? endTime;
	AuditStateEnum auditState;

	ContractRecordPageRequest({
		this.keyword,
		this.startTime,
		this.endTime,
		this.auditState = AuditStateEnum.Unaudited,
		int pageIndex = 0,
		int pageSize = 0,
		String? token,
	}) : super(
			pageIndex: pageIndex,
			pageSize: pageSize,
			token: token,
		);

	factory ContractRecordPageRequest.fromJson(Map<String, dynamic> map) {
		return ContractRecordPageRequest( 
			keyword: map['Keyword'],
			startTime: map['StartTime'] != null ? DateTime.parse(map['StartTime']) : null,
			endTime: map['EndTime'] != null ? DateTime.parse(map['EndTime']) : null,
			auditState: AuditStateEnum.values.firstWhere((e) => e.index == map['AuditState']),
			pageIndex: map['PageIndex'],
			pageSize: map['PageSize'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (keyword != null)
			map['Keyword'] = keyword;
		if (startTime != null)
			map['StartTime'] = JsonRpcUtils.dateFormat(startTime!);
		if (endTime != null)
			map['EndTime'] = JsonRpcUtils.dateFormat(endTime!);
		map['AuditState'] = auditState.index;
		return map;
	}
}

class RemoveContractRecordRequest extends TokenRequest{
	String? code;

	RemoveContractRecordRequest({
		this.code,
		String? token,
	}) : super(
			token: token,
		);

	factory RemoveContractRecordRequest.fromJson(Map<String, dynamic> map) {
		return RemoveContractRecordRequest( 
			code: map['Code'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		return map;
	}
}

class GetContractRecordListRequest extends TokenRequest{
	List<String>? codes;

	GetContractRecordListRequest({
		this.codes,
		String? token,
	}) : super(
			token: token,
		);

	factory GetContractRecordListRequest.fromJson(Map<String, dynamic> map) {
		return GetContractRecordListRequest( 
			codes: map['Codes']?.cast<String>().toList(),
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (codes != null)
			map['Codes'] = codes;
		return map;
	}
}

class UpdateContractRecordRequest extends TokenRequest{
	String? code;
	String? contractRecordNo;
	ContractStateEnum? contractState;
	bool? contractIsValid;
	String? contractedDoctor;
	String? contractedPatient;
	String? contractedTeam;
	DateTime? contractedTime;
	AuditStateEnum? auditState;
	String? contractedFileUrl;
	List<String>? servicePacks;
	DateTime? serviceStartDate;
	DateTime? serviceEndDate;
	List<String>? photos;
	String? notes;

	UpdateContractRecordRequest({
		this.code,
		this.contractRecordNo,
		this.contractState,
		this.contractIsValid,
		this.contractedDoctor,
		this.contractedPatient,
		this.contractedTeam,
		this.contractedTime,
		this.auditState,
		this.contractedFileUrl,
		this.servicePacks,
		this.serviceStartDate,
		this.serviceEndDate,
		this.photos,
		this.notes,
		String? token,
	}) : super(
			token: token,
		);

	factory UpdateContractRecordRequest.fromJson(Map<String, dynamic> map) {
		return UpdateContractRecordRequest( 
			code: map['Code'],
			contractRecordNo: map['ContractRecordNo'],
			contractState: map['ContractState'] != null ? ContractStateEnum.values.firstWhere((e) => e.index == map['ContractState']) : null,
			contractIsValid: map['ContractIsValid'],
			contractedDoctor: map['ContractedDoctor'],
			contractedPatient: map['ContractedPatient'],
			contractedTeam: map['ContractedTeam'],
			contractedTime: map['ContractedTime'] != null ? DateTime.parse(map['ContractedTime']) : null,
			auditState: map['AuditState'] != null ? AuditStateEnum.values.firstWhere((e) => e.index == map['AuditState']) : null,
			contractedFileUrl: map['ContractedFileUrl'],
			servicePacks: map['ServicePacks']?.cast<String>().toList(),
			serviceStartDate: map['ServiceStartDate'] != null ? DateTime.parse(map['ServiceStartDate']) : null,
			serviceEndDate: map['ServiceEndDate'] != null ? DateTime.parse(map['ServiceEndDate']) : null,
			photos: map['Photos']?.cast<String>().toList(),
			notes: map['Notes'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		if (contractRecordNo != null)
			map['ContractRecordNo'] = contractRecordNo;
		if (contractState != null)
		map['ContractState'] = contractState?.index;
		if (contractIsValid != null)
			map['ContractIsValid'] = contractIsValid;
		if (contractedDoctor != null)
			map['ContractedDoctor'] = contractedDoctor;
		if (contractedPatient != null)
			map['ContractedPatient'] = contractedPatient;
		if (contractedTeam != null)
			map['ContractedTeam'] = contractedTeam;
		if (contractedTime != null)
			map['ContractedTime'] = JsonRpcUtils.dateFormat(contractedTime!);
		if (auditState != null)
		map['AuditState'] = auditState?.index;
		if (contractedFileUrl != null)
			map['ContractedFileUrl'] = contractedFileUrl;
		if (servicePacks != null)
			map['ServicePacks'] = servicePacks;
		if (serviceStartDate != null)
			map['ServiceStartDate'] = JsonRpcUtils.dateFormat(serviceStartDate!);
		if (serviceEndDate != null)
			map['ServiceEndDate'] = JsonRpcUtils.dateFormat(serviceEndDate!);
		if (photos != null)
			map['Photos'] = photos;
		if (notes != null)
			map['Notes'] = notes;
		return map;
	}
}

class GetContractRecordPageByPatientCodeRequest extends PageRequest{
	String? keyword;
	DateTime? startTime;
	DateTime? endTime;
	String? patientCode;

	GetContractRecordPageByPatientCodeRequest({
		this.keyword,
		this.startTime,
		this.endTime,
		this.patientCode,
		int pageIndex = 0,
		int pageSize = 0,
		String? token,
	}) : super(
			pageIndex: pageIndex,
			pageSize: pageSize,
			token: token,
		);

	factory GetContractRecordPageByPatientCodeRequest.fromJson(Map<String, dynamic> map) {
		return GetContractRecordPageByPatientCodeRequest( 
			keyword: map['Keyword'],
			startTime: map['StartTime'] != null ? DateTime.parse(map['StartTime']) : null,
			endTime: map['EndTime'] != null ? DateTime.parse(map['EndTime']) : null,
			patientCode: map['PatientCode'],
			pageIndex: map['PageIndex'],
			pageSize: map['PageSize'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (keyword != null)
			map['Keyword'] = keyword;
		if (startTime != null)
			map['StartTime'] = JsonRpcUtils.dateFormat(startTime!);
		if (endTime != null)
			map['EndTime'] = JsonRpcUtils.dateFormat(endTime!);
		if (patientCode != null)
			map['PatientCode'] = patientCode;
		return map;
	}
}

class GetContractPatientPageRequest extends PageRequest{
	String? keyword;
	DateTime? startTime;
	DateTime? endTime;

	GetContractPatientPageRequest({
		this.keyword,
		this.startTime,
		this.endTime,
		int pageIndex = 0,
		int pageSize = 0,
		String? token,
	}) : super(
			pageIndex: pageIndex,
			pageSize: pageSize,
			token: token,
		);

	factory GetContractPatientPageRequest.fromJson(Map<String, dynamic> map) {
		return GetContractPatientPageRequest( 
			keyword: map['Keyword'],
			startTime: map['StartTime'] != null ? DateTime.parse(map['StartTime']) : null,
			endTime: map['EndTime'] != null ? DateTime.parse(map['EndTime']) : null,
			pageIndex: map['PageIndex'],
			pageSize: map['PageSize'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (keyword != null)
			map['Keyword'] = keyword;
		if (startTime != null)
			map['StartTime'] = JsonRpcUtils.dateFormat(startTime!);
		if (endTime != null)
			map['EndTime'] = JsonRpcUtils.dateFormat(endTime!);
		return map;
	}
}

class UpdateContractRecordStateRequest extends TokenRequest{
	String? code;
	ContractStateEnum? contractState;
	String? reason;

	UpdateContractRecordStateRequest({
		this.code,
		this.contractState,
		this.reason,
		String? token,
	}) : super(
			token: token,
		);

	factory UpdateContractRecordStateRequest.fromJson(Map<String, dynamic> map) {
		return UpdateContractRecordStateRequest( 
			code: map['Code'],
			contractState: map['ContractState'] != null ? ContractStateEnum.values.firstWhere((e) => e.index == map['ContractState']) : null,
			reason: map['Reason'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		if (contractState != null)
		map['ContractState'] = contractState?.index;
		if (reason != null)
			map['Reason'] = reason;
		return map;
	}
}

class RenewalContractRecordRequest extends TokenRequest{
	String? code;
	DateTime? serviceStartDate;
	DateTime? serviceEndDate;

	RenewalContractRecordRequest({
		this.code,
		this.serviceStartDate,
		this.serviceEndDate,
		String? token,
	}) : super(
			token: token,
		);

	factory RenewalContractRecordRequest.fromJson(Map<String, dynamic> map) {
		return RenewalContractRecordRequest( 
			code: map['Code'],
			serviceStartDate: map['ServiceStartDate'] != null ? DateTime.parse(map['ServiceStartDate']) : null,
			serviceEndDate: map['ServiceEndDate'] != null ? DateTime.parse(map['ServiceEndDate']) : null,
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		if (serviceStartDate != null)
			map['ServiceStartDate'] = JsonRpcUtils.dateFormat(serviceStartDate!);
		if (serviceEndDate != null)
			map['ServiceEndDate'] = JsonRpcUtils.dateFormat(serviceEndDate!);
		return map;
	}
}

class GetDoctorContractRecordRequest extends TokenRequest{

	GetDoctorContractRecordRequest({
		String? token,
	}) : super(
			token: token,
		);

	factory GetDoctorContractRecordRequest.fromJson(Map<String, dynamic> map) {
		return GetDoctorContractRecordRequest( 
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		return map;
	}
}


