import 'researchEdition.m.dart';
import 'notification.m.dart';

import 'package:fis_jsonrpc/utils.dart';

class CreateContractTemplateRequest extends TokenRequest{
	String? code;
	String? key;
	String? templateName;
	String? templateContent;
	String? provinceCode;
	String? cityCode;
	String? districtCode;
	String? townCode;

	CreateContractTemplateRequest({
		this.code,
		this.key,
		this.templateName,
		this.templateContent,
		this.provinceCode,
		this.cityCode,
		this.districtCode,
		this.townCode,
		String? token,
	}) : super(
			token: token,
		);

	factory CreateContractTemplateRequest.fromJson(Map<String, dynamic> map) {
		return CreateContractTemplateRequest( 
			code: map['Code'],
			key: map['Key'],
			templateName: map['TemplateName'],
			templateContent: map['TemplateContent'],
			provinceCode: map['ProvinceCode'],
			cityCode: map['CityCode'],
			districtCode: map['DistrictCode'],
			townCode: map['TownCode'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		if (key != null)
			map['Key'] = key;
		if (templateName != null)
			map['TemplateName'] = templateName;
		if (templateContent != null)
			map['TemplateContent'] = templateContent;
		if (provinceCode != null)
			map['ProvinceCode'] = provinceCode;
		if (cityCode != null)
			map['CityCode'] = cityCode;
		if (districtCode != null)
			map['DistrictCode'] = districtCode;
		if (townCode != null)
			map['TownCode'] = townCode;
		return map;
	}
}

class ContractTemplateDTO extends BaseDTO{
	String? code;
	String? key;
	String? templateName;
	String? templateContent;
	String? provinceCode;
	String? cityCode;
	String? districtCode;
	String? townCode;
	String? townName;

	ContractTemplateDTO({
		this.code,
		this.key,
		this.templateName,
		this.templateContent,
		this.provinceCode,
		this.cityCode,
		this.districtCode,
		this.townCode,
		this.townName,
		bool isDelete = false,
		DateTime? createTime,
		DateTime? updateTime,
	}) : super(
			isDelete: isDelete,
			createTime: createTime,
			updateTime: updateTime,
		);

	factory ContractTemplateDTO.fromJson(Map<String, dynamic> map) {
		return ContractTemplateDTO( 
			code: map['Code'],
			key: map['Key'],
			templateName: map['TemplateName'],
			templateContent: map['TemplateContent'],
			provinceCode: map['ProvinceCode'],
			cityCode: map['CityCode'],
			districtCode: map['DistrictCode'],
			townCode: map['TownCode'],
			townName: map['TownName'],
			isDelete: map['IsDelete'],
			createTime: map['CreateTime'] != null ? DateTime.parse(map['CreateTime']) : null,
			updateTime: map['UpdateTime'] != null ? DateTime.parse(map['UpdateTime']) : null,
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		if (key != null)
			map['Key'] = key;
		if (templateName != null)
			map['TemplateName'] = templateName;
		if (templateContent != null)
			map['TemplateContent'] = templateContent;
		if (provinceCode != null)
			map['ProvinceCode'] = provinceCode;
		if (cityCode != null)
			map['CityCode'] = cityCode;
		if (districtCode != null)
			map['DistrictCode'] = districtCode;
		if (townCode != null)
			map['TownCode'] = townCode;
		if (townName != null)
			map['TownName'] = townName;
		return map;
	}
}

class GetContractTemplateRequest extends TokenRequest{
	String? code;

	GetContractTemplateRequest({
		this.code,
		String? token,
	}) : super(
			token: token,
		);

	factory GetContractTemplateRequest.fromJson(Map<String, dynamic> map) {
		return GetContractTemplateRequest( 
			code: map['Code'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		return map;
	}
}

class GetContractTemplateByKeyRequest extends TokenRequest{
	String? key;
	String? value;

	GetContractTemplateByKeyRequest({
		this.key,
		this.value,
		String? token,
	}) : super(
			token: token,
		);

	factory GetContractTemplateByKeyRequest.fromJson(Map<String, dynamic> map) {
		return GetContractTemplateByKeyRequest( 
			key: map['Key'],
			value: map['Value'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (key != null)
			map['Key'] = key;
		if (value != null)
			map['Value'] = value;
		return map;
	}
}

class ContractTemplatePageRequest extends PageRequest{
	String? keyword;
	DateTime? startTime;
	DateTime? endTime;

	ContractTemplatePageRequest({
		this.keyword,
		this.startTime,
		this.endTime,
		int pageIndex = 0,
		int pageSize = 0,
		String? token,
	}) : super(
			pageIndex: pageIndex,
			pageSize: pageSize,
			token: token,
		);

	factory ContractTemplatePageRequest.fromJson(Map<String, dynamic> map) {
		return ContractTemplatePageRequest( 
			keyword: map['Keyword'],
			startTime: map['StartTime'] != null ? DateTime.parse(map['StartTime']) : null,
			endTime: map['EndTime'] != null ? DateTime.parse(map['EndTime']) : null,
			pageIndex: map['PageIndex'],
			pageSize: map['PageSize'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (keyword != null)
			map['Keyword'] = keyword;
		if (startTime != null)
			map['StartTime'] = JsonRpcUtils.dateFormat(startTime!);
		if (endTime != null)
			map['EndTime'] = JsonRpcUtils.dateFormat(endTime!);
		return map;
	}
}

class RemoveContractTemplateRequest extends TokenRequest{
	String? code;

	RemoveContractTemplateRequest({
		this.code,
		String? token,
	}) : super(
			token: token,
		);

	factory RemoveContractTemplateRequest.fromJson(Map<String, dynamic> map) {
		return RemoveContractTemplateRequest( 
			code: map['Code'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		return map;
	}
}

class GetContractTemplateListRequest extends TokenRequest{
	List<String>? codes;

	GetContractTemplateListRequest({
		this.codes,
		String? token,
	}) : super(
			token: token,
		);

	factory GetContractTemplateListRequest.fromJson(Map<String, dynamic> map) {
		return GetContractTemplateListRequest( 
			codes: map['Codes']?.cast<String>().toList(),
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (codes != null)
			map['Codes'] = codes;
		return map;
	}
}

class UpdateContractTemplateRequest extends TokenRequest{
	String? code;
	String? key;
	String? templateName;
	String? templateContent;
	String? provinceCode;
	String? cityCode;
	String? districtCode;
	String? townCode;

	UpdateContractTemplateRequest({
		this.code,
		this.key,
		this.templateName,
		this.templateContent,
		this.provinceCode,
		this.cityCode,
		this.districtCode,
		this.townCode,
		String? token,
	}) : super(
			token: token,
		);

	factory UpdateContractTemplateRequest.fromJson(Map<String, dynamic> map) {
		return UpdateContractTemplateRequest( 
			code: map['Code'],
			key: map['Key'],
			templateName: map['TemplateName'],
			templateContent: map['TemplateContent'],
			provinceCode: map['ProvinceCode'],
			cityCode: map['CityCode'],
			districtCode: map['DistrictCode'],
			townCode: map['TownCode'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		if (key != null)
			map['Key'] = key;
		if (templateName != null)
			map['TemplateName'] = templateName;
		if (templateContent != null)
			map['TemplateContent'] = templateContent;
		if (provinceCode != null)
			map['ProvinceCode'] = provinceCode;
		if (cityCode != null)
			map['CityCode'] = cityCode;
		if (districtCode != null)
			map['DistrictCode'] = districtCode;
		if (townCode != null)
			map['TownCode'] = townCode;
		return map;
	}
}


