import 'dart:core';

import 'package:fis_jsonrpc/client_base.dart';
import 'package:fis_common/json_convert.dart';

import 'vitalDevice.m.dart';

import 'liveConsultation.m.dart';
import 'researchEdition.m.dart';


class VitalDeviceService extends JsonRpcClientBase {
	VitalDeviceService(
		String host, {
		String serviceName = "IVitalDeviceService",
		Map<String, String>? headers,
		int? timeout,
	}) : super(
						host,
						serviceName,
						headers: headers,
						timeout: timeout,
				) {
		/// 注册响应实体反序列化处理器
		FJsonConvert.setDecoder((map) => DeviceDTO.fromJson(map));
		FJsonConvert.setDecoder((map) => DeviceInfoDTO.fromJson(map));
		FJsonConvert.setDecoder((map) => PageCollection<DeviceDTO>.fromJson(map));
	}

	Future<String> createDeviceAsync(CreateDeviceRequest2 request) async {
		var rpcRst = await call("CreateDeviceAsync", request);
		return rpcRst;
	}

	Future<DeviceDTO> getDeviceDetailAsync(GetDeviceRequest2 request) async {
		var rpcRst = await call("GetDeviceDetailAsync", request);
		var result = DeviceDTO.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<DeviceInfoDTO> getUltrasoundByCodeAsync(GetUltrasoundByCodeRequest request) async {
		var rpcRst = await call("GetUltrasoundByCodeAsync", request);
		var result = DeviceInfoDTO.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<DeviceInfoDTO> getUltrasoundByShortCodeAsync(GetUltrasoundByShortCodeRequest request) async {
		var rpcRst = await call("GetUltrasoundByShortCodeAsync", request);
		var result = DeviceInfoDTO.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<DeviceDTO> getDeviceDetailByUniqueCodeAsync(GetDeviceByUniqueCodeRequest request) async {
		var rpcRst = await call("GetDeviceDetailByUniqueCodeAsync", request);
		var result = DeviceDTO.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<DeviceDTO> getDeviceDetailBySerialNumberAsync(GetDeviceBySerialNumberRequest request) async {
		var rpcRst = await call("GetDeviceDetailBySerialNumberAsync", request);
		var result = DeviceDTO.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<bool> setDeviceOrganizationAsync(SetDeviceOrganizationRequest request) async {
		var rpcRst = await call("SetDeviceOrganizationAsync", request);
		return rpcRst;
	}

	Future<PageCollection<DeviceDTO>> getDevicePageAsync(DevicePageRequest request) async {
		var rpcRst = await call("GetDevicePageAsync", request);
		var result = PageCollection<DeviceDTO>.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<bool> removeDeviceAsync(RemoveDeviceRequest request) async {
		var rpcRst = await call("RemoveDeviceAsync", request);
		return rpcRst;
	}

	Future<bool> updateDeviceAsync(UpdateDeviceRequest2 request) async {
		var rpcRst = await call("UpdateDeviceAsync", request);
		return rpcRst;
	}

	Future<bool> reportingDeviceInfoAsync(ReportingDeviceInfoRequest request) async {
		var rpcRst = await call("ReportingDeviceInfoAsync", request);
		return rpcRst;
	}

	Future<bool> createPeripheralDeviceAsync(CreatePeripheralDeviceRequest request) async {
		var rpcRst = await call("CreatePeripheralDeviceAsync", request);
		return rpcRst;
	}

	Future<bool> removePeripheralDeviceAsync(RemovePeripheralDeviceRequest request) async {
		var rpcRst = await call("RemovePeripheralDeviceAsync", request);
		return rpcRst;
	}

	Future<List<String>> getEnablePeripheralDeviceKeysAsync(GetEnablePeripheralDeviceKeysRequest request) async {
		var rpcRst = await call("GetEnablePeripheralDeviceKeysAsync", request);
		var result = (rpcRst as List).cast<String>().toList();
		return result;
	}

}

