import 'researchEdition.m.dart';
import 'notification.m.dart';
import 'liveConsultation.m.dart';

import 'package:fis_jsonrpc/utils.dart';

class PeripheralDeviceDTO {
	String? code;
	String? key;
	String? name;
	bool enable;

	PeripheralDeviceDTO({
		this.code,
		this.key,
		this.name,
		this.enable = false,
	});

	factory PeripheralDeviceDTO.fromJson(Map<String, dynamic> map) {
		return PeripheralDeviceDTO( 
			code: map['Code'],
			key: map['Key'],
			name: map['Name'],
			enable: map['Enable'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		if (code != null)
			map['Code'] = code;
		if (key != null)
			map['Key'] = key;
		if (name != null)
			map['Name'] = name;
		map['Enable'] = enable;
		return map;
	}
}

class CreateDeviceRequest2 extends TokenRequest{
	String? code;
	String? serialNumber;
	String? model;
	String? softwareVersion;
	String? oSVersion;
	String? description;
	String? organizationCode;
	String? teamCode;
	List<PeripheralDeviceDTO>? peripheralPermissions;
	int deviceType;

	CreateDeviceRequest2({
		this.code,
		this.serialNumber,
		this.model,
		this.softwareVersion,
		this.oSVersion,
		this.description,
		this.organizationCode,
		this.teamCode,
		this.peripheralPermissions,
		this.deviceType = 0,
		String? token,
	}) : super(
			token: token,
		);

	factory CreateDeviceRequest2.fromJson(Map<String, dynamic> map) {
		return CreateDeviceRequest2( 
			code: map['Code'],
			serialNumber: map['SerialNumber'],
			model: map['Model'],
			softwareVersion: map['SoftwareVersion'],
			oSVersion: map['OSVersion'],
			description: map['Description'],
			organizationCode: map['OrganizationCode'],
			teamCode: map['TeamCode'],
			peripheralPermissions: map['PeripheralPermissions'] != null ? (map['PeripheralPermissions'] as List).map((e)=>PeripheralDeviceDTO.fromJson(e as Map<String,dynamic>)).toList() : null,
			deviceType: map['DeviceType'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		if (serialNumber != null)
			map['SerialNumber'] = serialNumber;
		if (model != null)
			map['Model'] = model;
		if (softwareVersion != null)
			map['SoftwareVersion'] = softwareVersion;
		if (oSVersion != null)
			map['OSVersion'] = oSVersion;
		if (description != null)
			map['Description'] = description;
		if (organizationCode != null)
			map['OrganizationCode'] = organizationCode;
		if (teamCode != null)
			map['TeamCode'] = teamCode;
		if (peripheralPermissions != null)
			map['PeripheralPermissions'] = peripheralPermissions;
		map['DeviceType'] = deviceType;
		return map;
	}
}

class DeviceDTO extends BaseDTO{
	String? code;
	String? uniqueCode;
	String? serialNumber;
	String? model;
	String? softwareVersion;
	String? oSVersion;
	String? description;
	String? organizationCode;
	String? organizationName;
	String? teamCode;
	String? teamName;
	List<PeripheralDeviceDTO>? peripheralPermissions;
	int deviceType;

	DeviceDTO({
		this.code,
		this.uniqueCode,
		this.serialNumber,
		this.model,
		this.softwareVersion,
		this.oSVersion,
		this.description,
		this.organizationCode,
		this.organizationName,
		this.teamCode,
		this.teamName,
		this.peripheralPermissions,
		this.deviceType = 0,
		bool isDelete = false,
		DateTime? createTime,
		DateTime? updateTime,
	}) : super(
			isDelete: isDelete,
			createTime: createTime,
			updateTime: updateTime,
		);

	factory DeviceDTO.fromJson(Map<String, dynamic> map) {
		return DeviceDTO( 
			code: map['Code'],
			uniqueCode: map['UniqueCode'],
			serialNumber: map['SerialNumber'],
			model: map['Model'],
			softwareVersion: map['SoftwareVersion'],
			oSVersion: map['OSVersion'],
			description: map['Description'],
			organizationCode: map['OrganizationCode'],
			organizationName: map['OrganizationName'],
			teamCode: map['TeamCode'],
			teamName: map['TeamName'],
			peripheralPermissions: map['PeripheralPermissions'] != null ? (map['PeripheralPermissions'] as List).map((e)=>PeripheralDeviceDTO.fromJson(e as Map<String,dynamic>)).toList() : null,
			deviceType: map['DeviceType'],
			isDelete: map['IsDelete'],
			createTime: map['CreateTime'] != null ? DateTime.parse(map['CreateTime']) : null,
			updateTime: map['UpdateTime'] != null ? DateTime.parse(map['UpdateTime']) : null,
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		if (uniqueCode != null)
			map['UniqueCode'] = uniqueCode;
		if (serialNumber != null)
			map['SerialNumber'] = serialNumber;
		if (model != null)
			map['Model'] = model;
		if (softwareVersion != null)
			map['SoftwareVersion'] = softwareVersion;
		if (oSVersion != null)
			map['OSVersion'] = oSVersion;
		if (description != null)
			map['Description'] = description;
		if (organizationCode != null)
			map['OrganizationCode'] = organizationCode;
		if (organizationName != null)
			map['OrganizationName'] = organizationName;
		if (teamCode != null)
			map['TeamCode'] = teamCode;
		if (teamName != null)
			map['TeamName'] = teamName;
		if (peripheralPermissions != null)
			map['PeripheralPermissions'] = peripheralPermissions;
		map['DeviceType'] = deviceType;
		return map;
	}
}

class GetDeviceRequest2 extends TokenRequest{
	String? code;

	GetDeviceRequest2({
		this.code,
		String? token,
	}) : super(
			token: token,
		);

	factory GetDeviceRequest2.fromJson(Map<String, dynamic> map) {
		return GetDeviceRequest2( 
			code: map['Code'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		return map;
	}
}

class GetUltrasoundByCodeRequest extends TokenRequest{
	String? code;

	GetUltrasoundByCodeRequest({
		this.code,
		String? token,
	}) : super(
			token: token,
		);

	factory GetUltrasoundByCodeRequest.fromJson(Map<String, dynamic> map) {
		return GetUltrasoundByCodeRequest( 
			code: map['Code'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		return map;
	}
}

class GetUltrasoundByShortCodeRequest extends TokenRequest{
	String? shortCode;

	GetUltrasoundByShortCodeRequest({
		this.shortCode,
		String? token,
	}) : super(
			token: token,
		);

	factory GetUltrasoundByShortCodeRequest.fromJson(Map<String, dynamic> map) {
		return GetUltrasoundByShortCodeRequest( 
			shortCode: map['ShortCode'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (shortCode != null)
			map['ShortCode'] = shortCode;
		return map;
	}
}

class GetDeviceByUniqueCodeRequest extends TokenRequest{
	String? uniqueCode;

	GetDeviceByUniqueCodeRequest({
		this.uniqueCode,
		String? token,
	}) : super(
			token: token,
		);

	factory GetDeviceByUniqueCodeRequest.fromJson(Map<String, dynamic> map) {
		return GetDeviceByUniqueCodeRequest( 
			uniqueCode: map['UniqueCode'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (uniqueCode != null)
			map['UniqueCode'] = uniqueCode;
		return map;
	}
}

class GetDeviceBySerialNumberRequest extends TokenRequest{
	String? uniqueCode;

	GetDeviceBySerialNumberRequest({
		this.uniqueCode,
		String? token,
	}) : super(
			token: token,
		);

	factory GetDeviceBySerialNumberRequest.fromJson(Map<String, dynamic> map) {
		return GetDeviceBySerialNumberRequest( 
			uniqueCode: map['UniqueCode'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (uniqueCode != null)
			map['UniqueCode'] = uniqueCode;
		return map;
	}
}

class SetDeviceOrganizationRequest extends TokenRequest{
	String? code;
	String? organizationCode;
	String? teamCode;

	SetDeviceOrganizationRequest({
		this.code,
		this.organizationCode,
		this.teamCode,
		String? token,
	}) : super(
			token: token,
		);

	factory SetDeviceOrganizationRequest.fromJson(Map<String, dynamic> map) {
		return SetDeviceOrganizationRequest( 
			code: map['Code'],
			organizationCode: map['OrganizationCode'],
			teamCode: map['TeamCode'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		if (organizationCode != null)
			map['OrganizationCode'] = organizationCode;
		if (teamCode != null)
			map['TeamCode'] = teamCode;
		return map;
	}
}

class DevicePageRequest extends PageRequest{
	String? keyword;
	DateTime? startTime;
	DateTime? endTime;
	int deviceType;
	String? topByDeviceCode;

	DevicePageRequest({
		this.keyword,
		this.startTime,
		this.endTime,
		this.deviceType = 0,
		this.topByDeviceCode,
		int pageIndex = 0,
		int pageSize = 0,
		String? token,
	}) : super(
			pageIndex: pageIndex,
			pageSize: pageSize,
			token: token,
		);

	factory DevicePageRequest.fromJson(Map<String, dynamic> map) {
		return DevicePageRequest( 
			keyword: map['Keyword'],
			startTime: map['StartTime'] != null ? DateTime.parse(map['StartTime']) : null,
			endTime: map['EndTime'] != null ? DateTime.parse(map['EndTime']) : null,
			deviceType: map['DeviceType'],
			topByDeviceCode: map['TopByDeviceCode'],
			pageIndex: map['PageIndex'],
			pageSize: map['PageSize'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (keyword != null)
			map['Keyword'] = keyword;
		if (startTime != null)
			map['StartTime'] = JsonRpcUtils.dateFormat(startTime!);
		if (endTime != null)
			map['EndTime'] = JsonRpcUtils.dateFormat(endTime!);
		map['DeviceType'] = deviceType;
		if (topByDeviceCode != null)
			map['TopByDeviceCode'] = topByDeviceCode;
		return map;
	}
}

class RemoveDeviceRequest extends TokenRequest{
	String? code;

	RemoveDeviceRequest({
		this.code,
		String? token,
	}) : super(
			token: token,
		);

	factory RemoveDeviceRequest.fromJson(Map<String, dynamic> map) {
		return RemoveDeviceRequest( 
			code: map['Code'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		return map;
	}
}

class UpdateDeviceRequest2 extends TokenRequest{
	String? code;
	String? model;
	String? softwareVersion;
	String? oSVersion;
	String? description;
	String? organizationCode;
	String? teamCode;

	UpdateDeviceRequest2({
		this.code,
		this.model,
		this.softwareVersion,
		this.oSVersion,
		this.description,
		this.organizationCode,
		this.teamCode,
		String? token,
	}) : super(
			token: token,
		);

	factory UpdateDeviceRequest2.fromJson(Map<String, dynamic> map) {
		return UpdateDeviceRequest2( 
			code: map['Code'],
			model: map['Model'],
			softwareVersion: map['SoftwareVersion'],
			oSVersion: map['OSVersion'],
			description: map['Description'],
			organizationCode: map['OrganizationCode'],
			teamCode: map['TeamCode'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		if (model != null)
			map['Model'] = model;
		if (softwareVersion != null)
			map['SoftwareVersion'] = softwareVersion;
		if (oSVersion != null)
			map['OSVersion'] = oSVersion;
		if (description != null)
			map['Description'] = description;
		if (organizationCode != null)
			map['OrganizationCode'] = organizationCode;
		if (teamCode != null)
			map['TeamCode'] = teamCode;
		return map;
	}
}

class ReportingDeviceInfoRequest extends TokenRequest{
	String? serialNumber;
	String? model;
	String? softwareVersion;
	String? oSVersion;

	ReportingDeviceInfoRequest({
		this.serialNumber,
		this.model,
		this.softwareVersion,
		this.oSVersion,
		String? token,
	}) : super(
			token: token,
		);

	factory ReportingDeviceInfoRequest.fromJson(Map<String, dynamic> map) {
		return ReportingDeviceInfoRequest( 
			serialNumber: map['SerialNumber'],
			model: map['Model'],
			softwareVersion: map['SoftwareVersion'],
			oSVersion: map['OSVersion'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (serialNumber != null)
			map['SerialNumber'] = serialNumber;
		if (model != null)
			map['Model'] = model;
		if (softwareVersion != null)
			map['SoftwareVersion'] = softwareVersion;
		if (oSVersion != null)
			map['OSVersion'] = oSVersion;
		return map;
	}
}

class CreatePeripheralDeviceRequest extends TokenRequest{
	String? deviceCode;
	String? key;
	String? name;
	bool enable;

	CreatePeripheralDeviceRequest({
		this.deviceCode,
		this.key,
		this.name,
		this.enable = false,
		String? token,
	}) : super(
			token: token,
		);

	factory CreatePeripheralDeviceRequest.fromJson(Map<String, dynamic> map) {
		return CreatePeripheralDeviceRequest( 
			deviceCode: map['DeviceCode'],
			key: map['Key'],
			name: map['Name'],
			enable: map['Enable'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (deviceCode != null)
			map['DeviceCode'] = deviceCode;
		if (key != null)
			map['Key'] = key;
		if (name != null)
			map['Name'] = name;
		map['Enable'] = enable;
		return map;
	}
}

class RemovePeripheralDeviceRequest extends TokenRequest{
	String? deviceCode;
	String? peripheralDeviceCode;

	RemovePeripheralDeviceRequest({
		this.deviceCode,
		this.peripheralDeviceCode,
		String? token,
	}) : super(
			token: token,
		);

	factory RemovePeripheralDeviceRequest.fromJson(Map<String, dynamic> map) {
		return RemovePeripheralDeviceRequest( 
			deviceCode: map['DeviceCode'],
			peripheralDeviceCode: map['PeripheralDeviceCode'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (deviceCode != null)
			map['DeviceCode'] = deviceCode;
		if (peripheralDeviceCode != null)
			map['PeripheralDeviceCode'] = peripheralDeviceCode;
		return map;
	}
}

class GetEnablePeripheralDeviceKeysRequest extends TokenRequest{
	String? deviceCode;

	GetEnablePeripheralDeviceKeysRequest({
		this.deviceCode,
		String? token,
	}) : super(
			token: token,
		);

	factory GetEnablePeripheralDeviceKeysRequest.fromJson(Map<String, dynamic> map) {
		return GetEnablePeripheralDeviceKeysRequest( 
			deviceCode: map['DeviceCode'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (deviceCode != null)
			map['DeviceCode'] = deviceCode;
		return map;
	}
}


