import 'dart:core';

import 'package:fis_jsonrpc/client_base.dart';
import 'package:fis_common/json_convert.dart';

import 'vitalDiagnosis.m.dart';

import 'researchEdition.m.dart';


class VitalDiagnosisService extends JsonRpcClientBase {
	VitalDiagnosisService(
		String host, {
		String serviceName = "IVitalDiagnosisService",
		Map<String, String>? headers,
		int? timeout,
	}) : super(
						host,
						serviceName,
						headers: headers,
						timeout: timeout,
				) {
		/// 注册响应实体反序列化处理器
		FJsonConvert.setDecoder((map) => DiagnosisDTO.fromJson(map));
		FJsonConvert.setDecoder((map) => PageCollection<DiagnosisDTO>.fromJson(map));
		FJsonConvert.setDecoder((map) => PageCollection<DiagnosisAggregationRecord>.fromJson(map));
		FJsonConvert.setDecoder((map) => DiagnosisAggregationRecord.fromJson(map));
	}

	Future<String> createDiagnosisAsync(CreateDiagnosisRequest request) async {
		var rpcRst = await call("CreateDiagnosisAsync", request);
		return rpcRst;
	}

	Future<DiagnosisDTO> getDiagnosisDetailAsync(GetDiagnosisRequest request) async {
		var rpcRst = await call("GetDiagnosisDetailAsync", request);
		var result = DiagnosisDTO.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<DiagnosisDTO> getDiagnosisDetailByKeyAsync(GetDiagnosisByKeyRequest request) async {
		var rpcRst = await call("GetDiagnosisDetailByKeyAsync", request);
		var result = DiagnosisDTO.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<PageCollection<DiagnosisDTO>> getDiagnosisPageAsync(DiagnosisPageRequest request) async {
		var rpcRst = await call("GetDiagnosisPageAsync", request);
		var result = PageCollection<DiagnosisDTO>.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<bool> removeDiagnosisAsync(RemoveDiagnosisRequest request) async {
		var rpcRst = await call("RemoveDiagnosisAsync", request);
		return rpcRst;
	}

	Future<List<DiagnosisDTO>> getDiagnosisListAsync(GetDiagnosisListRequest request) async {
		var rpcRst = await call("GetDiagnosisListAsync", request);
		var result = (rpcRst as List).map((e)=>DiagnosisDTO.fromJson(e as Map<String, dynamic>)).toList();
		return result;
	}

	Future<bool> updateDiagnosisAsync(UpdateDiagnosisRequest request) async {
		var rpcRst = await call("UpdateDiagnosisAsync", request);
		return rpcRst;
	}

	Future<PageCollection<DiagnosisAggregationRecord>> getDiagnosisAggregationPageAsync(DiagnosisPageRequest request) async {
		var rpcRst = await call("GetDiagnosisAggregationPageAsync", request);
		var result = PageCollection<DiagnosisAggregationRecord>.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<bool> submitDiagnosisAsync(SubmitDiagnosisRequest request) async {
		var rpcRst = await call("SubmitDiagnosisAsync", request);
		return rpcRst;
	}

	Future<bool> reinfusionDiagnosisAsync(ReinfusionDiagnosisRequest request) async {
		var rpcRst = await call("ReinfusionDiagnosisAsync", request);
		return rpcRst;
	}

	Future<bool> setDiagnosisTimeAsync(SetDiagnosisTimeRequest request) async {
		var rpcRst = await call("SetDiagnosisTimeAsync", request);
		return rpcRst;
	}

	Future<bool> syncPatientAndDiagnosisDataAsync(SyncPatientAndDiagnosisDataRequest request) async {
		var rpcRst = await call("SyncPatientAndDiagnosisDataAsync", request);
		return rpcRst;
	}

	Future<String> oldPlatformDiagnosisDataCountAsync(OldPlatformDiagnosisDataCountRequest request) async {
		var rpcRst = await call("OldPlatformDiagnosisDataCountAsync", request);
		return rpcRst;
	}

	Future<bool> removeDiagnosisByAppDataIdAsync(RemoveDiagnosisByAppDataIdRequest request) async {
		var rpcRst = await call("RemoveDiagnosisByAppDataIdAsync", request);
		return rpcRst;
	}

}

