import 'researchEdition.m.dart';
import 'notification.m.dart';
import 'exam.m.dart';

import 'package:fis_jsonrpc/utils.dart';

class CreateDiagnosisRequest extends TokenRequest{
	String? code;
	String? key;
	String? patientCode;
	String? doctorCode;
	String? diagnosisData;
	DateTime? diagnosisTime;
	String? appDataId;

	CreateDiagnosisRequest({
		this.code,
		this.key,
		this.patientCode,
		this.doctorCode,
		this.diagnosisData,
		this.diagnosisTime,
		this.appDataId,
		String? token,
	}) : super(
			token: token,
		);

	factory CreateDiagnosisRequest.fromJson(Map<String, dynamic> map) {
		return CreateDiagnosisRequest( 
			code: map['Code'],
			key: map['Key'],
			patientCode: map['PatientCode'],
			doctorCode: map['DoctorCode'],
			diagnosisData: map['DiagnosisData'],
			diagnosisTime: map['DiagnosisTime'] != null ? DateTime.parse(map['DiagnosisTime']) : null,
			appDataId: map['AppDataId'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		if (key != null)
			map['Key'] = key;
		if (patientCode != null)
			map['PatientCode'] = patientCode;
		if (doctorCode != null)
			map['DoctorCode'] = doctorCode;
		if (diagnosisData != null)
			map['DiagnosisData'] = diagnosisData;
		if (diagnosisTime != null)
			map['DiagnosisTime'] = JsonRpcUtils.dateFormat(diagnosisTime!);
		if (appDataId != null)
			map['AppDataId'] = appDataId;
		return map;
	}
}

class DiagnosisDTO extends BaseDTO{
	String? code;
	String? key;
	String? patientCode;
	String? doctorCode;
	String? diagnosisData;
	DateTime? diagnosisTime;
	String? doctorName;
	String? patientName;
	GenderEnum patientGender;
	String? phone;
	String? cardNo;
	DateTime? birthday;
	String? patientAddress;
	List<String>? crowdLabels;
	List<String>? labelNames;
	String? organizationName;
	String? appDataId;
	String? national;
	String? physicalExamNumber;
	String? examCode;

	DiagnosisDTO({
		this.code,
		this.key,
		this.patientCode,
		this.doctorCode,
		this.diagnosisData,
		this.diagnosisTime,
		this.doctorName,
		this.patientName,
		this.patientGender = GenderEnum.Unknown,
		this.phone,
		this.cardNo,
		this.birthday,
		this.patientAddress,
		this.crowdLabels,
		this.labelNames,
		this.organizationName,
		this.appDataId,
		this.national,
		this.physicalExamNumber,
		this.examCode,
		bool isDelete = false,
		DateTime? createTime,
		DateTime? updateTime,
	}) : super(
			isDelete: isDelete,
			createTime: createTime,
			updateTime: updateTime,
		);

	factory DiagnosisDTO.fromJson(Map<String, dynamic> map) {
		return DiagnosisDTO( 
			code: map['Code'],
			key: map['Key'],
			patientCode: map['PatientCode'],
			doctorCode: map['DoctorCode'],
			diagnosisData: map['DiagnosisData'],
			diagnosisTime: map['DiagnosisTime'] != null ? DateTime.parse(map['DiagnosisTime']) : null,
			doctorName: map['DoctorName'],
			patientName: map['PatientName'],
			patientGender: GenderEnum.values.firstWhere((e) => e.index == map['PatientGender']),
			phone: map['Phone'],
			cardNo: map['CardNo'],
			birthday: map['Birthday'] != null ? DateTime.parse(map['Birthday']) : null,
			patientAddress: map['PatientAddress'],
			crowdLabels: map['CrowdLabels']?.cast<String>().toList(),
			labelNames: map['LabelNames']?.cast<String>().toList(),
			organizationName: map['OrganizationName'],
			appDataId: map['AppDataId'],
			national: map['National'],
			physicalExamNumber: map['PhysicalExamNumber'],
			examCode: map['ExamCode'],
			isDelete: map['IsDelete'],
			createTime: map['CreateTime'] != null ? DateTime.parse(map['CreateTime']) : null,
			updateTime: map['UpdateTime'] != null ? DateTime.parse(map['UpdateTime']) : null,
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		if (key != null)
			map['Key'] = key;
		if (patientCode != null)
			map['PatientCode'] = patientCode;
		if (doctorCode != null)
			map['DoctorCode'] = doctorCode;
		if (diagnosisData != null)
			map['DiagnosisData'] = diagnosisData;
		if (diagnosisTime != null)
			map['DiagnosisTime'] = JsonRpcUtils.dateFormat(diagnosisTime!);
		if (doctorName != null)
			map['DoctorName'] = doctorName;
		if (patientName != null)
			map['PatientName'] = patientName;
		map['PatientGender'] = patientGender.index;
		if (phone != null)
			map['Phone'] = phone;
		if (cardNo != null)
			map['CardNo'] = cardNo;
		if (birthday != null)
			map['Birthday'] = JsonRpcUtils.dateFormat(birthday!);
		if (patientAddress != null)
			map['PatientAddress'] = patientAddress;
		if (crowdLabels != null)
			map['CrowdLabels'] = crowdLabels;
		if (labelNames != null)
			map['LabelNames'] = labelNames;
		if (organizationName != null)
			map['OrganizationName'] = organizationName;
		if (appDataId != null)
			map['AppDataId'] = appDataId;
		if (national != null)
			map['National'] = national;
		if (physicalExamNumber != null)
			map['PhysicalExamNumber'] = physicalExamNumber;
		if (examCode != null)
			map['ExamCode'] = examCode;
		return map;
	}
}

class GetDiagnosisRequest extends TokenRequest{
	String? code;

	GetDiagnosisRequest({
		this.code,
		String? token,
	}) : super(
			token: token,
		);

	factory GetDiagnosisRequest.fromJson(Map<String, dynamic> map) {
		return GetDiagnosisRequest( 
			code: map['Code'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		return map;
	}
}

class GetDiagnosisByKeyRequest extends TokenRequest{
	String? key;
	String? value;

	GetDiagnosisByKeyRequest({
		this.key,
		this.value,
		String? token,
	}) : super(
			token: token,
		);

	factory GetDiagnosisByKeyRequest.fromJson(Map<String, dynamic> map) {
		return GetDiagnosisByKeyRequest( 
			key: map['Key'],
			value: map['Value'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (key != null)
			map['Key'] = key;
		if (value != null)
			map['Value'] = value;
		return map;
	}
}

class DiagnosisPageRequest extends PageRequest{
	String? appDataId;
	String? cardNo;
	String? patientCode;
	String? keyword;
	DateTime? startTime;
	DateTime? endTime;

	DiagnosisPageRequest({
		this.appDataId,
		this.cardNo,
		this.patientCode,
		this.keyword,
		this.startTime,
		this.endTime,
		int pageIndex = 0,
		int pageSize = 0,
		String? token,
	}) : super(
			pageIndex: pageIndex,
			pageSize: pageSize,
			token: token,
		);

	factory DiagnosisPageRequest.fromJson(Map<String, dynamic> map) {
		return DiagnosisPageRequest( 
			appDataId: map['AppDataId'],
			cardNo: map['CardNo'],
			patientCode: map['PatientCode'],
			keyword: map['Keyword'],
			startTime: map['StartTime'] != null ? DateTime.parse(map['StartTime']) : null,
			endTime: map['EndTime'] != null ? DateTime.parse(map['EndTime']) : null,
			pageIndex: map['PageIndex'],
			pageSize: map['PageSize'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (appDataId != null)
			map['AppDataId'] = appDataId;
		if (cardNo != null)
			map['CardNo'] = cardNo;
		if (patientCode != null)
			map['PatientCode'] = patientCode;
		if (keyword != null)
			map['Keyword'] = keyword;
		if (startTime != null)
			map['StartTime'] = JsonRpcUtils.dateFormat(startTime!);
		if (endTime != null)
			map['EndTime'] = JsonRpcUtils.dateFormat(endTime!);
		return map;
	}
}

class RemoveDiagnosisRequest extends TokenRequest{
	String? code;

	RemoveDiagnosisRequest({
		this.code,
		String? token,
	}) : super(
			token: token,
		);

	factory RemoveDiagnosisRequest.fromJson(Map<String, dynamic> map) {
		return RemoveDiagnosisRequest( 
			code: map['Code'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		return map;
	}
}

class GetDiagnosisListRequest extends TokenRequest{
	List<String>? codes;

	GetDiagnosisListRequest({
		this.codes,
		String? token,
	}) : super(
			token: token,
		);

	factory GetDiagnosisListRequest.fromJson(Map<String, dynamic> map) {
		return GetDiagnosisListRequest( 
			codes: map['Codes']?.cast<String>().toList(),
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (codes != null)
			map['Codes'] = codes;
		return map;
	}
}

class UpdateDiagnosisRequest extends TokenRequest{
	String? code;
	String? key;
	String? patientCode;
	String? doctorCode;
	String? diagnosisData;
	DateTime? diagnosisTime;
	String? appDataId;

	UpdateDiagnosisRequest({
		this.code,
		this.key,
		this.patientCode,
		this.doctorCode,
		this.diagnosisData,
		this.diagnosisTime,
		this.appDataId,
		String? token,
	}) : super(
			token: token,
		);

	factory UpdateDiagnosisRequest.fromJson(Map<String, dynamic> map) {
		return UpdateDiagnosisRequest( 
			code: map['Code'],
			key: map['Key'],
			patientCode: map['PatientCode'],
			doctorCode: map['DoctorCode'],
			diagnosisData: map['DiagnosisData'],
			diagnosisTime: map['DiagnosisTime'] != null ? DateTime.parse(map['DiagnosisTime']) : null,
			appDataId: map['AppDataId'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		if (key != null)
			map['Key'] = key;
		if (patientCode != null)
			map['PatientCode'] = patientCode;
		if (doctorCode != null)
			map['DoctorCode'] = doctorCode;
		if (diagnosisData != null)
			map['DiagnosisData'] = diagnosisData;
		if (diagnosisTime != null)
			map['DiagnosisTime'] = JsonRpcUtils.dateFormat(diagnosisTime!);
		if (appDataId != null)
			map['AppDataId'] = appDataId;
		return map;
	}
}

class DiagnosisAggregationData {
	String? key;
	String? diagnosisData;

	DiagnosisAggregationData({
		this.key,
		this.diagnosisData,
	});

	factory DiagnosisAggregationData.fromJson(Map<String, dynamic> map) {
		return DiagnosisAggregationData( 
			key: map['Key'],
			diagnosisData: map['DiagnosisData'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		if (key != null)
			map['Key'] = key;
		if (diagnosisData != null)
			map['DiagnosisData'] = diagnosisData;
		return map;
	}
}

class DiagnosisAggregationRecord {
	String? patientCode;
	String? doctorCode;
	String? doctorName;
	String? patientName;
	GenderEnum patientGender;
	String? phone;
	String? cardNo;
	DateTime? birthday;
	String? patientAddress;
	List<String>? crowdLabels;
	String? organizationName;
	String? appDataId;
	DateTime? diagnosisTime;
	DateTime? updateTime;
	DateTime? registTime;
	List<DiagnosisAggregationData>? diagnosisAggregationData;
	String? national;

	DiagnosisAggregationRecord({
		this.patientCode,
		this.doctorCode,
		this.doctorName,
		this.patientName,
		this.patientGender = GenderEnum.Unknown,
		this.phone,
		this.cardNo,
		this.birthday,
		this.patientAddress,
		this.crowdLabels,
		this.organizationName,
		this.appDataId,
		this.diagnosisTime,
		this.updateTime,
		this.registTime,
		this.diagnosisAggregationData,
		this.national,
	});

	factory DiagnosisAggregationRecord.fromJson(Map<String, dynamic> map) {
		return DiagnosisAggregationRecord( 
			patientCode: map['PatientCode'],
			doctorCode: map['DoctorCode'],
			doctorName: map['DoctorName'],
			patientName: map['PatientName'],
			patientGender: GenderEnum.values.firstWhere((e) => e.index == map['PatientGender']),
			phone: map['Phone'],
			cardNo: map['CardNo'],
			birthday: map['Birthday'] != null ? DateTime.parse(map['Birthday']) : null,
			patientAddress: map['PatientAddress'],
			crowdLabels: map['CrowdLabels']?.cast<String>().toList(),
			organizationName: map['OrganizationName'],
			appDataId: map['AppDataId'],
			diagnosisTime: map['DiagnosisTime'] != null ? DateTime.parse(map['DiagnosisTime']) : null,
			updateTime: map['UpdateTime'] != null ? DateTime.parse(map['UpdateTime']) : null,
			registTime: map['RegistTime'] != null ? DateTime.parse(map['RegistTime']) : null,
			diagnosisAggregationData: map['DiagnosisAggregationData'] != null ? (map['DiagnosisAggregationData'] as List).map((e)=>DiagnosisAggregationData.fromJson(e as Map<String,dynamic>)).toList() : null,
			national: map['National'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		if (patientCode != null)
			map['PatientCode'] = patientCode;
		if (doctorCode != null)
			map['DoctorCode'] = doctorCode;
		if (doctorName != null)
			map['DoctorName'] = doctorName;
		if (patientName != null)
			map['PatientName'] = patientName;
		map['PatientGender'] = patientGender.index;
		if (phone != null)
			map['Phone'] = phone;
		if (cardNo != null)
			map['CardNo'] = cardNo;
		if (birthday != null)
			map['Birthday'] = JsonRpcUtils.dateFormat(birthday!);
		if (patientAddress != null)
			map['PatientAddress'] = patientAddress;
		if (crowdLabels != null)
			map['CrowdLabels'] = crowdLabels;
		if (organizationName != null)
			map['OrganizationName'] = organizationName;
		if (appDataId != null)
			map['AppDataId'] = appDataId;
		if (diagnosisTime != null)
			map['DiagnosisTime'] = JsonRpcUtils.dateFormat(diagnosisTime!);
		if (updateTime != null)
			map['UpdateTime'] = JsonRpcUtils.dateFormat(updateTime!);
		if (registTime != null)
			map['RegistTime'] = JsonRpcUtils.dateFormat(registTime!);
		if (diagnosisAggregationData != null)
			map['DiagnosisAggregationData'] = diagnosisAggregationData;
		if (national != null)
			map['National'] = national;
		return map;
	}
}

class DiagnosisItem {
	String? key;
	String? diagnosisData;

	DiagnosisItem({
		this.key,
		this.diagnosisData,
	});

	factory DiagnosisItem.fromJson(Map<String, dynamic> map) {
		return DiagnosisItem( 
			key: map['Key'],
			diagnosisData: map['DiagnosisData'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		if (key != null)
			map['Key'] = key;
		if (diagnosisData != null)
			map['DiagnosisData'] = diagnosisData;
		return map;
	}
}

class SubmitDiagnosisRequest extends TokenRequest{
	String? appDataId;
	DateTime? diagnosisTime;
	String? patientCode;
	String? doctorCode;
	List<DiagnosisItem>? diagnosisItems;

	SubmitDiagnosisRequest({
		this.appDataId,
		this.diagnosisTime,
		this.patientCode,
		this.doctorCode,
		this.diagnosisItems,
		String? token,
	}) : super(
			token: token,
		);

	factory SubmitDiagnosisRequest.fromJson(Map<String, dynamic> map) {
		return SubmitDiagnosisRequest( 
			appDataId: map['AppDataId'],
			diagnosisTime: map['DiagnosisTime'] != null ? DateTime.parse(map['DiagnosisTime']) : null,
			patientCode: map['PatientCode'],
			doctorCode: map['DoctorCode'],
			diagnosisItems: map['DiagnosisItems'] != null ? (map['DiagnosisItems'] as List).map((e)=>DiagnosisItem.fromJson(e as Map<String,dynamic>)).toList() : null,
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (appDataId != null)
			map['AppDataId'] = appDataId;
		if (diagnosisTime != null)
			map['DiagnosisTime'] = JsonRpcUtils.dateFormat(diagnosisTime!);
		if (patientCode != null)
			map['PatientCode'] = patientCode;
		if (doctorCode != null)
			map['DoctorCode'] = doctorCode;
		if (diagnosisItems != null)
			map['DiagnosisItems'] = diagnosisItems;
		return map;
	}
}

class ReinfusionDiagnosisRequest extends TokenRequest{
	String? appDataId;

	ReinfusionDiagnosisRequest({
		this.appDataId,
		String? token,
	}) : super(
			token: token,
		);

	factory ReinfusionDiagnosisRequest.fromJson(Map<String, dynamic> map) {
		return ReinfusionDiagnosisRequest( 
			appDataId: map['AppDataId'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (appDataId != null)
			map['AppDataId'] = appDataId;
		return map;
	}
}

class SetDiagnosisTimeRequest extends TokenRequest{
	String? appDataId;
	DateTime? diagnosisTime;

	SetDiagnosisTimeRequest({
		this.appDataId,
		this.diagnosisTime,
		String? token,
	}) : super(
			token: token,
		);

	factory SetDiagnosisTimeRequest.fromJson(Map<String, dynamic> map) {
		return SetDiagnosisTimeRequest( 
			appDataId: map['AppDataId'],
			diagnosisTime: map['DiagnosisTime'] != null ? DateTime.parse(map['DiagnosisTime']) : null,
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (appDataId != null)
			map['AppDataId'] = appDataId;
		if (diagnosisTime != null)
			map['DiagnosisTime'] = JsonRpcUtils.dateFormat(diagnosisTime!);
		return map;
	}
}

enum CardTypeEnum {
	Identity,
	SocialInsurance,
	Passport,
}

class SyncPatientAndDiagnosisDataRequest extends TokenRequest{
	String? patientCode;
	String? patientName;
	String? phone;
	String? cardNo;
	String? nationality;
	DateTime? birthday;
	List<String>? crowdLabels;
	CardTypeEnum cardType;
	GenderEnum patientGender;
	String? patientAddress;
	String? permanentResidenceAddress;
	String? contractedDoctor;
	String? appDataId;
	DateTime? diagnosisTime;
	String? doctorCode;
	List<DiagnosisItem>? diagnosisItems;

	SyncPatientAndDiagnosisDataRequest({
		this.patientCode,
		this.patientName,
		this.phone,
		this.cardNo,
		this.nationality,
		this.birthday,
		this.crowdLabels,
		this.cardType = CardTypeEnum.Identity,
		this.patientGender = GenderEnum.Unknown,
		this.patientAddress,
		this.permanentResidenceAddress,
		this.contractedDoctor,
		this.appDataId,
		this.diagnosisTime,
		this.doctorCode,
		this.diagnosisItems,
		String? token,
	}) : super(
			token: token,
		);

	factory SyncPatientAndDiagnosisDataRequest.fromJson(Map<String, dynamic> map) {
		return SyncPatientAndDiagnosisDataRequest( 
			patientCode: map['PatientCode'],
			patientName: map['PatientName'],
			phone: map['Phone'],
			cardNo: map['CardNo'],
			nationality: map['Nationality'],
			birthday: map['Birthday'] != null ? DateTime.parse(map['Birthday']) : null,
			crowdLabels: map['CrowdLabels']?.cast<String>().toList(),
			cardType: CardTypeEnum.values.firstWhere((e) => e.index == map['CardType']),
			patientGender: GenderEnum.values.firstWhere((e) => e.index == map['PatientGender']),
			patientAddress: map['PatientAddress'],
			permanentResidenceAddress: map['PermanentResidenceAddress'],
			contractedDoctor: map['ContractedDoctor'],
			appDataId: map['AppDataId'],
			diagnosisTime: map['DiagnosisTime'] != null ? DateTime.parse(map['DiagnosisTime']) : null,
			doctorCode: map['DoctorCode'],
			diagnosisItems: map['DiagnosisItems'] != null ? (map['DiagnosisItems'] as List).map((e)=>DiagnosisItem.fromJson(e as Map<String,dynamic>)).toList() : null,
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (patientCode != null)
			map['PatientCode'] = patientCode;
		if (patientName != null)
			map['PatientName'] = patientName;
		if (phone != null)
			map['Phone'] = phone;
		if (cardNo != null)
			map['CardNo'] = cardNo;
		if (nationality != null)
			map['Nationality'] = nationality;
		if (birthday != null)
			map['Birthday'] = JsonRpcUtils.dateFormat(birthday!);
		if (crowdLabels != null)
			map['CrowdLabels'] = crowdLabels;
		map['CardType'] = cardType.index;
		map['PatientGender'] = patientGender.index;
		if (patientAddress != null)
			map['PatientAddress'] = patientAddress;
		if (permanentResidenceAddress != null)
			map['PermanentResidenceAddress'] = permanentResidenceAddress;
		if (contractedDoctor != null)
			map['ContractedDoctor'] = contractedDoctor;
		if (appDataId != null)
			map['AppDataId'] = appDataId;
		if (diagnosisTime != null)
			map['DiagnosisTime'] = JsonRpcUtils.dateFormat(diagnosisTime!);
		if (doctorCode != null)
			map['DoctorCode'] = doctorCode;
		if (diagnosisItems != null)
			map['DiagnosisItems'] = diagnosisItems;
		return map;
	}
}

class OldPlatformDiagnosisDataCountRequest extends TokenRequest{

	OldPlatformDiagnosisDataCountRequest({
		String? token,
	}) : super(
			token: token,
		);

	factory OldPlatformDiagnosisDataCountRequest.fromJson(Map<String, dynamic> map) {
		return OldPlatformDiagnosisDataCountRequest( 
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		return map;
	}
}

class RemoveDiagnosisByAppDataIdRequest extends TokenRequest{
	String? appDataId;

	RemoveDiagnosisByAppDataIdRequest({
		this.appDataId,
		String? token,
	}) : super(
			token: token,
		);

	factory RemoveDiagnosisByAppDataIdRequest.fromJson(Map<String, dynamic> map) {
		return RemoveDiagnosisByAppDataIdRequest( 
			appDataId: map['AppDataId'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (appDataId != null)
			map['AppDataId'] = appDataId;
		return map;
	}
}


