import 'dart:core';

import 'package:fis_jsonrpc/client_base.dart';
import 'package:fis_common/json_convert.dart';

import 'vitalDictionary.m.dart';

import 'researchEdition.m.dart';


class VitalDictionaryService extends JsonRpcClientBase {
	VitalDictionaryService(
		String host, {
		String serviceName = "IVitalDictionaryService",
		Map<String, String>? headers,
		int? timeout,
	}) : super(
						host,
						serviceName,
						headers: headers,
						timeout: timeout,
				) {
		/// 注册响应实体反序列化处理器
		FJsonConvert.setDecoder((map) => DictionaryDTO2.fromJson(map));
		FJsonConvert.setDecoder((map) => PageCollection<DictionaryDTO2>.fromJson(map));
		FJsonConvert.setDecoder((map) => DictionaryWithUnitDTO.fromJson(map));
	}

	Future<String> createDictionaryAsync(CreateDictionaryRequest request) async {
		var rpcRst = await call("CreateDictionaryAsync", request);
		return rpcRst;
	}

	Future<DictionaryDTO2> getDictionaryDetailAsync(GetDictionaryRequest request) async {
		var rpcRst = await call("GetDictionaryDetailAsync", request);
		var result = DictionaryDTO2.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<DictionaryDTO2> getDictionaryDetailByKeyAsync(GetDictionaryByKeyRequest request) async {
		var rpcRst = await call("GetDictionaryDetailByKeyAsync", request);
		var result = DictionaryDTO2.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<PageCollection<DictionaryDTO2>> getDictionaryPageAsync(DictionaryPageRequest request) async {
		var rpcRst = await call("GetDictionaryPageAsync", request);
		var result = PageCollection<DictionaryDTO2>.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<bool> removeDictionaryAsync(RemoveDictionaryRequest request) async {
		var rpcRst = await call("RemoveDictionaryAsync", request);
		return rpcRst;
	}

	Future<List<DictionaryDTO2>> getDictionaryListAsync(GetDictionaryListRequest request) async {
		var rpcRst = await call("GetDictionaryListAsync", request);
		var result = (rpcRst as List).map((e)=>DictionaryDTO2.fromJson(e as Map<String, dynamic>)).toList();
		return result;
	}

	Future<bool> updateDictionaryAsync(UpdateDictionaryRequest request) async {
		var rpcRst = await call("UpdateDictionaryAsync", request);
		return rpcRst;
	}

	Future<List<DictionaryWithUnitDTO>> getDictionaryNameAndUnitByKeysAsync(GetDictionaryNameAndUnitByKeysRequest request) async {
		var rpcRst = await call("GetDictionaryNameAndUnitByKeysAsync", request);
		var result = (rpcRst as List).map((e)=>DictionaryWithUnitDTO.fromJson(e as Map<String, dynamic>)).toList();
		return result;
	}

}

