import 'dart:core';

import 'package:fis_jsonrpc/client_base.dart';
import 'package:fis_common/json_convert.dart';

import 'vitalDynamicType.m.dart';

import 'researchEdition.m.dart';


class VitalDynamicTypeService extends JsonRpcClientBase {
	VitalDynamicTypeService(
		String host, {
		String serviceName = "IVitalDynamicTypeService",
		Map<String, String>? headers,
		int? timeout,
	}) : super(
						host,
						serviceName,
						headers: headers,
						timeout: timeout,
				) {
		/// 注册响应实体反序列化处理器
		FJsonConvert.setDecoder((map) => DynamicTypeDTO.fromJson(map));
		FJsonConvert.setDecoder((map) => PageCollection<DynamicTypeDTO>.fromJson(map));
	}

	Future<String> createDynamicTypeAsync(CreateDynamicTypeRequest request) async {
		var rpcRst = await call("CreateDynamicTypeAsync", request);
		return rpcRst;
	}

	Future<DynamicTypeDTO> getDynamicTypeDetailAsync(GetDynamicTypeRequest request) async {
		var rpcRst = await call("GetDynamicTypeDetailAsync", request);
		var result = DynamicTypeDTO.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<DynamicTypeDTO> getDynamicTypeDetailByKeyAsync(GetDynamicTypeByKeyRequest request) async {
		var rpcRst = await call("GetDynamicTypeDetailByKeyAsync", request);
		var result = DynamicTypeDTO.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<PageCollection<DynamicTypeDTO>> getDynamicTypePageAsync(DynamicTypePageRequest request) async {
		var rpcRst = await call("GetDynamicTypePageAsync", request);
		var result = PageCollection<DynamicTypeDTO>.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<bool> removeDynamicTypeAsync(RemoveDynamicTypeRequest request) async {
		var rpcRst = await call("RemoveDynamicTypeAsync", request);
		return rpcRst;
	}

	Future<List<DynamicTypeDTO>> getDynamicTypeListAsync(GetDynamicTypeListRequest request) async {
		var rpcRst = await call("GetDynamicTypeListAsync", request);
		var result = (rpcRst as List).map((e)=>DynamicTypeDTO.fromJson(e as Map<String, dynamic>)).toList();
		return result;
	}

	Future<bool> updateDynamicTypeAsync(UpdateDynamicTypeRequest request) async {
		var rpcRst = await call("UpdateDynamicTypeAsync", request);
		return rpcRst;
	}

	Future<List<DynamicTypeDTO>> getDynamicTypeListByKeyAsync(GetDynamicTypeListByKeyRequest request) async {
		var rpcRst = await call("GetDynamicTypeListByKeyAsync", request);
		var result = (rpcRst as List).map((e)=>DynamicTypeDTO.fromJson(e as Map<String, dynamic>)).toList();
		return result;
	}

}

