import 'researchEdition.m.dart';
import 'notification.m.dart';

import 'package:fis_jsonrpc/utils.dart';

class CreateDynamicTypeRequest extends TokenRequest{
	String? code;
	String? typeName;
	String? typeKey;

	CreateDynamicTypeRequest({
		this.code,
		this.typeName,
		this.typeKey,
		String? token,
	}) : super(
			token: token,
		);

	factory CreateDynamicTypeRequest.fromJson(Map<String, dynamic> map) {
		return CreateDynamicTypeRequest( 
			code: map['Code'],
			typeName: map['TypeName'],
			typeKey: map['TypeKey'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		if (typeName != null)
			map['TypeName'] = typeName;
		if (typeKey != null)
			map['TypeKey'] = typeKey;
		return map;
	}
}

class DynamicTypeDTO extends BaseDTO{
	String? code;
	String? typeName;
	String? typeKey;

	DynamicTypeDTO({
		this.code,
		this.typeName,
		this.typeKey,
		bool isDelete = false,
		DateTime? createTime,
		DateTime? updateTime,
	}) : super(
			isDelete: isDelete,
			createTime: createTime,
			updateTime: updateTime,
		);

	factory DynamicTypeDTO.fromJson(Map<String, dynamic> map) {
		return DynamicTypeDTO( 
			code: map['Code'],
			typeName: map['TypeName'],
			typeKey: map['TypeKey'],
			isDelete: map['IsDelete'],
			createTime: map['CreateTime'] != null ? DateTime.parse(map['CreateTime']) : null,
			updateTime: map['UpdateTime'] != null ? DateTime.parse(map['UpdateTime']) : null,
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		if (typeName != null)
			map['TypeName'] = typeName;
		if (typeKey != null)
			map['TypeKey'] = typeKey;
		return map;
	}
}

class GetDynamicTypeRequest extends TokenRequest{
	String? code;

	GetDynamicTypeRequest({
		this.code,
		String? token,
	}) : super(
			token: token,
		);

	factory GetDynamicTypeRequest.fromJson(Map<String, dynamic> map) {
		return GetDynamicTypeRequest( 
			code: map['Code'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		return map;
	}
}

class GetDynamicTypeByKeyRequest extends TokenRequest{
	String? key;
	String? value;

	GetDynamicTypeByKeyRequest({
		this.key,
		this.value,
		String? token,
	}) : super(
			token: token,
		);

	factory GetDynamicTypeByKeyRequest.fromJson(Map<String, dynamic> map) {
		return GetDynamicTypeByKeyRequest( 
			key: map['Key'],
			value: map['Value'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (key != null)
			map['Key'] = key;
		if (value != null)
			map['Value'] = value;
		return map;
	}
}

class DynamicTypePageRequest extends PageRequest{
	String? keyword;
	DateTime? startTime;
	DateTime? endTime;

	DynamicTypePageRequest({
		this.keyword,
		this.startTime,
		this.endTime,
		int pageIndex = 0,
		int pageSize = 0,
		String? token,
	}) : super(
			pageIndex: pageIndex,
			pageSize: pageSize,
			token: token,
		);

	factory DynamicTypePageRequest.fromJson(Map<String, dynamic> map) {
		return DynamicTypePageRequest( 
			keyword: map['Keyword'],
			startTime: map['StartTime'] != null ? DateTime.parse(map['StartTime']) : null,
			endTime: map['EndTime'] != null ? DateTime.parse(map['EndTime']) : null,
			pageIndex: map['PageIndex'],
			pageSize: map['PageSize'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (keyword != null)
			map['Keyword'] = keyword;
		if (startTime != null)
			map['StartTime'] = JsonRpcUtils.dateFormat(startTime!);
		if (endTime != null)
			map['EndTime'] = JsonRpcUtils.dateFormat(endTime!);
		return map;
	}
}

class RemoveDynamicTypeRequest extends TokenRequest{
	String? code;

	RemoveDynamicTypeRequest({
		this.code,
		String? token,
	}) : super(
			token: token,
		);

	factory RemoveDynamicTypeRequest.fromJson(Map<String, dynamic> map) {
		return RemoveDynamicTypeRequest( 
			code: map['Code'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		return map;
	}
}

class GetDynamicTypeListRequest extends TokenRequest{
	List<String>? codes;

	GetDynamicTypeListRequest({
		this.codes,
		String? token,
	}) : super(
			token: token,
		);

	factory GetDynamicTypeListRequest.fromJson(Map<String, dynamic> map) {
		return GetDynamicTypeListRequest( 
			codes: map['Codes']?.cast<String>().toList(),
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (codes != null)
			map['Codes'] = codes;
		return map;
	}
}

class UpdateDynamicTypeRequest extends TokenRequest{
	String? code;
	String? typeName;
	String? typeKey;

	UpdateDynamicTypeRequest({
		this.code,
		this.typeName,
		this.typeKey,
		String? token,
	}) : super(
			token: token,
		);

	factory UpdateDynamicTypeRequest.fromJson(Map<String, dynamic> map) {
		return UpdateDynamicTypeRequest( 
			code: map['Code'],
			typeName: map['TypeName'],
			typeKey: map['TypeKey'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		if (typeName != null)
			map['TypeName'] = typeName;
		if (typeKey != null)
			map['TypeKey'] = typeKey;
		return map;
	}
}

class GetDynamicTypeListByKeyRequest extends TokenRequest{
	String? key;

	GetDynamicTypeListByKeyRequest({
		this.key,
		String? token,
	}) : super(
			token: token,
		);

	factory GetDynamicTypeListByKeyRequest.fromJson(Map<String, dynamic> map) {
		return GetDynamicTypeListByKeyRequest( 
			key: map['Key'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (key != null)
			map['Key'] = key;
		return map;
	}
}


