import 'notification.m.dart';
import 'exam.m.dart';
import 'vitalHealthExamBooking.m.dart';
import 'researchEdition.m.dart';

import 'package:fis_jsonrpc/utils.dart';

class ElectrocardiogramRecord extends BaseDTO{
	String? code;
	String? examData;
	String? patientName;
	String? cardNo;
	GenderEnum patientGender;
	String? patientAddress;
	DateTime? birthday;
	ExamStateEnum examState;
	DateTime? examTime;
	String? examDoctor;
	String? physicalExamNumber;
	String? organizationCode;
	String? organizationName;
	String? phone;
	String? deviceCode;

	ElectrocardiogramRecord({
		this.code,
		this.examData,
		this.patientName,
		this.cardNo,
		this.patientGender = GenderEnum.Unknown,
		this.patientAddress,
		this.birthday,
		this.examState = ExamStateEnum.Unchecked,
		this.examTime,
		this.examDoctor,
		this.physicalExamNumber,
		this.organizationCode,
		this.organizationName,
		this.phone,
		this.deviceCode,
		bool isDelete = false,
		DateTime? createTime,
		DateTime? updateTime,
	}) : super(
			isDelete: isDelete,
			createTime: createTime,
			updateTime: updateTime,
		);

	factory ElectrocardiogramRecord.fromJson(Map<String, dynamic> map) {
		return ElectrocardiogramRecord( 
			code: map['Code'],
			examData: map['ExamData'],
			patientName: map['PatientName'],
			cardNo: map['CardNo'],
			patientGender: GenderEnum.values.firstWhere((e) => e.index == map['PatientGender']),
			patientAddress: map['PatientAddress'],
			birthday: map['Birthday'] != null ? DateTime.parse(map['Birthday']) : null,
			examState: ExamStateEnum.values.firstWhere((e) => e.index == map['ExamState']),
			examTime: map['ExamTime'] != null ? DateTime.parse(map['ExamTime']) : null,
			examDoctor: map['ExamDoctor'],
			physicalExamNumber: map['PhysicalExamNumber'],
			organizationCode: map['OrganizationCode'],
			organizationName: map['OrganizationName'],
			phone: map['Phone'],
			deviceCode: map['DeviceCode'],
			isDelete: map['IsDelete'],
			createTime: map['CreateTime'] != null ? DateTime.parse(map['CreateTime']) : null,
			updateTime: map['UpdateTime'] != null ? DateTime.parse(map['UpdateTime']) : null,
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		if (examData != null)
			map['ExamData'] = examData;
		if (patientName != null)
			map['PatientName'] = patientName;
		if (cardNo != null)
			map['CardNo'] = cardNo;
		map['PatientGender'] = patientGender.index;
		if (patientAddress != null)
			map['PatientAddress'] = patientAddress;
		if (birthday != null)
			map['Birthday'] = JsonRpcUtils.dateFormat(birthday!);
		map['ExamState'] = examState.index;
		if (examTime != null)
			map['ExamTime'] = JsonRpcUtils.dateFormat(examTime!);
		if (examDoctor != null)
			map['ExamDoctor'] = examDoctor;
		if (physicalExamNumber != null)
			map['PhysicalExamNumber'] = physicalExamNumber;
		if (organizationCode != null)
			map['OrganizationCode'] = organizationCode;
		if (organizationName != null)
			map['OrganizationName'] = organizationName;
		if (phone != null)
			map['Phone'] = phone;
		if (deviceCode != null)
			map['DeviceCode'] = deviceCode;
		return map;
	}
}

class GetElectrocardiogramRecordRequest extends TokenRequest{
	String? code;

	GetElectrocardiogramRecordRequest({
		this.code,
		String? token,
	}) : super(
			token: token,
		);

	factory GetElectrocardiogramRecordRequest.fromJson(Map<String, dynamic> map) {
		return GetElectrocardiogramRecordRequest( 
			code: map['Code'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		return map;
	}
}

class ElectrocardiogramRecordPageRequest extends PageRequest{
	List<ExamStateEnum>? states;
	String? keyWord;
	DateTime? startTime;
	DateTime? endTime;
	bool isQuerySubordinate;

	ElectrocardiogramRecordPageRequest({
		this.states,
		this.keyWord,
		this.startTime,
		this.endTime,
		this.isQuerySubordinate = false,
		int pageIndex = 0,
		int pageSize = 0,
		String? token,
	}) : super(
			pageIndex: pageIndex,
			pageSize: pageSize,
			token: token,
		);

	factory ElectrocardiogramRecordPageRequest.fromJson(Map<String, dynamic> map) {
		return ElectrocardiogramRecordPageRequest( 
			states: map['States'] != null ? (map['States'] as List).map((e)=>ExamStateEnum.values.firstWhere((i) => i.index == e)).toList() : null,
			keyWord: map['KeyWord'],
			startTime: map['StartTime'] != null ? DateTime.parse(map['StartTime']) : null,
			endTime: map['EndTime'] != null ? DateTime.parse(map['EndTime']) : null,
			isQuerySubordinate: map['IsQuerySubordinate'],
			pageIndex: map['PageIndex'],
			pageSize: map['PageSize'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (states != null) {
			List<int> statesList = [];
			states!.forEach((e) => statesList.add(e.index));
			map['States'] = statesList;
		}
		if (keyWord != null)
			map['KeyWord'] = keyWord;
		if (startTime != null)
			map['StartTime'] = JsonRpcUtils.dateFormat(startTime!);
		if (endTime != null)
			map['EndTime'] = JsonRpcUtils.dateFormat(endTime!);
		map['IsQuerySubordinate'] = isQuerySubordinate;
		return map;
	}
}

class GetElectrocardiogramRecordByPhysicalExamNumberRequest extends TokenRequest{
	String? physicalExamNumber;

	GetElectrocardiogramRecordByPhysicalExamNumberRequest({
		this.physicalExamNumber,
		String? token,
	}) : super(
			token: token,
		);

	factory GetElectrocardiogramRecordByPhysicalExamNumberRequest.fromJson(Map<String, dynamic> map) {
		return GetElectrocardiogramRecordByPhysicalExamNumberRequest( 
			physicalExamNumber: map['PhysicalExamNumber'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (physicalExamNumber != null)
			map['PhysicalExamNumber'] = physicalExamNumber;
		return map;
	}
}

class UpdateElectrocardiogramExamInfoRecordRequest extends TokenRequest{
	String? code;
	String? examData;

	UpdateElectrocardiogramExamInfoRecordRequest({
		this.code,
		this.examData,
		String? token,
	}) : super(
			token: token,
		);

	factory UpdateElectrocardiogramExamInfoRecordRequest.fromJson(Map<String, dynamic> map) {
		return UpdateElectrocardiogramExamInfoRecordRequest( 
			code: map['Code'],
			examData: map['ExamData'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		if (examData != null)
			map['ExamData'] = examData;
		return map;
	}
}


