import 'dart:core';

import 'package:fis_jsonrpc/client_base.dart';
import 'package:fis_common/json_convert.dart';

import 'vitalExam.m.dart';

import 'exam.m.dart';
import 'researchEdition.m.dart';


class VitalExamService extends JsonRpcClientBase {
	VitalExamService(
		String host, {
		String serviceName = "IVitalExamService",
		Map<String, String>? headers,
		int? timeout,
	}) : super(
						host,
						serviceName,
						headers: headers,
						timeout: timeout,
				) {
		/// 注册响应实体反序列化处理器
		FJsonConvert.setDecoder((map) => ExamDTO.fromJson(map));
		FJsonConvert.setDecoder((map) => PageCollection<ExamDTO>.fromJson(map));
		FJsonConvert.setDecoder((map) => PageCollection<ExamConclusionDTO>.fromJson(map));
		FJsonConvert.setDecoder((map) => ExamConclusionDTO.fromJson(map));
		FJsonConvert.setDecoder((map) => ExamRecordDTO.fromJson(map));
	}

	Future<String> createExamAsync(CreateExamRequest request) async {
		var rpcRst = await call("CreateExamAsync", request);
		return rpcRst;
	}

	Future<int> batchAddExamAsync(BatchAddExamRequest request) async {
		var rpcRst = await call("BatchAddExamAsync", request);
		return rpcRst;
	}

	Future<ExamDTO> getExamDetailAsync(GetExamRequest request) async {
		var rpcRst = await call("GetExamDetailAsync", request);
		var result = ExamDTO.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<ExamDTO> getExamDetailByKeyAsync(GetExamByKeyRequest request) async {
		var rpcRst = await call("GetExamDetailByKeyAsync", request);
		var result = ExamDTO.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<PageCollection<ExamDTO>> getExamPageAsync(ExamPageRequest request) async {
		var rpcRst = await call("GetExamPageAsync", request);
		var result = PageCollection<ExamDTO>.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<PageCollection<ExamConclusionDTO>> getPatientExamByPageAsync(GetPatientExamByPageRequest request) async {
		var rpcRst = await call("GetPatientExamByPageAsync", request);
		var result = PageCollection<ExamConclusionDTO>.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<bool> removeExamAsync(RemoveExamRequest request) async {
		var rpcRst = await call("RemoveExamAsync", request);
		return rpcRst;
	}

	Future<List<ExamDTO>> getExamListAsync(GetExamListRequest request) async {
		var rpcRst = await call("GetExamListAsync", request);
		var result = (rpcRst as List).map((e)=>ExamDTO.fromJson(e as Map<String, dynamic>)).toList();
		return result;
	}

	Future<bool> updateExamAsync(UpdateExamRequest request) async {
		var rpcRst = await call("UpdateExamAsync", request);
		return rpcRst;
	}

	Future<PageCollection<ExamDTO>> getExamPageByKeyAsync(GetExamPageByKeyRequest request) async {
		var rpcRst = await call("GetExamPageByKeyAsync", request);
		var result = PageCollection<ExamDTO>.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<PageCollection<ExamDTO>> getExamPatientPageByKeyAsync(GetExamPatientPageByKeyRequest request) async {
		var rpcRst = await call("GetExamPatientPageByKeyAsync", request);
		var result = PageCollection<ExamDTO>.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<PageCollection<ExamDTO>> getExamRecordPageAsync(GetExamRecordPageRequest request) async {
		var rpcRst = await call("GetExamRecordPageAsync", request);
		var result = PageCollection<ExamDTO>.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<List<ExamDTO>> getExamByBatchNumberAsync(GetExamByBatchNumberRequest request) async {
		var rpcRst = await call("GetExamByBatchNumberAsync", request);
		var result = (rpcRst as List).map((e)=>ExamDTO.fromJson(e as Map<String, dynamic>)).toList();
		return result;
	}

	Future<List<ExamRecordDTO>> getExamRecordListAsync(GetExamRecordListRequest request) async {
		var rpcRst = await call("GetExamRecordListAsync", request);
		var result = (rpcRst as List).map((e)=>ExamRecordDTO.fromJson(e as Map<String, dynamic>)).toList();
		return result;
	}

	Future<bool> saveQuickCheckRecordAsync(SaveQuickCheckRecordRequest request) async {
		var rpcRst = await call("SaveQuickCheckRecordAsync", request);
		return rpcRst;
	}

	Future<bool> updateExamByBatchNumberAsync(UpdateExamByBatchNumberRequest request) async {
		var rpcRst = await call("UpdateExamByBatchNumberAsync", request);
		return rpcRst;
	}

	Future<List<ExamDTO>> getExamListByPhysicalExamNumberAsync(GetExamListByPhysicalExamNumberRequest request) async {
		var rpcRst = await call("GetExamListByPhysicalExamNumberAsync", request);
		var result = (rpcRst as List).map((e)=>ExamDTO.fromJson(e as Map<String, dynamic>)).toList();
		return result;
	}

}

