import 'researchEdition.m.dart';
import 'notification.m.dart';
import 'exam.m.dart';
import 'vitalHealthExamBooking.m.dart';

import 'package:fis_jsonrpc/utils.dart';

class CreateExamRequest extends TokenRequest{
	String? code;
	String? batchNumber;
	String? key;
	String? patientCode;
	String? contractedDoctor;
	String? examData;
	String? templateCode;
	String? physicalExamNumber;
	bool isRemoteEcgExam;

	CreateExamRequest({
		this.code,
		this.batchNumber,
		this.key,
		this.patientCode,
		this.contractedDoctor,
		this.examData,
		this.templateCode,
		this.physicalExamNumber,
		this.isRemoteEcgExam = false,
		String? token,
	}) : super(
			token: token,
		);

	factory CreateExamRequest.fromJson(Map<String, dynamic> map) {
		return CreateExamRequest( 
			code: map['Code'],
			batchNumber: map['BatchNumber'],
			key: map['Key'],
			patientCode: map['PatientCode'],
			contractedDoctor: map['ContractedDoctor'],
			examData: map['ExamData'],
			templateCode: map['TemplateCode'],
			physicalExamNumber: map['PhysicalExamNumber'],
			isRemoteEcgExam: map['IsRemoteEcgExam'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		if (batchNumber != null)
			map['BatchNumber'] = batchNumber;
		if (key != null)
			map['Key'] = key;
		if (patientCode != null)
			map['PatientCode'] = patientCode;
		if (contractedDoctor != null)
			map['ContractedDoctor'] = contractedDoctor;
		if (examData != null)
			map['ExamData'] = examData;
		if (templateCode != null)
			map['TemplateCode'] = templateCode;
		if (physicalExamNumber != null)
			map['PhysicalExamNumber'] = physicalExamNumber;
		map['IsRemoteEcgExam'] = isRemoteEcgExam;
		return map;
	}
}

class AddExamDTO {
	String? physicalExamNumber;
	String? examNumber;
	DateTime? examTime;
	String? key;
	String? examData;

	AddExamDTO({
		this.physicalExamNumber,
		this.examNumber,
		this.examTime,
		this.key,
		this.examData,
	});

	factory AddExamDTO.fromJson(Map<String, dynamic> map) {
		return AddExamDTO( 
			physicalExamNumber: map['PhysicalExamNumber'],
			examNumber: map['ExamNumber'],
			examTime: map['ExamTime'] != null ? DateTime.parse(map['ExamTime']) : null,
			key: map['Key'],
			examData: map['ExamData'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		if (physicalExamNumber != null)
			map['PhysicalExamNumber'] = physicalExamNumber;
		if (examNumber != null)
			map['ExamNumber'] = examNumber;
		if (examTime != null)
			map['ExamTime'] = JsonRpcUtils.dateFormat(examTime!);
		if (key != null)
			map['Key'] = key;
		if (examData != null)
			map['ExamData'] = examData;
		return map;
	}
}

class BatchAddExamRequest extends TokenRequest{
	List<AddExamDTO>? examInfos;

	BatchAddExamRequest({
		this.examInfos,
		String? token,
	}) : super(
			token: token,
		);

	factory BatchAddExamRequest.fromJson(Map<String, dynamic> map) {
		return BatchAddExamRequest( 
			examInfos: map['ExamInfos'] != null ? (map['ExamInfos'] as List).map((e)=>AddExamDTO.fromJson(e as Map<String,dynamic>)).toList() : null,
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (examInfos != null)
			map['ExamInfos'] = examInfos;
		return map;
	}
}

class GetExamRequest extends TokenRequest{
	String? key;
	String? code;

	GetExamRequest({
		this.key,
		this.code,
		String? token,
	}) : super(
			token: token,
		);

	factory GetExamRequest.fromJson(Map<String, dynamic> map) {
		return GetExamRequest( 
			key: map['Key'],
			code: map['Code'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (key != null)
			map['Key'] = key;
		if (code != null)
			map['Code'] = code;
		return map;
	}
}

class GetExamByKeyRequest extends TokenRequest{
	String? key;
	String? value;

	GetExamByKeyRequest({
		this.key,
		this.value,
		String? token,
	}) : super(
			token: token,
		);

	factory GetExamByKeyRequest.fromJson(Map<String, dynamic> map) {
		return GetExamByKeyRequest( 
			key: map['Key'],
			value: map['Value'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (key != null)
			map['Key'] = key;
		if (value != null)
			map['Value'] = value;
		return map;
	}
}

class ExamPageRequest extends PageRequest{
	String? keyword;
	DateTime? startTime;
	DateTime? endTime;

	ExamPageRequest({
		this.keyword,
		this.startTime,
		this.endTime,
		int pageIndex = 0,
		int pageSize = 0,
		String? token,
	}) : super(
			pageIndex: pageIndex,
			pageSize: pageSize,
			token: token,
		);

	factory ExamPageRequest.fromJson(Map<String, dynamic> map) {
		return ExamPageRequest( 
			keyword: map['Keyword'],
			startTime: map['StartTime'] != null ? DateTime.parse(map['StartTime']) : null,
			endTime: map['EndTime'] != null ? DateTime.parse(map['EndTime']) : null,
			pageIndex: map['PageIndex'],
			pageSize: map['PageSize'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (keyword != null)
			map['Keyword'] = keyword;
		if (startTime != null)
			map['StartTime'] = JsonRpcUtils.dateFormat(startTime!);
		if (endTime != null)
			map['EndTime'] = JsonRpcUtils.dateFormat(endTime!);
		return map;
	}
}

class GetPatientExamByPageRequest extends PageRequest{
	String? keyword;
	DateTime? startTime;
	DateTime? endTime;
	String? patientCode;
	String? examKey;

	GetPatientExamByPageRequest({
		this.keyword,
		this.startTime,
		this.endTime,
		this.patientCode,
		this.examKey,
		int pageIndex = 0,
		int pageSize = 0,
		String? token,
	}) : super(
			pageIndex: pageIndex,
			pageSize: pageSize,
			token: token,
		);

	factory GetPatientExamByPageRequest.fromJson(Map<String, dynamic> map) {
		return GetPatientExamByPageRequest( 
			keyword: map['Keyword'],
			startTime: map['StartTime'] != null ? DateTime.parse(map['StartTime']) : null,
			endTime: map['EndTime'] != null ? DateTime.parse(map['EndTime']) : null,
			patientCode: map['PatientCode'],
			examKey: map['ExamKey'],
			pageIndex: map['PageIndex'],
			pageSize: map['PageSize'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (keyword != null)
			map['Keyword'] = keyword;
		if (startTime != null)
			map['StartTime'] = JsonRpcUtils.dateFormat(startTime!);
		if (endTime != null)
			map['EndTime'] = JsonRpcUtils.dateFormat(endTime!);
		if (patientCode != null)
			map['PatientCode'] = patientCode;
		if (examKey != null)
			map['ExamKey'] = examKey;
		return map;
	}
}

class RemoveExamRequest extends TokenRequest{
	String? key;
	String? code;

	RemoveExamRequest({
		this.key,
		this.code,
		String? token,
	}) : super(
			token: token,
		);

	factory RemoveExamRequest.fromJson(Map<String, dynamic> map) {
		return RemoveExamRequest( 
			key: map['Key'],
			code: map['Code'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (key != null)
			map['Key'] = key;
		if (code != null)
			map['Code'] = code;
		return map;
	}
}

class GetExamListRequest extends TokenRequest{
	List<String>? codes;

	GetExamListRequest({
		this.codes,
		String? token,
	}) : super(
			token: token,
		);

	factory GetExamListRequest.fromJson(Map<String, dynamic> map) {
		return GetExamListRequest( 
			codes: map['Codes']?.cast<String>().toList(),
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (codes != null)
			map['Codes'] = codes;
		return map;
	}
}

class UpdateExamRequest extends TokenRequest{
	String? code;
	String? key;
	String? examData;

	UpdateExamRequest({
		this.code,
		this.key,
		this.examData,
		String? token,
	}) : super(
			token: token,
		);

	factory UpdateExamRequest.fromJson(Map<String, dynamic> map) {
		return UpdateExamRequest( 
			code: map['Code'],
			key: map['Key'],
			examData: map['ExamData'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		if (key != null)
			map['Key'] = key;
		if (examData != null)
			map['ExamData'] = examData;
		return map;
	}
}

class GetExamPageByKeyRequest extends PageRequest{
	String? keyword;
	DateTime? startTime;
	DateTime? endTime;
	String? key;
	String? patientCode;

	GetExamPageByKeyRequest({
		this.keyword,
		this.startTime,
		this.endTime,
		this.key,
		this.patientCode,
		int pageIndex = 0,
		int pageSize = 0,
		String? token,
	}) : super(
			pageIndex: pageIndex,
			pageSize: pageSize,
			token: token,
		);

	factory GetExamPageByKeyRequest.fromJson(Map<String, dynamic> map) {
		return GetExamPageByKeyRequest( 
			keyword: map['Keyword'],
			startTime: map['StartTime'] != null ? DateTime.parse(map['StartTime']) : null,
			endTime: map['EndTime'] != null ? DateTime.parse(map['EndTime']) : null,
			key: map['Key'],
			patientCode: map['PatientCode'],
			pageIndex: map['PageIndex'],
			pageSize: map['PageSize'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (keyword != null)
			map['Keyword'] = keyword;
		if (startTime != null)
			map['StartTime'] = JsonRpcUtils.dateFormat(startTime!);
		if (endTime != null)
			map['EndTime'] = JsonRpcUtils.dateFormat(endTime!);
		if (key != null)
			map['Key'] = key;
		if (patientCode != null)
			map['PatientCode'] = patientCode;
		return map;
	}
}

class GetExamPatientPageByKeyRequest extends PageRequest{
	String? keyword;
	DateTime? startTime;
	DateTime? endTime;
	String? key;

	GetExamPatientPageByKeyRequest({
		this.keyword,
		this.startTime,
		this.endTime,
		this.key,
		int pageIndex = 0,
		int pageSize = 0,
		String? token,
	}) : super(
			pageIndex: pageIndex,
			pageSize: pageSize,
			token: token,
		);

	factory GetExamPatientPageByKeyRequest.fromJson(Map<String, dynamic> map) {
		return GetExamPatientPageByKeyRequest( 
			keyword: map['Keyword'],
			startTime: map['StartTime'] != null ? DateTime.parse(map['StartTime']) : null,
			endTime: map['EndTime'] != null ? DateTime.parse(map['EndTime']) : null,
			key: map['Key'],
			pageIndex: map['PageIndex'],
			pageSize: map['PageSize'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (keyword != null)
			map['Keyword'] = keyword;
		if (startTime != null)
			map['StartTime'] = JsonRpcUtils.dateFormat(startTime!);
		if (endTime != null)
			map['EndTime'] = JsonRpcUtils.dateFormat(endTime!);
		if (key != null)
			map['Key'] = key;
		return map;
	}
}

class GetExamRecordPageRequest extends PageRequest{
	String? keyword;
	DateTime? startTime;
	DateTime? endTime;
	List<String>? keys;

	GetExamRecordPageRequest({
		this.keyword,
		this.startTime,
		this.endTime,
		this.keys,
		int pageIndex = 0,
		int pageSize = 0,
		String? token,
	}) : super(
			pageIndex: pageIndex,
			pageSize: pageSize,
			token: token,
		);

	factory GetExamRecordPageRequest.fromJson(Map<String, dynamic> map) {
		return GetExamRecordPageRequest( 
			keyword: map['Keyword'],
			startTime: map['StartTime'] != null ? DateTime.parse(map['StartTime']) : null,
			endTime: map['EndTime'] != null ? DateTime.parse(map['EndTime']) : null,
			keys: map['Keys']?.cast<String>().toList(),
			pageIndex: map['PageIndex'],
			pageSize: map['PageSize'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (keyword != null)
			map['Keyword'] = keyword;
		if (startTime != null)
			map['StartTime'] = JsonRpcUtils.dateFormat(startTime!);
		if (endTime != null)
			map['EndTime'] = JsonRpcUtils.dateFormat(endTime!);
		if (keys != null)
			map['Keys'] = keys;
		return map;
	}
}

class GetExamByBatchNumberRequest extends TokenRequest{
	String? batchNumber;

	GetExamByBatchNumberRequest({
		this.batchNumber,
		String? token,
	}) : super(
			token: token,
		);

	factory GetExamByBatchNumberRequest.fromJson(Map<String, dynamic> map) {
		return GetExamByBatchNumberRequest( 
			batchNumber: map['BatchNumber'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (batchNumber != null)
			map['BatchNumber'] = batchNumber;
		return map;
	}
}

class ExamRecordDataDTO {
	String? key;
	String? code;
	String? examData;
	String? templateCode;

	ExamRecordDataDTO({
		this.key,
		this.code,
		this.examData,
		this.templateCode,
	});

	factory ExamRecordDataDTO.fromJson(Map<String, dynamic> map) {
		return ExamRecordDataDTO( 
			key: map['Key'],
			code: map['Code'],
			examData: map['ExamData'],
			templateCode: map['TemplateCode'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		if (key != null)
			map['Key'] = key;
		if (code != null)
			map['Code'] = code;
		if (examData != null)
			map['ExamData'] = examData;
		if (templateCode != null)
			map['TemplateCode'] = templateCode;
		return map;
	}
}

class ExamRecordDTO {
	String? batchNumber;
	String? contractedDoctor;
	String? patientName;
	String? cardNo;
	GenderEnum patientGender;
	String? patientAddress;
	DateTime? birthday;
	ExamStateEnum examState;
	DateTime? examTime;
	String? examDoctor;
	List<ExamRecordDataDTO>? examRecordDatas;
	DateTime? updateTime;

	ExamRecordDTO({
		this.batchNumber,
		this.contractedDoctor,
		this.patientName,
		this.cardNo,
		this.patientGender = GenderEnum.Unknown,
		this.patientAddress,
		this.birthday,
		this.examState = ExamStateEnum.Unchecked,
		this.examTime,
		this.examDoctor,
		this.examRecordDatas,
		this.updateTime,
	});

	factory ExamRecordDTO.fromJson(Map<String, dynamic> map) {
		return ExamRecordDTO( 
			batchNumber: map['BatchNumber'],
			contractedDoctor: map['ContractedDoctor'],
			patientName: map['PatientName'],
			cardNo: map['CardNo'],
			patientGender: GenderEnum.values.firstWhere((e) => e.index == map['PatientGender']),
			patientAddress: map['PatientAddress'],
			birthday: map['Birthday'] != null ? DateTime.parse(map['Birthday']) : null,
			examState: ExamStateEnum.values.firstWhere((e) => e.index == map['ExamState']),
			examTime: map['ExamTime'] != null ? DateTime.parse(map['ExamTime']) : null,
			examDoctor: map['ExamDoctor'],
			examRecordDatas: map['ExamRecordDatas'] != null ? (map['ExamRecordDatas'] as List).map((e)=>ExamRecordDataDTO.fromJson(e as Map<String,dynamic>)).toList() : null,
			updateTime: map['UpdateTime'] != null ? DateTime.parse(map['UpdateTime']) : null,
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		if (batchNumber != null)
			map['BatchNumber'] = batchNumber;
		if (contractedDoctor != null)
			map['ContractedDoctor'] = contractedDoctor;
		if (patientName != null)
			map['PatientName'] = patientName;
		if (cardNo != null)
			map['CardNo'] = cardNo;
		map['PatientGender'] = patientGender.index;
		if (patientAddress != null)
			map['PatientAddress'] = patientAddress;
		if (birthday != null)
			map['Birthday'] = JsonRpcUtils.dateFormat(birthday!);
		map['ExamState'] = examState.index;
		if (examTime != null)
			map['ExamTime'] = JsonRpcUtils.dateFormat(examTime!);
		if (examDoctor != null)
			map['ExamDoctor'] = examDoctor;
		if (examRecordDatas != null)
			map['ExamRecordDatas'] = examRecordDatas;
		if (updateTime != null)
			map['UpdateTime'] = JsonRpcUtils.dateFormat(updateTime!);
		return map;
	}
}

class GetExamRecordListRequest extends TokenRequest{
	List<String>? keys;
	String? patientCode;

	GetExamRecordListRequest({
		this.keys,
		this.patientCode,
		String? token,
	}) : super(
			token: token,
		);

	factory GetExamRecordListRequest.fromJson(Map<String, dynamic> map) {
		return GetExamRecordListRequest( 
			keys: map['Keys']?.cast<String>().toList(),
			patientCode: map['PatientCode'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (keys != null)
			map['Keys'] = keys;
		if (patientCode != null)
			map['PatientCode'] = patientCode;
		return map;
	}
}

class SaveQuickCheckRecordRequest extends TokenRequest{
	String? patientCode;
	List<String>? keys;
	String? quickData;

	SaveQuickCheckRecordRequest({
		this.patientCode,
		this.keys,
		this.quickData,
		String? token,
	}) : super(
			token: token,
		);

	factory SaveQuickCheckRecordRequest.fromJson(Map<String, dynamic> map) {
		return SaveQuickCheckRecordRequest( 
			patientCode: map['PatientCode'],
			keys: map['Keys']?.cast<String>().toList(),
			quickData: map['QuickData'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (patientCode != null)
			map['PatientCode'] = patientCode;
		if (keys != null)
			map['Keys'] = keys;
		if (quickData != null)
			map['QuickData'] = quickData;
		return map;
	}
}

class UpdateExamByBatchNumberRequest extends TokenRequest{
	String? batchNumber;
	String? patientCode;
	String? key;
	String? examData;

	UpdateExamByBatchNumberRequest({
		this.batchNumber,
		this.patientCode,
		this.key,
		this.examData,
		String? token,
	}) : super(
			token: token,
		);

	factory UpdateExamByBatchNumberRequest.fromJson(Map<String, dynamic> map) {
		return UpdateExamByBatchNumberRequest( 
			batchNumber: map['BatchNumber'],
			patientCode: map['PatientCode'],
			key: map['Key'],
			examData: map['ExamData'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (batchNumber != null)
			map['BatchNumber'] = batchNumber;
		if (patientCode != null)
			map['PatientCode'] = patientCode;
		if (key != null)
			map['Key'] = key;
		if (examData != null)
			map['ExamData'] = examData;
		return map;
	}
}

class GetExamListByPhysicalExamNumberRequest extends TokenRequest{
	String? physicalExamNumber;

	GetExamListByPhysicalExamNumberRequest({
		this.physicalExamNumber,
		String? token,
	}) : super(
			token: token,
		);

	factory GetExamListByPhysicalExamNumberRequest.fromJson(Map<String, dynamic> map) {
		return GetExamListByPhysicalExamNumberRequest( 
			physicalExamNumber: map['PhysicalExamNumber'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (physicalExamNumber != null)
			map['PhysicalExamNumber'] = physicalExamNumber;
		return map;
	}
}


