import 'dart:core';

import 'package:fis_jsonrpc/client_base.dart';
import 'package:fis_common/json_convert.dart';

import 'vitalFollowUp.m.dart';

import 'researchEdition.m.dart';


class VitalFollowUpService extends JsonRpcClientBase {
	VitalFollowUpService(
		String host, {
		String serviceName = "IVitalFollowUpService",
		Map<String, String>? headers,
		int? timeout,
	}) : super(
						host,
						serviceName,
						headers: headers,
						timeout: timeout,
				) {
		/// 注册响应实体反序列化处理器
		FJsonConvert.setDecoder((map) => FollowUpDTO.fromJson(map));
		FJsonConvert.setDecoder((map) => PageCollection<FollowUpDTO>.fromJson(map));
		FJsonConvert.setDecoder((map) => FollowUpRecordDTO.fromJson(map));
	}

	Future<String> createFollowUpAsync(CreateFollowUpRequest request) async {
		var rpcRst = await call("CreateFollowUpAsync", request);
		return rpcRst;
	}

	Future<FollowUpDTO> getFollowUpDetailByPhysicalExamNumberAsync(GetFollowUpByPhysicalExamNumberRequest request) async {
		var rpcRst = await call("GetFollowUpDetailByPhysicalExamNumberAsync", request);
		var result = FollowUpDTO.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<FollowUpDTO> getFollowUpDetailAsync(GetFollowUpRequest request) async {
		var rpcRst = await call("GetFollowUpDetailAsync", request);
		var result = FollowUpDTO.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<FollowUpDTO> getFollowUpDetailByKeyAsync(GetFollowUpByKeyRequest request) async {
		var rpcRst = await call("GetFollowUpDetailByKeyAsync", request);
		var result = FollowUpDTO.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<PageCollection<FollowUpDTO>> getFollowUpPageAsync(FollowUpPageRequest request) async {
		var rpcRst = await call("GetFollowUpPageAsync", request);
		var result = PageCollection<FollowUpDTO>.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<bool> removeFollowUpAsync(RemoveFollowUpRequest request) async {
		var rpcRst = await call("RemoveFollowUpAsync", request);
		return rpcRst;
	}

	Future<List<FollowUpDTO>> getFollowUpListAsync(GetFollowUpListRequest request) async {
		var rpcRst = await call("GetFollowUpListAsync", request);
		var result = (rpcRst as List).map((e)=>FollowUpDTO.fromJson(e as Map<String, dynamic>)).toList();
		return result;
	}

	Future<bool> updateFollowUpAsync(UpdateFollowUpRequest request) async {
		var rpcRst = await call("UpdateFollowUpAsync", request);
		return rpcRst;
	}

	Future<PageCollection<FollowUpDTO>> getFollowUpPageByKeyAsync(GetFollowUpPageByKeyRequest request) async {
		var rpcRst = await call("GetFollowUpPageByKeyAsync", request);
		var result = PageCollection<FollowUpDTO>.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<PageCollection<FollowUpDTO>> getFollowUpPatientPageByKeyAsync(GetFollowUpPatientPageByKeyRequest request) async {
		var rpcRst = await call("GetFollowUpPatientPageByKeyAsync", request);
		var result = PageCollection<FollowUpDTO>.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<List<FollowUpRecordDTO>> getFollowUpRecordListAsync(GetFollowUpRecordListRequest request) async {
		var rpcRst = await call("GetFollowUpRecordListAsync", request);
		var result = (rpcRst as List).map((e)=>FollowUpRecordDTO.fromJson(e as Map<String, dynamic>)).toList();
		return result;
	}

	Future<List<FollowUpRecordDTO>> getFollowUpRecordListByYearAsync(GetFollowUpRecordListByYearRequest request) async {
		var rpcRst = await call("GetFollowUpRecordListByYearAsync", request);
		var result = (rpcRst as List).map((e)=>FollowUpRecordDTO.fromJson(e as Map<String, dynamic>)).toList();
		return result;
	}

}

