import 'dart:core';

import 'package:fis_jsonrpc/client_base.dart';
import 'package:fis_common/json_convert.dart';

import 'vitalHealthExamBooking.m.dart';

import 'liveConsultation.m.dart';
import 'remedical.m.dart';


class VitalHealthExamBookingService extends JsonRpcClientBase {
	VitalHealthExamBookingService(
		String host, {
		String serviceName = "IVitalHealthExamBookingService",
		Map<String, String>? headers,
		int? timeout,
	}) : super(
						host,
						serviceName,
						headers: headers,
						timeout: timeout,
				) {
		/// 注册响应实体反序列化处理器
		FJsonConvert.setDecoder((map) => PageResult<HealthExamBookingDTO>.fromJson(map));
		FJsonConvert.setDecoder((map) => HealthExamBookingDTO.fromJson(map));
		FJsonConvert.setDecoder((map) => HealthExamPersonDTO.fromJson(map));
		FJsonConvert.setDecoder((map) => HealthExamItemDTO.fromJson(map));
		FJsonConvert.setDecoder((map) => GetExamLabelsByExamNoResult.fromJson(map));
		FJsonConvert.setDecoder((map) => AddRegiterInfoResult.fromJson(map));
		FJsonConvert.setDecoder((map) => PageResult<RegisterInfoDTO>.fromJson(map));
		FJsonConvert.setDecoder((map) => RegisterInfoDTO.fromJson(map));
		FJsonConvert.setDecoder((map) => RegisterPersonInfoDTO.fromJson(map));
		FJsonConvert.setDecoder((map) => RecordInfoDTO.fromJson(map));
	}

	Future<PageResult<HealthExamBookingDTO>> getHealthExamBookingPageAsync(GetHealthExamBookingPageRequest request) async {
		var rpcRst = await call("GetHealthExamBookingPageAsync", request);
		var result = PageResult<HealthExamBookingDTO>.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<String> saveHealthExamBookingAsync(SaveHealthExamBookingRequest request) async {
		var rpcRst = await call("SaveHealthExamBookingAsync", request);
		return rpcRst;
	}

	Future<HealthExamBookingDTO> getHealthExamBookingAsync(GetHealthExamBookingRequest request) async {
		var rpcRst = await call("GetHealthExamBookingAsync", request);
		var result = HealthExamBookingDTO.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<bool> deleteHealthExamBookingAsync(DeleteHealthExamBookingRequest request) async {
		var rpcRst = await call("DeleteHealthExamBookingAsync", request);
		return rpcRst;
	}

	Future<bool> signUpASync(SignUpHealthExamBookingRequest request) async {
		var rpcRst = await call("SignUpASync", request);
		return rpcRst;
	}

	Future<HealthExamPersonDTO> getExamBookingByIDCardAsync(GetExamBookingByIDCardRequest request) async {
		var rpcRst = await call("GetExamBookingByIDCardAsync", request);
		var result = HealthExamPersonDTO.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<List<HealthExamItemDTO>> getExamItemsByExamNoAsync(GetExamItemsByExamNoRequest request) async {
		var rpcRst = await call("GetExamItemsByExamNoAsync", request);
		var result = (rpcRst as List).map((e)=>HealthExamItemDTO.fromJson(e as Map<String, dynamic>)).toList();
		return result;
	}

	Future<GetExamLabelsByExamNoResult> getExamLabelsByExamNoAsync(GetExamLabelsByExamNoRequest request) async {
		var rpcRst = await call("GetExamLabelsByExamNoAsync", request);
		var result = GetExamLabelsByExamNoResult.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<AddRegiterInfoResult> addRegiterInfoAsync(AddRegiterInfoRequest request) async {
		var rpcRst = await call("AddRegiterInfoAsync", request);
		var result = AddRegiterInfoResult.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<bool> updateRegiterInfoAsync(UpdateRegiterInfoRequest request) async {
		var rpcRst = await call("UpdateRegiterInfoAsync", request);
		return rpcRst;
	}

	Future<bool> updateResultsAndSuggestionsAsync(UpdateResultsAndSuggestionsRequest request) async {
		var rpcRst = await call("UpdateResultsAndSuggestionsAsync", request);
		return rpcRst;
	}

	Future<PageResult<RegisterInfoDTO>> getRegisterInfoPageAsync(GetRegiterInfoPageRequest request) async {
		var rpcRst = await call("GetRegisterInfoPageAsync", request);
		var result = PageResult<RegisterInfoDTO>.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<RegisterPersonInfoDTO> getRegisterPersonInfoByPhysicalExamNumberAsync(GetRegisterPersonRequest request) async {
		var rpcRst = await call("GetRegisterPersonInfoByPhysicalExamNumberAsync", request);
		var result = RegisterPersonInfoDTO.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<RecordInfoDTO> getVitalRecordByPhysicalExamNumberAsync(GetVitalRecordByPhysicalExamNumberRequest request) async {
		var rpcRst = await call("GetVitalRecordByPhysicalExamNumberAsync", request);
		var result = RecordInfoDTO.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<bool> cancelHealthExamBookingAsync(CancelHealthExamBookingRequest request) async {
		var rpcRst = await call("CancelHealthExamBookingAsync", request);
		return rpcRst;
	}

}

