import 'notification.m.dart';
import 'appletAPI.m.dart';
import 'liveConsultation.m.dart';
import 'researchEdition.m.dart';
import 'report.m.dart';
import 'patient.m.dart';
import 'remedical.m.dart';

import 'package:fis_jsonrpc/utils.dart';

enum BookingTypeEnum {
	Personal,
	Group,
}

enum BookingStatusEnum {
	UnSubmitted,
	Booked,
	Canceled,
}

class HealthExamPersonDTO {
	String? name;
	PatientGenderEnum gender;
	String? identityCard;
	String? phone;

	HealthExamPersonDTO({
		this.name,
		this.gender = PatientGenderEnum.NotFilled,
		this.identityCard,
		this.phone,
	});

	factory HealthExamPersonDTO.fromJson(Map<String, dynamic> map) {
		return HealthExamPersonDTO( 
			name: map['Name'],
			gender: PatientGenderEnum.values.firstWhere((e) => e.index == map['Gender']),
			identityCard: map['IdentityCard'],
			phone: map['Phone'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		if (name != null)
			map['Name'] = name;
		map['Gender'] = gender.index;
		if (identityCard != null)
			map['IdentityCard'] = identityCard;
		if (phone != null)
			map['Phone'] = phone;
		return map;
	}
}

class HealthExamItemDTO {
	String? name;
	String? content;
	String? code;

	HealthExamItemDTO({
		this.name,
		this.content,
		this.code,
	});

	factory HealthExamItemDTO.fromJson(Map<String, dynamic> map) {
		return HealthExamItemDTO( 
			name: map['Name'],
			content: map['Content'],
			code: map['Code'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		if (name != null)
			map['Name'] = name;
		if (content != null)
			map['Content'] = content;
		if (code != null)
			map['Code'] = code;
		return map;
	}
}

class HealthExamBookingDTO extends BaseDTO{
	String? code;
	BookingTypeEnum bookingType;
	String? name;
	String? location;
	DateTime? startDate;
	DateTime? endDate;
	String? subject;
	String? description;
	String? initiatorCode;
	String? orgCode;
	BookingStatusEnum status;
	List<HealthExamPersonDTO>? persons;
	List<HealthExamItemDTO>? examItems;
	String? shareUrl;

	HealthExamBookingDTO({
		this.code,
		this.bookingType = BookingTypeEnum.Personal,
		this.name,
		this.location,
		this.startDate,
		this.endDate,
		this.subject,
		this.description,
		this.initiatorCode,
		this.orgCode,
		this.status = BookingStatusEnum.UnSubmitted,
		this.persons,
		this.examItems,
		this.shareUrl,
		bool isDelete = false,
		DateTime? createTime,
		DateTime? updateTime,
	}) : super(
			isDelete: isDelete,
			createTime: createTime,
			updateTime: updateTime,
		);

	factory HealthExamBookingDTO.fromJson(Map<String, dynamic> map) {
		return HealthExamBookingDTO( 
			code: map['Code'],
			bookingType: BookingTypeEnum.values.firstWhere((e) => e.index == map['BookingType']),
			name: map['Name'],
			location: map['Location'],
			startDate: map['StartDate'] != null ? DateTime.parse(map['StartDate']) : null,
			endDate: map['EndDate'] != null ? DateTime.parse(map['EndDate']) : null,
			subject: map['Subject'],
			description: map['Description'],
			initiatorCode: map['InitiatorCode'],
			orgCode: map['OrgCode'],
			status: BookingStatusEnum.values.firstWhere((e) => e.index == map['Status']),
			persons: map['Persons'] != null ? (map['Persons'] as List).map((e)=>HealthExamPersonDTO.fromJson(e as Map<String,dynamic>)).toList() : null,
			examItems: map['ExamItems'] != null ? (map['ExamItems'] as List).map((e)=>HealthExamItemDTO.fromJson(e as Map<String,dynamic>)).toList() : null,
			shareUrl: map['ShareUrl'],
			isDelete: map['IsDelete'],
			createTime: map['CreateTime'] != null ? DateTime.parse(map['CreateTime']) : null,
			updateTime: map['UpdateTime'] != null ? DateTime.parse(map['UpdateTime']) : null,
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		map['BookingType'] = bookingType.index;
		if (name != null)
			map['Name'] = name;
		if (location != null)
			map['Location'] = location;
		if (startDate != null)
			map['StartDate'] = JsonRpcUtils.dateFormat(startDate!);
		if (endDate != null)
			map['EndDate'] = JsonRpcUtils.dateFormat(endDate!);
		if (subject != null)
			map['Subject'] = subject;
		if (description != null)
			map['Description'] = description;
		if (initiatorCode != null)
			map['InitiatorCode'] = initiatorCode;
		if (orgCode != null)
			map['OrgCode'] = orgCode;
		map['Status'] = status.index;
		if (persons != null)
			map['Persons'] = persons;
		if (examItems != null)
			map['ExamItems'] = examItems;
		if (shareUrl != null)
			map['ShareUrl'] = shareUrl;
		return map;
	}
}

class GetHealthExamBookingPageRequest extends PageRequest{
	String? keyword;
	List<String>? orgCodes;
	DateTime? startTime;
	DateTime? endTime;
	bool orderByAscending;

	GetHealthExamBookingPageRequest({
		this.keyword,
		this.orgCodes,
		this.startTime,
		this.endTime,
		this.orderByAscending = false,
		int pageIndex = 0,
		int pageSize = 0,
		String? token,
	}) : super(
			pageIndex: pageIndex,
			pageSize: pageSize,
			token: token,
		);

	factory GetHealthExamBookingPageRequest.fromJson(Map<String, dynamic> map) {
		return GetHealthExamBookingPageRequest( 
			keyword: map['Keyword'],
			orgCodes: map['OrgCodes']?.cast<String>().toList(),
			startTime: map['StartTime'] != null ? DateTime.parse(map['StartTime']) : null,
			endTime: map['EndTime'] != null ? DateTime.parse(map['EndTime']) : null,
			orderByAscending: map['OrderByAscending'],
			pageIndex: map['PageIndex'],
			pageSize: map['PageSize'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (keyword != null)
			map['Keyword'] = keyword;
		if (orgCodes != null)
			map['OrgCodes'] = orgCodes;
		if (startTime != null)
			map['StartTime'] = JsonRpcUtils.dateFormat(startTime!);
		if (endTime != null)
			map['EndTime'] = JsonRpcUtils.dateFormat(endTime!);
		map['OrderByAscending'] = orderByAscending;
		return map;
	}
}

class SaveHealthExamBookingRequest extends TokenRequest{
	String? code;
	BookingTypeEnum bookingType;
	String? name;
	String? location;
	DateTime? startDate;
	DateTime? endDate;
	String? subject;
	String? description;
	String? initiatorCode;
	String? orgCode;
	BookingStatusEnum status;
	List<HealthExamPersonDTO>? persons;
	List<HealthExamItemDTO>? examItems;

	SaveHealthExamBookingRequest({
		this.code,
		this.bookingType = BookingTypeEnum.Personal,
		this.name,
		this.location,
		this.startDate,
		this.endDate,
		this.subject,
		this.description,
		this.initiatorCode,
		this.orgCode,
		this.status = BookingStatusEnum.UnSubmitted,
		this.persons,
		this.examItems,
		String? token,
	}) : super(
			token: token,
		);

	factory SaveHealthExamBookingRequest.fromJson(Map<String, dynamic> map) {
		return SaveHealthExamBookingRequest( 
			code: map['Code'],
			bookingType: BookingTypeEnum.values.firstWhere((e) => e.index == map['BookingType']),
			name: map['Name'],
			location: map['Location'],
			startDate: map['StartDate'] != null ? DateTime.parse(map['StartDate']) : null,
			endDate: map['EndDate'] != null ? DateTime.parse(map['EndDate']) : null,
			subject: map['Subject'],
			description: map['Description'],
			initiatorCode: map['InitiatorCode'],
			orgCode: map['OrgCode'],
			status: BookingStatusEnum.values.firstWhere((e) => e.index == map['Status']),
			persons: map['Persons'] != null ? (map['Persons'] as List).map((e)=>HealthExamPersonDTO.fromJson(e as Map<String,dynamic>)).toList() : null,
			examItems: map['ExamItems'] != null ? (map['ExamItems'] as List).map((e)=>HealthExamItemDTO.fromJson(e as Map<String,dynamic>)).toList() : null,
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		map['BookingType'] = bookingType.index;
		if (name != null)
			map['Name'] = name;
		if (location != null)
			map['Location'] = location;
		if (startDate != null)
			map['StartDate'] = JsonRpcUtils.dateFormat(startDate!);
		if (endDate != null)
			map['EndDate'] = JsonRpcUtils.dateFormat(endDate!);
		if (subject != null)
			map['Subject'] = subject;
		if (description != null)
			map['Description'] = description;
		if (initiatorCode != null)
			map['InitiatorCode'] = initiatorCode;
		if (orgCode != null)
			map['OrgCode'] = orgCode;
		map['Status'] = status.index;
		if (persons != null)
			map['Persons'] = persons;
		if (examItems != null)
			map['ExamItems'] = examItems;
		return map;
	}
}

class GetHealthExamBookingRequest extends TokenRequest{
	String? code;

	GetHealthExamBookingRequest({
		this.code,
		String? token,
	}) : super(
			token: token,
		);

	factory GetHealthExamBookingRequest.fromJson(Map<String, dynamic> map) {
		return GetHealthExamBookingRequest( 
			code: map['Code'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		return map;
	}
}

class DeleteHealthExamBookingRequest extends TokenRequest{
	String? code;

	DeleteHealthExamBookingRequest({
		this.code,
		String? token,
	}) : super(
			token: token,
		);

	factory DeleteHealthExamBookingRequest.fromJson(Map<String, dynamic> map) {
		return DeleteHealthExamBookingRequest( 
			code: map['Code'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		return map;
	}
}

class SignUpHealthExamBookingRequest extends TokenRequest{
	String? code;
	String? name;
	PatientGenderEnum gender;
	String? identityCard;
	String? phone;

	SignUpHealthExamBookingRequest({
		this.code,
		this.name,
		this.gender = PatientGenderEnum.NotFilled,
		this.identityCard,
		this.phone,
		String? token,
	}) : super(
			token: token,
		);

	factory SignUpHealthExamBookingRequest.fromJson(Map<String, dynamic> map) {
		return SignUpHealthExamBookingRequest( 
			code: map['Code'],
			name: map['Name'],
			gender: PatientGenderEnum.values.firstWhere((e) => e.index == map['Gender']),
			identityCard: map['IdentityCard'],
			phone: map['Phone'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		if (name != null)
			map['Name'] = name;
		map['Gender'] = gender.index;
		if (identityCard != null)
			map['IdentityCard'] = identityCard;
		if (phone != null)
			map['Phone'] = phone;
		return map;
	}
}

class GetExamBookingByIDCardRequest extends TokenRequest{
	String? iDCardNo;
	String? operatorCode;

	GetExamBookingByIDCardRequest({
		this.iDCardNo,
		this.operatorCode,
		String? token,
	}) : super(
			token: token,
		);

	factory GetExamBookingByIDCardRequest.fromJson(Map<String, dynamic> map) {
		return GetExamBookingByIDCardRequest( 
			iDCardNo: map['IDCardNo'],
			operatorCode: map['OperatorCode'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (iDCardNo != null)
			map['IDCardNo'] = iDCardNo;
		if (operatorCode != null)
			map['OperatorCode'] = operatorCode;
		return map;
	}
}

class GetExamItemsByExamNoRequest extends TokenRequest{
	String? physicalExamNumber;

	GetExamItemsByExamNoRequest({
		this.physicalExamNumber,
		String? token,
	}) : super(
			token: token,
		);

	factory GetExamItemsByExamNoRequest.fromJson(Map<String, dynamic> map) {
		return GetExamItemsByExamNoRequest( 
			physicalExamNumber: map['PhysicalExamNumber'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (physicalExamNumber != null)
			map['PhysicalExamNumber'] = physicalExamNumber;
		return map;
	}
}

class HealthExamLabelDTO {
	String? type;
	String? title;
	String? uniquedCode;
	bool valid;
	bool forceExamNumber;

	HealthExamLabelDTO({
		this.type,
		this.title,
		this.uniquedCode,
		this.valid = false,
		this.forceExamNumber = false,
	});

	factory HealthExamLabelDTO.fromJson(Map<String, dynamic> map) {
		return HealthExamLabelDTO( 
			type: map['Type'],
			title: map['Title'],
			uniquedCode: map['UniquedCode'],
			valid: map['Valid'],
			forceExamNumber: map['ForceExamNumber'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		if (type != null)
			map['Type'] = type;
		if (title != null)
			map['Title'] = title;
		if (uniquedCode != null)
			map['UniquedCode'] = uniquedCode;
		map['Valid'] = valid;
		map['ForceExamNumber'] = forceExamNumber;
		return map;
	}
}

class GetExamLabelsByExamNoResult {
	String? registerPersonName;
	String? physicalExamNumber;
	String? sex;
	String? age;
	List<HealthExamLabelDTO>? eaxmLabels;

	GetExamLabelsByExamNoResult({
		this.registerPersonName,
		this.physicalExamNumber,
		this.sex,
		this.age,
		this.eaxmLabels,
	});

	factory GetExamLabelsByExamNoResult.fromJson(Map<String, dynamic> map) {
		return GetExamLabelsByExamNoResult( 
			registerPersonName: map['RegisterPersonName'],
			physicalExamNumber: map['PhysicalExamNumber'],
			sex: map['Sex'],
			age: map['Age'],
			eaxmLabels: map['EaxmLabels'] != null ? (map['EaxmLabels'] as List).map((e)=>HealthExamLabelDTO.fromJson(e as Map<String,dynamic>)).toList() : null,
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		if (registerPersonName != null)
			map['RegisterPersonName'] = registerPersonName;
		if (physicalExamNumber != null)
			map['PhysicalExamNumber'] = physicalExamNumber;
		if (sex != null)
			map['Sex'] = sex;
		if (age != null)
			map['Age'] = age;
		if (eaxmLabels != null)
			map['EaxmLabels'] = eaxmLabels;
		return map;
	}
}

class GetExamLabelsByExamNoRequest extends TokenRequest{
	String? physicalExamNumber;

	GetExamLabelsByExamNoRequest({
		this.physicalExamNumber,
		String? token,
	}) : super(
			token: token,
		);

	factory GetExamLabelsByExamNoRequest.fromJson(Map<String, dynamic> map) {
		return GetExamLabelsByExamNoRequest( 
			physicalExamNumber: map['PhysicalExamNumber'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (physicalExamNumber != null)
			map['PhysicalExamNumber'] = physicalExamNumber;
		return map;
	}
}

class AddRegiterInfoResult {
	String? registerPersonCode;
	bool isNewPatient;

	AddRegiterInfoResult({
		this.registerPersonCode,
		this.isNewPatient = false,
	});

	factory AddRegiterInfoResult.fromJson(Map<String, dynamic> map) {
		return AddRegiterInfoResult( 
			registerPersonCode: map['RegisterPersonCode'],
			isNewPatient: map['IsNewPatient'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		if (registerPersonCode != null)
			map['RegisterPersonCode'] = registerPersonCode;
		map['IsNewPatient'] = isNewPatient;
		return map;
	}
}

enum VitalProjectTypeEnum {
	VinnoHealth,
	VitalStation,
	VitalCloud,
}

class AddRegiterInfoRequest extends TokenRequest{
	String? code;
	String? iDCardNo;
	String? name;
	String? sex;
	String? age;
	DateTime? birthday;
	String? phone;
	String? adress;
	VitalProjectTypeEnum projectType;
	String? nationality;
	String? permanentResidenceAddress;

	AddRegiterInfoRequest({
		this.code,
		this.iDCardNo,
		this.name,
		this.sex,
		this.age,
		this.birthday,
		this.phone,
		this.adress,
		this.projectType = VitalProjectTypeEnum.VinnoHealth,
		this.nationality,
		this.permanentResidenceAddress,
		String? token,
	}) : super(
			token: token,
		);

	factory AddRegiterInfoRequest.fromJson(Map<String, dynamic> map) {
		return AddRegiterInfoRequest( 
			code: map['Code'],
			iDCardNo: map['IDCardNo'],
			name: map['Name'],
			sex: map['Sex'],
			age: map['Age'],
			birthday: map['Birthday'] != null ? DateTime.parse(map['Birthday']) : null,
			phone: map['Phone'],
			adress: map['Adress'],
			projectType: VitalProjectTypeEnum.values.firstWhere((e) => e.index == map['ProjectType']),
			nationality: map['Nationality'],
			permanentResidenceAddress: map['PermanentResidenceAddress'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		if (iDCardNo != null)
			map['IDCardNo'] = iDCardNo;
		if (name != null)
			map['Name'] = name;
		if (sex != null)
			map['Sex'] = sex;
		if (age != null)
			map['Age'] = age;
		if (birthday != null)
			map['Birthday'] = JsonRpcUtils.dateFormat(birthday!);
		if (phone != null)
			map['Phone'] = phone;
		if (adress != null)
			map['Adress'] = adress;
		map['ProjectType'] = projectType.index;
		if (nationality != null)
			map['Nationality'] = nationality;
		if (permanentResidenceAddress != null)
			map['PermanentResidenceAddress'] = permanentResidenceAddress;
		return map;
	}
}

class UpdateRegiterInfoRequest extends AddRegiterInfoRequest{

	UpdateRegiterInfoRequest({
		String? code,
		String? iDCardNo,
		String? name,
		String? sex,
		String? age,
		DateTime? birthday,
		String? phone,
		String? adress,
		VitalProjectTypeEnum projectType = VitalProjectTypeEnum.VinnoHealth,
		String? nationality,
		String? permanentResidenceAddress,
		String? token,
	}) : super(
			code: code,
			iDCardNo: iDCardNo,
			name: name,
			sex: sex,
			age: age,
			birthday: birthday,
			phone: phone,
			adress: adress,
			projectType: projectType,
			nationality: nationality,
			permanentResidenceAddress: permanentResidenceAddress,
			token: token,
		);

	factory UpdateRegiterInfoRequest.fromJson(Map<String, dynamic> map) {
		return UpdateRegiterInfoRequest( 
			code: map['Code'],
			iDCardNo: map['IDCardNo'],
			name: map['Name'],
			sex: map['Sex'],
			age: map['Age'],
			birthday: map['Birthday'] != null ? DateTime.parse(map['Birthday']) : null,
			phone: map['Phone'],
			adress: map['Adress'],
			projectType: VitalProjectTypeEnum.values.firstWhere((e) => e.index == map['ProjectType']),
			nationality: map['Nationality'],
			permanentResidenceAddress: map['PermanentResidenceAddress'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		return map;
	}
}

class UpdateResultsAndSuggestionsRequest extends TokenRequest{
	String? code;
	String? resultsAndSuggestions;
	String? healthGuidance;
	List<DataItemDTO2>? diagnosisExceptionResult;

	UpdateResultsAndSuggestionsRequest({
		this.code,
		this.resultsAndSuggestions,
		this.healthGuidance,
		this.diagnosisExceptionResult,
		String? token,
	}) : super(
			token: token,
		);

	factory UpdateResultsAndSuggestionsRequest.fromJson(Map<String, dynamic> map) {
		return UpdateResultsAndSuggestionsRequest( 
			code: map['Code'],
			resultsAndSuggestions: map['ResultsAndSuggestions'],
			healthGuidance: map['HealthGuidance'],
			diagnosisExceptionResult: map['DiagnosisExceptionResult'] != null ? (map['DiagnosisExceptionResult'] as List).map((e)=>DataItemDTO2.fromJson(e as Map<String,dynamic>)).toList() : null,
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		if (resultsAndSuggestions != null)
			map['ResultsAndSuggestions'] = resultsAndSuggestions;
		if (healthGuidance != null)
			map['HealthGuidance'] = healthGuidance;
		if (diagnosisExceptionResult != null)
			map['DiagnosisExceptionResult'] = diagnosisExceptionResult;
		return map;
	}
}

enum ExamStateEnum {
	Unchecked,
	Invalid,
	Inspected,
	Reported,
}

class RegisterInfoDTO extends BaseDTO{
	String? code;
	String? physicalExamNumber;
	String? iDCardNo;
	String? name;
	String? sex;
	String? age;
	DateTime? birthday;
	String? phone;
	String? adress;
	ExamStateEnum state;
	String? organizationCode;
	String? resultsAndSuggestions;
	String? healthGuidance;
	List<String>? finishedExamKeys;
	List<DataItemDTO2>? diagnosisExceptionResult;
	String? batchNumber;
	VitalProjectTypeEnum projectType;
	String? createdDoctorName;
	String? examNumber;

	RegisterInfoDTO({
		this.code,
		this.physicalExamNumber,
		this.iDCardNo,
		this.name,
		this.sex,
		this.age,
		this.birthday,
		this.phone,
		this.adress,
		this.state = ExamStateEnum.Unchecked,
		this.organizationCode,
		this.resultsAndSuggestions,
		this.healthGuidance,
		this.finishedExamKeys,
		this.diagnosisExceptionResult,
		this.batchNumber,
		this.projectType = VitalProjectTypeEnum.VinnoHealth,
		this.createdDoctorName,
		this.examNumber,
		bool isDelete = false,
		DateTime? createTime,
		DateTime? updateTime,
	}) : super(
			isDelete: isDelete,
			createTime: createTime,
			updateTime: updateTime,
		);

	factory RegisterInfoDTO.fromJson(Map<String, dynamic> map) {
		return RegisterInfoDTO( 
			code: map['Code'],
			physicalExamNumber: map['PhysicalExamNumber'],
			iDCardNo: map['IDCardNo'],
			name: map['Name'],
			sex: map['Sex'],
			age: map['Age'],
			birthday: map['Birthday'] != null ? DateTime.parse(map['Birthday']) : null,
			phone: map['Phone'],
			adress: map['Adress'],
			state: ExamStateEnum.values.firstWhere((e) => e.index == map['State']),
			organizationCode: map['OrganizationCode'],
			resultsAndSuggestions: map['ResultsAndSuggestions'],
			healthGuidance: map['HealthGuidance'],
			finishedExamKeys: map['FinishedExamKeys']?.cast<String>().toList(),
			diagnosisExceptionResult: map['DiagnosisExceptionResult'] != null ? (map['DiagnosisExceptionResult'] as List).map((e)=>DataItemDTO2.fromJson(e as Map<String,dynamic>)).toList() : null,
			batchNumber: map['BatchNumber'],
			projectType: VitalProjectTypeEnum.values.firstWhere((e) => e.index == map['ProjectType']),
			createdDoctorName: map['CreatedDoctorName'],
			examNumber: map['ExamNumber'],
			isDelete: map['IsDelete'],
			createTime: map['CreateTime'] != null ? DateTime.parse(map['CreateTime']) : null,
			updateTime: map['UpdateTime'] != null ? DateTime.parse(map['UpdateTime']) : null,
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		if (physicalExamNumber != null)
			map['PhysicalExamNumber'] = physicalExamNumber;
		if (iDCardNo != null)
			map['IDCardNo'] = iDCardNo;
		if (name != null)
			map['Name'] = name;
		if (sex != null)
			map['Sex'] = sex;
		if (age != null)
			map['Age'] = age;
		if (birthday != null)
			map['Birthday'] = JsonRpcUtils.dateFormat(birthday!);
		if (phone != null)
			map['Phone'] = phone;
		if (adress != null)
			map['Adress'] = adress;
		map['State'] = state.index;
		if (organizationCode != null)
			map['OrganizationCode'] = organizationCode;
		if (resultsAndSuggestions != null)
			map['ResultsAndSuggestions'] = resultsAndSuggestions;
		if (healthGuidance != null)
			map['HealthGuidance'] = healthGuidance;
		if (finishedExamKeys != null)
			map['FinishedExamKeys'] = finishedExamKeys;
		if (diagnosisExceptionResult != null)
			map['DiagnosisExceptionResult'] = diagnosisExceptionResult;
		if (batchNumber != null)
			map['BatchNumber'] = batchNumber;
		map['ProjectType'] = projectType.index;
		if (createdDoctorName != null)
			map['CreatedDoctorName'] = createdDoctorName;
		if (examNumber != null)
			map['ExamNumber'] = examNumber;
		return map;
	}
}

class GetRegiterInfoPageRequest extends PageRequest{
	String? keyword;
	String? operatorCode;
	DateTime? startTime;
	DateTime? endTime;
	String? iDCardNo;
	VitalProjectTypeEnum? projectType;

	GetRegiterInfoPageRequest({
		this.keyword,
		this.operatorCode,
		this.startTime,
		this.endTime,
		this.iDCardNo,
		this.projectType,
		int pageIndex = 0,
		int pageSize = 0,
		String? token,
	}) : super(
			pageIndex: pageIndex,
			pageSize: pageSize,
			token: token,
		);

	factory GetRegiterInfoPageRequest.fromJson(Map<String, dynamic> map) {
		return GetRegiterInfoPageRequest( 
			keyword: map['Keyword'],
			operatorCode: map['OperatorCode'],
			startTime: map['StartTime'] != null ? DateTime.parse(map['StartTime']) : null,
			endTime: map['EndTime'] != null ? DateTime.parse(map['EndTime']) : null,
			iDCardNo: map['IDCardNo'],
			projectType: map['ProjectType'] != null ? VitalProjectTypeEnum.values.firstWhere((e) => e.index == map['ProjectType']) : null,
			pageIndex: map['PageIndex'],
			pageSize: map['PageSize'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (keyword != null)
			map['Keyword'] = keyword;
		if (operatorCode != null)
			map['OperatorCode'] = operatorCode;
		if (startTime != null)
			map['StartTime'] = JsonRpcUtils.dateFormat(startTime!);
		if (endTime != null)
			map['EndTime'] = JsonRpcUtils.dateFormat(endTime!);
		if (iDCardNo != null)
			map['IDCardNo'] = iDCardNo;
		if (projectType != null)
		map['ProjectType'] = projectType?.index;
		return map;
	}
}

class RegisterPersonInfoDTO extends RegisterInfoDTO{
	String? headImg;
	PatientGenderEnum gender;

	RegisterPersonInfoDTO({
		this.headImg,
		this.gender = PatientGenderEnum.NotFilled,
		String? code,
		String? physicalExamNumber,
		String? iDCardNo,
		String? name,
		String? sex,
		String? age,
		DateTime? birthday,
		String? phone,
		String? adress,
		ExamStateEnum state = ExamStateEnum.Unchecked,
		String? organizationCode,
		String? resultsAndSuggestions,
		String? healthGuidance,
		List<String>? finishedExamKeys,
		List<DataItemDTO2>? diagnosisExceptionResult,
		String? batchNumber,
		VitalProjectTypeEnum projectType = VitalProjectTypeEnum.VinnoHealth,
		String? createdDoctorName,
		String? examNumber,
		bool isDelete = false,
		DateTime? createTime,
		DateTime? updateTime,
	}) : super(
			code: code,
			physicalExamNumber: physicalExamNumber,
			iDCardNo: iDCardNo,
			name: name,
			sex: sex,
			age: age,
			birthday: birthday,
			phone: phone,
			adress: adress,
			state: state,
			organizationCode: organizationCode,
			resultsAndSuggestions: resultsAndSuggestions,
			healthGuidance: healthGuidance,
			finishedExamKeys: finishedExamKeys,
			diagnosisExceptionResult: diagnosisExceptionResult,
			batchNumber: batchNumber,
			projectType: projectType,
			createdDoctorName: createdDoctorName,
			examNumber: examNumber,
			isDelete: isDelete,
			createTime: createTime,
			updateTime: updateTime,
		);

	factory RegisterPersonInfoDTO.fromJson(Map<String, dynamic> map) {
		return RegisterPersonInfoDTO( 
			headImg: map['HeadImg'],
			gender: PatientGenderEnum.values.firstWhere((e) => e.index == map['Gender']),
			code: map['Code'],
			physicalExamNumber: map['PhysicalExamNumber'],
			iDCardNo: map['IDCardNo'],
			name: map['Name'],
			sex: map['Sex'],
			age: map['Age'],
			birthday: map['Birthday'] != null ? DateTime.parse(map['Birthday']) : null,
			phone: map['Phone'],
			adress: map['Adress'],
			state: ExamStateEnum.values.firstWhere((e) => e.index == map['State']),
			organizationCode: map['OrganizationCode'],
			resultsAndSuggestions: map['ResultsAndSuggestions'],
			healthGuidance: map['HealthGuidance'],
			finishedExamKeys: map['FinishedExamKeys']?.cast<String>().toList(),
			diagnosisExceptionResult: map['DiagnosisExceptionResult'] != null ? (map['DiagnosisExceptionResult'] as List).map((e)=>DataItemDTO2.fromJson(e as Map<String,dynamic>)).toList() : null,
			batchNumber: map['BatchNumber'],
			projectType: VitalProjectTypeEnum.values.firstWhere((e) => e.index == map['ProjectType']),
			createdDoctorName: map['CreatedDoctorName'],
			examNumber: map['ExamNumber'],
			isDelete: map['IsDelete'],
			createTime: map['CreateTime'] != null ? DateTime.parse(map['CreateTime']) : null,
			updateTime: map['UpdateTime'] != null ? DateTime.parse(map['UpdateTime']) : null,
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (headImg != null)
			map['HeadImg'] = headImg;
		map['Gender'] = gender.index;
		return map;
	}
}

class GetRegisterPersonRequest {
	String? physicalExamNumber;

	GetRegisterPersonRequest({
		this.physicalExamNumber,
	});

	factory GetRegisterPersonRequest.fromJson(Map<String, dynamic> map) {
		return GetRegisterPersonRequest( 
			physicalExamNumber: map['PhysicalExamNumber'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		if (physicalExamNumber != null)
			map['PhysicalExamNumber'] = physicalExamNumber;
		return map;
	}
}

class GetVitalRecordByPhysicalExamNumberRequest extends TokenRequest{
	String? physicalExamNumber;

	GetVitalRecordByPhysicalExamNumberRequest({
		this.physicalExamNumber,
		String? token,
	}) : super(
			token: token,
		);

	factory GetVitalRecordByPhysicalExamNumberRequest.fromJson(Map<String, dynamic> map) {
		return GetVitalRecordByPhysicalExamNumberRequest( 
			physicalExamNumber: map['PhysicalExamNumber'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (physicalExamNumber != null)
			map['PhysicalExamNumber'] = physicalExamNumber;
		return map;
	}
}

class CancelHealthExamBookingRequest extends TokenRequest{
	String? code;
	String? identityCard;

	CancelHealthExamBookingRequest({
		this.code,
		this.identityCard,
		String? token,
	}) : super(
			token: token,
		);

	factory CancelHealthExamBookingRequest.fromJson(Map<String, dynamic> map) {
		return CancelHealthExamBookingRequest( 
			code: map['Code'],
			identityCard: map['IdentityCard'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		if (identityCard != null)
			map['IdentityCard'] = identityCard;
		return map;
	}
}


