import 'dart:core';

import 'package:fis_jsonrpc/client_base.dart';
import 'package:fis_common/json_convert.dart';

import 'vitalLabel.m.dart';

import 'researchEdition.m.dart';


class VitalLabelService extends JsonRpcClientBase {
	VitalLabelService(
		String host, {
		String serviceName = "IVitalLabelService",
		Map<String, String>? headers,
		int? timeout,
	}) : super(
						host,
						serviceName,
						headers: headers,
						timeout: timeout,
				) {
		/// 注册响应实体反序列化处理器
		FJsonConvert.setDecoder((map) => LabelDTO.fromJson(map));
		FJsonConvert.setDecoder((map) => PageCollection<LabelDTO>.fromJson(map));
	}

	Future<String> createLabelAsync(CreateLabelRequest request) async {
		var rpcRst = await call("CreateLabelAsync", request);
		return rpcRst;
	}

	Future<LabelDTO> getLabelDetailAsync(GetLabelRequest request) async {
		var rpcRst = await call("GetLabelDetailAsync", request);
		var result = LabelDTO.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<LabelDTO> getLabelDetailByKeyAsync(GetLabelByKeyRequest request) async {
		var rpcRst = await call("GetLabelDetailByKeyAsync", request);
		var result = LabelDTO.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<PageCollection<LabelDTO>> getLabelPageAsync(LabelPageRequest request) async {
		var rpcRst = await call("GetLabelPageAsync", request);
		var result = PageCollection<LabelDTO>.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<bool> removeLabelAsync(RemoveLabelRequest request) async {
		var rpcRst = await call("RemoveLabelAsync", request);
		return rpcRst;
	}

	Future<List<LabelDTO>> getLabelListAsync(GetLabelListRequest request) async {
		var rpcRst = await call("GetLabelListAsync", request);
		var result = (rpcRst as List).map((e)=>LabelDTO.fromJson(e as Map<String, dynamic>)).toList();
		return result;
	}

	Future<bool> updateLabelAsync(UpdateLabelRequest request) async {
		var rpcRst = await call("UpdateLabelAsync", request);
		return rpcRst;
	}

	Future<List<LabelDTO>> getLabelListByKeyAsync(GetLabelListByKeyRequest request) async {
		var rpcRst = await call("GetLabelListByKeyAsync", request);
		var result = (rpcRst as List).map((e)=>LabelDTO.fromJson(e as Map<String, dynamic>)).toList();
		return result;
	}

	Future<List<LabelDTO>> getCrowdLabelsAsync(GetCrowdLabelsRequest request) async {
		var rpcRst = await call("GetCrowdLabelsAsync", request);
		var result = (rpcRst as List).map((e)=>LabelDTO.fromJson(e as Map<String, dynamic>)).toList();
		return result;
	}

}

