import 'dart:core';

import 'package:fis_jsonrpc/client_base.dart';
import 'package:fis_common/json_convert.dart';

import 'vitalOperationLog.m.dart';

import 'researchEdition.m.dart';


class VitalOperationLogService extends JsonRpcClientBase {
	VitalOperationLogService(
		String host, {
		String serviceName = "IVitalOperationLogService",
		Map<String, String>? headers,
		int? timeout,
	}) : super(
						host,
						serviceName,
						headers: headers,
						timeout: timeout,
				) {
		/// 注册响应实体反序列化处理器
		FJsonConvert.setDecoder((map) => OperationLogDTO.fromJson(map));
		FJsonConvert.setDecoder((map) => PageCollection<OperationLogDTO>.fromJson(map));
	}

	Future<String> createOperationLogAsync(CreateOperationLogRequest request) async {
		var rpcRst = await call("CreateOperationLogAsync", request);
		return rpcRst;
	}

	Future<OperationLogDTO> getOperationLogDetailAsync(GetOperationLogRequest request) async {
		var rpcRst = await call("GetOperationLogDetailAsync", request);
		var result = OperationLogDTO.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<OperationLogDTO> getOperationLogDetailByKeyAsync(GetOperationLogByKeyRequest request) async {
		var rpcRst = await call("GetOperationLogDetailByKeyAsync", request);
		var result = OperationLogDTO.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<PageCollection<OperationLogDTO>> getOperationLogPageAsync(OperationLogPageRequest request) async {
		var rpcRst = await call("GetOperationLogPageAsync", request);
		var result = PageCollection<OperationLogDTO>.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<bool> removeOperationLogAsync(RemoveOperationLogRequest request) async {
		var rpcRst = await call("RemoveOperationLogAsync", request);
		return rpcRst;
	}

	Future<List<OperationLogDTO>> getOperationLogListAsync(GetOperationLogListRequest request) async {
		var rpcRst = await call("GetOperationLogListAsync", request);
		var result = (rpcRst as List).map((e)=>OperationLogDTO.fromJson(e as Map<String, dynamic>)).toList();
		return result;
	}

	Future<bool> updateOperationLogAsync(UpdateOperationLogRequest request) async {
		var rpcRst = await call("UpdateOperationLogAsync", request);
		return rpcRst;
	}

}

