import 'researchEdition.m.dart';
import 'notification.m.dart';

import 'package:fis_jsonrpc/utils.dart';

class CreateOperationLogRequest extends TokenRequest{
	String? operation;
	DateTime? operationTime;
	int operationType;

	CreateOperationLogRequest({
		this.operation,
		this.operationTime,
		this.operationType = 0,
		String? token,
	}) : super(
			token: token,
		);

	factory CreateOperationLogRequest.fromJson(Map<String, dynamic> map) {
		return CreateOperationLogRequest( 
			operation: map['Operation'],
			operationTime: map['OperationTime'] != null ? DateTime.parse(map['OperationTime']) : null,
			operationType: map['OperationType'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (operation != null)
			map['Operation'] = operation;
		if (operationTime != null)
			map['OperationTime'] = JsonRpcUtils.dateFormat(operationTime!);
		map['OperationType'] = operationType;
		return map;
	}
}

class OperationLogDTO extends BaseDTO{
	String? code;
	String? operation;
	DateTime? operationTime;
	int operationType;

	OperationLogDTO({
		this.code,
		this.operation,
		this.operationTime,
		this.operationType = 0,
		bool isDelete = false,
		DateTime? createTime,
		DateTime? updateTime,
	}) : super(
			isDelete: isDelete,
			createTime: createTime,
			updateTime: updateTime,
		);

	factory OperationLogDTO.fromJson(Map<String, dynamic> map) {
		return OperationLogDTO( 
			code: map['Code'],
			operation: map['Operation'],
			operationTime: map['OperationTime'] != null ? DateTime.parse(map['OperationTime']) : null,
			operationType: map['OperationType'],
			isDelete: map['IsDelete'],
			createTime: map['CreateTime'] != null ? DateTime.parse(map['CreateTime']) : null,
			updateTime: map['UpdateTime'] != null ? DateTime.parse(map['UpdateTime']) : null,
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		if (operation != null)
			map['Operation'] = operation;
		if (operationTime != null)
			map['OperationTime'] = JsonRpcUtils.dateFormat(operationTime!);
		map['OperationType'] = operationType;
		return map;
	}
}

class GetOperationLogRequest extends TokenRequest{
	String? code;

	GetOperationLogRequest({
		this.code,
		String? token,
	}) : super(
			token: token,
		);

	factory GetOperationLogRequest.fromJson(Map<String, dynamic> map) {
		return GetOperationLogRequest( 
			code: map['Code'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		return map;
	}
}

class GetOperationLogByKeyRequest extends TokenRequest{
	String? key;
	String? value;

	GetOperationLogByKeyRequest({
		this.key,
		this.value,
		String? token,
	}) : super(
			token: token,
		);

	factory GetOperationLogByKeyRequest.fromJson(Map<String, dynamic> map) {
		return GetOperationLogByKeyRequest( 
			key: map['Key'],
			value: map['Value'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (key != null)
			map['Key'] = key;
		if (value != null)
			map['Value'] = value;
		return map;
	}
}

class OperationLogPageRequest extends PageRequest{
	String? keyword;
	DateTime? startTime;
	DateTime? endTime;

	OperationLogPageRequest({
		this.keyword,
		this.startTime,
		this.endTime,
		int pageIndex = 0,
		int pageSize = 0,
		String? token,
	}) : super(
			pageIndex: pageIndex,
			pageSize: pageSize,
			token: token,
		);

	factory OperationLogPageRequest.fromJson(Map<String, dynamic> map) {
		return OperationLogPageRequest( 
			keyword: map['Keyword'],
			startTime: map['StartTime'] != null ? DateTime.parse(map['StartTime']) : null,
			endTime: map['EndTime'] != null ? DateTime.parse(map['EndTime']) : null,
			pageIndex: map['PageIndex'],
			pageSize: map['PageSize'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (keyword != null)
			map['Keyword'] = keyword;
		if (startTime != null)
			map['StartTime'] = JsonRpcUtils.dateFormat(startTime!);
		if (endTime != null)
			map['EndTime'] = JsonRpcUtils.dateFormat(endTime!);
		return map;
	}
}

class RemoveOperationLogRequest extends TokenRequest{
	String? code;

	RemoveOperationLogRequest({
		this.code,
		String? token,
	}) : super(
			token: token,
		);

	factory RemoveOperationLogRequest.fromJson(Map<String, dynamic> map) {
		return RemoveOperationLogRequest( 
			code: map['Code'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		return map;
	}
}

class GetOperationLogListRequest extends TokenRequest{
	List<String>? codes;

	GetOperationLogListRequest({
		this.codes,
		String? token,
	}) : super(
			token: token,
		);

	factory GetOperationLogListRequest.fromJson(Map<String, dynamic> map) {
		return GetOperationLogListRequest( 
			codes: map['Codes']?.cast<String>().toList(),
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (codes != null)
			map['Codes'] = codes;
		return map;
	}
}

class UpdateOperationLogRequest extends TokenRequest{
	String? code;
	String? operation;
	DateTime? operationTime;
	int operationType;

	UpdateOperationLogRequest({
		this.code,
		this.operation,
		this.operationTime,
		this.operationType = 0,
		String? token,
	}) : super(
			token: token,
		);

	factory UpdateOperationLogRequest.fromJson(Map<String, dynamic> map) {
		return UpdateOperationLogRequest( 
			code: map['Code'],
			operation: map['Operation'],
			operationTime: map['OperationTime'] != null ? DateTime.parse(map['OperationTime']) : null,
			operationType: map['OperationType'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		if (operation != null)
			map['Operation'] = operation;
		if (operationTime != null)
			map['OperationTime'] = JsonRpcUtils.dateFormat(operationTime!);
		map['OperationType'] = operationType;
		return map;
	}
}


