import 'dart:core';

import 'package:fis_jsonrpc/client_base.dart';
import 'package:fis_common/json_convert.dart';

import 'vitalOrganization.m.dart';

import 'researchEdition.m.dart';


class VitalOrganizationService extends JsonRpcClientBase {
	VitalOrganizationService(
		String host, {
		String serviceName = "IVitalOrganizationService",
		Map<String, String>? headers,
		int? timeout,
	}) : super(
						host,
						serviceName,
						headers: headers,
						timeout: timeout,
				) {
		/// 注册响应实体反序列化处理器
		FJsonConvert.setDecoder((map) => OrganizationDTO2.fromJson(map));
		FJsonConvert.setDecoder((map) => PageCollection<OrganizationDTO2>.fromJson(map));
		FJsonConvert.setDecoder((map) => OrganizationTreeDTO.fromJson(map));
		FJsonConvert.setDecoder((map) => DynamicParameterDTO.fromJson(map));
	}

	Future<String> createOrganizationAsync(CreateOrganizationRequest request) async {
		var rpcRst = await call("CreateOrganizationAsync", request);
		return rpcRst;
	}

	Future<String> getNextOrganizationUniqueCodeAsync(TokenRequest request) async {
		var rpcRst = await call("GetNextOrganizationUniqueCodeAsync", request);
		return rpcRst;
	}

	Future<OrganizationDTO2> getOrganizationDetailAsync(GetOrganizationRequest request) async {
		var rpcRst = await call("GetOrganizationDetailAsync", request);
		var result = OrganizationDTO2.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<OrganizationDTO2> getOrganizationDetailByKeyAsync(GetOrganizationByKeyRequest request) async {
		var rpcRst = await call("GetOrganizationDetailByKeyAsync", request);
		var result = OrganizationDTO2.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<PageCollection<OrganizationDTO2>> getOrganizationPageAsync(OrganizationPageRequest request) async {
		var rpcRst = await call("GetOrganizationPageAsync", request);
		var result = PageCollection<OrganizationDTO2>.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<bool> removeOrganizationAsync(RemoveOrganizationRequest request) async {
		var rpcRst = await call("RemoveOrganizationAsync", request);
		return rpcRst;
	}

	Future<List<OrganizationDTO2>> getOrganizationListAsync(GetOrganizationListRequest request) async {
		var rpcRst = await call("GetOrganizationListAsync", request);
		var result = (rpcRst as List).map((e)=>OrganizationDTO2.fromJson(e as Map<String, dynamic>)).toList();
		return result;
	}

	Future<bool> updateOrganizationAsync(UpdateOrganizationRequest request) async {
		var rpcRst = await call("UpdateOrganizationAsync", request);
		return rpcRst;
	}

	Future<List<OrganizationTreeDTO>> getOrganizationTreeAsync(GetOrganizationTreeRequest request) async {
		var rpcRst = await call("GetOrganizationTreeAsync", request);
		var result = (rpcRst as List).map((e)=>OrganizationTreeDTO.fromJson(e as Map<String, dynamic>)).toList();
		return result;
	}

	Future<List<String>> getEnableDeviceKeysAsync(GetEnableDeviceKeysRequest request) async {
		var rpcRst = await call("GetEnableDeviceKeysAsync", request);
		var result = (rpcRst as List).cast<String>().toList();
		return result;
	}

	Future<List<DynamicParameterDTO>> getDynamicParameterAsync(GetDynamicParameterRequest request) async {
		var rpcRst = await call("GetDynamicParameterAsync", request);
		var result = (rpcRst as List).map((e)=>DynamicParameterDTO.fromJson(e as Map<String, dynamic>)).toList();
		return result;
	}

}

