import 'researchEdition.m.dart';
import 'notification.m.dart';

import 'package:fis_jsonrpc/utils.dart';

enum CustomTypeEnum {
	General,
	CustomFirst,
}

class CreateOrganizationRequest extends TokenRequest{
	String? code;
	String? provinceCode;
	String? cityCode;
	String? districtCode;
	String? townCode;
	String? residenceCode;
	String? organizationName;
	String? contactNumber;
	String? logoUrl;
	String? address;
	String? fatherCode;
	List<String>? featureCodes;
	CustomTypeEnum customType;
	List<String>? peripheralDeviceKeys;
	String? dynamicParameter;
	String? organizationUniqueCode;
	List<String>? examItemCodes;
	String? ultrasonicSignature;
	String? urinalysisSignature;
	String? biochemicalTemplateKey;
	String? bloodRoutineTemplateKey;
	bool isAutoCreateReport;

	CreateOrganizationRequest({
		this.code,
		this.provinceCode,
		this.cityCode,
		this.districtCode,
		this.townCode,
		this.residenceCode,
		this.organizationName,
		this.contactNumber,
		this.logoUrl,
		this.address,
		this.fatherCode,
		this.featureCodes,
		this.customType = CustomTypeEnum.General,
		this.peripheralDeviceKeys,
		this.dynamicParameter,
		this.organizationUniqueCode,
		this.examItemCodes,
		this.ultrasonicSignature,
		this.urinalysisSignature,
		this.biochemicalTemplateKey,
		this.bloodRoutineTemplateKey,
		this.isAutoCreateReport = false,
		String? token,
	}) : super(
			token: token,
		);

	factory CreateOrganizationRequest.fromJson(Map<String, dynamic> map) {
		return CreateOrganizationRequest( 
			code: map['Code'],
			provinceCode: map['ProvinceCode'],
			cityCode: map['CityCode'],
			districtCode: map['DistrictCode'],
			townCode: map['TownCode'],
			residenceCode: map['ResidenceCode'],
			organizationName: map['OrganizationName'],
			contactNumber: map['ContactNumber'],
			logoUrl: map['LogoUrl'],
			address: map['Address'],
			fatherCode: map['FatherCode'],
			featureCodes: map['FeatureCodes']?.cast<String>().toList(),
			customType: CustomTypeEnum.values.firstWhere((e) => e.index == map['CustomType']),
			peripheralDeviceKeys: map['PeripheralDeviceKeys']?.cast<String>().toList(),
			dynamicParameter: map['DynamicParameter'],
			organizationUniqueCode: map['OrganizationUniqueCode'],
			examItemCodes: map['ExamItemCodes']?.cast<String>().toList(),
			ultrasonicSignature: map['UltrasonicSignature'],
			urinalysisSignature: map['UrinalysisSignature'],
			biochemicalTemplateKey: map['BiochemicalTemplateKey'],
			bloodRoutineTemplateKey: map['BloodRoutineTemplateKey'],
			isAutoCreateReport: map['IsAutoCreateReport'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		if (provinceCode != null)
			map['ProvinceCode'] = provinceCode;
		if (cityCode != null)
			map['CityCode'] = cityCode;
		if (districtCode != null)
			map['DistrictCode'] = districtCode;
		if (townCode != null)
			map['TownCode'] = townCode;
		if (residenceCode != null)
			map['ResidenceCode'] = residenceCode;
		if (organizationName != null)
			map['OrganizationName'] = organizationName;
		if (contactNumber != null)
			map['ContactNumber'] = contactNumber;
		if (logoUrl != null)
			map['LogoUrl'] = logoUrl;
		if (address != null)
			map['Address'] = address;
		if (fatherCode != null)
			map['FatherCode'] = fatherCode;
		if (featureCodes != null)
			map['FeatureCodes'] = featureCodes;
		map['CustomType'] = customType.index;
		if (peripheralDeviceKeys != null)
			map['PeripheralDeviceKeys'] = peripheralDeviceKeys;
		if (dynamicParameter != null)
			map['DynamicParameter'] = dynamicParameter;
		if (organizationUniqueCode != null)
			map['OrganizationUniqueCode'] = organizationUniqueCode;
		if (examItemCodes != null)
			map['ExamItemCodes'] = examItemCodes;
		if (ultrasonicSignature != null)
			map['UltrasonicSignature'] = ultrasonicSignature;
		if (urinalysisSignature != null)
			map['UrinalysisSignature'] = urinalysisSignature;
		if (biochemicalTemplateKey != null)
			map['BiochemicalTemplateKey'] = biochemicalTemplateKey;
		if (bloodRoutineTemplateKey != null)
			map['BloodRoutineTemplateKey'] = bloodRoutineTemplateKey;
		map['IsAutoCreateReport'] = isAutoCreateReport;
		return map;
	}
}

class OrganizationDTO2 extends BaseDTO{
	String? code;
	String? provinceCode;
	String? cityCode;
	String? districtCode;
	String? townCode;
	String? residenceCode;
	String? townName;
	String? residenceName;
	String? organizationName;
	String? contactNumber;
	String? logoUrl;
	String? address;
	List<String>? directors;
	String? fatherCode;
	String? fatherName;
	List<String>? featureCodes;
	CustomTypeEnum customType;
	List<String>? peripheralDeviceKeys;
	String? dynamicParameter;
	String? organizationUniqueCode;
	List<String>? examItemCodes;
	String? ultrasonicSignature;
	String? urinalysisSignature;
	String? biochemicalTemplateKey;
	String? bloodRoutineTemplateKey;
	bool isAutoCreateReport;

	OrganizationDTO2({
		this.code,
		this.provinceCode,
		this.cityCode,
		this.districtCode,
		this.townCode,
		this.residenceCode,
		this.townName,
		this.residenceName,
		this.organizationName,
		this.contactNumber,
		this.logoUrl,
		this.address,
		this.directors,
		this.fatherCode,
		this.fatherName,
		this.featureCodes,
		this.customType = CustomTypeEnum.General,
		this.peripheralDeviceKeys,
		this.dynamicParameter,
		this.organizationUniqueCode,
		this.examItemCodes,
		this.ultrasonicSignature,
		this.urinalysisSignature,
		this.biochemicalTemplateKey,
		this.bloodRoutineTemplateKey,
		this.isAutoCreateReport = false,
		bool isDelete = false,
		DateTime? createTime,
		DateTime? updateTime,
	}) : super(
			isDelete: isDelete,
			createTime: createTime,
			updateTime: updateTime,
		);

	factory OrganizationDTO2.fromJson(Map<String, dynamic> map) {
		return OrganizationDTO2( 
			code: map['Code'],
			provinceCode: map['ProvinceCode'],
			cityCode: map['CityCode'],
			districtCode: map['DistrictCode'],
			townCode: map['TownCode'],
			residenceCode: map['ResidenceCode'],
			townName: map['TownName'],
			residenceName: map['ResidenceName'],
			organizationName: map['OrganizationName'],
			contactNumber: map['ContactNumber'],
			logoUrl: map['LogoUrl'],
			address: map['Address'],
			directors: map['Directors']?.cast<String>().toList(),
			fatherCode: map['FatherCode'],
			fatherName: map['FatherName'],
			featureCodes: map['FeatureCodes']?.cast<String>().toList(),
			customType: CustomTypeEnum.values.firstWhere((e) => e.index == map['CustomType']),
			peripheralDeviceKeys: map['PeripheralDeviceKeys']?.cast<String>().toList(),
			dynamicParameter: map['DynamicParameter'],
			organizationUniqueCode: map['OrganizationUniqueCode'],
			examItemCodes: map['ExamItemCodes']?.cast<String>().toList(),
			ultrasonicSignature: map['UltrasonicSignature'],
			urinalysisSignature: map['UrinalysisSignature'],
			biochemicalTemplateKey: map['BiochemicalTemplateKey'],
			bloodRoutineTemplateKey: map['BloodRoutineTemplateKey'],
			isAutoCreateReport: map['IsAutoCreateReport'],
			isDelete: map['IsDelete'],
			createTime: map['CreateTime'] != null ? DateTime.parse(map['CreateTime']) : null,
			updateTime: map['UpdateTime'] != null ? DateTime.parse(map['UpdateTime']) : null,
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		if (provinceCode != null)
			map['ProvinceCode'] = provinceCode;
		if (cityCode != null)
			map['CityCode'] = cityCode;
		if (districtCode != null)
			map['DistrictCode'] = districtCode;
		if (townCode != null)
			map['TownCode'] = townCode;
		if (residenceCode != null)
			map['ResidenceCode'] = residenceCode;
		if (townName != null)
			map['TownName'] = townName;
		if (residenceName != null)
			map['ResidenceName'] = residenceName;
		if (organizationName != null)
			map['OrganizationName'] = organizationName;
		if (contactNumber != null)
			map['ContactNumber'] = contactNumber;
		if (logoUrl != null)
			map['LogoUrl'] = logoUrl;
		if (address != null)
			map['Address'] = address;
		if (directors != null)
			map['Directors'] = directors;
		if (fatherCode != null)
			map['FatherCode'] = fatherCode;
		if (fatherName != null)
			map['FatherName'] = fatherName;
		if (featureCodes != null)
			map['FeatureCodes'] = featureCodes;
		map['CustomType'] = customType.index;
		if (peripheralDeviceKeys != null)
			map['PeripheralDeviceKeys'] = peripheralDeviceKeys;
		if (dynamicParameter != null)
			map['DynamicParameter'] = dynamicParameter;
		if (organizationUniqueCode != null)
			map['OrganizationUniqueCode'] = organizationUniqueCode;
		if (examItemCodes != null)
			map['ExamItemCodes'] = examItemCodes;
		if (ultrasonicSignature != null)
			map['UltrasonicSignature'] = ultrasonicSignature;
		if (urinalysisSignature != null)
			map['UrinalysisSignature'] = urinalysisSignature;
		if (biochemicalTemplateKey != null)
			map['BiochemicalTemplateKey'] = biochemicalTemplateKey;
		if (bloodRoutineTemplateKey != null)
			map['BloodRoutineTemplateKey'] = bloodRoutineTemplateKey;
		map['IsAutoCreateReport'] = isAutoCreateReport;
		return map;
	}
}

class GetOrganizationRequest extends TokenRequest{
	String? code;

	GetOrganizationRequest({
		this.code,
		String? token,
	}) : super(
			token: token,
		);

	factory GetOrganizationRequest.fromJson(Map<String, dynamic> map) {
		return GetOrganizationRequest( 
			code: map['Code'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		return map;
	}
}

class GetOrganizationByKeyRequest extends TokenRequest{
	String? key;
	String? value;

	GetOrganizationByKeyRequest({
		this.key,
		this.value,
		String? token,
	}) : super(
			token: token,
		);

	factory GetOrganizationByKeyRequest.fromJson(Map<String, dynamic> map) {
		return GetOrganizationByKeyRequest( 
			key: map['Key'],
			value: map['Value'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (key != null)
			map['Key'] = key;
		if (value != null)
			map['Value'] = value;
		return map;
	}
}

class OrganizationPageRequest extends PageRequest{
	String? keyword;
	DateTime? startTime;
	DateTime? endTime;

	OrganizationPageRequest({
		this.keyword,
		this.startTime,
		this.endTime,
		int pageIndex = 0,
		int pageSize = 0,
		String? token,
	}) : super(
			pageIndex: pageIndex,
			pageSize: pageSize,
			token: token,
		);

	factory OrganizationPageRequest.fromJson(Map<String, dynamic> map) {
		return OrganizationPageRequest( 
			keyword: map['Keyword'],
			startTime: map['StartTime'] != null ? DateTime.parse(map['StartTime']) : null,
			endTime: map['EndTime'] != null ? DateTime.parse(map['EndTime']) : null,
			pageIndex: map['PageIndex'],
			pageSize: map['PageSize'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (keyword != null)
			map['Keyword'] = keyword;
		if (startTime != null)
			map['StartTime'] = JsonRpcUtils.dateFormat(startTime!);
		if (endTime != null)
			map['EndTime'] = JsonRpcUtils.dateFormat(endTime!);
		return map;
	}
}

class RemoveOrganizationRequest extends TokenRequest{
	String? code;

	RemoveOrganizationRequest({
		this.code,
		String? token,
	}) : super(
			token: token,
		);

	factory RemoveOrganizationRequest.fromJson(Map<String, dynamic> map) {
		return RemoveOrganizationRequest( 
			code: map['Code'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		return map;
	}
}

class GetOrganizationListRequest extends TokenRequest{
	List<String>? codes;

	GetOrganizationListRequest({
		this.codes,
		String? token,
	}) : super(
			token: token,
		);

	factory GetOrganizationListRequest.fromJson(Map<String, dynamic> map) {
		return GetOrganizationListRequest( 
			codes: map['Codes']?.cast<String>().toList(),
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (codes != null)
			map['Codes'] = codes;
		return map;
	}
}

class UpdateOrganizationRequest extends TokenRequest{
	String? code;
	String? provinceCode;
	String? cityCode;
	String? districtCode;
	String? townCode;
	String? residenceCode;
	String? organizationName;
	String? contactNumber;
	String? logoUrl;
	String? address;
	String? fatherCode;
	List<String>? featureCodes;
	CustomTypeEnum customType;
	List<String>? peripheralDeviceKeys;
	String? dynamicParameter;
	String? organizationUniqueCode;
	List<String>? examItemCodes;
	String? ultrasonicSignature;
	String? urinalysisSignature;
	String? biochemicalTemplateKey;
	String? bloodRoutineTemplateKey;
	bool isAutoCreateReport;

	UpdateOrganizationRequest({
		this.code,
		this.provinceCode,
		this.cityCode,
		this.districtCode,
		this.townCode,
		this.residenceCode,
		this.organizationName,
		this.contactNumber,
		this.logoUrl,
		this.address,
		this.fatherCode,
		this.featureCodes,
		this.customType = CustomTypeEnum.General,
		this.peripheralDeviceKeys,
		this.dynamicParameter,
		this.organizationUniqueCode,
		this.examItemCodes,
		this.ultrasonicSignature,
		this.urinalysisSignature,
		this.biochemicalTemplateKey,
		this.bloodRoutineTemplateKey,
		this.isAutoCreateReport = false,
		String? token,
	}) : super(
			token: token,
		);

	factory UpdateOrganizationRequest.fromJson(Map<String, dynamic> map) {
		return UpdateOrganizationRequest( 
			code: map['Code'],
			provinceCode: map['ProvinceCode'],
			cityCode: map['CityCode'],
			districtCode: map['DistrictCode'],
			townCode: map['TownCode'],
			residenceCode: map['ResidenceCode'],
			organizationName: map['OrganizationName'],
			contactNumber: map['ContactNumber'],
			logoUrl: map['LogoUrl'],
			address: map['Address'],
			fatherCode: map['FatherCode'],
			featureCodes: map['FeatureCodes']?.cast<String>().toList(),
			customType: CustomTypeEnum.values.firstWhere((e) => e.index == map['CustomType']),
			peripheralDeviceKeys: map['PeripheralDeviceKeys']?.cast<String>().toList(),
			dynamicParameter: map['DynamicParameter'],
			organizationUniqueCode: map['OrganizationUniqueCode'],
			examItemCodes: map['ExamItemCodes']?.cast<String>().toList(),
			ultrasonicSignature: map['UltrasonicSignature'],
			urinalysisSignature: map['UrinalysisSignature'],
			biochemicalTemplateKey: map['BiochemicalTemplateKey'],
			bloodRoutineTemplateKey: map['BloodRoutineTemplateKey'],
			isAutoCreateReport: map['IsAutoCreateReport'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		if (provinceCode != null)
			map['ProvinceCode'] = provinceCode;
		if (cityCode != null)
			map['CityCode'] = cityCode;
		if (districtCode != null)
			map['DistrictCode'] = districtCode;
		if (townCode != null)
			map['TownCode'] = townCode;
		if (residenceCode != null)
			map['ResidenceCode'] = residenceCode;
		if (organizationName != null)
			map['OrganizationName'] = organizationName;
		if (contactNumber != null)
			map['ContactNumber'] = contactNumber;
		if (logoUrl != null)
			map['LogoUrl'] = logoUrl;
		if (address != null)
			map['Address'] = address;
		if (fatherCode != null)
			map['FatherCode'] = fatherCode;
		if (featureCodes != null)
			map['FeatureCodes'] = featureCodes;
		map['CustomType'] = customType.index;
		if (peripheralDeviceKeys != null)
			map['PeripheralDeviceKeys'] = peripheralDeviceKeys;
		if (dynamicParameter != null)
			map['DynamicParameter'] = dynamicParameter;
		if (organizationUniqueCode != null)
			map['OrganizationUniqueCode'] = organizationUniqueCode;
		if (examItemCodes != null)
			map['ExamItemCodes'] = examItemCodes;
		if (ultrasonicSignature != null)
			map['UltrasonicSignature'] = ultrasonicSignature;
		if (urinalysisSignature != null)
			map['UrinalysisSignature'] = urinalysisSignature;
		if (biochemicalTemplateKey != null)
			map['BiochemicalTemplateKey'] = biochemicalTemplateKey;
		if (bloodRoutineTemplateKey != null)
			map['BloodRoutineTemplateKey'] = bloodRoutineTemplateKey;
		map['IsAutoCreateReport'] = isAutoCreateReport;
		return map;
	}
}

class TeamBaseDTO {
	String? teamName;
	String? code;

	TeamBaseDTO({
		this.teamName,
		this.code,
	});

	factory TeamBaseDTO.fromJson(Map<String, dynamic> map) {
		return TeamBaseDTO( 
			teamName: map['TeamName'],
			code: map['Code'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		if (teamName != null)
			map['TeamName'] = teamName;
		if (code != null)
			map['Code'] = code;
		return map;
	}
}

class OrganizationTreeDTO extends BaseDTO{
	String? code;
	String? fatherCode;
	String? organizationName;
	List<TeamBaseDTO>? teams;

	OrganizationTreeDTO({
		this.code,
		this.fatherCode,
		this.organizationName,
		this.teams,
		bool isDelete = false,
		DateTime? createTime,
		DateTime? updateTime,
	}) : super(
			isDelete: isDelete,
			createTime: createTime,
			updateTime: updateTime,
		);

	factory OrganizationTreeDTO.fromJson(Map<String, dynamic> map) {
		return OrganizationTreeDTO( 
			code: map['Code'],
			fatherCode: map['FatherCode'],
			organizationName: map['OrganizationName'],
			teams: map['Teams'] != null ? (map['Teams'] as List).map((e)=>TeamBaseDTO.fromJson(e as Map<String,dynamic>)).toList() : null,
			isDelete: map['IsDelete'],
			createTime: map['CreateTime'] != null ? DateTime.parse(map['CreateTime']) : null,
			updateTime: map['UpdateTime'] != null ? DateTime.parse(map['UpdateTime']) : null,
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		if (fatherCode != null)
			map['FatherCode'] = fatherCode;
		if (organizationName != null)
			map['OrganizationName'] = organizationName;
		if (teams != null)
			map['Teams'] = teams;
		return map;
	}
}

class GetOrganizationTreeRequest extends TokenRequest{

	GetOrganizationTreeRequest({
		String? token,
	}) : super(
			token: token,
		);

	factory GetOrganizationTreeRequest.fromJson(Map<String, dynamic> map) {
		return GetOrganizationTreeRequest( 
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		return map;
	}
}

class GetEnableDeviceKeysRequest extends TokenRequest{
	String? organizationCode;

	GetEnableDeviceKeysRequest({
		this.organizationCode,
		String? token,
	}) : super(
			token: token,
		);

	factory GetEnableDeviceKeysRequest.fromJson(Map<String, dynamic> map) {
		return GetEnableDeviceKeysRequest( 
			organizationCode: map['OrganizationCode'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (organizationCode != null)
			map['OrganizationCode'] = organizationCode;
		return map;
	}
}

class DynamicParameterDTO {
	String? type;
	String? key;
	String? mode;

	DynamicParameterDTO({
		this.type,
		this.key,
		this.mode,
	});

	factory DynamicParameterDTO.fromJson(Map<String, dynamic> map) {
		return DynamicParameterDTO( 
			type: map['Type'],
			key: map['Key'],
			mode: map['Mode'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		if (type != null)
			map['Type'] = type;
		if (key != null)
			map['Key'] = key;
		if (mode != null)
			map['Mode'] = mode;
		return map;
	}
}

class GetDynamicParameterRequest extends TokenRequest{
	String? organizationCode;

	GetDynamicParameterRequest({
		this.organizationCode,
		String? token,
	}) : super(
			token: token,
		);

	factory GetDynamicParameterRequest.fromJson(Map<String, dynamic> map) {
		return GetDynamicParameterRequest( 
			organizationCode: map['OrganizationCode'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (organizationCode != null)
			map['OrganizationCode'] = organizationCode;
		return map;
	}
}


