import 'dart:core';

import 'package:fis_jsonrpc/client_base.dart';
import 'package:fis_common/json_convert.dart';

import 'vitalPatient.m.dart';

import 'researchEdition.m.dart';
import 'recognition.m.dart';


class VitalPatientService extends JsonRpcClientBase {
	VitalPatientService(
		String host, {
		String serviceName = "IVitalPatientService",
		Map<String, String>? headers,
		int? timeout,
	}) : super(
						host,
						serviceName,
						headers: headers,
						timeout: timeout,
				) {
		/// 注册响应实体反序列化处理器
		FJsonConvert.setDecoder((map) => PatientDTO.fromJson(map));
		FJsonConvert.setDecoder((map) => PageCollection<PatientDTO>.fromJson(map));
		FJsonConvert.setDecoder((map) => PatientBaseDTO.fromJson(map));
		FJsonConvert.setDecoder((map) => SavePersonDTO.fromJson(map));
		FJsonConvert.setDecoder((map) => DeletePersonDTO.fromJson(map));
		FJsonConvert.setDecoder((map) => PatientStatisticDTO.fromJson(map));
		FJsonConvert.setDecoder((map) => FaceRecognitionDTO.fromJson(map));
	}

	Future<String> createPatientAsync(CreatePatientRequest2 request) async {
		var rpcRst = await call("CreatePatientAsync", request);
		return rpcRst;
	}

	Future<PatientDTO> getPatientDetailAsync(GetPatientRequest request) async {
		var rpcRst = await call("GetPatientDetailAsync", request);
		var result = PatientDTO.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<PatientDTO> getPatientDetailByKeyAsync(GetPatientByKeyRequest request) async {
		var rpcRst = await call("GetPatientDetailByKeyAsync", request);
		var result = PatientDTO.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<PageCollection<PatientDTO>> getPatientPageAsync(PatientPageRequest request) async {
		var rpcRst = await call("GetPatientPageAsync", request);
		var result = PageCollection<PatientDTO>.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<bool> removePatientAsync(RemovePatientRequest request) async {
		var rpcRst = await call("RemovePatientAsync", request);
		return rpcRst;
	}

	Future<List<PatientDTO>> getPatientListAsync(GetPatientListRequest request) async {
		var rpcRst = await call("GetPatientListAsync", request);
		var result = (rpcRst as List).map((e)=>PatientDTO.fromJson(e as Map<String, dynamic>)).toList();
		return result;
	}

	Future<bool> updatePatientAsync(UpdatePatientRequest2 request) async {
		var rpcRst = await call("UpdatePatientAsync", request);
		return rpcRst;
	}

	Future<bool> setCrowdLabelsAsync(SetCrowdLabelsRequest request) async {
		var rpcRst = await call("SetCrowdLabelsAsync", request);
		return rpcRst;
	}

	Future<bool> updatePatientPhotosAsync(UpdatePatientPhotosRequest request) async {
		var rpcRst = await call("UpdatePatientPhotosAsync", request);
		return rpcRst;
	}

	Future<PatientBaseDTO> getPatientBaseByImageAsync(GetPatientBaseByImageRequest request) async {
		var rpcRst = await call("GetPatientBaseByImageAsync", request);
		var result = PatientBaseDTO.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<PatientBaseDTO> getPatientBaseByFaceImageAsync(GetPatientBaseByFaceImageRequest request) async {
		var rpcRst = await call("GetPatientBaseByFaceImageAsync", request);
		var result = PatientBaseDTO.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<SavePersonDTO> savePatientBaseByFaceImageAsync(SavePatientBaseByFaceImageRequest request) async {
		var rpcRst = await call("SavePatientBaseByFaceImageAsync", request);
		var result = SavePersonDTO.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<DeletePersonDTO> unbindAndCreateByFaceImageAsync(UnbindAndCreateByFaceImageRequest request) async {
		var rpcRst = await call("UnbindAndCreateByFaceImageAsync", request);
		var result = DeletePersonDTO.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<DeletePersonDTO> unbindByCardNoAsync(UnbindByCardNoRequest request) async {
		var rpcRst = await call("UnbindByCardNoAsync", request);
		var result = DeletePersonDTO.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<PatientStatisticDTO> getPatientStatisticAsync(GetPatientStatisticRequest request) async {
		var rpcRst = await call("GetPatientStatisticAsync", request);
		var result = PatientStatisticDTO.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<bool> savePatientBaseByFaceImageLocalAsync(SavePatientBaseByFaceImageLocalRequest request) async {
		var rpcRst = await call("SavePatientBaseByFaceImageLocalAsync", request);
		return rpcRst;
	}

	Future<bool> unbindByCardNoLocalAsync(UnbindByCardNoRequest request) async {
		var rpcRst = await call("UnbindByCardNoLocalAsync", request);
		return rpcRst;
	}

	Future<List<FaceRecognitionDTO>> getAllPersonListLocalAsync(GetPersonListRequest2 request) async {
		var rpcRst = await call("GetAllPersonListLocalAsync", request);
		var result = (rpcRst as List).map((e)=>FaceRecognitionDTO.fromJson(e as Map<String, dynamic>)).toList();
		return result;
	}

}

