import 'dart:core';

import 'package:fis_jsonrpc/client_base.dart';
import 'package:fis_common/json_convert.dart';

import 'vitalPrescription.m.dart';

import 'researchEdition.m.dart';


class VitalPrescriptionService extends JsonRpcClientBase {
	VitalPrescriptionService(
		String host, {
		String serviceName = "IVitalPrescriptionService",
		Map<String, String>? headers,
		int? timeout,
	}) : super(
						host,
						serviceName,
						headers: headers,
						timeout: timeout,
				) {
		/// 注册响应实体反序列化处理器
		FJsonConvert.setDecoder((map) => PrescriptionDTO.fromJson(map));
		FJsonConvert.setDecoder((map) => PageCollection<PrescriptionDTO>.fromJson(map));
	}

	Future<String> createPrescriptionAsync(CreatePrescriptionRequest request) async {
		var rpcRst = await call("CreatePrescriptionAsync", request);
		return rpcRst;
	}

	Future<PrescriptionDTO> getPrescriptionDetailAsync(GetPrescriptionRequest request) async {
		var rpcRst = await call("GetPrescriptionDetailAsync", request);
		var result = PrescriptionDTO.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<PrescriptionDTO> getPrescriptionDetailByFollowAnPatientAsync(GetPrescriptionDetailByFollowAnPatientRequest request) async {
		var rpcRst = await call("GetPrescriptionDetailByFollowAnPatientAsync", request);
		var result = PrescriptionDTO.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<PageCollection<PrescriptionDTO>> getPrescriptionPageAsync(PrescriptionPageRequest request) async {
		var rpcRst = await call("GetPrescriptionPageAsync", request);
		var result = PageCollection<PrescriptionDTO>.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<bool> removePrescriptionAsync(RemovePrescriptionRequest request) async {
		var rpcRst = await call("RemovePrescriptionAsync", request);
		return rpcRst;
	}

	Future<List<PrescriptionDTO>> getPrescriptionListAsync(GetPrescriptionListRequest request) async {
		var rpcRst = await call("GetPrescriptionListAsync", request);
		var result = (rpcRst as List).map((e)=>PrescriptionDTO.fromJson(e as Map<String, dynamic>)).toList();
		return result;
	}

	Future<bool> updatePrescriptionAsync(UpdatePrescriptionRequest request) async {
		var rpcRst = await call("UpdatePrescriptionAsync", request);
		return rpcRst;
	}

}

