import 'researchEdition.m.dart';
import 'notification.m.dart';

import 'package:fis_jsonrpc/utils.dart';

class CreatePrescriptionRequest extends TokenRequest{
	String? code;
	String? key;
	String? patientCode;
	String? physicalExamNumber;
	String? followUpCode;
	String? prescriptionData;

	CreatePrescriptionRequest({
		this.code,
		this.key,
		this.patientCode,
		this.physicalExamNumber,
		this.followUpCode,
		this.prescriptionData,
		String? token,
	}) : super(
			token: token,
		);

	factory CreatePrescriptionRequest.fromJson(Map<String, dynamic> map) {
		return CreatePrescriptionRequest( 
			code: map['Code'],
			key: map['Key'],
			patientCode: map['PatientCode'],
			physicalExamNumber: map['PhysicalExamNumber'],
			followUpCode: map['FollowUpCode'],
			prescriptionData: map['PrescriptionData'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		if (key != null)
			map['Key'] = key;
		if (patientCode != null)
			map['PatientCode'] = patientCode;
		if (physicalExamNumber != null)
			map['PhysicalExamNumber'] = physicalExamNumber;
		if (followUpCode != null)
			map['FollowUpCode'] = followUpCode;
		if (prescriptionData != null)
			map['PrescriptionData'] = prescriptionData;
		return map;
	}
}

class PrescriptionDTO extends BaseDTO{
	String? code;
	String? patientCode;
	String? patientName;
	DateTime? prescriptionTime;
	String? previewUrl;
	String? prescriptionData;
	String? prescriptionTemplateKey;

	PrescriptionDTO({
		this.code,
		this.patientCode,
		this.patientName,
		this.prescriptionTime,
		this.previewUrl,
		this.prescriptionData,
		this.prescriptionTemplateKey,
		bool isDelete = false,
		DateTime? createTime,
		DateTime? updateTime,
	}) : super(
			isDelete: isDelete,
			createTime: createTime,
			updateTime: updateTime,
		);

	factory PrescriptionDTO.fromJson(Map<String, dynamic> map) {
		return PrescriptionDTO( 
			code: map['Code'],
			patientCode: map['PatientCode'],
			patientName: map['PatientName'],
			prescriptionTime: map['PrescriptionTime'] != null ? DateTime.parse(map['PrescriptionTime']) : null,
			previewUrl: map['PreviewUrl'],
			prescriptionData: map['PrescriptionData'],
			prescriptionTemplateKey: map['PrescriptionTemplateKey'],
			isDelete: map['IsDelete'],
			createTime: map['CreateTime'] != null ? DateTime.parse(map['CreateTime']) : null,
			updateTime: map['UpdateTime'] != null ? DateTime.parse(map['UpdateTime']) : null,
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		if (patientCode != null)
			map['PatientCode'] = patientCode;
		if (patientName != null)
			map['PatientName'] = patientName;
		if (prescriptionTime != null)
			map['PrescriptionTime'] = JsonRpcUtils.dateFormat(prescriptionTime!);
		if (previewUrl != null)
			map['PreviewUrl'] = previewUrl;
		if (prescriptionData != null)
			map['PrescriptionData'] = prescriptionData;
		if (prescriptionTemplateKey != null)
			map['PrescriptionTemplateKey'] = prescriptionTemplateKey;
		return map;
	}
}

class GetPrescriptionRequest extends TokenRequest{
	String? code;

	GetPrescriptionRequest({
		this.code,
		String? token,
	}) : super(
			token: token,
		);

	factory GetPrescriptionRequest.fromJson(Map<String, dynamic> map) {
		return GetPrescriptionRequest( 
			code: map['Code'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		return map;
	}
}

class GetPrescriptionDetailByFollowAnPatientRequest extends TokenRequest{
	String? followUpCode;
	String? patientCode;

	GetPrescriptionDetailByFollowAnPatientRequest({
		this.followUpCode,
		this.patientCode,
		String? token,
	}) : super(
			token: token,
		);

	factory GetPrescriptionDetailByFollowAnPatientRequest.fromJson(Map<String, dynamic> map) {
		return GetPrescriptionDetailByFollowAnPatientRequest( 
			followUpCode: map['FollowUpCode'],
			patientCode: map['PatientCode'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (followUpCode != null)
			map['FollowUpCode'] = followUpCode;
		if (patientCode != null)
			map['PatientCode'] = patientCode;
		return map;
	}
}

class PrescriptionPageRequest extends PageRequest{
	String? patientCode;
	String? physicalExamNumber;
	String? followUpCode;
	String? key;
	DateTime? startTime;
	DateTime? endTime;

	PrescriptionPageRequest({
		this.patientCode,
		this.physicalExamNumber,
		this.followUpCode,
		this.key,
		this.startTime,
		this.endTime,
		int pageIndex = 0,
		int pageSize = 0,
		String? token,
	}) : super(
			pageIndex: pageIndex,
			pageSize: pageSize,
			token: token,
		);

	factory PrescriptionPageRequest.fromJson(Map<String, dynamic> map) {
		return PrescriptionPageRequest( 
			patientCode: map['PatientCode'],
			physicalExamNumber: map['PhysicalExamNumber'],
			followUpCode: map['FollowUpCode'],
			key: map['Key'],
			startTime: map['StartTime'] != null ? DateTime.parse(map['StartTime']) : null,
			endTime: map['EndTime'] != null ? DateTime.parse(map['EndTime']) : null,
			pageIndex: map['PageIndex'],
			pageSize: map['PageSize'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (patientCode != null)
			map['PatientCode'] = patientCode;
		if (physicalExamNumber != null)
			map['PhysicalExamNumber'] = physicalExamNumber;
		if (followUpCode != null)
			map['FollowUpCode'] = followUpCode;
		if (key != null)
			map['Key'] = key;
		if (startTime != null)
			map['StartTime'] = JsonRpcUtils.dateFormat(startTime!);
		if (endTime != null)
			map['EndTime'] = JsonRpcUtils.dateFormat(endTime!);
		return map;
	}
}

class RemovePrescriptionRequest extends TokenRequest{
	String? code;

	RemovePrescriptionRequest({
		this.code,
		String? token,
	}) : super(
			token: token,
		);

	factory RemovePrescriptionRequest.fromJson(Map<String, dynamic> map) {
		return RemovePrescriptionRequest( 
			code: map['Code'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		return map;
	}
}

class GetPrescriptionListRequest extends TokenRequest{
	List<String>? codes;

	GetPrescriptionListRequest({
		this.codes,
		String? token,
	}) : super(
			token: token,
		);

	factory GetPrescriptionListRequest.fromJson(Map<String, dynamic> map) {
		return GetPrescriptionListRequest( 
			codes: map['Codes']?.cast<String>().toList(),
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (codes != null)
			map['Codes'] = codes;
		return map;
	}
}

class UpdatePrescriptionRequest extends TokenRequest{
	String? code;
	String? key;
	String? patientCode;
	String? prescriptionData;
	String? physicalExamNumber;
	String? followUpCode;

	UpdatePrescriptionRequest({
		this.code,
		this.key,
		this.patientCode,
		this.prescriptionData,
		this.physicalExamNumber,
		this.followUpCode,
		String? token,
	}) : super(
			token: token,
		);

	factory UpdatePrescriptionRequest.fromJson(Map<String, dynamic> map) {
		return UpdatePrescriptionRequest( 
			code: map['Code'],
			key: map['Key'],
			patientCode: map['PatientCode'],
			prescriptionData: map['PrescriptionData'],
			physicalExamNumber: map['PhysicalExamNumber'],
			followUpCode: map['FollowUpCode'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		if (key != null)
			map['Key'] = key;
		if (patientCode != null)
			map['PatientCode'] = patientCode;
		if (prescriptionData != null)
			map['PrescriptionData'] = prescriptionData;
		if (physicalExamNumber != null)
			map['PhysicalExamNumber'] = physicalExamNumber;
		if (followUpCode != null)
			map['FollowUpCode'] = followUpCode;
		return map;
	}
}


