import 'dart:core';

import 'package:fis_jsonrpc/client_base.dart';
import 'package:fis_common/json_convert.dart';

import 'vitalReport.m.dart';

import 'report.m.dart';
import 'researchEdition.m.dart';


class VitalReportService extends JsonRpcClientBase {
	VitalReportService(
		String host, {
		String serviceName = "IVitalReportService",
		Map<String, String>? headers,
		int? timeout,
	}) : super(
						host,
						serviceName,
						headers: headers,
						timeout: timeout,
				) {
		/// 注册响应实体反序列化处理器
		FJsonConvert.setDecoder((map) => ReportDTO2.fromJson(map));
		FJsonConvert.setDecoder((map) => PageCollection<ReportDTO2>.fromJson(map));
	}

	Future<String> createReportAsync(CreateReportRequest request) async {
		var rpcRst = await call("CreateReportAsync", request);
		return rpcRst;
	}

	Future<ReportDTO2> getReportDetailAsync(GetReportRequest request) async {
		var rpcRst = await call("GetReportDetailAsync", request);
		var result = ReportDTO2.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<ReportDTO2> getReportDetailByKeyAsync(GetReportByKeyRequest request) async {
		var rpcRst = await call("GetReportDetailByKeyAsync", request);
		var result = ReportDTO2.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<PageCollection<ReportDTO2>> getReportPageAsync(ReportPageRequest request) async {
		var rpcRst = await call("GetReportPageAsync", request);
		var result = PageCollection<ReportDTO2>.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<bool> removeReportAsync(RemoveReportRequest request) async {
		var rpcRst = await call("RemoveReportAsync", request);
		return rpcRst;
	}

	Future<List<ReportDTO2>> getReportListAsync(GetReportListRequest request) async {
		var rpcRst = await call("GetReportListAsync", request);
		var result = (rpcRst as List).map((e)=>ReportDTO2.fromJson(e as Map<String, dynamic>)).toList();
		return result;
	}

	Future<bool> updateReportAsync(UpdateReportRequest request) async {
		var rpcRst = await call("UpdateReportAsync", request);
		return rpcRst;
	}

}

