import 'researchEdition.m.dart';
import 'report.m.dart';
import 'notification.m.dart';

import 'package:fis_jsonrpc/utils.dart';

class CreateReportRequest extends TokenRequest{
	String? code;
	String? key;
	String? patientCode;
	String? contractedDoctor;
	String? reportDataJson;
	ReportStateEnum reportState;
	String? templateCode;
	String? physicalExamNumber;
	String? examCode;
	List<PreviewDTO>? previewList;
	Map<String,String>? reportData;

	CreateReportRequest({
		this.code,
		this.key,
		this.patientCode,
		this.contractedDoctor,
		this.reportDataJson,
		this.reportState = ReportStateEnum.Unchecked,
		this.templateCode,
		this.physicalExamNumber,
		this.examCode,
		this.previewList,
		this.reportData,
		String? token,
	}) : super(
			token: token,
		);

	factory CreateReportRequest.fromJson(Map<String, dynamic> map) {
		return CreateReportRequest( 
			code: map['Code'],
			key: map['Key'],
			patientCode: map['PatientCode'],
			contractedDoctor: map['ContractedDoctor'],
			reportDataJson: map['ReportDataJson'],
			reportState: ReportStateEnum.values.firstWhere((e) => e.index == map['ReportState']),
			templateCode: map['TemplateCode'],
			physicalExamNumber: map['PhysicalExamNumber'],
			examCode: map['ExamCode'],
			previewList: map['PreviewList'] != null ? (map['PreviewList'] as List).map((e)=>PreviewDTO.fromJson(e as Map<String,dynamic>)).toList() : null,
			reportData: map['ReportData']?.cast<String,String>(),
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		if (key != null)
			map['Key'] = key;
		if (patientCode != null)
			map['PatientCode'] = patientCode;
		if (contractedDoctor != null)
			map['ContractedDoctor'] = contractedDoctor;
		if (reportDataJson != null)
			map['ReportDataJson'] = reportDataJson;
		map['ReportState'] = reportState.index;
		if (templateCode != null)
			map['TemplateCode'] = templateCode;
		if (physicalExamNumber != null)
			map['PhysicalExamNumber'] = physicalExamNumber;
		if (examCode != null)
			map['ExamCode'] = examCode;
		if (previewList != null)
			map['PreviewList'] = previewList;
		if (reportData != null)
			map['ReportData'] = reportData;
		return map;
	}
}

class GetReportRequest extends TokenRequest{
	String? code;

	GetReportRequest({
		this.code,
		String? token,
	}) : super(
			token: token,
		);

	factory GetReportRequest.fromJson(Map<String, dynamic> map) {
		return GetReportRequest( 
			code: map['Code'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		return map;
	}
}

class GetReportByKeyRequest extends TokenRequest{
	String? key;
	String? value;

	GetReportByKeyRequest({
		this.key,
		this.value,
		String? token,
	}) : super(
			token: token,
		);

	factory GetReportByKeyRequest.fromJson(Map<String, dynamic> map) {
		return GetReportByKeyRequest( 
			key: map['Key'],
			value: map['Value'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (key != null)
			map['Key'] = key;
		if (value != null)
			map['Value'] = value;
		return map;
	}
}

class ReportPageRequest extends PageRequest{
	String? keyword;
	DateTime? startTime;
	DateTime? endTime;

	ReportPageRequest({
		this.keyword,
		this.startTime,
		this.endTime,
		int pageIndex = 0,
		int pageSize = 0,
		String? token,
	}) : super(
			pageIndex: pageIndex,
			pageSize: pageSize,
			token: token,
		);

	factory ReportPageRequest.fromJson(Map<String, dynamic> map) {
		return ReportPageRequest( 
			keyword: map['Keyword'],
			startTime: map['StartTime'] != null ? DateTime.parse(map['StartTime']) : null,
			endTime: map['EndTime'] != null ? DateTime.parse(map['EndTime']) : null,
			pageIndex: map['PageIndex'],
			pageSize: map['PageSize'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (keyword != null)
			map['Keyword'] = keyword;
		if (startTime != null)
			map['StartTime'] = JsonRpcUtils.dateFormat(startTime!);
		if (endTime != null)
			map['EndTime'] = JsonRpcUtils.dateFormat(endTime!);
		return map;
	}
}

class RemoveReportRequest extends TokenRequest{
	String? code;

	RemoveReportRequest({
		this.code,
		String? token,
	}) : super(
			token: token,
		);

	factory RemoveReportRequest.fromJson(Map<String, dynamic> map) {
		return RemoveReportRequest( 
			code: map['Code'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		return map;
	}
}

class GetReportListRequest extends TokenRequest{
	List<String>? codes;

	GetReportListRequest({
		this.codes,
		String? token,
	}) : super(
			token: token,
		);

	factory GetReportListRequest.fromJson(Map<String, dynamic> map) {
		return GetReportListRequest( 
			codes: map['Codes']?.cast<String>().toList(),
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (codes != null)
			map['Codes'] = codes;
		return map;
	}
}

class UpdateReportRequest extends TokenRequest{
	String? code;
	String? key;
	String? patientCode;
	String? contractedDoctor;
	String? reportDataJson;
	String? reportTemplateJson;
	ReportStateEnum? reportState;
	String? templateCode;
	String? physicalExamNumber;
	String? examCode;
	List<PreviewDTO>? previewList;
	Map<String,String>? reportData;

	UpdateReportRequest({
		this.code,
		this.key,
		this.patientCode,
		this.contractedDoctor,
		this.reportDataJson,
		this.reportTemplateJson,
		this.reportState,
		this.templateCode,
		this.physicalExamNumber,
		this.examCode,
		this.previewList,
		this.reportData,
		String? token,
	}) : super(
			token: token,
		);

	factory UpdateReportRequest.fromJson(Map<String, dynamic> map) {
		return UpdateReportRequest( 
			code: map['Code'],
			key: map['Key'],
			patientCode: map['PatientCode'],
			contractedDoctor: map['ContractedDoctor'],
			reportDataJson: map['ReportDataJson'],
			reportTemplateJson: map['ReportTemplateJson'],
			reportState: map['ReportState'] != null ? ReportStateEnum.values.firstWhere((e) => e.index == map['ReportState']) : null,
			templateCode: map['TemplateCode'],
			physicalExamNumber: map['PhysicalExamNumber'],
			examCode: map['ExamCode'],
			previewList: map['PreviewList'] != null ? (map['PreviewList'] as List).map((e)=>PreviewDTO.fromJson(e as Map<String,dynamic>)).toList() : null,
			reportData: map['ReportData']?.cast<String,String>(),
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		if (key != null)
			map['Key'] = key;
		if (patientCode != null)
			map['PatientCode'] = patientCode;
		if (contractedDoctor != null)
			map['ContractedDoctor'] = contractedDoctor;
		if (reportDataJson != null)
			map['ReportDataJson'] = reportDataJson;
		if (reportTemplateJson != null)
			map['ReportTemplateJson'] = reportTemplateJson;
		if (reportState != null)
		map['ReportState'] = reportState?.index;
		if (templateCode != null)
			map['TemplateCode'] = templateCode;
		if (physicalExamNumber != null)
			map['PhysicalExamNumber'] = physicalExamNumber;
		if (examCode != null)
			map['ExamCode'] = examCode;
		if (previewList != null)
			map['PreviewList'] = previewList;
		if (reportData != null)
			map['ReportData'] = reportData;
		return map;
	}
}


