import 'dart:core';

import 'package:fis_jsonrpc/client_base.dart';
import 'package:fis_common/json_convert.dart';

import 'vitalResidence.m.dart';

import 'researchEdition.m.dart';


class VitalResidenceService extends JsonRpcClientBase {
	VitalResidenceService(
		String host, {
		String serviceName = "IVitalResidenceService",
		Map<String, String>? headers,
		int? timeout,
	}) : super(
						host,
						serviceName,
						headers: headers,
						timeout: timeout,
				) {
		/// 注册响应实体反序列化处理器
		FJsonConvert.setDecoder((map) => ResidenceDTO.fromJson(map));
		FJsonConvert.setDecoder((map) => PageCollection<ResidenceDTO>.fromJson(map));
	}

	Future<String> createResidenceAsync(CreateResidenceRequest request) async {
		var rpcRst = await call("CreateResidenceAsync", request);
		return rpcRst;
	}

	Future<ResidenceDTO> getResidenceDetailAsync(GetResidenceRequest request) async {
		var rpcRst = await call("GetResidenceDetailAsync", request);
		var result = ResidenceDTO.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<ResidenceDTO> getResidenceDetailByKeyAsync(GetResidenceByKeyRequest request) async {
		var rpcRst = await call("GetResidenceDetailByKeyAsync", request);
		var result = ResidenceDTO.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<PageCollection<ResidenceDTO>> getResidencePageAsync(ResidencePageRequest request) async {
		var rpcRst = await call("GetResidencePageAsync", request);
		var result = PageCollection<ResidenceDTO>.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<bool> removeResidenceAsync(RemoveResidenceRequest request) async {
		var rpcRst = await call("RemoveResidenceAsync", request);
		return rpcRst;
	}

	Future<List<ResidenceDTO>> getResidenceListAsync(GetResidenceListRequest request) async {
		var rpcRst = await call("GetResidenceListAsync", request);
		var result = (rpcRst as List).map((e)=>ResidenceDTO.fromJson(e as Map<String, dynamic>)).toList();
		return result;
	}

	Future<bool> updateResidenceAsync(UpdateResidenceRequest request) async {
		var rpcRst = await call("UpdateResidenceAsync", request);
		return rpcRst;
	}

	Future<PageCollection<ResidenceDTO>> getResidencePageByTownAsync(GetResidencePageByTownRequest request) async {
		var rpcRst = await call("GetResidencePageByTownAsync", request);
		var result = PageCollection<ResidenceDTO>.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

}

