import 'researchEdition.m.dart';
import 'notification.m.dart';

import 'package:fis_jsonrpc/utils.dart';

class CreateResidenceRequest extends TokenRequest{
	String? code;
	String? townCode;
	String? name;

	CreateResidenceRequest({
		this.code,
		this.townCode,
		this.name,
		String? token,
	}) : super(
			token: token,
		);

	factory CreateResidenceRequest.fromJson(Map<String, dynamic> map) {
		return CreateResidenceRequest( 
			code: map['Code'],
			townCode: map['TownCode'],
			name: map['Name'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		if (townCode != null)
			map['TownCode'] = townCode;
		if (name != null)
			map['Name'] = name;
		return map;
	}
}

class ResidenceDTO extends BaseDTO{
	String? code;
	String? provinceCode;
	String? cityCode;
	String? districtCode;
	String? townName;
	String? townCode;
	String? name;

	ResidenceDTO({
		this.code,
		this.provinceCode,
		this.cityCode,
		this.districtCode,
		this.townName,
		this.townCode,
		this.name,
		bool isDelete = false,
		DateTime? createTime,
		DateTime? updateTime,
	}) : super(
			isDelete: isDelete,
			createTime: createTime,
			updateTime: updateTime,
		);

	factory ResidenceDTO.fromJson(Map<String, dynamic> map) {
		return ResidenceDTO( 
			code: map['Code'],
			provinceCode: map['ProvinceCode'],
			cityCode: map['CityCode'],
			districtCode: map['DistrictCode'],
			townName: map['TownName'],
			townCode: map['TownCode'],
			name: map['Name'],
			isDelete: map['IsDelete'],
			createTime: map['CreateTime'] != null ? DateTime.parse(map['CreateTime']) : null,
			updateTime: map['UpdateTime'] != null ? DateTime.parse(map['UpdateTime']) : null,
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		if (provinceCode != null)
			map['ProvinceCode'] = provinceCode;
		if (cityCode != null)
			map['CityCode'] = cityCode;
		if (districtCode != null)
			map['DistrictCode'] = districtCode;
		if (townName != null)
			map['TownName'] = townName;
		if (townCode != null)
			map['TownCode'] = townCode;
		if (name != null)
			map['Name'] = name;
		return map;
	}
}

class GetResidenceRequest extends TokenRequest{
	String? code;

	GetResidenceRequest({
		this.code,
		String? token,
	}) : super(
			token: token,
		);

	factory GetResidenceRequest.fromJson(Map<String, dynamic> map) {
		return GetResidenceRequest( 
			code: map['Code'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		return map;
	}
}

class GetResidenceByKeyRequest extends TokenRequest{
	String? key;
	String? value;

	GetResidenceByKeyRequest({
		this.key,
		this.value,
		String? token,
	}) : super(
			token: token,
		);

	factory GetResidenceByKeyRequest.fromJson(Map<String, dynamic> map) {
		return GetResidenceByKeyRequest( 
			key: map['Key'],
			value: map['Value'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (key != null)
			map['Key'] = key;
		if (value != null)
			map['Value'] = value;
		return map;
	}
}

class ResidencePageRequest extends PageRequest{
	String? keyword;
	DateTime? startTime;
	DateTime? endTime;

	ResidencePageRequest({
		this.keyword,
		this.startTime,
		this.endTime,
		int pageIndex = 0,
		int pageSize = 0,
		String? token,
	}) : super(
			pageIndex: pageIndex,
			pageSize: pageSize,
			token: token,
		);

	factory ResidencePageRequest.fromJson(Map<String, dynamic> map) {
		return ResidencePageRequest( 
			keyword: map['Keyword'],
			startTime: map['StartTime'] != null ? DateTime.parse(map['StartTime']) : null,
			endTime: map['EndTime'] != null ? DateTime.parse(map['EndTime']) : null,
			pageIndex: map['PageIndex'],
			pageSize: map['PageSize'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (keyword != null)
			map['Keyword'] = keyword;
		if (startTime != null)
			map['StartTime'] = JsonRpcUtils.dateFormat(startTime!);
		if (endTime != null)
			map['EndTime'] = JsonRpcUtils.dateFormat(endTime!);
		return map;
	}
}

class RemoveResidenceRequest extends TokenRequest{
	String? code;

	RemoveResidenceRequest({
		this.code,
		String? token,
	}) : super(
			token: token,
		);

	factory RemoveResidenceRequest.fromJson(Map<String, dynamic> map) {
		return RemoveResidenceRequest( 
			code: map['Code'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		return map;
	}
}

class GetResidenceListRequest extends TokenRequest{
	List<String>? codes;

	GetResidenceListRequest({
		this.codes,
		String? token,
	}) : super(
			token: token,
		);

	factory GetResidenceListRequest.fromJson(Map<String, dynamic> map) {
		return GetResidenceListRequest( 
			codes: map['Codes']?.cast<String>().toList(),
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (codes != null)
			map['Codes'] = codes;
		return map;
	}
}

class UpdateResidenceRequest extends TokenRequest{
	String? code;
	String? townCode;
	String? name;

	UpdateResidenceRequest({
		this.code,
		this.townCode,
		this.name,
		String? token,
	}) : super(
			token: token,
		);

	factory UpdateResidenceRequest.fromJson(Map<String, dynamic> map) {
		return UpdateResidenceRequest( 
			code: map['Code'],
			townCode: map['TownCode'],
			name: map['Name'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		if (townCode != null)
			map['TownCode'] = townCode;
		if (name != null)
			map['Name'] = name;
		return map;
	}
}

class GetResidencePageByTownRequest extends PageRequest{
	String? keyword;
	DateTime? startTime;
	DateTime? endTime;
	String? townCode;

	GetResidencePageByTownRequest({
		this.keyword,
		this.startTime,
		this.endTime,
		this.townCode,
		int pageIndex = 0,
		int pageSize = 0,
		String? token,
	}) : super(
			pageIndex: pageIndex,
			pageSize: pageSize,
			token: token,
		);

	factory GetResidencePageByTownRequest.fromJson(Map<String, dynamic> map) {
		return GetResidencePageByTownRequest( 
			keyword: map['Keyword'],
			startTime: map['StartTime'] != null ? DateTime.parse(map['StartTime']) : null,
			endTime: map['EndTime'] != null ? DateTime.parse(map['EndTime']) : null,
			townCode: map['TownCode'],
			pageIndex: map['PageIndex'],
			pageSize: map['PageSize'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (keyword != null)
			map['Keyword'] = keyword;
		if (startTime != null)
			map['StartTime'] = JsonRpcUtils.dateFormat(startTime!);
		if (endTime != null)
			map['EndTime'] = JsonRpcUtils.dateFormat(endTime!);
		if (townCode != null)
			map['TownCode'] = townCode;
		return map;
	}
}


