import 'dart:core';

import 'package:fis_jsonrpc/client_base.dart';
import 'package:fis_common/json_convert.dart';

import 'vitalRole.m.dart';

import 'researchEdition.m.dart';


class VitalRoleService extends JsonRpcClientBase {
	VitalRoleService(
		String host, {
		String serviceName = "IVitalRoleService",
		Map<String, String>? headers,
		int? timeout,
	}) : super(
						host,
						serviceName,
						headers: headers,
						timeout: timeout,
				) {
		/// 注册响应实体反序列化处理器
		FJsonConvert.setDecoder((map) => RoleDTO2.fromJson(map));
		FJsonConvert.setDecoder((map) => PageCollection<RoleDTO2>.fromJson(map));
	}

	Future<String> createRoleAsync(CreateRoleRequest request) async {
		var rpcRst = await call("CreateRoleAsync", request);
		return rpcRst;
	}

	Future<RoleDTO2> getRoleDetailAsync(GetRoleRequest request) async {
		var rpcRst = await call("GetRoleDetailAsync", request);
		var result = RoleDTO2.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<RoleDTO2> getRoleDetailByKeyAsync(GetRoleByKeyRequest request) async {
		var rpcRst = await call("GetRoleDetailByKeyAsync", request);
		var result = RoleDTO2.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<PageCollection<RoleDTO2>> getRolePageAsync(RolePageRequest request) async {
		var rpcRst = await call("GetRolePageAsync", request);
		var result = PageCollection<RoleDTO2>.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<bool> removeRoleAsync(RemoveRoleRequest request) async {
		var rpcRst = await call("RemoveRoleAsync", request);
		return rpcRst;
	}

	Future<List<RoleDTO2>> getRoleListAsync(GetRoleListRequest request) async {
		var rpcRst = await call("GetRoleListAsync", request);
		var result = (rpcRst as List).map((e)=>RoleDTO2.fromJson(e as Map<String, dynamic>)).toList();
		return result;
	}

	Future<bool> updateRoleAsync(UpdateRoleRequest request) async {
		var rpcRst = await call("UpdateRoleAsync", request);
		return rpcRst;
	}

}

