import 'researchEdition.m.dart';
import 'notification.m.dart';

import 'package:fis_jsonrpc/utils.dart';

class CreateRoleRequest extends TokenRequest{
	String? code;
	String? roleName;
	List<String>? featureCodes;
	String? description;

	CreateRoleRequest({
		this.code,
		this.roleName,
		this.featureCodes,
		this.description,
		String? token,
	}) : super(
			token: token,
		);

	factory CreateRoleRequest.fromJson(Map<String, dynamic> map) {
		return CreateRoleRequest( 
			code: map['Code'],
			roleName: map['RoleName'],
			featureCodes: map['FeatureCodes']?.cast<String>().toList(),
			description: map['Description'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		if (roleName != null)
			map['RoleName'] = roleName;
		if (featureCodes != null)
			map['FeatureCodes'] = featureCodes;
		if (description != null)
			map['Description'] = description;
		return map;
	}
}

class RoleDTO2 extends BaseDTO{
	String? code;
	String? roleName;
	List<String>? featureCodes;
	String? description;

	RoleDTO2({
		this.code,
		this.roleName,
		this.featureCodes,
		this.description,
		bool isDelete = false,
		DateTime? createTime,
		DateTime? updateTime,
	}) : super(
			isDelete: isDelete,
			createTime: createTime,
			updateTime: updateTime,
		);

	factory RoleDTO2.fromJson(Map<String, dynamic> map) {
		return RoleDTO2( 
			code: map['Code'],
			roleName: map['RoleName'],
			featureCodes: map['FeatureCodes']?.cast<String>().toList(),
			description: map['Description'],
			isDelete: map['IsDelete'],
			createTime: map['CreateTime'] != null ? DateTime.parse(map['CreateTime']) : null,
			updateTime: map['UpdateTime'] != null ? DateTime.parse(map['UpdateTime']) : null,
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		if (roleName != null)
			map['RoleName'] = roleName;
		if (featureCodes != null)
			map['FeatureCodes'] = featureCodes;
		if (description != null)
			map['Description'] = description;
		return map;
	}
}

class GetRoleRequest extends TokenRequest{
	String? code;

	GetRoleRequest({
		this.code,
		String? token,
	}) : super(
			token: token,
		);

	factory GetRoleRequest.fromJson(Map<String, dynamic> map) {
		return GetRoleRequest( 
			code: map['Code'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		return map;
	}
}

class GetRoleByKeyRequest extends TokenRequest{
	String? key;
	String? value;

	GetRoleByKeyRequest({
		this.key,
		this.value,
		String? token,
	}) : super(
			token: token,
		);

	factory GetRoleByKeyRequest.fromJson(Map<String, dynamic> map) {
		return GetRoleByKeyRequest( 
			key: map['Key'],
			value: map['Value'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (key != null)
			map['Key'] = key;
		if (value != null)
			map['Value'] = value;
		return map;
	}
}

class RolePageRequest extends PageRequest{
	String? keyword;
	DateTime? startTime;
	DateTime? endTime;

	RolePageRequest({
		this.keyword,
		this.startTime,
		this.endTime,
		int pageIndex = 0,
		int pageSize = 0,
		String? token,
	}) : super(
			pageIndex: pageIndex,
			pageSize: pageSize,
			token: token,
		);

	factory RolePageRequest.fromJson(Map<String, dynamic> map) {
		return RolePageRequest( 
			keyword: map['Keyword'],
			startTime: map['StartTime'] != null ? DateTime.parse(map['StartTime']) : null,
			endTime: map['EndTime'] != null ? DateTime.parse(map['EndTime']) : null,
			pageIndex: map['PageIndex'],
			pageSize: map['PageSize'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (keyword != null)
			map['Keyword'] = keyword;
		if (startTime != null)
			map['StartTime'] = JsonRpcUtils.dateFormat(startTime!);
		if (endTime != null)
			map['EndTime'] = JsonRpcUtils.dateFormat(endTime!);
		return map;
	}
}

class RemoveRoleRequest extends TokenRequest{
	String? code;

	RemoveRoleRequest({
		this.code,
		String? token,
	}) : super(
			token: token,
		);

	factory RemoveRoleRequest.fromJson(Map<String, dynamic> map) {
		return RemoveRoleRequest( 
			code: map['Code'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		return map;
	}
}

class GetRoleListRequest extends TokenRequest{
	List<String>? codes;

	GetRoleListRequest({
		this.codes,
		String? token,
	}) : super(
			token: token,
		);

	factory GetRoleListRequest.fromJson(Map<String, dynamic> map) {
		return GetRoleListRequest( 
			codes: map['Codes']?.cast<String>().toList(),
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (codes != null)
			map['Codes'] = codes;
		return map;
	}
}

class UpdateRoleRequest extends TokenRequest{
	String? code;
	String? roleName;
	List<String>? featureCodes;
	String? description;

	UpdateRoleRequest({
		this.code,
		this.roleName,
		this.featureCodes,
		this.description,
		String? token,
	}) : super(
			token: token,
		);

	factory UpdateRoleRequest.fromJson(Map<String, dynamic> map) {
		return UpdateRoleRequest( 
			code: map['Code'],
			roleName: map['RoleName'],
			featureCodes: map['FeatureCodes']?.cast<String>().toList(),
			description: map['Description'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		if (roleName != null)
			map['RoleName'] = roleName;
		if (featureCodes != null)
			map['FeatureCodes'] = featureCodes;
		if (description != null)
			map['Description'] = description;
		return map;
	}
}


