import 'researchEdition.m.dart';

import 'package:fis_jsonrpc/utils.dart';

enum TransactionStatusEnum2 {
	placeHolder_0,
	Applied,
	Withdrawn,
	Rejected,
	ToStart,
	InProgress,
	PendingReport,
	End,
	Embedded,
	Common,
	Tencent,
	TRTC,
	VRTC,
	Expired,
}

enum ScheduleTypeEnum2 {
	Exercise,
	FollowUp,
}

class ClientScheduleDTO2 {
	String? title;
	TransactionStatusEnum2 status;
	ScheduleTypeEnum2 scheduleType;
	DateTime? startTime;
	DateTime? endTime;
	String? relevanceCode;

	ClientScheduleDTO2({
		this.title,
		this.status = TransactionStatusEnum2.Applied,
		this.scheduleType = ScheduleTypeEnum2.Exercise,
		this.startTime,
		this.endTime,
		this.relevanceCode,
	});

	factory ClientScheduleDTO2.fromJson(Map<String, dynamic> map) {
		return ClientScheduleDTO2( 
			title: map['Title'],
			status: TransactionStatusEnum2.values.firstWhere((e) => e.index == map['Status']),
			scheduleType: ScheduleTypeEnum2.values.firstWhere((e) => e.index == map['ScheduleType']),
			startTime: map['StartTime'] != null ? DateTime.parse(map['StartTime']) : null,
			endTime: map['EndTime'] != null ? DateTime.parse(map['EndTime']) : null,
			relevanceCode: map['RelevanceCode'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		if (title != null)
			map['Title'] = title;
		map['Status'] = status.index;
		map['ScheduleType'] = scheduleType.index;
		if (startTime != null)
			map['StartTime'] = JsonRpcUtils.dateFormat(startTime!);
		if (endTime != null)
			map['EndTime'] = JsonRpcUtils.dateFormat(endTime!);
		if (relevanceCode != null)
			map['RelevanceCode'] = relevanceCode;
		return map;
	}
}

class FindSchedulesRequest2 extends TokenRequest{
	DateTime? startTime;
	DateTime? endTime;

	FindSchedulesRequest2({
		this.startTime,
		this.endTime,
		String? token,
	}) : super(
			token: token,
		);

	factory FindSchedulesRequest2.fromJson(Map<String, dynamic> map) {
		return FindSchedulesRequest2( 
			startTime: map['StartTime'] != null ? DateTime.parse(map['StartTime']) : null,
			endTime: map['EndTime'] != null ? DateTime.parse(map['EndTime']) : null,
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (startTime != null)
			map['StartTime'] = JsonRpcUtils.dateFormat(startTime!);
		if (endTime != null)
			map['EndTime'] = JsonRpcUtils.dateFormat(endTime!);
		return map;
	}
}


