import 'dart:core';

import 'package:fis_jsonrpc/client_base.dart';
import 'package:fis_common/json_convert.dart';

import 'vitalServicePack.m.dart';

import 'vitalContractRecord.m.dart';
import 'researchEdition.m.dart';


class VitalServicePackService extends JsonRpcClientBase {
	VitalServicePackService(
		String host, {
		String serviceName = "IVitalServicePackService",
		Map<String, String>? headers,
		int? timeout,
	}) : super(
						host,
						serviceName,
						headers: headers,
						timeout: timeout,
				) {
		/// 注册响应实体反序列化处理器
		FJsonConvert.setDecoder((map) => ServicePackDTO.fromJson(map));
		FJsonConvert.setDecoder((map) => PageCollection<ServicePackDTO>.fromJson(map));
		FJsonConvert.setDecoder((map) => ServiceItemDTO.fromJson(map));
		FJsonConvert.setDecoder((map) => PageCollection<ServiceItemDTO>.fromJson(map));
	}

	Future<String> createServicePackAsync(CreateServicePackRequest request) async {
		var rpcRst = await call("CreateServicePackAsync", request);
		return rpcRst;
	}

	Future<ServicePackDTO> getServicePackDetailAsync(GetServicePackRequest request) async {
		var rpcRst = await call("GetServicePackDetailAsync", request);
		var result = ServicePackDTO.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<PageCollection<ServicePackDTO>> getServicePackPageAsync(ServicePackPageRequest request) async {
		var rpcRst = await call("GetServicePackPageAsync", request);
		var result = PageCollection<ServicePackDTO>.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<bool> removetServicePackAsync(RemovetServicePackRequest request) async {
		var rpcRst = await call("RemovetServicePackAsync", request);
		return rpcRst;
	}

	Future<bool> updateServicePackAsync(UpdateServicePackRequest request) async {
		var rpcRst = await call("UpdateServicePackAsync", request);
		return rpcRst;
	}

	Future<bool> updateServicePackForItemsAsync(UpdateServicePackForItemsRequest request) async {
		var rpcRst = await call("UpdateServicePackForItemsAsync", request);
		return rpcRst;
	}

	Future<String> createServiceItemAsync(CreateServiceItemRequest request) async {
		var rpcRst = await call("CreateServiceItemAsync", request);
		return rpcRst;
	}

	Future<ServiceItemDTO> getServiceItemDetailAsync(GetServiceItemRequest request) async {
		var rpcRst = await call("GetServiceItemDetailAsync", request);
		var result = ServiceItemDTO.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<PageCollection<ServiceItemDTO>> getServiceItemPageAsync(GetServiceItemPageRequest request) async {
		var rpcRst = await call("GetServiceItemPageAsync", request);
		var result = PageCollection<ServiceItemDTO>.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<List<ServiceItemDTO>> getServiceItemListAsync(GetServiceItemListRequest request) async {
		var rpcRst = await call("GetServiceItemListAsync", request);
		var result = (rpcRst as List).map((e)=>ServiceItemDTO.fromJson(e as Map<String, dynamic>)).toList();
		return result;
	}

	Future<bool> removetServiceItemAsync(RemovetServiceItemRequest request) async {
		var rpcRst = await call("RemovetServiceItemAsync", request);
		return rpcRst;
	}

	Future<bool> updateServiceItemAsync(UpdateServiceItemRequest request) async {
		var rpcRst = await call("UpdateServiceItemAsync", request);
		return rpcRst;
	}

	Future<bool> updateServicePackForLabelsAsync(UpdateServicePackForLabelsRequest request) async {
		var rpcRst = await call("UpdateServicePackForLabelsAsync", request);
		return rpcRst;
	}

}

