import 'dart:core';

import 'package:fis_jsonrpc/client_base.dart';
import 'package:fis_common/json_convert.dart';

import 'vitalStatistic.m.dart';

import 'researchEdition.m.dart';


class VitalStatisticService extends JsonRpcClientBase {
	VitalStatisticService(
		String host, {
		String serviceName = "IVitalStatisticService",
		Map<String, String>? headers,
		int? timeout,
	}) : super(
						host,
						serviceName,
						headers: headers,
						timeout: timeout,
				) {
		/// 注册响应实体反序列化处理器
		FJsonConvert.setDecoder((map) => StatisticDTO.fromJson(map));
		FJsonConvert.setDecoder((map) => PageCollection<StatisticDTO>.fromJson(map));
	}

	Future<String> createStatisticAsync(CreateStatisticRequest request) async {
		var rpcRst = await call("CreateStatisticAsync", request);
		return rpcRst;
	}

	Future<StatisticDTO> getStatisticDetailAsync(GetStatisticRequest request) async {
		var rpcRst = await call("GetStatisticDetailAsync", request);
		var result = StatisticDTO.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<StatisticDTO> getStatisticDetailByKeyAsync(GetStatisticByKeyRequest request) async {
		var rpcRst = await call("GetStatisticDetailByKeyAsync", request);
		var result = StatisticDTO.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<PageCollection<StatisticDTO>> getStatisticPageAsync(StatisticPageRequest request) async {
		var rpcRst = await call("GetStatisticPageAsync", request);
		var result = PageCollection<StatisticDTO>.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<bool> removeStatisticAsync(RemoveStatisticRequest request) async {
		var rpcRst = await call("RemoveStatisticAsync", request);
		return rpcRst;
	}

	Future<List<StatisticDTO>> getStatisticListAsync(GetStatisticListRequest request) async {
		var rpcRst = await call("GetStatisticListAsync", request);
		var result = (rpcRst as List).map((e)=>StatisticDTO.fromJson(e as Map<String, dynamic>)).toList();
		return result;
	}

	Future<bool> updateStatisticAsync(UpdateStatisticRequest request) async {
		var rpcRst = await call("UpdateStatisticAsync", request);
		return rpcRst;
	}

	Future<String> getHomePageStatisticAsync(GetHomePageStatisticRequest request) async {
		var rpcRst = await call("GetHomePageStatisticAsync", request);
		return rpcRst;
	}

}

