import 'researchEdition.m.dart';
import 'notification.m.dart';

import 'package:fis_jsonrpc/utils.dart';

enum StatisticTypeEnum {
	Number,
	Customer,
}

class CreateStatisticRequest extends TokenRequest{
	String? code;
	String? statisticKey;
	StatisticTypeEnum statisticType;
	String? time;
	String? statisticData;

	CreateStatisticRequest({
		this.code,
		this.statisticKey,
		this.statisticType = StatisticTypeEnum.Number,
		this.time,
		this.statisticData,
		String? token,
	}) : super(
			token: token,
		);

	factory CreateStatisticRequest.fromJson(Map<String, dynamic> map) {
		return CreateStatisticRequest( 
			code: map['Code'],
			statisticKey: map['StatisticKey'],
			statisticType: StatisticTypeEnum.values.firstWhere((e) => e.index == map['StatisticType']),
			time: map['Time'],
			statisticData: map['StatisticData'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		if (statisticKey != null)
			map['StatisticKey'] = statisticKey;
		map['StatisticType'] = statisticType.index;
		if (time != null)
			map['Time'] = time;
		if (statisticData != null)
			map['StatisticData'] = statisticData;
		return map;
	}
}

class StatisticDTO extends BaseDTO{
	String? code;
	String? statisticKey;
	StatisticTypeEnum statisticType;
	String? time;
	String? statisticData;

	StatisticDTO({
		this.code,
		this.statisticKey,
		this.statisticType = StatisticTypeEnum.Number,
		this.time,
		this.statisticData,
		bool isDelete = false,
		DateTime? createTime,
		DateTime? updateTime,
	}) : super(
			isDelete: isDelete,
			createTime: createTime,
			updateTime: updateTime,
		);

	factory StatisticDTO.fromJson(Map<String, dynamic> map) {
		return StatisticDTO( 
			code: map['Code'],
			statisticKey: map['StatisticKey'],
			statisticType: StatisticTypeEnum.values.firstWhere((e) => e.index == map['StatisticType']),
			time: map['Time'],
			statisticData: map['StatisticData'],
			isDelete: map['IsDelete'],
			createTime: map['CreateTime'] != null ? DateTime.parse(map['CreateTime']) : null,
			updateTime: map['UpdateTime'] != null ? DateTime.parse(map['UpdateTime']) : null,
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		if (statisticKey != null)
			map['StatisticKey'] = statisticKey;
		map['StatisticType'] = statisticType.index;
		if (time != null)
			map['Time'] = time;
		if (statisticData != null)
			map['StatisticData'] = statisticData;
		return map;
	}
}

class GetStatisticRequest extends TokenRequest{
	String? code;

	GetStatisticRequest({
		this.code,
		String? token,
	}) : super(
			token: token,
		);

	factory GetStatisticRequest.fromJson(Map<String, dynamic> map) {
		return GetStatisticRequest( 
			code: map['Code'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		return map;
	}
}

class GetStatisticByKeyRequest extends TokenRequest{
	String? key;
	String? value;

	GetStatisticByKeyRequest({
		this.key,
		this.value,
		String? token,
	}) : super(
			token: token,
		);

	factory GetStatisticByKeyRequest.fromJson(Map<String, dynamic> map) {
		return GetStatisticByKeyRequest( 
			key: map['Key'],
			value: map['Value'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (key != null)
			map['Key'] = key;
		if (value != null)
			map['Value'] = value;
		return map;
	}
}

class StatisticPageRequest extends PageRequest{
	String? keyword;
	DateTime? startTime;
	DateTime? endTime;

	StatisticPageRequest({
		this.keyword,
		this.startTime,
		this.endTime,
		int pageIndex = 0,
		int pageSize = 0,
		String? token,
	}) : super(
			pageIndex: pageIndex,
			pageSize: pageSize,
			token: token,
		);

	factory StatisticPageRequest.fromJson(Map<String, dynamic> map) {
		return StatisticPageRequest( 
			keyword: map['Keyword'],
			startTime: map['StartTime'] != null ? DateTime.parse(map['StartTime']) : null,
			endTime: map['EndTime'] != null ? DateTime.parse(map['EndTime']) : null,
			pageIndex: map['PageIndex'],
			pageSize: map['PageSize'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (keyword != null)
			map['Keyword'] = keyword;
		if (startTime != null)
			map['StartTime'] = JsonRpcUtils.dateFormat(startTime!);
		if (endTime != null)
			map['EndTime'] = JsonRpcUtils.dateFormat(endTime!);
		return map;
	}
}

class RemoveStatisticRequest extends TokenRequest{
	String? code;

	RemoveStatisticRequest({
		this.code,
		String? token,
	}) : super(
			token: token,
		);

	factory RemoveStatisticRequest.fromJson(Map<String, dynamic> map) {
		return RemoveStatisticRequest( 
			code: map['Code'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		return map;
	}
}

class GetStatisticListRequest extends TokenRequest{
	List<String>? codes;

	GetStatisticListRequest({
		this.codes,
		String? token,
	}) : super(
			token: token,
		);

	factory GetStatisticListRequest.fromJson(Map<String, dynamic> map) {
		return GetStatisticListRequest( 
			codes: map['Codes']?.cast<String>().toList(),
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (codes != null)
			map['Codes'] = codes;
		return map;
	}
}

class UpdateStatisticRequest extends TokenRequest{
	String? code;
	String? statisticKey;
	StatisticTypeEnum statisticType;
	String? time;
	String? statisticData;

	UpdateStatisticRequest({
		this.code,
		this.statisticKey,
		this.statisticType = StatisticTypeEnum.Number,
		this.time,
		this.statisticData,
		String? token,
	}) : super(
			token: token,
		);

	factory UpdateStatisticRequest.fromJson(Map<String, dynamic> map) {
		return UpdateStatisticRequest( 
			code: map['Code'],
			statisticKey: map['StatisticKey'],
			statisticType: StatisticTypeEnum.values.firstWhere((e) => e.index == map['StatisticType']),
			time: map['Time'],
			statisticData: map['StatisticData'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		if (statisticKey != null)
			map['StatisticKey'] = statisticKey;
		map['StatisticType'] = statisticType.index;
		if (time != null)
			map['Time'] = time;
		if (statisticData != null)
			map['StatisticData'] = statisticData;
		return map;
	}
}

class GetHomePageStatisticRequest extends TokenRequest{

	GetHomePageStatisticRequest({
		String? token,
	}) : super(
			token: token,
		);

	factory GetHomePageStatisticRequest.fromJson(Map<String, dynamic> map) {
		return GetHomePageStatisticRequest( 
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		return map;
	}
}


