import 'dart:core';

import 'package:fis_jsonrpc/client_base.dart';
import 'package:fis_common/json_convert.dart';

import 'vitalSystemSetting.m.dart';

import 'researchEdition.m.dart';


class VitalSystemSettingService extends JsonRpcClientBase {
	VitalSystemSettingService(
		String host, {
		String serviceName = "IVitalSystemSettingService",
		Map<String, String>? headers,
		int? timeout,
	}) : super(
						host,
						serviceName,
						headers: headers,
						timeout: timeout,
				) {
		/// 注册响应实体反序列化处理器
		FJsonConvert.setDecoder((map) => SystemSettingDTO.fromJson(map));
		FJsonConvert.setDecoder((map) => PageCollection<SystemSettingDTO>.fromJson(map));
		FJsonConvert.setDecoder((map) => SyncSettingsDTO.fromJson(map));
	}

	Future<String> createSystemSettingAsync(CreateSystemSettingRequest request) async {
		var rpcRst = await call("CreateSystemSettingAsync", request);
		return rpcRst;
	}

	Future<SystemSettingDTO> getSystemSettingDetailAsync(GetSystemSettingRequest request) async {
		var rpcRst = await call("GetSystemSettingDetailAsync", request);
		var result = SystemSettingDTO.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<SystemSettingDTO> getSystemSettingDetailByKeyAsync(GetSystemSettingByKeyRequest request) async {
		var rpcRst = await call("GetSystemSettingDetailByKeyAsync", request);
		var result = SystemSettingDTO.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<PageCollection<SystemSettingDTO>> getSystemSettingPageAsync(SystemSettingPageRequest request) async {
		var rpcRst = await call("GetSystemSettingPageAsync", request);
		var result = PageCollection<SystemSettingDTO>.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<bool> removeSystemSettingAsync(RemoveSystemSettingRequest request) async {
		var rpcRst = await call("RemoveSystemSettingAsync", request);
		return rpcRst;
	}

	Future<List<SystemSettingDTO>> getSystemSettingListAsync(GetSystemSettingListRequest request) async {
		var rpcRst = await call("GetSystemSettingListAsync", request);
		var result = (rpcRst as List).map((e)=>SystemSettingDTO.fromJson(e as Map<String, dynamic>)).toList();
		return result;
	}

	Future<bool> updateSystemSettingAsync(UpdateSystemSettingRequest request) async {
		var rpcRst = await call("UpdateSystemSettingAsync", request);
		return rpcRst;
	}

	Future<SyncSettingsDTO> syncSettingAsync(SyncSettingRequest request) async {
		var rpcRst = await call("SyncSettingAsync", request);
		var result = SyncSettingsDTO.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

}

