import 'dart:core';

import 'package:fis_jsonrpc/client_base.dart';
import 'package:fis_common/json_convert.dart';

import 'vitalTeam.m.dart';

import 'researchEdition.m.dart';


class VitalTeamService extends JsonRpcClientBase {
	VitalTeamService(
		String host, {
		String serviceName = "IVitalTeamService",
		Map<String, String>? headers,
		int? timeout,
	}) : super(
						host,
						serviceName,
						headers: headers,
						timeout: timeout,
				) {
		/// 注册响应实体反序列化处理器
		FJsonConvert.setDecoder((map) => TeamDTO.fromJson(map));
		FJsonConvert.setDecoder((map) => PageCollection<TeamDTO>.fromJson(map));
	}

	Future<String> createTeamAsync(CreateTeamRequest request) async {
		var rpcRst = await call("CreateTeamAsync", request);
		return rpcRst;
	}

	Future<TeamDTO> getTeamDetailAsync(GetTeamRequest request) async {
		var rpcRst = await call("GetTeamDetailAsync", request);
		var result = TeamDTO.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<TeamDTO> getTeamDetailByKeyAsync(GetTeamByKeyRequest request) async {
		var rpcRst = await call("GetTeamDetailByKeyAsync", request);
		var result = TeamDTO.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<PageCollection<TeamDTO>> getTeamPageAsync(TeamPageRequest request) async {
		var rpcRst = await call("GetTeamPageAsync", request);
		var result = PageCollection<TeamDTO>.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<bool> removeTeamAsync(RemoveTeamRequest request) async {
		var rpcRst = await call("RemoveTeamAsync", request);
		return rpcRst;
	}

	Future<List<TeamDTO>> getTeamListAsync(GetTeamListRequest request) async {
		var rpcRst = await call("GetTeamListAsync", request);
		var result = (rpcRst as List).map((e)=>TeamDTO.fromJson(e as Map<String, dynamic>)).toList();
		return result;
	}

	Future<bool> updateTeamAsync(UpdateTeamRequest request) async {
		var rpcRst = await call("UpdateTeamAsync", request);
		return rpcRst;
	}

	Future<bool> joinTeamAsync(JoinTeamRequest request) async {
		var rpcRst = await call("JoinTeamAsync", request);
		return rpcRst;
	}

	Future<bool> quitTeamAsync(QuitTeamRequest request) async {
		var rpcRst = await call("QuitTeamAsync", request);
		return rpcRst;
	}

	Future<PageCollection<TeamDTO>> getTeamPageByOrganizationAsync(GetTeamPageByOrganizationRequest request) async {
		var rpcRst = await call("GetTeamPageByOrganizationAsync", request);
		var result = PageCollection<TeamDTO>.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<bool> setTeamPrincipalAsync(SetTeamPrincipalRequest request) async {
		var rpcRst = await call("SetTeamPrincipalAsync", request);
		return rpcRst;
	}

}

