import 'researchEdition.m.dart';
import 'notification.m.dart';

import 'package:fis_jsonrpc/utils.dart';

class CreateTeamRequest extends TokenRequest{
	String? code;
	String? teamName;
	String? description;
	String? organizationCode;
	List<String>? members;
	String? principal;

	CreateTeamRequest({
		this.code,
		this.teamName,
		this.description,
		this.organizationCode,
		this.members,
		this.principal,
		String? token,
	}) : super(
			token: token,
		);

	factory CreateTeamRequest.fromJson(Map<String, dynamic> map) {
		return CreateTeamRequest( 
			code: map['Code'],
			teamName: map['TeamName'],
			description: map['Description'],
			organizationCode: map['OrganizationCode'],
			members: map['Members']?.cast<String>().toList(),
			principal: map['Principal'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		if (teamName != null)
			map['TeamName'] = teamName;
		if (description != null)
			map['Description'] = description;
		if (organizationCode != null)
			map['OrganizationCode'] = organizationCode;
		if (members != null)
			map['Members'] = members;
		if (principal != null)
			map['Principal'] = principal;
		return map;
	}
}

class TeamDTO extends BaseDTO{
	String? code;
	String? teamName;
	String? description;
	String? organizationCode;
	List<String>? members;
	String? principal;
	String? principalName;

	TeamDTO({
		this.code,
		this.teamName,
		this.description,
		this.organizationCode,
		this.members,
		this.principal,
		this.principalName,
		bool isDelete = false,
		DateTime? createTime,
		DateTime? updateTime,
	}) : super(
			isDelete: isDelete,
			createTime: createTime,
			updateTime: updateTime,
		);

	factory TeamDTO.fromJson(Map<String, dynamic> map) {
		return TeamDTO( 
			code: map['Code'],
			teamName: map['TeamName'],
			description: map['Description'],
			organizationCode: map['OrganizationCode'],
			members: map['Members']?.cast<String>().toList(),
			principal: map['Principal'],
			principalName: map['PrincipalName'],
			isDelete: map['IsDelete'],
			createTime: map['CreateTime'] != null ? DateTime.parse(map['CreateTime']) : null,
			updateTime: map['UpdateTime'] != null ? DateTime.parse(map['UpdateTime']) : null,
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		if (teamName != null)
			map['TeamName'] = teamName;
		if (description != null)
			map['Description'] = description;
		if (organizationCode != null)
			map['OrganizationCode'] = organizationCode;
		if (members != null)
			map['Members'] = members;
		if (principal != null)
			map['Principal'] = principal;
		if (principalName != null)
			map['PrincipalName'] = principalName;
		return map;
	}
}

class GetTeamRequest extends TokenRequest{
	String? code;

	GetTeamRequest({
		this.code,
		String? token,
	}) : super(
			token: token,
		);

	factory GetTeamRequest.fromJson(Map<String, dynamic> map) {
		return GetTeamRequest( 
			code: map['Code'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		return map;
	}
}

class GetTeamByKeyRequest extends TokenRequest{
	String? key;
	String? value;

	GetTeamByKeyRequest({
		this.key,
		this.value,
		String? token,
	}) : super(
			token: token,
		);

	factory GetTeamByKeyRequest.fromJson(Map<String, dynamic> map) {
		return GetTeamByKeyRequest( 
			key: map['Key'],
			value: map['Value'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (key != null)
			map['Key'] = key;
		if (value != null)
			map['Value'] = value;
		return map;
	}
}

class TeamPageRequest extends PageRequest{
	String? keyword;
	DateTime? startTime;
	DateTime? endTime;

	TeamPageRequest({
		this.keyword,
		this.startTime,
		this.endTime,
		int pageIndex = 0,
		int pageSize = 0,
		String? token,
	}) : super(
			pageIndex: pageIndex,
			pageSize: pageSize,
			token: token,
		);

	factory TeamPageRequest.fromJson(Map<String, dynamic> map) {
		return TeamPageRequest( 
			keyword: map['Keyword'],
			startTime: map['StartTime'] != null ? DateTime.parse(map['StartTime']) : null,
			endTime: map['EndTime'] != null ? DateTime.parse(map['EndTime']) : null,
			pageIndex: map['PageIndex'],
			pageSize: map['PageSize'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (keyword != null)
			map['Keyword'] = keyword;
		if (startTime != null)
			map['StartTime'] = JsonRpcUtils.dateFormat(startTime!);
		if (endTime != null)
			map['EndTime'] = JsonRpcUtils.dateFormat(endTime!);
		return map;
	}
}

class RemoveTeamRequest extends TokenRequest{
	String? code;

	RemoveTeamRequest({
		this.code,
		String? token,
	}) : super(
			token: token,
		);

	factory RemoveTeamRequest.fromJson(Map<String, dynamic> map) {
		return RemoveTeamRequest( 
			code: map['Code'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		return map;
	}
}

class GetTeamListRequest extends TokenRequest{
	List<String>? codes;

	GetTeamListRequest({
		this.codes,
		String? token,
	}) : super(
			token: token,
		);

	factory GetTeamListRequest.fromJson(Map<String, dynamic> map) {
		return GetTeamListRequest( 
			codes: map['Codes']?.cast<String>().toList(),
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (codes != null)
			map['Codes'] = codes;
		return map;
	}
}

class UpdateTeamRequest extends TokenRequest{
	String? code;
	String? teamName;
	String? description;
	String? organizationCode;
	List<String>? members;
	String? principal;

	UpdateTeamRequest({
		this.code,
		this.teamName,
		this.description,
		this.organizationCode,
		this.members,
		this.principal,
		String? token,
	}) : super(
			token: token,
		);

	factory UpdateTeamRequest.fromJson(Map<String, dynamic> map) {
		return UpdateTeamRequest( 
			code: map['Code'],
			teamName: map['TeamName'],
			description: map['Description'],
			organizationCode: map['OrganizationCode'],
			members: map['Members']?.cast<String>().toList(),
			principal: map['Principal'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		if (teamName != null)
			map['TeamName'] = teamName;
		if (description != null)
			map['Description'] = description;
		if (organizationCode != null)
			map['OrganizationCode'] = organizationCode;
		if (members != null)
			map['Members'] = members;
		if (principal != null)
			map['Principal'] = principal;
		return map;
	}
}

class JoinTeamRequest extends TokenRequest{
	List<String>? userCodes;
	String? teamCode;

	JoinTeamRequest({
		this.userCodes,
		this.teamCode,
		String? token,
	}) : super(
			token: token,
		);

	factory JoinTeamRequest.fromJson(Map<String, dynamic> map) {
		return JoinTeamRequest( 
			userCodes: map['UserCodes']?.cast<String>().toList(),
			teamCode: map['TeamCode'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (userCodes != null)
			map['UserCodes'] = userCodes;
		if (teamCode != null)
			map['TeamCode'] = teamCode;
		return map;
	}
}

class QuitTeamRequest extends TokenRequest{
	List<String>? userCodes;
	String? teamCode;

	QuitTeamRequest({
		this.userCodes,
		this.teamCode,
		String? token,
	}) : super(
			token: token,
		);

	factory QuitTeamRequest.fromJson(Map<String, dynamic> map) {
		return QuitTeamRequest( 
			userCodes: map['UserCodes']?.cast<String>().toList(),
			teamCode: map['TeamCode'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (userCodes != null)
			map['UserCodes'] = userCodes;
		if (teamCode != null)
			map['TeamCode'] = teamCode;
		return map;
	}
}

class GetTeamPageByOrganizationRequest extends PageRequest{
	String? keyword;
	DateTime? startTime;
	DateTime? endTime;
	String? organizationCode;

	GetTeamPageByOrganizationRequest({
		this.keyword,
		this.startTime,
		this.endTime,
		this.organizationCode,
		int pageIndex = 0,
		int pageSize = 0,
		String? token,
	}) : super(
			pageIndex: pageIndex,
			pageSize: pageSize,
			token: token,
		);

	factory GetTeamPageByOrganizationRequest.fromJson(Map<String, dynamic> map) {
		return GetTeamPageByOrganizationRequest( 
			keyword: map['Keyword'],
			startTime: map['StartTime'] != null ? DateTime.parse(map['StartTime']) : null,
			endTime: map['EndTime'] != null ? DateTime.parse(map['EndTime']) : null,
			organizationCode: map['OrganizationCode'],
			pageIndex: map['PageIndex'],
			pageSize: map['PageSize'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (keyword != null)
			map['Keyword'] = keyword;
		if (startTime != null)
			map['StartTime'] = JsonRpcUtils.dateFormat(startTime!);
		if (endTime != null)
			map['EndTime'] = JsonRpcUtils.dateFormat(endTime!);
		if (organizationCode != null)
			map['OrganizationCode'] = organizationCode;
		return map;
	}
}

class SetTeamPrincipalRequest extends TokenRequest{
	String? teamCode;
	String? principal;

	SetTeamPrincipalRequest({
		this.teamCode,
		this.principal,
		String? token,
	}) : super(
			token: token,
		);

	factory SetTeamPrincipalRequest.fromJson(Map<String, dynamic> map) {
		return SetTeamPrincipalRequest( 
			teamCode: map['TeamCode'],
			principal: map['Principal'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (teamCode != null)
			map['TeamCode'] = teamCode;
		if (principal != null)
			map['Principal'] = principal;
		return map;
	}
}


