import 'researchEdition.m.dart';
import 'notification.m.dart';

import 'package:fis_jsonrpc/utils.dart';

class CreateTeamRegionRequest extends TokenRequest{
	String? code;
	String? teamCode;
	String? fullName;
	String? regionCode;

	CreateTeamRegionRequest({
		this.code,
		this.teamCode,
		this.fullName,
		this.regionCode,
		String? token,
	}) : super(
			token: token,
		);

	factory CreateTeamRegionRequest.fromJson(Map<String, dynamic> map) {
		return CreateTeamRegionRequest( 
			code: map['Code'],
			teamCode: map['TeamCode'],
			fullName: map['FullName'],
			regionCode: map['RegionCode'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		if (teamCode != null)
			map['TeamCode'] = teamCode;
		if (fullName != null)
			map['FullName'] = fullName;
		if (regionCode != null)
			map['RegionCode'] = regionCode;
		return map;
	}
}

class TeamRegionDTO extends BaseDTO{
	String? code;
	String? teamCode;
	String? fullName;
	String? regionCode;

	TeamRegionDTO({
		this.code,
		this.teamCode,
		this.fullName,
		this.regionCode,
		bool isDelete = false,
		DateTime? createTime,
		DateTime? updateTime,
	}) : super(
			isDelete: isDelete,
			createTime: createTime,
			updateTime: updateTime,
		);

	factory TeamRegionDTO.fromJson(Map<String, dynamic> map) {
		return TeamRegionDTO( 
			code: map['Code'],
			teamCode: map['TeamCode'],
			fullName: map['FullName'],
			regionCode: map['RegionCode'],
			isDelete: map['IsDelete'],
			createTime: map['CreateTime'] != null ? DateTime.parse(map['CreateTime']) : null,
			updateTime: map['UpdateTime'] != null ? DateTime.parse(map['UpdateTime']) : null,
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		if (teamCode != null)
			map['TeamCode'] = teamCode;
		if (fullName != null)
			map['FullName'] = fullName;
		if (regionCode != null)
			map['RegionCode'] = regionCode;
		return map;
	}
}

class GetTeamRegionRequest extends TokenRequest{
	String? code;

	GetTeamRegionRequest({
		this.code,
		String? token,
	}) : super(
			token: token,
		);

	factory GetTeamRegionRequest.fromJson(Map<String, dynamic> map) {
		return GetTeamRegionRequest( 
			code: map['Code'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		return map;
	}
}

class GetTeamRegionByKeyRequest extends TokenRequest{
	String? key;
	String? value;

	GetTeamRegionByKeyRequest({
		this.key,
		this.value,
		String? token,
	}) : super(
			token: token,
		);

	factory GetTeamRegionByKeyRequest.fromJson(Map<String, dynamic> map) {
		return GetTeamRegionByKeyRequest( 
			key: map['Key'],
			value: map['Value'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (key != null)
			map['Key'] = key;
		if (value != null)
			map['Value'] = value;
		return map;
	}
}

class TeamRegionPageRequest extends PageRequest{
	String? keyword;
	DateTime? startTime;
	DateTime? endTime;

	TeamRegionPageRequest({
		this.keyword,
		this.startTime,
		this.endTime,
		int pageIndex = 0,
		int pageSize = 0,
		String? token,
	}) : super(
			pageIndex: pageIndex,
			pageSize: pageSize,
			token: token,
		);

	factory TeamRegionPageRequest.fromJson(Map<String, dynamic> map) {
		return TeamRegionPageRequest( 
			keyword: map['Keyword'],
			startTime: map['StartTime'] != null ? DateTime.parse(map['StartTime']) : null,
			endTime: map['EndTime'] != null ? DateTime.parse(map['EndTime']) : null,
			pageIndex: map['PageIndex'],
			pageSize: map['PageSize'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (keyword != null)
			map['Keyword'] = keyword;
		if (startTime != null)
			map['StartTime'] = JsonRpcUtils.dateFormat(startTime!);
		if (endTime != null)
			map['EndTime'] = JsonRpcUtils.dateFormat(endTime!);
		return map;
	}
}

class RemoveTeamRegionRequest extends TokenRequest{
	String? code;

	RemoveTeamRegionRequest({
		this.code,
		String? token,
	}) : super(
			token: token,
		);

	factory RemoveTeamRegionRequest.fromJson(Map<String, dynamic> map) {
		return RemoveTeamRegionRequest( 
			code: map['Code'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		return map;
	}
}

class GetTeamRegionListRequest extends TokenRequest{
	List<String>? codes;

	GetTeamRegionListRequest({
		this.codes,
		String? token,
	}) : super(
			token: token,
		);

	factory GetTeamRegionListRequest.fromJson(Map<String, dynamic> map) {
		return GetTeamRegionListRequest( 
			codes: map['Codes']?.cast<String>().toList(),
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (codes != null)
			map['Codes'] = codes;
		return map;
	}
}

class UpdateTeamRegionRequest extends TokenRequest{
	String? code;
	String? teamCode;
	String? fullName;
	String? regionCode;

	UpdateTeamRegionRequest({
		this.code,
		this.teamCode,
		this.fullName,
		this.regionCode,
		String? token,
	}) : super(
			token: token,
		);

	factory UpdateTeamRegionRequest.fromJson(Map<String, dynamic> map) {
		return UpdateTeamRegionRequest( 
			code: map['Code'],
			teamCode: map['TeamCode'],
			fullName: map['FullName'],
			regionCode: map['RegionCode'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		if (teamCode != null)
			map['TeamCode'] = teamCode;
		if (fullName != null)
			map['FullName'] = fullName;
		if (regionCode != null)
			map['RegionCode'] = regionCode;
		return map;
	}
}


