import 'dart:core';

import 'package:fis_jsonrpc/client_base.dart';
import 'package:fis_common/json_convert.dart';

import 'vitalTown.m.dart';

import 'researchEdition.m.dart';


class VitalTownService extends JsonRpcClientBase {
	VitalTownService(
		String host, {
		String serviceName = "IVitalTownService",
		Map<String, String>? headers,
		int? timeout,
	}) : super(
						host,
						serviceName,
						headers: headers,
						timeout: timeout,
				) {
		/// 注册响应实体反序列化处理器
		FJsonConvert.setDecoder((map) => TownDTO.fromJson(map));
		FJsonConvert.setDecoder((map) => PageCollection<TownDTO>.fromJson(map));
	}

	Future<String> createTownAsync(CreateTownRequest request) async {
		var rpcRst = await call("CreateTownAsync", request);
		return rpcRst;
	}

	Future<TownDTO> getTownDetailAsync(GetTownRequest request) async {
		var rpcRst = await call("GetTownDetailAsync", request);
		var result = TownDTO.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<TownDTO> getTownDetailByKeyAsync(GetTownByKeyRequest request) async {
		var rpcRst = await call("GetTownDetailByKeyAsync", request);
		var result = TownDTO.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<PageCollection<TownDTO>> getTownPageAsync(TownPageRequest request) async {
		var rpcRst = await call("GetTownPageAsync", request);
		var result = PageCollection<TownDTO>.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<bool> removeTownAsync(RemoveTownRequest request) async {
		var rpcRst = await call("RemoveTownAsync", request);
		return rpcRst;
	}

	Future<List<TownDTO>> getTownListAsync(GetTownListRequest request) async {
		var rpcRst = await call("GetTownListAsync", request);
		var result = (rpcRst as List).map((e)=>TownDTO.fromJson(e as Map<String, dynamic>)).toList();
		return result;
	}

	Future<bool> updateTownAsync(UpdateTownRequest request) async {
		var rpcRst = await call("UpdateTownAsync", request);
		return rpcRst;
	}

	Future<PageCollection<TownDTO>> getTownPageByDistrictAsync(GetTownPageByDistrictRequest request) async {
		var rpcRst = await call("GetTownPageByDistrictAsync", request);
		var result = PageCollection<TownDTO>.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

}

