import 'dart:core';

import 'package:fis_jsonrpc/client_base.dart';
import 'package:fis_common/json_convert.dart';

import 'vitalUpgrade.m.dart';

import 'researchEdition.m.dart';


class VitalUpgradeService extends JsonRpcClientBase {
	VitalUpgradeService(
		String host, {
		String serviceName = "IVitalUpgradeService",
		Map<String, String>? headers,
		int? timeout,
	}) : super(
						host,
						serviceName,
						headers: headers,
						timeout: timeout,
				) {
		/// 注册响应实体反序列化处理器
		FJsonConvert.setDecoder((map) => UpgradeDTO.fromJson(map));
		FJsonConvert.setDecoder((map) => PageCollection<UpgradeDTO>.fromJson(map));
		FJsonConvert.setDecoder((map) => VitalResourceInfoDTO.fromJson(map));
	}

	Future<String> createUpgradeAsync(CreateUpgradeRequest request) async {
		var rpcRst = await call("CreateUpgradeAsync", request);
		return rpcRst;
	}

	Future<UpgradeDTO> getUpgradeDetailAsync(GetUpgradeRequest request) async {
		var rpcRst = await call("GetUpgradeDetailAsync", request);
		var result = UpgradeDTO.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<PageCollection<UpgradeDTO>> getUpgradePageAsync(UpgradePageRequest request) async {
		var rpcRst = await call("GetUpgradePageAsync", request);
		var result = PageCollection<UpgradeDTO>.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<UpgradeDTO> getLastUpgradeAsync(GetLastUpgradeRequest request) async {
		var rpcRst = await call("GetLastUpgradeAsync", request);
		var result = UpgradeDTO.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<VitalResourceInfoDTO> getResourceInfoByVersionAsync(GetResourceInfoByVersionRequest request) async {
		var rpcRst = await call("GetResourceInfoByVersionAsync", request);
		var result = VitalResourceInfoDTO.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

}

