import 'researchEdition.m.dart';
import 'notification.m.dart';

import 'package:fis_jsonrpc/utils.dart';

class CreateUpgradeRequest extends TokenRequest{
	String? code;
	String? version;
	String? upgradeNotes;
	String? upgradeFileUrl;
	List<String>? applicableEquipment;
	bool isGatedLaunch;

	CreateUpgradeRequest({
		this.code,
		this.version,
		this.upgradeNotes,
		this.upgradeFileUrl,
		this.applicableEquipment,
		this.isGatedLaunch = false,
		String? token,
	}) : super(
			token: token,
		);

	factory CreateUpgradeRequest.fromJson(Map<String, dynamic> map) {
		return CreateUpgradeRequest( 
			code: map['Code'],
			version: map['Version'],
			upgradeNotes: map['UpgradeNotes'],
			upgradeFileUrl: map['UpgradeFileUrl'],
			applicableEquipment: map['ApplicableEquipment']?.cast<String>().toList(),
			isGatedLaunch: map['IsGatedLaunch'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		if (version != null)
			map['Version'] = version;
		if (upgradeNotes != null)
			map['UpgradeNotes'] = upgradeNotes;
		if (upgradeFileUrl != null)
			map['UpgradeFileUrl'] = upgradeFileUrl;
		if (applicableEquipment != null)
			map['ApplicableEquipment'] = applicableEquipment;
		map['IsGatedLaunch'] = isGatedLaunch;
		return map;
	}
}

class UpgradeDTO extends BaseDTO{
	String? code;
	bool isNeedUpdate;
	String? version;
	String? upgradeNotes;
	String? upgradeFileUrl;
	List<String>? applicableEquipment;
	bool isGatedLaunch;
	bool isCoerce;

	UpgradeDTO({
		this.code,
		this.isNeedUpdate = false,
		this.version,
		this.upgradeNotes,
		this.upgradeFileUrl,
		this.applicableEquipment,
		this.isGatedLaunch = false,
		this.isCoerce = false,
		bool isDelete = false,
		DateTime? createTime,
		DateTime? updateTime,
	}) : super(
			isDelete: isDelete,
			createTime: createTime,
			updateTime: updateTime,
		);

	factory UpgradeDTO.fromJson(Map<String, dynamic> map) {
		return UpgradeDTO( 
			code: map['Code'],
			isNeedUpdate: map['IsNeedUpdate'],
			version: map['Version'],
			upgradeNotes: map['UpgradeNotes'],
			upgradeFileUrl: map['UpgradeFileUrl'],
			applicableEquipment: map['ApplicableEquipment']?.cast<String>().toList(),
			isGatedLaunch: map['IsGatedLaunch'],
			isCoerce: map['IsCoerce'],
			isDelete: map['IsDelete'],
			createTime: map['CreateTime'] != null ? DateTime.parse(map['CreateTime']) : null,
			updateTime: map['UpdateTime'] != null ? DateTime.parse(map['UpdateTime']) : null,
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		map['IsNeedUpdate'] = isNeedUpdate;
		if (version != null)
			map['Version'] = version;
		if (upgradeNotes != null)
			map['UpgradeNotes'] = upgradeNotes;
		if (upgradeFileUrl != null)
			map['UpgradeFileUrl'] = upgradeFileUrl;
		if (applicableEquipment != null)
			map['ApplicableEquipment'] = applicableEquipment;
		map['IsGatedLaunch'] = isGatedLaunch;
		map['IsCoerce'] = isCoerce;
		return map;
	}
}

class GetUpgradeRequest extends TokenRequest{
	String? code;

	GetUpgradeRequest({
		this.code,
		String? token,
	}) : super(
			token: token,
		);

	factory GetUpgradeRequest.fromJson(Map<String, dynamic> map) {
		return GetUpgradeRequest( 
			code: map['Code'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		return map;
	}
}

class UpgradePageRequest extends PageRequest{
	String? keyword;
	DateTime? startTime;
	DateTime? endTime;

	UpgradePageRequest({
		this.keyword,
		this.startTime,
		this.endTime,
		int pageIndex = 0,
		int pageSize = 0,
		String? token,
	}) : super(
			pageIndex: pageIndex,
			pageSize: pageSize,
			token: token,
		);

	factory UpgradePageRequest.fromJson(Map<String, dynamic> map) {
		return UpgradePageRequest( 
			keyword: map['Keyword'],
			startTime: map['StartTime'] != null ? DateTime.parse(map['StartTime']) : null,
			endTime: map['EndTime'] != null ? DateTime.parse(map['EndTime']) : null,
			pageIndex: map['PageIndex'],
			pageSize: map['PageSize'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (keyword != null)
			map['Keyword'] = keyword;
		if (startTime != null)
			map['StartTime'] = JsonRpcUtils.dateFormat(startTime!);
		if (endTime != null)
			map['EndTime'] = JsonRpcUtils.dateFormat(endTime!);
		return map;
	}
}

class GetLastUpgradeRequest extends TokenRequest{
	String? clientVersion;
	String? deviceSerialNumber;

	GetLastUpgradeRequest({
		this.clientVersion,
		this.deviceSerialNumber,
		String? token,
	}) : super(
			token: token,
		);

	factory GetLastUpgradeRequest.fromJson(Map<String, dynamic> map) {
		return GetLastUpgradeRequest( 
			clientVersion: map['ClientVersion'],
			deviceSerialNumber: map['DeviceSerialNumber'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (clientVersion != null)
			map['ClientVersion'] = clientVersion;
		if (deviceSerialNumber != null)
			map['DeviceSerialNumber'] = deviceSerialNumber;
		return map;
	}
}

class VitalResourceInfoDTO {
	String? resourceKey;
	String? version;
	String? content;

	VitalResourceInfoDTO({
		this.resourceKey,
		this.version,
		this.content,
	});

	factory VitalResourceInfoDTO.fromJson(Map<String, dynamic> map) {
		return VitalResourceInfoDTO( 
			resourceKey: map['ResourceKey'],
			version: map['Version'],
			content: map['Content'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		if (resourceKey != null)
			map['ResourceKey'] = resourceKey;
		if (version != null)
			map['Version'] = version;
		if (content != null)
			map['Content'] = content;
		return map;
	}
}

class GetResourceInfoByVersionRequest extends TokenRequest{
	String? version;
	String? resourceKey;

	GetResourceInfoByVersionRequest({
		this.version,
		this.resourceKey,
		String? token,
	}) : super(
			token: token,
		);

	factory GetResourceInfoByVersionRequest.fromJson(Map<String, dynamic> map) {
		return GetResourceInfoByVersionRequest( 
			version: map['Version'],
			resourceKey: map['ResourceKey'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (version != null)
			map['Version'] = version;
		if (resourceKey != null)
			map['ResourceKey'] = resourceKey;
		return map;
	}
}


