import 'dart:core';

import 'package:fis_jsonrpc/client_base.dart';
import 'package:fis_common/json_convert.dart';

import 'vitalUserFeature.m.dart';

import 'researchEdition.m.dart';


class VitalUserFeatureService extends JsonRpcClientBase {
	VitalUserFeatureService(
		String host, {
		String serviceName = "IVitalUserFeatureService",
		Map<String, String>? headers,
		int? timeout,
	}) : super(
						host,
						serviceName,
						headers: headers,
						timeout: timeout,
				) {
		/// 注册响应实体反序列化处理器
		FJsonConvert.setDecoder((map) => UserFeatureDTO.fromJson(map));
		FJsonConvert.setDecoder((map) => PageCollection<UserFeatureDTO>.fromJson(map));
	}

	Future<String> createUserFeatureAsync(CreateUserFeatureRequest request) async {
		var rpcRst = await call("CreateUserFeatureAsync", request);
		return rpcRst;
	}

	Future<UserFeatureDTO> getUserFeatureDetailAsync(GetUserFeatureRequest request) async {
		var rpcRst = await call("GetUserFeatureDetailAsync", request);
		var result = UserFeatureDTO.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<UserFeatureDTO> getUserFeatureDetailByKeyAsync(GetUserFeatureByKeyRequest request) async {
		var rpcRst = await call("GetUserFeatureDetailByKeyAsync", request);
		var result = UserFeatureDTO.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<PageCollection<UserFeatureDTO>> getUserFeaturePageAsync(UserFeaturePageRequest request) async {
		var rpcRst = await call("GetUserFeaturePageAsync", request);
		var result = PageCollection<UserFeatureDTO>.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<bool> removeUserFeatureAsync(RemoveUserFeatureRequest request) async {
		var rpcRst = await call("RemoveUserFeatureAsync", request);
		return rpcRst;
	}

	Future<List<UserFeatureDTO>> getUserFeatureListAsync(GetUserFeatureListRequest request) async {
		var rpcRst = await call("GetUserFeatureListAsync", request);
		var result = (rpcRst as List).map((e)=>UserFeatureDTO.fromJson(e as Map<String, dynamic>)).toList();
		return result;
	}

	Future<bool> updateUserFeatureAsync(UpdateUserFeatureRequest request) async {
		var rpcRst = await call("UpdateUserFeatureAsync", request);
		return rpcRst;
	}

}

