import 'researchEdition.m.dart';
import 'notification.m.dart';

import 'package:fis_jsonrpc/utils.dart';

enum ApplicationTypeEnum {
	Web,
	App,
}

enum FeatureTypeEnum {
	Menu,
	Operation,
}

class CreateUserFeatureRequest extends TokenRequest{
	String? code;
	String? featureName;
	String? featureShowName;
	String? description;
	String? fatherCode;
	int sort;
	ApplicationTypeEnum appType;
	FeatureTypeEnum featureType;

	CreateUserFeatureRequest({
		this.code,
		this.featureName,
		this.featureShowName,
		this.description,
		this.fatherCode,
		this.sort = 0,
		this.appType = ApplicationTypeEnum.Web,
		this.featureType = FeatureTypeEnum.Menu,
		String? token,
	}) : super(
			token: token,
		);

	factory CreateUserFeatureRequest.fromJson(Map<String, dynamic> map) {
		return CreateUserFeatureRequest( 
			code: map['Code'],
			featureName: map['FeatureName'],
			featureShowName: map['FeatureShowName'],
			description: map['Description'],
			fatherCode: map['FatherCode'],
			sort: map['Sort'],
			appType: ApplicationTypeEnum.values.firstWhere((e) => e.index == map['AppType']),
			featureType: FeatureTypeEnum.values.firstWhere((e) => e.index == map['FeatureType']),
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		if (featureName != null)
			map['FeatureName'] = featureName;
		if (featureShowName != null)
			map['FeatureShowName'] = featureShowName;
		if (description != null)
			map['Description'] = description;
		if (fatherCode != null)
			map['FatherCode'] = fatherCode;
		map['Sort'] = sort;
		map['AppType'] = appType.index;
		map['FeatureType'] = featureType.index;
		return map;
	}
}

class UserFeatureDTO extends BaseDTO{
	String? code;
	String? featureName;
	String? featureShowName;
	String? description;
	String? fatherCode;
	int sort;
	ApplicationTypeEnum appType;
	FeatureTypeEnum featureType;

	UserFeatureDTO({
		this.code,
		this.featureName,
		this.featureShowName,
		this.description,
		this.fatherCode,
		this.sort = 0,
		this.appType = ApplicationTypeEnum.Web,
		this.featureType = FeatureTypeEnum.Menu,
		bool isDelete = false,
		DateTime? createTime,
		DateTime? updateTime,
	}) : super(
			isDelete: isDelete,
			createTime: createTime,
			updateTime: updateTime,
		);

	factory UserFeatureDTO.fromJson(Map<String, dynamic> map) {
		return UserFeatureDTO( 
			code: map['Code'],
			featureName: map['FeatureName'],
			featureShowName: map['FeatureShowName'],
			description: map['Description'],
			fatherCode: map['FatherCode'],
			sort: map['Sort'],
			appType: ApplicationTypeEnum.values.firstWhere((e) => e.index == map['AppType']),
			featureType: FeatureTypeEnum.values.firstWhere((e) => e.index == map['FeatureType']),
			isDelete: map['IsDelete'],
			createTime: map['CreateTime'] != null ? DateTime.parse(map['CreateTime']) : null,
			updateTime: map['UpdateTime'] != null ? DateTime.parse(map['UpdateTime']) : null,
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		if (featureName != null)
			map['FeatureName'] = featureName;
		if (featureShowName != null)
			map['FeatureShowName'] = featureShowName;
		if (description != null)
			map['Description'] = description;
		if (fatherCode != null)
			map['FatherCode'] = fatherCode;
		map['Sort'] = sort;
		map['AppType'] = appType.index;
		map['FeatureType'] = featureType.index;
		return map;
	}
}

class GetUserFeatureRequest extends TokenRequest{
	String? code;

	GetUserFeatureRequest({
		this.code,
		String? token,
	}) : super(
			token: token,
		);

	factory GetUserFeatureRequest.fromJson(Map<String, dynamic> map) {
		return GetUserFeatureRequest( 
			code: map['Code'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		return map;
	}
}

class GetUserFeatureByKeyRequest extends TokenRequest{
	String? key;
	String? value;

	GetUserFeatureByKeyRequest({
		this.key,
		this.value,
		String? token,
	}) : super(
			token: token,
		);

	factory GetUserFeatureByKeyRequest.fromJson(Map<String, dynamic> map) {
		return GetUserFeatureByKeyRequest( 
			key: map['Key'],
			value: map['Value'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (key != null)
			map['Key'] = key;
		if (value != null)
			map['Value'] = value;
		return map;
	}
}

class UserFeaturePageRequest extends PageRequest{
	String? keyword;
	DateTime? startTime;
	DateTime? endTime;

	UserFeaturePageRequest({
		this.keyword,
		this.startTime,
		this.endTime,
		int pageIndex = 0,
		int pageSize = 0,
		String? token,
	}) : super(
			pageIndex: pageIndex,
			pageSize: pageSize,
			token: token,
		);

	factory UserFeaturePageRequest.fromJson(Map<String, dynamic> map) {
		return UserFeaturePageRequest( 
			keyword: map['Keyword'],
			startTime: map['StartTime'] != null ? DateTime.parse(map['StartTime']) : null,
			endTime: map['EndTime'] != null ? DateTime.parse(map['EndTime']) : null,
			pageIndex: map['PageIndex'],
			pageSize: map['PageSize'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (keyword != null)
			map['Keyword'] = keyword;
		if (startTime != null)
			map['StartTime'] = JsonRpcUtils.dateFormat(startTime!);
		if (endTime != null)
			map['EndTime'] = JsonRpcUtils.dateFormat(endTime!);
		return map;
	}
}

class RemoveUserFeatureRequest extends TokenRequest{
	String? code;

	RemoveUserFeatureRequest({
		this.code,
		String? token,
	}) : super(
			token: token,
		);

	factory RemoveUserFeatureRequest.fromJson(Map<String, dynamic> map) {
		return RemoveUserFeatureRequest( 
			code: map['Code'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		return map;
	}
}

class GetUserFeatureListRequest extends TokenRequest{
	List<String>? codes;

	GetUserFeatureListRequest({
		this.codes,
		String? token,
	}) : super(
			token: token,
		);

	factory GetUserFeatureListRequest.fromJson(Map<String, dynamic> map) {
		return GetUserFeatureListRequest( 
			codes: map['Codes']?.cast<String>().toList(),
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (codes != null)
			map['Codes'] = codes;
		return map;
	}
}

class UpdateUserFeatureRequest extends TokenRequest{
	String? code;
	String? featureName;
	String? featureShowName;
	String? description;
	String? fatherCode;
	int sort;
	ApplicationTypeEnum appType;
	FeatureTypeEnum featureType;

	UpdateUserFeatureRequest({
		this.code,
		this.featureName,
		this.featureShowName,
		this.description,
		this.fatherCode,
		this.sort = 0,
		this.appType = ApplicationTypeEnum.Web,
		this.featureType = FeatureTypeEnum.Menu,
		String? token,
	}) : super(
			token: token,
		);

	factory UpdateUserFeatureRequest.fromJson(Map<String, dynamic> map) {
		return UpdateUserFeatureRequest( 
			code: map['Code'],
			featureName: map['FeatureName'],
			featureShowName: map['FeatureShowName'],
			description: map['Description'],
			fatherCode: map['FatherCode'],
			sort: map['Sort'],
			appType: ApplicationTypeEnum.values.firstWhere((e) => e.index == map['AppType']),
			featureType: FeatureTypeEnum.values.firstWhere((e) => e.index == map['FeatureType']),
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		if (featureName != null)
			map['FeatureName'] = featureName;
		if (featureShowName != null)
			map['FeatureShowName'] = featureShowName;
		if (description != null)
			map['Description'] = description;
		if (fatherCode != null)
			map['FatherCode'] = fatherCode;
		map['Sort'] = sort;
		map['AppType'] = appType.index;
		map['FeatureType'] = featureType.index;
		return map;
	}
}


