import 'researchEdition.m.dart';
import 'notification.m.dart';

class CreateUserPasswordRequest extends TokenRequest{
	String? secretPassword;

	CreateUserPasswordRequest({
		this.secretPassword,
		String? token,
	}) : super(
			token: token,
		);

	factory CreateUserPasswordRequest.fromJson(Map<String, dynamic> map) {
		return CreateUserPasswordRequest( 
			secretPassword: map['SecretPassword'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (secretPassword != null)
			map['SecretPassword'] = secretPassword;
		return map;
	}
}

class UserPasswordDTO extends BaseDTO{
	String? code;
	String? secretPassword;

	UserPasswordDTO({
		this.code,
		this.secretPassword,
		bool isDelete = false,
		DateTime? createTime,
		DateTime? updateTime,
	}) : super(
			isDelete: isDelete,
			createTime: createTime,
			updateTime: updateTime,
		);

	factory UserPasswordDTO.fromJson(Map<String, dynamic> map) {
		return UserPasswordDTO( 
			code: map['Code'],
			secretPassword: map['SecretPassword'],
			isDelete: map['IsDelete'],
			createTime: map['CreateTime'] != null ? DateTime.parse(map['CreateTime']) : null,
			updateTime: map['UpdateTime'] != null ? DateTime.parse(map['UpdateTime']) : null,
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		if (secretPassword != null)
			map['SecretPassword'] = secretPassword;
		return map;
	}
}

class GetUserPasswordRequest extends TokenRequest{
	String? code;

	GetUserPasswordRequest({
		this.code,
		String? token,
	}) : super(
			token: token,
		);

	factory GetUserPasswordRequest.fromJson(Map<String, dynamic> map) {
		return GetUserPasswordRequest( 
			code: map['Code'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		return map;
	}
}

class UpdateUserPasswordRequest extends TokenRequest{
	String? code;
	String? secretPassword;

	UpdateUserPasswordRequest({
		this.code,
		this.secretPassword,
		String? token,
	}) : super(
			token: token,
		);

	factory UpdateUserPasswordRequest.fromJson(Map<String, dynamic> map) {
		return UpdateUserPasswordRequest( 
			code: map['Code'],
			secretPassword: map['SecretPassword'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		if (secretPassword != null)
			map['SecretPassword'] = secretPassword;
		return map;
	}
}


